(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    290982,       7560]*)
(*NotebookOutlinePosition[    330321,       8880]*)
(*  CellTagsIndexPosition[    330277,       8876]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Approximations symboliques", "Subtitle",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["R\[EAcute]mi Barr\[EGrave]re\n",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox["rbarrere@ens2m.fr",
    FontSize->10,
    FontSlant->"Plain",
    FontVariations->{"CompatibilityType"->0}]
}], "Subsubtitle",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Le calcul formel coupl\[EAcute] \[AGrave] la programmation \
symbolique ouvre la porte aux m\[EAcute]thodes analytiques \
approch\[EAcute]es, parfois plus int\[EAcute]ressantes que les techniques \
purement num\[EAcute]riques. Les approximations symboliques d\[EAcute]rivent \
du m\[EHat]me cadre fonctionnel qui justifie les m\[EAcute]thodes \
num\[EAcute]riques. Nous pr\[EAcute]sentons ici trois m\[EAcute]thodes, comme \
autant de pistes \[AGrave] suivre pour des recherches \[AGrave] venir.\
\>", \
"SmallText",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell["\<\
Le d\[EAcute]veloppement des techniques num\[EAcute]riques et \
\[AGrave] certains \[EAcute]gards du calcul formel a contribu\[EAcute] \
\[AGrave] nous faire perdre de vue les bonnes vieilles m\[EAcute]thodes de \
calcul analytique approch\[EAcute]. Pourtant, gr\[AHat]ce \[AGrave] leurs \
param\[EGrave]tres symboliques, les expressions litt\[EAcute]rales \
pr\[EAcute]sentent en mod\[EAcute]lisation l\[CloseCurlyQuote]avantage de \
fournir des repr\[EAcute]sentations plus p\[EAcute]n\[EAcute]trantes des syst\
\[EGrave]mes ou des processus physiques sous-jacents\[NonBreakingSpace]; \
elles conduisent \[AGrave] des descriptions g\[EAcute]n\[EAcute]riques de \
familles de solutions. Du reste, une expression symbolique avec des param\
\[EGrave]tres contient des informations plus pratiques que des \
donn\[EAcute]es num\[EAcute]riques\[NonBreakingSpace]: il n'y a pas de \
calculs \[AGrave] r\[EAcute]it\[EAcute]rer pour analyser l'influence des \
param\[EGrave]tres ou calculer des sensibilit\[EAcute]s. Enfin, les \
manipulations symboliques facilitent l'encha\[IHat]nement des calculs. \
\>", \
"Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell["\<\
C\[CloseCurlyQuote]est pourquoi, on pr\[EAcute]f\[EGrave]rera bien \
souvent des expressions litt\[EAcute]rales, m\[EHat]me sommairement approch\
\[EAcute]es, \[AGrave] des r\[EAcute]sultats purement num\[EAcute]riques plus \
pr\[EAcute]cis. Par ailleurs, il arrive que les solutions exactes aient une \
complexit\[EAcute] telle qu\[CloseCurlyQuote]elles s\[CloseCurlyQuote]av\
\[EGrave]rent peu utiles en tant que telles ; dans ces cas, on peut envisager \
l\[CloseCurlyQuote]approximation comme moyen de simplification.Tentante et \
gratifiante intellectuellement, la qu\[EHat]te de solutions exactes n'est pas \
forc\[EAcute]ment justifi\[EAcute]e dans la mesure o\[UGrave] les \
\[EAcute]quations \[AGrave] r\[EAcute]soudre d\[EAcute]coulent de \
mod\[EGrave]les qui sont d\[EAcute]j\[AGrave] des simplifications de la r\
\[EAcute]alit\[EAcute]\[NonBreakingSpace]; de m\[EHat]me que l'on travaille \
plus couramment avec des d\[EAcute]cimaux qu'avec des rationnels ou des \
radicaux, il est souvent plus naturel de chercher des approximations que des \
solutions exactes. \
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell["\<\
En fait, plusieurs techniques num\[EAcute]riques fondamentales se \
justifient dans un cadre fonctionnel fonci\[EGrave]rement symbolique\
\[NonBreakingSpace]; c'est le cas des approximations successives (espaces m\
\[EAcute]triques), de la m\[EAcute]thode de Newton (espaces de Banach) ou \
encore du proc\[EAcute]d\[EAcute] de Galerkin (espaces de Hilbert) dont la m\
\[EAcute]thode des \[EAcute]l\[EAcute]ments finis n'est qu'un cas \
particulier. C'est aussi le cas de la m\[EAcute]thode de perturbation \
(espaces de Banach), mais nous ne l'aborderons pas ici. \
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["M\[EAcute]thode des approximations successives", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[TextData[{
  "Lorsqu'une \[EAcute]quation s'exprime comme une recherche de point fixe ",
  StyleBox["f[x]==x", "InlineOutput"],
  " et \[AGrave] condition que f soit contractante, sa solution s'exprime \
comme la limite\[NonBreakingSpace]:"
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_\[Infinity]\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(n -> \[Infinity]\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f\^on\)]],
  "[x]"
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1],

Cell[TextData[{
  "De plus, sous r\[EAcute]serve que l'approximation initiale ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " se trouve dans le domaine de contraction de f, tout it\[EAcute]r\[EAcute] \
",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`f\^on\)]],
  "[",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  "]  est une approximation du point fixe ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\[Infinity]\)]],
  "\[NonBreakingSpace]; ces approximants sont parfois appel\[EAcute]s \
fonctions it\[EAcute]r\[EAcute]es. Du fait qu'elle est valable en espace m\
\[EAcute]trique, la m\[EAcute]thode s'applique \[AGrave] des \
\[EAcute]quations fonctionnelles ordinaires ou op\[EAcute]ratorielles et \
aussi \[AGrave] des constructions g\[EAcute]om\[EAcute]triques (fractales). \
L'it\[EAcute]ration s'exprime en Mathematica avec l'op\[EAcute]rateur ",
  StyleBox["Nest", "InlineOutput"],
  "."
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[TextData[{
  "Un premier exemple concerne l'\[EAcute]quation fonctionnelle:\n\t\t\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(-\(\(a\ x\)\/\(a + 1\)\)\) == 
        x\ \((a \[GreaterEqual] 0)\)\)]],
  "\n x et a sont respectivement l'inconnue et un param\[EGrave]tre \
symbolique (positif), de sorte que la solution d\[EAcute]pend de a. Nous \
allons calculer une approximation num\[EAcute]rique (m\[EAcute]thode de \
Newton) et les premiers approximants calcul\[EAcute]s \[AGrave] partir de \
l'approximation initiale ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u\_0\)], "Informal"], "Informal"],
  StyleBox["[a]=1", "Informal"],
  ". Le graphique visualise les ",
  Cell[BoxData[
      \(TraditionalForm\`3\^e\)]],
  " et ",
  Cell[BoxData[
      \(TraditionalForm\`4\^e\)]],
  " approximants."
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[BoxData[
    \(\(g0 = 
        ListPlot[\[IndentingNewLine]Table[{a, 
              x /. \[InvisibleSpace]FindRoot[
                  Exp[\(-a\)\ x/\((1 + a)\)] == x, {x, 0}]}, {a, 0, 15, 1}], 
          PlotStyle \[Rule] {PointSize[0.02]}, PlotRange \[Rule] {0.4, 1}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell["NestList[Exp[-a #/(1+a)]&, 1, 2]", "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \({1, \[ExponentialE]\^\(-\(a\/\(1 + a\)\)\), \[ExponentialE]\^\(-\(\(a\ \
\[ExponentialE]\^\(-\(a\/\(1 + a\)\)\)\)\/\(1 + a\)\)\)}\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[BoxData[
    \(\(g1 = 
        Plot[\[IndentingNewLine]Evaluate[{Drop[
                NestList[Exp[\(-a\)\ #/\((1 + a)\)] &, 1, 4], 3]}], {a, 0, 
            15}, PlotRange \[Rule] {0.5, 1}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[g0, g1, DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",\

  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 -0.412023 1.03006 [
[.15079 .60553 -3 -9 ]
[.15079 .60553 3 0 ]
[.27778 .60553 -3 -9 ]
[.27778 .60553 3 0 ]
[.40476 .60553 -3 -9 ]
[.40476 .60553 3 0 ]
[.53175 .60553 -3 -9 ]
[.53175 .60553 3 0 ]
[.65873 .60553 -6 -9 ]
[.65873 .60553 6 0 ]
[.78571 .60553 -6 -9 ]
[.78571 .60553 6 0 ]
[.9127 .60553 -6 -9 ]
[.9127 .60553 6 0 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -18 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .62428 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .61803 m
.15079 .62428 L
s
[(2)] .15079 .60553 0 1 Mshowa
.27778 .61803 m
.27778 .62428 L
s
[(4)] .27778 .60553 0 1 Mshowa
.40476 .61803 m
.40476 .62428 L
s
[(6)] .40476 .60553 0 1 Mshowa
.53175 .61803 m
.53175 .62428 L
s
[(8)] .53175 .60553 0 1 Mshowa
.65873 .61803 m
.65873 .62428 L
s
[(10)] .65873 .60553 0 1 Mshowa
.78571 .61803 m
.78571 .62428 L
s
[(12)] .78571 .60553 0 1 Mshowa
.9127 .61803 m
.9127 .62428 L
s
[(14)] .9127 .60553 0 1 Mshowa
.125 Mabswid
.05556 .61803 m
.05556 .62178 L
s
.0873 .61803 m
.0873 .62178 L
s
.11905 .61803 m
.11905 .62178 L
s
.18254 .61803 m
.18254 .62178 L
s
.21429 .61803 m
.21429 .62178 L
s
.24603 .61803 m
.24603 .62178 L
s
.30952 .61803 m
.30952 .62178 L
s
.34127 .61803 m
.34127 .62178 L
s
.37302 .61803 m
.37302 .62178 L
s
.43651 .61803 m
.43651 .62178 L
s
.46825 .61803 m
.46825 .62178 L
s
.5 .61803 m
.5 .62178 L
s
.56349 .61803 m
.56349 .62178 L
s
.59524 .61803 m
.59524 .62178 L
s
.62698 .61803 m
.62698 .62178 L
s
.69048 .61803 m
.69048 .62178 L
s
.72222 .61803 m
.72222 .62178 L
s
.75397 .61803 m
.75397 .62178 L
s
.81746 .61803 m
.81746 .62178 L
s
.84921 .61803 m
.84921 .62178 L
s
.88095 .61803 m
.88095 .62178 L
s
.94444 .61803 m
.94444 .62178 L
s
.97619 .61803 m
.97619 .62178 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.02381 0 m
.03006 0 L
s
[(0.4)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(0.6)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.7)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(0.8)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(0.9)] .01131 .51503 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .61803 Mdot
.0873 .31259 Mdot
.15079 .25632 Mdot
.21429 .23231 Mdot
.27778 .21897 Mdot
.34127 .21048 Mdot
.40476 .2046 Mdot
.46825 .20028 Mdot
.53175 .19698 Mdot
.59524 .19438 Mdot
.65873 .19226 Mdot
.72222 .19052 Mdot
.78571 .18905 Mdot
.84921 .1878 Mdot
.9127 .18673 Mdot
.97619 .18579 Mdot
.5 Mabswid
.02381 .61803 m
.02846 .55419 L
.03279 .50979 L
.03754 .47174 L
.04262 .43934 L
.053 .38997 L
.06244 .35724 L
.07283 .32948 L
.0841 .30583 L
.10458 .27389 L
.12442 .25148 L
.14545 .23345 L
.18328 .21017 L
.20269 .20121 L
.22357 .19312 L
.26479 .18053 L
.3045 .17136 L
.34269 .16439 L
.38334 .15839 L
.42247 .15363 L
.46405 .14941 L
.50412 .14596 L
.54267 .1431 L
.58367 .14045 L
.62316 .13821 L
.66113 .1363 L
.70156 .13449 L
.74046 .13292 L
.78183 .13142 L
.82167 .13011 L
.86 .12897 L
.90078 .12785 L
.94005 .12686 L
.97619 .12602 L
s
.02381 .61803 m
.02846 .5542 L
.03279 .50996 L
.03754 .47233 L
.04262 .44074 L
.04795 .41435 L
.053 .39404 L
.06244 .36452 L
.07295 .34049 L
.08265 .32372 L
.09329 .30939 L
.10458 .29747 L
.12411 .28216 L
.14241 .27184 L
.16266 .2633 L
.18119 .25728 L
.20178 .25199 L
.2209 .24803 L
.25909 .24203 L
.29822 .23761 L
.3398 .23412 L
.37987 .23154 L
.41842 .22957 L
.45942 .22786 L
.49891 .22651 L
.53688 .22541 L
.5773 .22441 L
.61621 .22358 L
.65757 .22281 L
.69742 .22217 L
.73575 .22162 L
.77653 .2211 L
.8158 .22065 L
.85355 .22026 L
.89375 .21988 L
.93244 .21955 L
.97358 .21923 L
.97619 .21921 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{191.312, 117.875},
  ImageMargins->{{102.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002I0000GR000`400?l00000o`00003oV@3oool0
09T0oooo002I0?ooo`00V@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2:0?ooo`0000<000000?ooo`0000001`3oool3000000<0oooo0P000027
0?ooo`0000<000000?ooo`0000001`3oool00`000000oooo000000030?ooo`030000003oool0oooo
08H0oooo00000`000000oooo000000080?ooo`8000000`3oool00`000000oooo0?ooo`260?ooo`00
00<0oooo0000003oool02@3oool01@000000oooo0?ooo`3oool0000008P0oooo000@0?ooo`030000
003oool0oooo08H0oooo000@0?ooo`030000003oool0oooo08H0oooo000@0?ooo`030000003oool0
oooo08H0oooo000@0?ooo`030000003oool0oooo08H0oooo000@0?ooo`030000003oool0oooo08H0
oooo000@0?ooo`030000003oool0oooo08H0oooo000@0?ooo`030000003oool0oooo08H0oooo000@
0?ooo`030000003oool0oooo08H0oooo000@0?ooo`030000003oool0oooo08H0oooo000@0?ooo`03
0000003oool0oooo08H0oooo00000`3oool000000?ooo`030?ooo`040000003oool0oooo0?ooo`<0
00000`3oool00`000000oooo0?ooo`260?ooo`0000<000000?ooo`0000002@3oool010000000oooo
0?ooo`3oool2000008L0oooo00000`000000oooo000000070?ooo`<000000`3oool00`000000oooo
0?ooo`260?ooo`0000<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo08H0oooo00000`3oool000000?ooo`070?ooo`<000000`3oool00`000000oooo0?ooo`1Y
0?oooaT00000103oool00100oooo00<000000?ooo`3oool0CP3ooolK000001d0oooo000@0?ooo`03
0000003oool0oooo0480oooo3000000h0?ooo`00403oool00`000000oooo0?ooo`0g0?ooo`/00000
A03oool00100oooo00<000000?ooo`3oool0;03oool;000004l0oooo000@0?ooo`030000003oool0
oooo02L0oooo1@00001J0?ooo`00403oool00`000000oooo0?ooo`0Q0?ooo`H00000G`3oool00100
oooo00<000000?ooo`3oool07@3oool4000006D0oooo000@0?ooo`030000003oool0oooo01X0oooo
0`0000190?ooo`8000001`3oool2000000H0oooo0P0000070?ooo`800000103oool00100oooo00<0
00000?ooo`3oool05`3oool300000340oooo0P0000070?ooo`8000001`3oool2000000L0oooo0P00
00070?ooo`8000001P3oool2000000L0oooo0P0000040?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0E0?ooo`8000008`3oool2
000000H0oooo0P0000070?ooo`8000001`3oool2000000L0oooo0P00000W0?ooo`0000<000000?oo
o`0000001`3oool00`000000oooo000000030?ooo`8000004`3oool3000001<0oooo0P0000070?oo
o`8000001`3oool2000000H0oooo0P0000120?ooo`0000<000000?ooo`0000001`3oool3000000<0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`8000001`3oool2000005<0
oooo00000`000000oooo000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0<0?ooo`8000009P3ooolk000000@0oooo00000`3oool000000?oo
o`080?ooo`8000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0P00
00070?ooo`8000002`3ooolK000003l0oooo000@0?ooo`030000003oool0oooo00d0oooo0P000007
0?ooo`800000203oool<000005X0oooo000@0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool5000006H0oooo000@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01P3oool7000006/0oooo000@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P0000030?ooo`800000LP3oool00100oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`3oool5000007@0oooo000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool2000007L0oooo000@0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
001i0?ooo`00403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00800000NP3oool0
0100oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00001l0?ooo`0000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool3000007d0oooo00000`000000oooo000000080?ooo`030000003oool0oooo0080
oooo0P0000060?ooo`800000O`3oool000030000003oool0000000P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`800000O`3oool000030000003oool0000000T0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`<00000O`3oool000030?ooo`000000oooo00L0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000P03oool00100oooo00<00000
0?ooo`3oool00`3oool200000840oooo000@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0P03oool00100oooo00<000000?ooo`3oool00P3oool200000880oooo000@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`210?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0840oooo000@0?ooo`040000003oool0oooo0?ooo`800000P`3oool00100oooo00D000000?oo
o`3oool0oooo000000240?ooo`00403oool01@000000oooo0?ooo`3oool0000008@0oooo000@0?oo
o`050000003oool0oooo0?ooo`000000Q03oool000030?ooo`000000oooo00<0oooo00@000000?oo
o`3oool0oooo0`0000030?ooo`040000003oool0oooo000008D0oooo00000`000000oooo00000007
0?ooo`030000003oool0000000<0oooo0P0000000`3oool000000?ooo`240?ooo`0000<000000?oo
o`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000008D0oooo00000`00
0000oooo000000070?ooo`030000003oool0000000<0oooo00@000000?ooo`0000000000Q@3oool0
00030?ooo`000000oooo00L0oooo0`0000030?ooo`030000003oool0000008H0oooo000@0?ooo`03
0000003oool0000008H0oooo000@0?ooo`030000003oool0000008H0oooo000@0?ooo`030000003o
ool0000008H0oooo000@0?ooo`030000003oool0000008H0oooo000@0?ooo`030000003oool00000
08H0oooo000@0?ooo`030000003oool0000008H0oooo000@0?ooo`030000003oool0000008H0oooo
000@0?ooo`800000Q`3oool00100oooo0P0000270?ooo`0000<0oooo0000003oool00`3oool01000
0000oooo0?ooo`3oool2000000@0oooo0P0000270?ooo`0000<000000?ooo`0000002@3oool01000
0000oooo0?ooo`3oool2000008L0oooo00000`000000oooo000000070?ooo`<000000`3oool20000
08L0oooo00000`000000oooo000000070?ooo`030000003oool0000000<0oooo0P0000270?ooo`00
00<0oooo0000003oool01`3oool2000000@0oooo00<000000?ooo`3oool0QP3oool00100oooo00<0
00000?ooo`3oool0QP3oool00100oooo00<000000?ooo`3oool0QP3oool00100oooo00<000000?oo
o`3oool0QP3oool00100oooo00<000000?ooo`3oool0QP3oool00100oooo00<000000?ooo`3oool0
3@3oool300000100oooo00<000000?ooo`3oool03P3oool2000000l0oooo0`00000<0?ooo`<00000
0`3oool00`000000oooo0?ooo`090?ooo`<000000P3oool3000000T0oooo0`0000040?ooo`030000
003oool0oooo00P0oooo000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool3000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000=0?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`3oool3000000X0oooo000@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0303oool00`000000oooo0000000?0?ooo`<00000403oool00`000000
oooo0?ooo`0<0?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool01`000000oooo0?ooo`3oool000000?ooo`000000
2P3oool00100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`8000003`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000d0oooo00L000000?ooo`3oool0oooo
0000003oool0000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo0P00000:0?ooo`00403oool00`000000oooo0?ooo`0=0?ooo`<00000
403oool00`000000oooo0?ooo`0>0?ooo`8000003`3oool3000000`0oooo0P0000040?ooo`030000
003oool0oooo00T0oooo0P0000030?ooo`<000002@3oool2000000D0oooo00<000000?ooo`3oool0
203oool00100oooo00<000000?ooo`3oool0QP3oool000`0ooooS@00000000l0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`00V@3oool00001\
\>"],
  ImageRangeCache->{{{200.812, 352.812}, {136.312, 43.0625}} -> {-24.5523, \
0.665623, 0.090535, 0.00558051}}]
}, Open  ]],

Cell[TextData[{
  "Lorsque le coefficient de contraction est petit, une ou deux \
it\[EAcute]rations peuvent donner des r\[EAcute]sultats satisfaisants\
\[NonBreakingSpace]; sinon, le proc\[EAcute]d\[EAcute] d'acc\[EAcute]l\
\[EAcute]ration d'Aitken-Schanks se montre efficace, car ces suites sont \
asymptotiquement g\[EAcute]om\[EAcute]triques. Du reste, un peu d'astuce aide \
\[AGrave] trouver une forme de l'\[EAcute]quation telle que f soit \
contractante, par exemple en r\[EAcute]crivant l'\[EAcute]quation ",
  StyleBox["f[x]==x", "InlineOutput"],
  " sous la forme ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f\^\(-1\)\)], "InlineOutput"], "InlineOutput"],
  StyleBox["[x]==x", "InlineOutput"],
  ". C'est le cas avec l'\[EAcute]quation ",
  StyleBox["Tan[x]==x", "InlineOutput"],
  "\[NonBreakingSpace]; compte tenu de ce que ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`Tan\^\(-1\)\)], "InlineOutput"], "InlineOutput"],
  " est multiforme et contractante sur chaque branche, on exprime ainsi \
l'approximation d'ordre n du ",
  Cell[BoxData[
      \(TraditionalForm\`k\^e\)]],
  " z\[EAcute]ro de ",
  StyleBox["Tan[x]-x", "InlineOutput"],
  "\[NonBreakingSpace]:"
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[BoxData[
    \(approximateRoot[k_, 
        n_] := \[IndentingNewLine]Nest[\((k\ Pi + ArcTan[#])\) &, k\ Pi, 
        n]\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(approximateRoot[k, 2]\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \(k\ \[Pi] + ArcTan[k\ \[Pi] + ArcTan[k\ \[Pi]]]\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{x, Tan[x]}, {x, \(-2\) Pi, 3  Pi}, 
        PlotRange \[Rule] {\(-10\), 10}, 
        Epilog \[Rule] {PointSize[0.02], 
            Map[Point, 
              Table[approximateRoot[k, 1], {k, \(-1\), 
                  2}, {2}]]}];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.0606305 0.309017 0.0309017 [
[.10161 .29652 -6 -9 ]
[.10161 .29652 6 0 ]
[.25319 .29652 -12 -9 ]
[.25319 .29652 12 0 ]
[.55634 .29652 -9 -9 ]
[.55634 .29652 9 0 ]
[.70791 .29652 -3 -9 ]
[.70791 .29652 3 0 ]
[.85949 .29652 -9 -9 ]
[.85949 .29652 9 0 ]
[.39226 0 -18 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -24 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -12 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -24 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -18 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -6 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -18 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -12 -4.5 ]
[.39226 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10161 .30902 m
.10161 .31527 L
s
[(-5)] .10161 .29652 0 1 Mshowa
.25319 .30902 m
.25319 .31527 L
s
[(-2.5)] .25319 .29652 0 1 Mshowa
.55634 .30902 m
.55634 .31527 L
s
[(2.5)] .55634 .29652 0 1 Mshowa
.70791 .30902 m
.70791 .31527 L
s
[(5)] .70791 .29652 0 1 Mshowa
.85949 .30902 m
.85949 .31527 L
s
[(7.5)] .85949 .29652 0 1 Mshowa
.125 Mabswid
.13192 .30902 m
.13192 .31277 L
s
.16224 .30902 m
.16224 .31277 L
s
.19256 .30902 m
.19256 .31277 L
s
.22287 .30902 m
.22287 .31277 L
s
.2835 .30902 m
.2835 .31277 L
s
.31382 .30902 m
.31382 .31277 L
s
.34413 .30902 m
.34413 .31277 L
s
.37445 .30902 m
.37445 .31277 L
s
.43508 .30902 m
.43508 .31277 L
s
.46539 .30902 m
.46539 .31277 L
s
.49571 .30902 m
.49571 .31277 L
s
.52602 .30902 m
.52602 .31277 L
s
.58665 .30902 m
.58665 .31277 L
s
.61697 .30902 m
.61697 .31277 L
s
.64728 .30902 m
.64728 .31277 L
s
.6776 .30902 m
.6776 .31277 L
s
.73823 .30902 m
.73823 .31277 L
s
.76854 .30902 m
.76854 .31277 L
s
.79886 .30902 m
.79886 .31277 L
s
.82918 .30902 m
.82918 .31277 L
s
.07129 .30902 m
.07129 .31277 L
s
.04098 .30902 m
.04098 .31277 L
s
.01066 .30902 m
.01066 .31277 L
s
.88981 .30902 m
.88981 .31277 L
s
.92012 .30902 m
.92012 .31277 L
s
.95044 .30902 m
.95044 .31277 L
s
.98075 .30902 m
.98075 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-10)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-7.5)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-2.5)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(2.5)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(7.5)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(10)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11486 m
.06244 .13455 L
.10458 .15602 L
.14415 .17619 L
.18221 .19559 L
.22272 .21623 L
.26171 .23611 L
.30316 .25723 L
.34309 .27758 L
.3815 .29716 L
.42237 .31799 L
.46172 .33805 L
.49955 .35733 L
.53984 .37786 L
.57861 .39762 L
.61984 .41863 L
.65954 .43887 L
.69774 .45834 L
.73838 .47905 L
.77751 .499 L
.81909 .52019 L
.85916 .54061 L
.89771 .56026 L
.93871 .58116 L
.97619 .60026 L
s
.02381 .30902 m
.04262 .31892 L
.06244 .33189 L
.06747 .33613 L
.07286 .34141 L
.07751 .34683 L
.08255 .354 L
.08848 .36503 L
.0912 .37151 L
.09409 .37979 L
.09668 .38896 L
.09954 .40174 L
.10214 .41697 L
.10458 .43605 L
.10583 .44846 L
.10715 .46451 L
.1083 .48153 L
.10954 .50452 L
.1103 .52182 L
.11101 .54062 L
.11166 .56146 L
.11238 .58904 L
s
.11238 .58904 m
.11294 .61803 L
s
.11916 .61803 m
.11927 0 L
s
.12513 0 m
.12591 .03712 L
.12709 .07749 L
.12833 .10871 L
.12948 .13116 L
.13154 .16116 L
.13374 .18402 L
.13633 .20357 L
.13878 .21743 L
.14335 .2361 L
.14574 .24343 L
.14798 .24925 L
.15307 .25986 L
.15803 .26777 L
.16337 .27455 L
.17301 .28399 L
.18182 .29068 L
.22158 .31275 L
.24165 .32399 L
.25039 .32995 L
.25982 .33787 L
.26512 .34338 L
.26998 .34948 L
.27493 .35716 L
.27954 .36631 L
.28441 .3793 L
.28699 .38828 L
.28975 .40037 L
.29265 .41714 L
.29407 .42762 L
.29539 .43913 L
.29785 .46749 L
.29915 .48777 L
.30052 .51561 L
.30166 .54606 L
.30291 .59127 L
s
.30291 .59127 m
.30341 .61803 L
s
.30914 .61803 m
.30923 0 L
s
.31563 0 m
.31609 .02458 L
.31682 .0535 L
.31749 .07524 L
.3188 .10853 L
.32003 .13251 L
.32224 .1638 L
.32335 .17586 L
.32458 .18714 L
.32879 .21506 L
.33115 .22611 L
.33371 .23569 L
.33832 .24893 L
.34327 .25936 L
.34788 .26687 L
.35834 .27931 L
.36853 .28799 L
.37943 .2953 L
.39932 .30624 L
.4209 .31744 L
.43099 .32328 L
.44167 .33056 L
.4508 .33835 L
.46085 .35003 L
.46605 .35831 L
.47099 .3686 L
.47543 .38105 L
.47794 .39017 L
.48027 .40061 L
.483 .41634 L
.48557 .43644 L
.48788 .4616 L
.48919 .48042 L
.49038 .50217 L
.49167 .53263 L
.49288 .57096 L
.49357 .59943 L
s
.49357 .59943 m
.49394 .61803 L
s
.49999 .61803 m
.50004 0 L
s
.50606 0 m
.50612 .00387 L
.50727 .05261 L
.50833 .08564 L
.5095 .11344 L
.51074 .13632 L
.51198 .15465 L
.51331 .17056 L
.51572 .19255 L
.51859 .21142 L
.52121 .22432 L
.52639 .24257 L
.52932 .25018 L
.53204 .25609 L
.54231 .27217 L
.54741 .27791 L
.55292 .2831 L
.56289 .29077 L
.58152 .3019 L
.60112 .31202 L
.62259 .32399 L
.63248 .33081 L
.64307 .34014 L
.6482 .34591 L
.65306 .35257 L
.65742 .35996 L
.66215 .37028 L
.6645 .37667 L
.66702 .38487 L
.6692 .39345 L
.67159 .40497 L
.67437 .42257 L
.67565 .43283 L
.67701 .44588 L
.67836 .46162 L
.67959 .47923 L
.68073 .49955 L
.68198 .52807 L
.6833 .56872 L
.68402 .59789 L
s
.68402 .59789 m
.68442 .61803 L
s
.69101 .61803 m
.69112 0 L
s
.69653 0 m
.69667 .00734 L
.6974 .03954 L
.69807 .06343 L
.6993 .09824 L
.70062 .12612 L
.70185 .14629 L
.70301 .16162 L
.70531 .18526 L
.70785 .20415 L
.71032 .21801 L
.71298 .22962 L
.71779 .24512 L
.72218 .25541 L
.72728 .26453 L
.73285 .27224 L
.74298 .28273 L
.75331 .29073 L
.76268 .29668 L
.78366 .30797 L
.80456 .31894 L
.81372 .3244 L
.82377 .33144 L
.83348 .34007 L
.84254 .35109 L
.84755 .35931 L
.85211 .369 L
.85463 .37568 L
.85738 .38444 L
.85977 .39386 L
.86236 .4066 L
.86489 .42295 L
.86722 .44309 L
.86944 .46979 L
.87056 .48746 L
.87178 .51163 L
.87314 .54754 L
.87438 .59296 L
s
.87438 .59296 m
.8749 .61803 L
s
.88212 .61803 m
.88213 0 L
s
.887 0 m
.887 .00024 L
.8878 .03661 L
.88916 .0821 L
.89059 .11625 L
.89181 .13833 L
.89315 .15749 L
.89566 .18413 L
.89834 .20425 L
.90088 .21839 L
.90318 .22853 L
.90801 .24444 L
.91314 .25638 L
.91751 .26414 L
.92233 .271 L
.93306 .28239 L
.94312 .29026 L
.97619 .30902 L
s
.02 w
.13773 .17292 Mdot
.40476 .30902 Mdot
.67179 .44511 Mdot
.87138 .54684 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{297.625, 183.688},
  ImageMargins->{{69.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003^0000TR000`400?l00000o`00003okP3oool0
0>h0oooo001E0?ooo`<000000`3oool00`000000oooo0?ooo`2@0?ooo`008@3oool2000002P0oooo
00<000000?ooo`0000000P3oool400000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo0P00000C0?ooo`800000:@3oool2000002T0oooo0P00000P0?ooo`008@3oool2000002P0
oooo00<000000?ooo`000000203oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
0`000000oooo0?ooo`0B0?ooo`800000:@3oool2000002T0oooo0P00000P0?ooo`008@3oool20000
02P0oooo00<000000?ooo`000000203oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool00`000000oooo0?ooo`0B0?ooo`800000:@3oool2000002T0oooo0P00000P0?ooo`008@3oool2
000002P0oooo00<000000?ooo`0000001`3oool2000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0B0?ooo`800000:@3oool2000002T0oooo0P00000P0?ooo`008@3oool20000
02P0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`800000:@3oool20000
02T0oooo0P00000P0?ooo`008@3oool2000002P0oooo00<000000?ooo`0000004`3oool00`000000
oooo0?ooo`0B0?ooo`800000:@3oool2000002T0oooo0P00000P0?ooo`008@3oool2000002P0oooo
00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`800000:@3oool2000002T0oooo
0P00000P0?ooo`008@3oool2000002P0oooo00<000000?ooo`0000004`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0000002P0oooo0P00000Y0?ooo`800000803oool00240oooo0P00000X
0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000X
0?ooo`800000:@3oool200000200oooo000Q0?ooo`800000:03oool00`000000oooo0000000C0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`000000:03oool2000002T0oooo0P00000P0?oo
o`008@3oool2000002P0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0000002P0oooo0P00000Y0?ooo`800000803oool00240oooo0P00000X0?ooo`030000
003oool0000001<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000X0?ooo`800000
:@3oool200000200oooo000Q0?ooo`800000:03oool00`000000oooo0000000C0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`000000:03oool2000002T0oooo0P00000P0?ooo`008@3oool2
000002P0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
000002P0oooo0P00000Y0?ooo`800000803oool00240oooo0P00000X0?ooo`030000003oool00000
01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000X0?ooo`800000:@3oool20000
0200oooo000Q0?ooo`800000:03oool00`000000oooo0000000C0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000:03oool2000002T0oooo0P00000P0?ooo`008@3oool2000002P0oooo
00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002P0oooo
0P00000Y0?ooo`800000803oool00240oooo0P00000X0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0000000X0?ooo`800000:@3oool200000200oooo000Q0?ooo`800000:03o
ool400000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000004`3o
ool00`000000oooo0000000X0?ooo`800000:@3oool200000200oooo000Q0?ooo`800000:03oool0
0`000000oooo000000030?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`030000003oool0
oooo0180oooo00<000000?ooo`000000:03oool00`000000oooo0000000X0?ooo`800000803oool0
0240oooo0P00000X0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`000000:03oool00`00
0000oooo0000000X0?ooo`800000803oool00240oooo0P00000X0?ooo`030000003oool000000080
oooo0`0000070?ooo`<00000103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002P0
oooo00<000000?ooo`000000:03oool200000200oooo000Q0?ooo`030000003oool0000002L0oooo
00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002P0oooo
00<000000?ooo`000000:03oool200000200oooo000Q0?ooo`030000003oool0000002L0oooo00<0
00000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002P0oooo00<0
00000?ooo`000000:03oool00`000000oooo0000000O0?ooo`008@3oool00`000000oooo0000000W
0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000X
0?ooo`030000003oool0000002P0oooo00<000000?ooo`0000007`3oool00240oooo00<000000?oo
o`0000009`3oool00`000000oooo0000000C0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`000000:03oool00`000000oooo0000000X0?ooo`030000003oool0000001l0oooo000;0?ooo`80
0000503oool00`000000oooo0000000W0?ooo`030000003oool0000001<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0000000X0?ooo`030000003oool0000002P0oooo00<000000?ooo`00
00007`3oool000d0oooo0P00000B0?ooo`030000003oool0000002L0oooo00<000000?ooo`000000
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002P0oooo00<000000?ooo`000000
:03oool00`000000oooo0000000O0?ooo`003`3oool3000000l0oooo00<000000?ooo`0000009`3o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`000000
:03oool00`000000oooo0000000X0?ooo`030000003oool0000001l0oooo000B0?ooo`8000003@3o
ool00`000000oooo0000000W0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0000000X0?ooo`030000003oool0000002P0oooo00<000000?ooo`000000
7`3oool001@0oooo0P00000;0?ooo`030000003oool0000002L0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000002P0oooo00<000000?ooo`000000
:03oool00`000000oooo0000000O0?ooo`005P3oool2000000T0oooo00<000000?ooo`0000009`3o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`000000
:03oool00`000000oooo0000000X0?ooo`030000003oool0000001l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0000000W0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0000000X0?ooo`030000003oool0000002P0oooo00<000000?ooo`000000
7`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000W0?ooo`040000003o
ool0oooo00000180oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000X0?ooo`030000
003oool0000002P0oooo00<000000?ooo`0000007`3oool001/0oooo0P0000040?ooo`030000003o
ool0000002L0oooo00@000000?ooo`3oool000002`3oool3000000@0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0000002P0oooo00<000000?ooo`00
00007`3oool001d0oooo0P0000020?ooo`030000003oool0000002L0oooo00@000000?ooo`3oool0
00001P3oool4000000<0oooo00<000000?ooo`3oool00P3oool2000001<0oooo00@000000?ooo`3o
ool000009`3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0000001l0oooo000O0?oo
o`<0000000<0oooo0000003oool09P3oool010000000oooo0?ooo`00000;0?ooo`<00000103oool0
0`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000002L0oooo00@000000?ooo`3oool00000
9`3oool00`000000oooo0000000O0?ooo`008@3oool3000002L0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
00009`3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0000001l0oooo000Q0?ooo`03
0000003oool00000008000009@3oool010000000oooo0?ooo`00000;0?ooo`<00000103oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000002L0oooo00@000000?ooo`3oool000009`3o
ool00`000000oooo0000000O0?ooo`008@3oool00`000000oooo00000003000002@0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000002L0oooo
00@000000?ooo`3oool000009`3oool010000000oooo0?ooo`00000N0?ooo`008@3oool00`000000
oooo00000004000002<0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0B0?oo
o`040000003oool0oooo000002L0oooo00@000000?ooo`3oool000009`3oool010000000oooo0?oo
o`00000N0?ooo`008@3oool00`000000oooo0?ooo`0200000080oooo0P00000Q0?ooo`040000003o
ool0oooo00000180oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000002H0
oooo00@000000?ooo`3oool000009`3oool010000000oooo0?ooo`00000N0?ooo`008@3oool01000
0000oooo0?ooo`0000050?ooo`<000007P3oool01@000000oooo0?ooo`3oool000000140oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000002H0oooo00@000000?ooo`3oool0
00009`3oool010000000oooo0?ooo`00000N0?ooo`008@3oool010000000oooo0?ooo`0000080?oo
o`800000703oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool04P3oool0
1@000000oooo0?ooo`3oool0000002H0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`00000N0?ooo`008@3oool010000000oooo0?ooo`00000:0?ooo`8000006P3oool01@000000
oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
000002H0oooo00@000000?ooo`3oool000009`3oool010000000oooo0?ooo`00000N0?ooo`008@3o
ool010000000oooo0?ooo`00000<0?ooo`800000603oool01@000000oooo0?ooo`3oool000000140
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000002H0oooo00D000000?oo
o`3oool0oooo0000000V0?ooo`040000003oool0oooo000001h0oooo000Q0?ooo`040000003oool0
oooo000000h0oooo0P00000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000009P3oool01@000000oooo
0?ooo`3oool0000002H0oooo00@000000?ooo`3oool000007P3oool00240oooo00@000000?ooo`3o
ool00000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000009P3oool0
1@000000oooo0?ooo`3oool0000002H0oooo00@000000?ooo`3oool000007P3oool00240oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D000000?ooo`3oool0oooo0000000V0?ooo`050000003oool0oooo0?ooo`0000007@3oool0
0240oooo00D000000?ooo`3oool0oooo0000000B0?ooo`8000004@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3o
ool0000002H0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`050000003oool0oooo0?ooo`00
00007@3oool00240oooo00D000000?ooo`3oool0oooo0000000D0?ooo`8000003`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000V0?oo
o`050000003oool0oooo0?ooo`0000007@3oool00240oooo00D000000?ooo`3oool0oooo0000000F
0?ooo`<00000303oool00`000000oooo0?ooo`020?ooo`<000000`3oool010000000oooo0?ooo`3o
ool3000000@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06P3oool00240oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0F0?ooo`8000002P3oool4000000030?ooo`000000000000X0oooo00<00000
0?ooo`3oool00P3oool2000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01X0oooo000Q0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0603oool2000000P0oooo00<000000?ooo`3oool00`3oool2000000L0oooo0`0000040?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06P3oool2000000H0oooo00<000000?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01/0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000070?ooo`<00000
103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0I0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01d0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06@3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0N0?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01P0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool2
000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`008@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo0`0000050?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool05`3oool00240oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00<000000`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01L0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000003oool02`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0F0?ooo`007P3oool4000000P0oooo0P00000?0?ooo`<000000`3oool010000000oooo0?oo
o`3oool3000000<0oooo00<000000?ooo`3oool01@3oool3000000/0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`030?ooo`<0000000@0oooo0000003oool000000`3oool3000001P0
oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool3000000P0oooo00<000000?ooo`3oool05P3oool001T0
oooo100000030?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`@000000P3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002@3oool3000000T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0E0?ooo`007P3oool4000000/0oooo0P00000>0?ooo`030000003oool0oooo00D0oooo0`000003
0?ooo`030000003oool0oooo00P0oooo0`0000080?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`3oool200000080oooo0`00000H0?ooo`030000003o
ool00000008000001`3oool200000180oooo00<000000?ooo`3oool01P3oool3000000X0oooo0`00
000D0?ooo`007P3oool010000000oooo0?ooo`00000=0?ooo`800000303oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool3000000H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0`00
000J0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000d0oooo0P00000B0?ooo`007P3oool4000000l0oooo0P000008
0?ooo`<000001`3oool3000000<0oooo00<000000?ooo`3oool0303oool3000000@0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`<000001`3oool3000001P0oooo00<00000
0?ooo`0000000P00000:0?ooo`030000003oool0oooo00d0oooo0`0000070?ooo`<000003`3oool0
0`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`8000005P3oool00`00
0000oooo0?ooo`0=0?ooo`<000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`8000006@3oool00`00
0000oooo0?ooo`0>0?ooo`8000003`3oool00240oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool000000000000D0?ooo`03
0000003oool0oooo00l0oooo0P00000G0?ooo`030000003oool0oooo00l0oooo0`00000F0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00240oooo00<000000?ooo`3oool0
4P3oool2000001<0oooo00<000000?ooo`3oool04@3oool4000001<0oooo00<000000?ooo`3oool0
4@3oool3000001@0oooo00<000000?ooo`3oool04P3oool2000001@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0;0?ooo`001P3ooooQ000000L0oooo000=0?ooo`8000003P3oool0
1@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0180oooo0P000000103oool0000000000000000@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool200000100oooo00D000000?ooo`3oool0
oooo0000000C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0O0?ooo`003`3oool200000100oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`80
0000403oool00`000000oooo0?ooo`0O0?ooo`004@3oool2000000h0oooo00<000000?ooo`3oool0
603oool2000000d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`800000
3@3oool00`000000oooo0?ooo`0I0?ooo`8000003@3oool00`000000oooo0?ooo`0H0?ooo`800000
3P3oool00`000000oooo0?ooo`0O0?ooo`004`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00D0oooo0P00000;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07`3o
ool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`<000002@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo000E0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000070?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01l0oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`<000000P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01l0oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool07P3oool2000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00@0oooo0`00000Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo000H0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`800000
803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0O0?ooo`006@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool010000000oooo00000000000O0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000007@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0O0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000001/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2000001X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`800000603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`006`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2000000h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`<000005P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`00703oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool200000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7`3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`050000003o
ool0oooo0?ooo`000000103oool3000000L0oooo0`0000040?ooo`030000003oool0oooo00h0oooo
00D000000?ooo`3oool0oooo0000000C0?ooo`8000004@3oool01@000000oooo0?ooo`3oool00000
02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`00703oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000E0?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`8000003`3oool0
1@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0O0?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00D00000
0?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo
0000000G0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool001d0oooo00D000000?ooo`3oool0
oooo0000000U0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`000000603oool2000000`0oooo00D000000?ooo`3oool0oooo0000
000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool001d0oooo00D00000
0?ooo`3oool0oooo0000000U0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000006P3oool2000000X0oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`050000003oool0oooo0?ooo`0000008@3oool001d0oooo00D000000?oo
o`3oool0oooo0000000U0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`000000703oool2000000P0oooo00D000000?ooo`3oool0
oooo0000000V0?ooo`050000003oool0oooo0?ooo`0000008@3oool001d0oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool0000001h0oooo0P0000060?ooo`050000003oool0oooo0?ooo`000000
9P3oool01@000000oooo0?ooo`3oool000000240oooo000M0?ooo`050000003oool0oooo0?ooo`00
00009P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool00000803oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000009P3o
ool01@000000oooo0?ooo`3oool000000240oooo000M0?ooo`050000003oool0oooo0?ooo`000000
9P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3o
ool000008@3oool2000000<0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`050000003oool0
oooo0?ooo`0000008@3oool001d0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`040000003o
ool0oooo000001D0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000S0?ooo`D0
00000P3oool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`0000008@3oool001h0
oooo00@000000?ooo`3oool000009P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0
oooo00l0oooo00@000000?ooo`3oool00000903oool400000080oooo00<000000?ooo`3oool0903o
ool01@000000oooo0?ooo`3oool000000240oooo000N0?ooo`040000003oool0oooo000002H0oooo
00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0000
02@0oooo1@0000000`3oool000000?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000008@3oool0
01h0oooo00@000000?ooo`3oool000009P3oool010000000oooo0?ooo`00000E0?ooo`030000003o
ool0oooo00l0oooo00@000000?ooo`3oool000009@3oool3000000030?ooo`000000000002H0oooo
00D000000?ooo`3oool0oooo0000000Q0?ooo`007P3oool010000000oooo0?ooo`00000W0?ooo`03
0000003oool0000000h0oooo0`0000040?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3o
ool000009`3oool00`000000oooo0?ooo`03000002@0oooo00D000000?ooo`3oool0oooo0000000Q
0?ooo`007P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool000000100oooo00<00000
0?ooo`3oool00P3oool200000100oooo00@000000?ooo`3oool000009`3oool010000000oooo0?oo
o`0000020?ooo`8000008`3oool010000000oooo0?ooo`00000Q0?ooo`007P3oool010000000oooo
0?ooo`00000W0?ooo`030000003oool0000000h0oooo0`0000040?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool000009`3oool010000000oooo0?ooo`0000040?ooo`8000008@3oool0
10000000oooo0?ooo`00000Q0?ooo`007P3oool010000000oooo0?ooo`00000W0?ooo`030000003o
ool0000000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo000002L0oooo00@000000?ooo`3oool000001P3oool2000001l0oooo00@000000?ooo`3o
ool000008@3oool001h0oooo00@000000?ooo`3oool000009`3oool00`000000oooo0000000>0?oo
o`<00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000002L0oooo00@000000?oo
o`3oool00000203oool2000001d0oooo00@000000?ooo`3oool000008@3oool001h0oooo00@00000
0?ooo`3oool000009`3oool00`000000oooo0000000E0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`0000009`3oool010000000oooo0?ooo`00000:0?ooo`8000006`3oool010000000oooo
0?ooo`00000Q0?ooo`007P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0000001D0
oooo00<000000?ooo`3oool0403oool00`000000oooo0000000W0?ooo`040000003oool0oooo0000
00`0oooo0P00000I0?ooo`040000003oool0oooo00000240oooo000N0?ooo`040000003oool0oooo
000002L0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
000002L0oooo00@000000?ooo`3oool000003P3oool2000001L0oooo00@000000?ooo`3oool00000
8@3oool001h0oooo00@000000?ooo`3oool000009`3oool00`000000oooo0000000E0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`000000:03oool00`000000oooo0000000@0?ooo`800000
5@3oool010000000oooo0?ooo`00000Q0?ooo`007P3oool010000000oooo0?ooo`00000W0?ooo`03
0000003oool0000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0000000X0?ooo`03
0000003oool000000180oooo0P00000C0?ooo`040000003oool0oooo00000240oooo000N0?ooo`04
0000003oool0oooo000002L0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0000002P0oooo00<000000?ooo`000000503oool200000140oooo00@000000?oo
o`3oool000008@3oool001h0oooo00@000000?ooo`3oool000009`3oool00`000000oooo0000000E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000:03oool00`000000oooo0000000F
0?ooo`8000003`3oool010000000oooo0?ooo`00000Q0?ooo`007P3oool010000000oooo0?ooo`00
000W0?ooo`030000003oool0000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0000
000X0?ooo`030000003oool0000001P0oooo0P00000=0?ooo`040000003oool0oooo00000240oooo
000O0?ooo`030000003oool0000002L0oooo00<000000?ooo`0000005@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0000002P0oooo00<000000?ooo`0000006P3oool2000000/0oooo00@0
00000?ooo`3oool000008@3oool001l0oooo00<000000?ooo`0000009`3oool00`000000oooo0000
000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000:03oool00`000000oooo0000
000L0?ooo`8000002@3oool010000000oooo0?ooo`00000Q0?ooo`007`3oool00`000000oooo0000
000W0?ooo`030000003oool0000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0000
000X0?ooo`030000003oool0000001h0oooo0P0000070?ooo`040000003oool0oooo00000240oooo
000O0?ooo`030000003oool0000002L0oooo00<000000?ooo`0000005@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0000002P0oooo00<000000?ooo`000000803oool2000000D0oooo00@0
00000?ooo`3oool000008@3oool001l0oooo00<000000?ooo`000000:03oool2000001D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0000000X0?ooo`030000003oool000000280oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0000000Q0?ooo`007`3oool00`000000oooo0000000X
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<00000103o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0000002P0oooo00<000000?ooo`0000008`3o
ool2000000<0oooo00<000000?ooo`0000008@3oool001l0oooo00<000000?ooo`000000:03oool2
000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000004@3oool0
0`000000oooo0000000X0?ooo`030000003oool0000002D0oooo100000000`3oool000000?ooo`0P
0?ooo`007`3oool00`000000oooo0000000X0?ooo`8000001@3oool00`000000oooo0?ooo`060?oo
o`<00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000002P0oooo00<000000?oo
o`0000009P3oool500000240oooo000O0?ooo`030000003oool0000002P0oooo0P0000060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0000002P0oooo00<000000?ooo`0000009P3oool500000240oooo000O0?ooo`030000
003oool0000002P0oooo0P0000040?ooo`<000001`3oool3000000@0oooo00<000000?ooo`3oool0
403oool00`000000oooo0000000X0?ooo`030000003oool0000002L0oooo0P000000103oool00000
00000000000O0?ooo`007`3oool00`000000oooo0000000X0?ooo`8000005@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0000002P0oooo00<000000?ooo`000000:03oool00`000000oooo
000000020?ooo`8000007@3oool001l0oooo00<000000?ooo`000000:03oool2000001D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0000000X0?ooo`030000003oool0000002P0oooo00<0
00000?ooo`000000103oool2000001/0oooo000O0?ooo`030000003oool0000002P0oooo0P00000E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000:03oool00`000000oooo0000000X
0?ooo`030000003oool0000000H0oooo0P00000I0?ooo`007`3oool00`000000oooo0000000X0?oo
o`8000005@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000002P0oooo00<000000?oo
o`000000:03oool00`000000oooo000000080?ooo`8000005`3oool001l0oooo00<000000?ooo`00
0000:03oool2000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0000000X0?ooo`03
0000003oool0000002P0oooo00<000000?ooo`0000002P3oool2000001D0oooo000O0?ooo`030000
003oool0000002P0oooo0P00000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000
:03oool00`000000oooo0000000X0?ooo`030000003oool0000000`0oooo0P00000C0?ooo`007`3o
ool00`000000oooo0000000X0?ooo`8000005@3oool00`000000oooo0?ooo`0A0?ooo`800000:03o
ool00`000000oooo0000000X0?ooo`030000003oool0000000h0oooo0P00000A0?ooo`007`3oool0
0`000000oooo0000000X0?ooo`8000005@3oool00`000000oooo0?ooo`0A0?ooo`800000:03oool0
0`000000oooo0000000X0?ooo`030000003oool000000100oooo0P00000?0?ooo`007`3oool00`00
0000oooo0000000X0?ooo`8000005@3oool00`000000oooo0?ooo`0A0?ooo`800000:03oool00`00
0000oooo0000000X0?ooo`030000003oool000000180oooo0P00000=0?ooo`007`3oool00`000000
oooo0000000X0?ooo`8000005@3oool00`000000oooo0?ooo`0A0?ooo`800000:03oool00`000000
oooo0000000X0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool02P3oool001l0oooo
00<000000?ooo`000000:03oool2000001D0oooo00<000000?ooo`3oool04@3oool2000002P0oooo
00<000000?ooo`000000:03oool00`000000oooo0000000Q0?ooo`007`3oool00`000000oooo0000
000X0?ooo`8000005@3oool00`000000oooo0?ooo`0A0?ooo`800000:03oool00`000000oooo0000
000X0?ooo`030000003oool000000240oooo000O0?ooo`030000003oool0000002P0oooo0P000009
0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo0P00000X
0?ooo`030000003oool0000002P0oooo00<000000?ooo`0000008@3oool001l0oooo00<000000?oo
o`000000:03oool2000000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo0P00
000B0?ooo`800000:03oool00`000000oooo0000000X0?ooo`030000003oool000000240oooo001F
0?ooo`070000003oool0oooo0?ooo`000000oooo0000002A0?ooo`00EP3oool01`000000oooo0?oo
o`3oool000000?ooo`000000T@3oool005D0oooo0P0000040?ooo`030000003oool0oooo0900oooo
0000\
\>"],
  ImageRangeCache->{{{174.875, 411.938}, {525.5, 379.562}} -> {-19.9867, \
44.1978, 0.0587786, 0.115326}}]
}, Open  ]],

Cell[TextData[{
  "Testons maintenant la m\[EAcute]thode sur une \[EAcute]quation \
int\[EAcute]grale de Fredholm dont on sait par ailleurs d\[EAcute]terminer la \
solution ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](x) = 1\/2\ \((3\ x + 1)\)\)]],
  " par la m\[EAcute]thode des noyaux \
d\[EAcute]g\[EAcute]n\[EAcute]r\[EAcute]s\[NonBreakingSpace]: "
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[TextData[{
  "\[CurlyPhi][x]==x+",
  Cell[BoxData[
      FormBox[
        FractionBox["1", 
          AdjustmentBox["2",
            BoxBaselineShift->-0.5]], TraditionalForm]]],
  " -",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Integral]\_\(-1\)\%1\((y + x)\) \[CurlyPhi][
                y]\[ThinSpace]\[DifferentialD]y\),
          ScriptLevel->0], TraditionalForm]]]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1],

Cell[BoxData[
    \(operator[u_, x_] := \[IndentingNewLine]Simplify[
        x + Integrate[\((y + x)\)*\((u /. x \[Rule] y)\), {y, \(-1\), 1}]/
            2]\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell["NestList[operator[#,x]&, 1, 3]", "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \({1, 2\ x, 2\/3 + x, 1\/3\ \((1 + 5\ x)\)}\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]Plot[\ \((3\ x + 1)\)/2, {x, \(-1\), 1}, 
          DisplayFunction \[Rule] Identity], 
        Plot[Evaluate[
            NestList[\[IndentingNewLine]operator[#1, x] &, 0, 
              4]], {x, \(-1\), 
            1}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.02, 0.02}]}, 
          DisplayFunction \[Rule] Identity], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.210916 0.196201 [
[.02381 .19842 -6 -9 ]
[.02381 .19842 6 0 ]
[.2619 .19842 -12 -9 ]
[.2619 .19842 12 0 ]
[.7381 .19842 -9 -9 ]
[.7381 .19842 9 0 ]
[.97619 .19842 -3 -9 ]
[.97619 .19842 3 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .11282 -24 -4.5 ]
[.4875 .11282 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .40712 -6 -4.5 ]
[.4875 .40712 0 4.5 ]
[.4875 .50522 -18 -4.5 ]
[.4875 .50522 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .21092 m
.02381 .21717 L
s
[(-1)] .02381 .19842 0 1 Mshowa
.2619 .21092 m
.2619 .21717 L
s
[(-0.5)] .2619 .19842 0 1 Mshowa
.7381 .21092 m
.7381 .21717 L
s
[(0.5)] .7381 .19842 0 1 Mshowa
.97619 .21092 m
.97619 .21717 L
s
[(1)] .97619 .19842 0 1 Mshowa
.125 Mabswid
.07143 .21092 m
.07143 .21467 L
s
.11905 .21092 m
.11905 .21467 L
s
.16667 .21092 m
.16667 .21467 L
s
.21429 .21092 m
.21429 .21467 L
s
.30952 .21092 m
.30952 .21467 L
s
.35714 .21092 m
.35714 .21467 L
s
.40476 .21092 m
.40476 .21467 L
s
.45238 .21092 m
.45238 .21467 L
s
.54762 .21092 m
.54762 .21467 L
s
.59524 .21092 m
.59524 .21467 L
s
.64286 .21092 m
.64286 .21467 L
s
.69048 .21092 m
.69048 .21467 L
s
.78571 .21092 m
.78571 .21467 L
s
.83333 .21092 m
.83333 .21467 L
s
.88095 .21092 m
.88095 .21467 L
s
.92857 .21092 m
.92857 .21467 L
s
.25 Mabswid
0 .21092 m
1 .21092 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .11282 m
.50625 .11282 L
s
[(-0.5)] .4875 .11282 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.5)] .4875 .30902 1 0 Mshowa
.5 .40712 m
.50625 .40712 L
s
[(1)] .4875 .40712 1 0 Mshowa
.5 .50522 m
.50625 .50522 L
s
[(1.5)] .4875 .50522 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .03434 m
.50375 .03434 L
s
.5 .05396 m
.50375 .05396 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .0932 m
.50375 .0932 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .15206 m
.50375 .15206 L
s
.5 .17168 m
.50375 .17168 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .23054 m
.50375 .23054 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .26978 m
.50375 .26978 L
s
.5 .2894 m
.50375 .2894 L
s
.5 .32864 m
.50375 .32864 L
s
.5 .34826 m
.50375 .34826 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .44636 m
.50375 .44636 L
s
.5 .46598 m
.50375 .46598 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .52484 m
.50375 .52484 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .56408 m
.50375 .56408 L
s
.5 .5837 m
.50375 .5837 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
[ .02 .02 ] 0 setdash
.02381 .21092 m
.06244 .21092 L
.10458 .21092 L
.14415 .21092 L
.18221 .21092 L
.22272 .21092 L
.26171 .21092 L
.30316 .21092 L
.34309 .21092 L
.3815 .21092 L
.42237 .21092 L
.46172 .21092 L
.49955 .21092 L
.53984 .21092 L
.57861 .21092 L
.61984 .21092 L
.65954 .21092 L
.69774 .21092 L
.73838 .21092 L
.77751 .21092 L
.81909 .21092 L
.85916 .21092 L
.89771 .21092 L
.93871 .21092 L
.97619 .21092 L
s
.02381 .01472 m
.06244 .03063 L
.10458 .04799 L
.14415 .0643 L
.18221 .07998 L
.22272 .09667 L
.26171 .11274 L
.30316 .12981 L
.34309 .14626 L
.3815 .16209 L
.42237 .17893 L
.46172 .19514 L
.49955 .21073 L
.53984 .22733 L
.57861 .24331 L
.61984 .26029 L
.65954 .27665 L
.69774 .29239 L
.73838 .30914 L
.77751 .32526 L
.81909 .34239 L
.85916 .3589 L
.89771 .37478 L
.93871 .39168 L
.97619 .40712 L
s
.02381 .08012 m
.06244 .09603 L
.10458 .11339 L
.14415 .1297 L
.18221 .14538 L
.22272 .16207 L
.26171 .17814 L
.30316 .19521 L
.34309 .21166 L
.3815 .22749 L
.42237 .24433 L
.46172 .26054 L
.49955 .27613 L
.53984 .29273 L
.57861 .30871 L
.61984 .32569 L
.65954 .34205 L
.69774 .35779 L
.73838 .37454 L
.77751 .39066 L
.81909 .40779 L
.85916 .4243 L
.89771 .44018 L
.93871 .45708 L
.97619 .47252 L
s
.02381 .01472 m
.06244 .03594 L
.10458 .05909 L
.14415 .08083 L
.18221 .10173 L
.22272 .12399 L
.26171 .14541 L
.30316 .16818 L
.34309 .19011 L
.3815 .21122 L
.42237 .23367 L
.46172 .25529 L
.49955 .27607 L
.53984 .2982 L
.57861 .3195 L
.61984 .34215 L
.65954 .36396 L
.69774 .38495 L
.73838 .40728 L
.77751 .42877 L
.81909 .45162 L
.85916 .47363 L
.89771 .4948 L
.93871 .51733 L
.97619 .53792 L
s
.02381 .03652 m
.06244 .05774 L
.10458 .08089 L
.14415 .10263 L
.18221 .12353 L
.22272 .14579 L
.26171 .16721 L
.30316 .18998 L
.34309 .21191 L
.3815 .23302 L
.42237 .25547 L
.46172 .27709 L
.49955 .29787 L
.53984 .32 L
.57861 .3413 L
.61984 .36395 L
.65954 .38576 L
.69774 .40675 L
.73838 .42908 L
.77751 .45057 L
.81909 .47342 L
.85916 .49543 L
.89771 .51661 L
.93871 .53913 L
.97619 .55972 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{293.625, 181.312},
  ImageMargins->{{41, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004U0000]B000`400?l00000o`00003oT_ooool0
0ol0003oooooooooo`2@ooooo`00T_ooool00ol0003oooooooooo`2@ooooo`00ROooool3o`0000Ko
oooo00?o0000ooooooooool0T?ooool008[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2@ooooo`00P_ooool5o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2@ooooo`001oooool3o`00083ooooo00?o0000ooooooooool01Oooool3o`00093ooooo0009oooo
o`Co0000OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo093ooooo000:ooooo`Co
0000Noooool2o`0000Oooooo00?o0000ooooooooool0T?ooool000cooooo0_l0001looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0T?ooool000kooooo00Co0000oooooooooooooooo
0_l0001nooooo`03o`000?oooooooooo093ooooo000?ooooo`?o00000_ooool3o`0007_ooooo0_l0
002Aooooo`001oooool2o`0000Sooooo0ol00003ooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0T?ooool000Wooooo0_l00007ooooo`Co0000O?ooool00ol0003oooooooooo`2@oooo
o`002oooool00ol0003oooooooooo`06ooooo`?o0000Noooool00ol0003oooooooooo`2@ooooo`00
3?ooool00ol0003oooooooooo`07ooooo`;o00001Oooool4o`00077ooooo00?o0000ooooooooool0
T?ooool001Sooooo0_l00007ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0T?oo
ool001[ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`1]ooooo`;o0000TOoo
ool0017ooooo0ol00007ooooo`;o000000?oooooo`000?ooool0L_ooool00ol0003oooooooooo`2@
ooooo`005?ooool2o`0000Oooooo1?l00006ooooo`?o0000J?ooool00ol0003oooooooooo`2@oooo
o`005_ooool00ol0003oooooooooo`06ooooo`?o00002?ooool3o`0006Gooooo00?o0000oooooooo
ool0T?ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo093ooooo000Rooooo`;o0000K_ooool00ol0003oooooooooo`2@ooooo`007?ooool2
o`0000Kooooo1?l0000:ooooo`;o0000G_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooool0003o00002_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo093ooooo0007ooooo`?o00005Oooool2o`0000Kooooo0_l000000ooooooo0000o`000009oooo
o`?o0000F_ooool00ol0003oooooooooo`2@ooooo`002_ooool3o`0001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool0T?ooool000gooooo00?o0000ooooooooool06_ooool2o`0006Kooooo00?o0000ooooooooool0
T?ooool002cooooo00Co0000oooooooooooooooo0_l0000;ooooo`;o0000Doooool00ol0003ooooo
ooooo`2@ooooo`004_ooool2o`0001;ooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo0_l0
001Aooooo`;o0000TOooool001Cooooo0ol0000Aooooo`;o00001Oooool2o`0000?ooooo00?o0000
ooooooooool02_ooool2o`0004oooooo00?o0000ooooooooool0T?ooool001Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000G?ooool0
0ol0003oooooooooo`2@ooooo`00:oooool00ol0003oooooooooo`04ooooo`;o00005?ooool2o`00
03Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo
093ooooo000dooooo`03o`000?oooooooooo01?ooooo0_l0000aooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo093ooooo000Moooo
o`Co00003oooool2o`0000?ooooo0_l00003ooooo`;o00004?ooool00ol0003oooooooooo`0Woooo
o`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo0ol0002@
ooooo`008Oooool00ol0003oooooooooo`0>ooooo`;o00000oooool2o`0000?ooooo0_l0000?oooo
o`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo093ooooo000Rooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00Co0000oooo
oooooooo00001oooool4o`0000Kooooo00?o0000ooooooooool0T?ooool003Gooooo00?o0000oooo
ooooool00_ooool2o`0000?ooooo00?o0000ooooooooool04Oooool2o`0002Sooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo093ooooo000Woooo
o`?o00004_ooool2o`0001Oooooo0ol0000Vooooo`;o00002?ooool5o`0000Gooooo00?o0000oooo
ooooool0T?ooool002[ooooo0ol0000Aooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0T?ooool002gooooo00?o0000ooooooooool0
2_ooool2o`0000?ooooo0_l00005ooooo`;o0000B_ooool2o`00097ooooo000looooo`;o00000ooo
ool2o`0000Gooooo0_l0000Cooooo`?o0000<_ooool00ol0003oooooooooo`2@ooooo`00<_ooool2
o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo0ol0000_ooooo`03o`000?oooooooooo093ooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool2o`0001gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`2@ooooo`00=Oooool3o`0000kooooo0_l0001:ooooo`03o`000?oooooooooo093o
oooo000hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`00047ooooo
00?o0000ooooooooool0T?ooool004Cooooo0_l00003ooooo`;o00001_ooool2o`0001Gooooo0_l0
000Xooooo`;o0000TOooool003gooooo0_l00007ooooo`;o00000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo0ol0000Uooooo`03o`000?oooooooooo093ooooo000ooooo
o`;o00001oooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2@ooooo`00@Oooool2o`0000Oooooo00Go0000oooooooo
ooooooooo`000013ooooo`03o`000?oooooooooo093ooooo001?ooooo`;o00008_ooool2o`0001go
oooo00?o0000ooooooooool0T?ooool000Sooooo0ol0000mooooo`?o00001?ooool4o`000004oooo
ool0003o0000o`0000;ooooo0_l0000Jooooo`?o00006_ooool2o`0003cooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol0000looooo`?o00002?ooool000Wooooo00?o0000ooooooooool0
??ooool01?l0003oooooo`000?l00005ooooo`?o00000oooool01?l0003oooooooooooooool3o`00
01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0jooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo00Oooooo0000
0ooooooo0000o`000003o`0000?ooooo00?o0000ooooooooool0=Oooool5o`0000;ooooo00?o0000
ooooooooool00_l00006ooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00Oooooo0009ooooo`03o`000?oooooooooo03cooooo00Ko0000
oooooooooooo0000ooooool00006ooooo`04o`000?oooooo0000o`0002Kooooo0_l0000Booooo`03
o`000?oooooooooo03[ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Oooooo0009ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooo
oooo00001oooool4o`000003ooooool0003ooooo02Kooooo0_l0000@ooooo`03o`000?oooooooooo
03[ooooo00Co0000oooooooooooo00001oooool4o`0003gooooo00?o0000ooooooooool01oooool0
00Sooooo0_l0000nooooo`04o`000?ooooooooooo`0000Oooooo0_l00004ooooo`;o00002?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo03gooooo0_l00009ooooo`002Oooool0
0ol0003oooooooooo`0mooooo`;o00002?ooool5o`000004ooooool0003o0000o`0000Sooooo0_l0
000Mooooo`03o`000?oooooooooo00cooooo0_l0000looooo`;o00002?ooool5o`0003cooooo00?o
0000ooooooooool01oooool005Sooooo00?o0000ooooooooool00ol00008ooooo`;o0000:_ooool0
0ol0003oooooooooo`2@ooooo`00GOooool3o`0000Sooooo00?o0000ooooooooool07Oooool3o`00
00Oooooo00?o0000ooooooooool0T?ooool005gooooo1?l0000Zooooo`?o00001?ooool00ol0003o
ooooooooo`2@ooooo`00H?ooool3o`0002_ooooo00Go0000ooooooooooooooooo`00002Booooo`00
Hoooool00ol0003oooooooooo`07ooooo`;o00008oooool00ol0003oooooooooo`2@ooooo`00ool0
000Uo`00007ooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0ol00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;o00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01Oooooo0ol00008ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool01_ooool006Wooooo1?l0000Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0R_ooool006_ooooo00?o0000ooooool000002Oooool2o`0001Wooooo00?o0000ooooooooool0
T?ooool006cooooo0ol0000:ooooo`;o00005oooool00ol0003oooooooooo`09ooooo`;o0000QOoo
ool006kooooo0ol00002ooooo`;o00001_ooool2o`0001Gooooo0_l0000<ooooo`?o0000P_ooool0
06oooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Ooooool0077ooooo0_l00005ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0T?ooool007?ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Dooooo`;o0000N_ooool007Cooooo0_l0000<ooooo`;o00003_ooool00ol0003ooooooooo
o`0Fooooo`?o0000Moooool007Kooooo0ol00005ooooo`;o00001?ooool2o`0000cooooo0_l0000J
ooooo`03o`000?oooooooooo07Cooooo001hooooo`?o00001Oooool3o`0000?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2@ooooo`00NOooool4o`0000Kooooo00Go0000oooooooo
ooooooooo`00000:ooooo`03o`000?oooooooooo093ooooo001kooooo`?o00005?ooool00ol0003o
ooooooooo`0Nooooo`Co0000K_ooool007gooooo0_l00009ooooo`?o00001oooool00ol0003ooooo
ooooo`0Rooooo`;o0000K?ooool007oooooo00?o0000ooooooooool00_l00007ooooo`?o00001?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Wooooo0020ooooo`;o00000_ooool2
o`0000Sooooo0ol000000ooooooo0000o`00002Aooooo`00P_ooool2o`0000;ooooo00?o0000oooo
ooooool02?ooool2o`0002_ooooo0_l0001Uooooo`00Q?ooool01?l0003oooooooooool0000:oooo
o`?o0000:oooool3o`0006;ooooo0025ooooo`;o00002oooool00ol0003oooooooooo`02o`0002co
oooo0_l0001Pooooo`00Qoooool2o`0000Wooooo00Co0000oooooooooooooooo0ol0002<ooooo`00
ROooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00oooool2o`0008_ooooo
002:ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooooooo02cooooo0_l0
001Jooooo`00S?ooool2o`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02
o`0002_ooooo0ol0001Gooooo`00S_ooool00ol0003oooooooooo`02o`0000gooooo0ol0000[oooo
o`03o`000?oooooooooo05Cooooo001nooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00000oooool2o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool0Ooooool007gooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000=oooo
o`;o0000<_ooool3o`0004kooooo001mooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool00oooool3o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o0000;?ooool2o`00
04cooooo001mooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000003ooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`;o0000;?ooool00ol0
003oooooooooo`19ooooo`00OOooool01?l0003oooooooooool00007ooooo`Co00001_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1eooooo`00OOooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooooooo0_l0000Fooooo`03o`000?oooooooooo02gooooo0_l0
0015ooooo`00O_ooool2o`0000Sooooo1Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03oooool2o`0003Cooooo0ol00012ooooo`00T_ooool00ol0003oooooooooo`04oooo
o`;o00001Oooool2o`0000[ooooo0_l00005ooooo`Co0000;?ooool00ol0003oooooooooo`0ooooo
o`00T_ooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l00007ooooo`;o
0000:oooool00ol0003oooooooooo`0nooooo`00T_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Wooooo002Booooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`03o`000?oo
oooooooo047ooooo0ol0000iooooo`00T_ooool00ol0003oooooooooo`0:ooooo`;o00007Oooool2
o`0002cooooo0ol0000fooooo`00T_ooool00ol0003oooooooooo`0<ooooo`;o00004_ooool2o`00
00Wooooo0ol0000/ooooo`03o`000?oooooooooo03?ooooo002Booooo`03o`000?oooooooooo00ko
oooo0_l00005ooooo`;o00002oooool2o`0000[ooooo0_l0001Pooooo`00T_ooool2o`00017ooooo
0_l00005ooooo`;o00002oooool00ol0003oooooooooo`0hooooo`;o0000;oooool009;ooooo00?o
0000ooooooooool04_ooool2o`0000Gooooo0_l0000:ooooo`03o`000?oooooooooo03Wooooo0ol0
000/ooooo`00T_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool00ol0003oooooooooo`0F
ooooo`;o0000;_ooool00ol0003oooooooooo`0Yooooo`00T_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01gooooo0ol0001Gooooo`00T_ooool00ol0003oooooooooo`0Gooooo`;o
00001oooool2o`0000Sooooo0ol0000<ooooo`03o`000?oooooooooo05Cooooo002Booooo`;o0000
6_ooool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`0003_ooooo0_l0000Tooooo`00T_oo
ool00ol0003oooooooooo`0Jooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00gooooo0ol0000Zooooo`?o00008Oooool009;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0_l0000[ooooo`03o`000?oooooo
oooo01kooooo002Booooo`03o`000?oooooooooo01gooooo0_l0000Uooooo`03o`000?oooooooooo
04Wooooo002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool2o`0003oo
oooo0_l0000Iooooo`00T_ooool00ol0003oooooooooo`0Pooooo`;o00002?ooool00ol0003ooooo
ooooo`09ooooo`;o00004Oooool2o`0002cooooo0ol0000Fooooo`00T_ooool2o`0002?ooooo00?o
0000ooooooooool01_ooool2o`0000_ooooo00?o0000ooooooooool04?ooool3o`0002cooooo00?o
0000ooooooooool04oooool009;ooooo00?o0000ooooooooool08oooool2o`0000Sooooo0_l0000:
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?oooool009;ooooo00?o0000oooo
ooooool09Oooool2o`0000Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0noooo
o`00ROooool3o`0000Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Eooooo`?o
00003_ooool008[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`;o0000
5?ooool2o`0001Cooooo0ol0000[ooooo`?o00002oooool008[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`;o00005Ooo
ool3o`0002_ooooo00?o0000ooooooooool02?ooool008[ooooo00?o0000ooooooooool01Oooool3
o`0002_ooooo0_l00009ooooo`?o00002Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03?ooooo002:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool008Wo
oooo0_l00007ooooo`03o`000?oooooooooo02kooooo0_l0000_ooooo`;o0000;oooool008[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`;o00005_ooool2o`0001Oooooo
0_l0000]ooooo`00T_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo0_l0
000:ooooo`;o00005oooool00ol0003oooooooooo`0Zooooo`00T_ooool00ol0003oooooooooo`0c
ooooo`;o00002oooool2o`0000[ooooo0_l0000Fooooo`03o`000?oooooooooo02Wooooo002Boooo
o`;o0000=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0?oooool009;ooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo00?o0000oooooooo
ool09?ooool2o`0002Cooooo002Booooo`03o`000?oooooooooo03Sooooo0_l0000booooo`?o0000
8Oooool009;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Fooooo`;o00006_oo
ool00ol0003oooooooooo`0Nooooo`00T_ooool00ol0003oooooooooo`0kooooo`;o00002oooool2
o`0000_ooooo0_l0000iooooo`00T_ooool2o`0003kooooo0_l0000;ooooo`;o00002oooool00ol0
003oooooooooo`0Kooooo`;o00006Oooool009;ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0:ooooo`;o00002_ooool00ol0003oooooooooo`0Looooo`?o00005_ooool009;ooooo
00?o0000ooooooooool0@?ooool2o`0000cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Cooooo`00T_ooool00ol0003oooooooooo`12ooooo`;o0000C?ooool009;ooooo00?o0000
ooooooooool0A?ooool2o`0000gooooo0_l00008ooooo`;o0000<Oooool009;ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0<ooooo`;o00002?ooool3o`0001gooooo0ol0000>oooo
o`00T_ooool2o`0004Sooooo0_l0000>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool07Oooool3o`0000_ooooo002Booooo`03o`000?oooooooooo04Wooooo0_l0000=ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool02?ooool009;ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`12ooooo`00T_ooool00ol0003oooooooooo`1<ooooo`;o00006Oooool2
o`0002Oooooo002Booooo`03o`000?oooooooooo04kooooo0_l0000=ooooo`;o00002_ooool2o`00
02Gooooo002Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo00?o0000ooooooooool08_ooool009;ooooo0_l0001Booooo`;o00003_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo027ooooo002Booooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`00T_ooool00ol0003oooooooooo`1D
ooooo`;o0000>_ooool007gooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00006oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool06?ooool2o`0001gooooo001nooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
05Oooooo0_l0000>ooooo`;o00002_ooool2o`0001_ooooo001nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool3o`0005Wooooo00?o0000ooooooooool03Oooool3o`0000Wo
oooo00?o0000ooooooooool06?ooool007kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05[ooooo0_l0000@ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05oooool007kooooo00?o0000ooooooooool01oooool4o`0000Kooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0aooooo`00OOooool2o`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Mooooo`;o00007?ooool2o`0001?ooooo001noooo
o`03o`000?oooooooooo00Oooooo1Ol00005ooooo`03o`000?oooooooooo05oooooo0_l0000@oooo
o`;o00002_ooool2o`00017ooooo002Booooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool03oooool2o`0000[ooooo0_l0000?ooooo`00T_ooool2o`0006?ooooo0_l0000Aooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03?ooool009;ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo002Booooo`03o`000?oooooo
oooo06Gooooo0_l0000Yooooo`00T_ooool00ol0003oooooooooo`1Wooooo`;o00007Oooool00ol0
003oooooooooo`07ooooo`00T_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00oo
oooo1?l00008ooooo`03o`000?oooooooooo00Kooooo002Booooo`03o`000?oooooooooo06[ooooo
0_l0000Cooooo`03o`000?oooooooooo00kooooo002Booooo`;o0000KOooool2o`0001;ooooo00?o
0000ooooooooool03Oooool009;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00cooooo002Booooo`03o`000?oooooooooo06oooooo0_l0000Ooooo
o`00T_ooool00ol0003oooooooooo`1aooooo`;o00004oooool00ol0003oooooooooo`07ooooo`00
T_ooool00ol0003oooooooooo`1cooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`00T_oo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo01Sooooo002Booooo`;o0000Moooool2
o`0001Sooooo002Booooo`03o`000?oooooooooo07Sooooo0_l0000Fooooo`00T_ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo01?ooooo002Booooo`03o`000?oooooooooo07_ooooo
0_l0000Cooooo`00T_ooool00ol0003oooooooooo`1mooooo`;o00004Oooool009;ooooo0_l00020
ooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?oooooooooo083ooooo0_l0000>oooo
o`00T_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00_ooooo0028ooooo`Go0000
1Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00[ooooo0029ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0Q?ooool2o`0000[ooooo002:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`00Roooool0
0ol0003oooooooooo`04ooooo`?o0000Qoooool00ol0003oooooooooo`06ooooo`00R?ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0T?ooool008Sooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo093ooooo0029ooooo`?o00001_ooool00ol0
003oooooooooo`2@ooooo`00T_ooool00ol0003oooooooooo`2@ooooo`00\
\>"],
  ImageRangeCache->{{{151.688, 385.562}, {424.812, 280.812}} -> {-2.42719, \
5.07926, 0.00722849, 0.0175439}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["M\[EAcute]thode de Newton symbolique", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[TextData[{
  "L'approche symbolique est rendue possible par cette particularit\[EAcute] \
de la m\[EAcute]thode de Newton de s'appliquer aux espaces de Banach, \
autrement dit aux fonctions aussi bien qu'aux nombres. Sous certaines \
conditions que nous ne pr\[EAcute]ciserons pas ici, la suite  ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u\_\(n + 1\)\)], "Informal"], "Informal"],
  StyleBox["\[MediumSpace]=\[MediumSpace]", "Informal"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u\_n\)], "Informal"], "Informal"],
  StyleBox["\[MediumSpace]-\[MediumSpace]", "Informal"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`DF\^\(-1\)\)], "Informal"], "Informal"],
  StyleBox["[", "Informal"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u\_n\)], "Informal"], "Informal"],
  StyleBox["].F[", "Informal"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u\_n\)], "Informal"], "Informal"],
  StyleBox["]", "Informal"],
  "  o\[UGrave] ",
  Cell[BoxData[
      \(TraditionalForm\`u\_0\)]],
  " d\[EAcute]signe une approximation initiale et ",
  Cell[BoxData[
      \(TraditionalForm\`DF\^\(-1\)\)]],
  " l'inverse de la d\[EAcute]riv\[EAcute]e de Fr\[EAcute]chet de F, converge \
vers une solution de l'\[EAcute]quation ",
  StyleBox["F[u]==0", "Informal"],
  ". ",
  StyleBox["Dans le cas d'une \[EAcute]quation fonctionnelle ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["F[x,\[MediumSpace]a", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["]==0", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" o\[UGrave] x d\[EAcute]signe l'inconnue et a",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" un (ou des) param\[EGrave]tre(s), la r\[EAcute]currence se r\
\[EAcute]duit \[AGrave]\[NonBreakingSpace]:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`F[x\_n, a\_i]\/\(\[PartialD]F/\[PartialD]x[x\_n, \
a\_i]\)\)]]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1],

Cell[TextData[{
  "les ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " \[EAcute]tant fonctions des ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ". Cette formule se traduit par un algorithme it\[EAcute]ratif assez \
facilement r\[EAcute]alis\[EAcute] en Mathematica avec l'op\[EAcute]rateur ",
  StyleBox["Nest", "InlineOutput"],
  ". Sur un exemple simple (l'\[EAcute]quation ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckE]\^\(\(-\[Mu]\)\ x\)\)], "Informal"], 
    "Informal"],
  StyleBox["-x==0", "Informal"],
  " sur ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalR]\^+\)\)]],
  "), nous allons comparer graphiquement le r\[EAcute]sultat obtenu de cette \
fa\[CCedilla]on (",
  Cell[BoxData[
      \(TraditionalForm\`1\^e\)]],
  " et ",
  Cell[BoxData[
      \(TraditionalForm\`2\^e\)]],
  " approximants) avec celui obtenu par ",
  StyleBox["FindRoot", "InlineOutput"],
  " (m\[EAcute]thode de Newton num\[EAcute]rique)."
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[BoxData[{
    \(\(iterator[
          x_, \[Mu]_] = \[IndentingNewLine]x - \((Exp[\(-\[Mu]\)\ x] - x)\)/
            D[Exp[\(-\[Mu]\)\ x] - x, x];\)\), "\n", 
    \(NewtonApproximation[\[Mu]_, x0_, n_] := 
      Nest[iterator[#, \[Mu]] &, x0, n]\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewtonApproximation[\[Mu], 0, 1]\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \(\(-\(1\/\(\(-1\) - \[Mu]\)\)\)\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        ListPlot[
          Table[{\[Mu], 
              x /. FindRoot[Exp[\(-\[Mu]\)\ x] == x, {x, 0}]}, {\[Mu], 0, 10, 
              1}], \[IndentingNewLine]PlotStyle \[Rule] {PointSize[0.02]}, 
          DisplayFunction -> Identity], 
        Plot[Evaluate[NestList[iterator[#, \[Mu]] &, 0, 2]], {\[Mu], 0, 10}, 
          DisplayFunction -> Identity], 
        DisplayFunction -> $DisplayFunction\n];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .60332 Mdot
.11905 .34854 Mdot
.21429 .26564 Mdot
.30952 .22071 Mdot
.40476 .19162 Mdot
.5 .1709 Mdot
.59524 .15523 Mdot
.69048 .14289 Mdot
.78571 .13286 Mdot
.88095 .12452 Mdot
.97619 .11746 Mdot
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.49955 .01472 L
.53984 .01472 L
.57861 .01472 L
.61984 .01472 L
.65954 .01472 L
.69774 .01472 L
.73838 .01472 L
.77751 .01472 L
.81909 .01472 L
.85916 .01472 L
.89771 .01472 L
.93871 .01472 L
.97619 .01472 L
s
.02381 .60332 m
.04262 .50625 L
.06244 .43345 L
.08255 .37877 L
.10458 .33321 L
.12579 .29895 L
.14509 .27362 L
.18408 .23411 L
.22401 .20446 L
.26243 .18263 L
.30329 .16431 L
.34264 .1501 L
.38048 .13876 L
.42077 .12861 L
.45954 .12029 L
.50076 .11269 L
.54047 .10633 L
.57866 .10095 L
.61931 .09587 L
.65844 .09152 L
.70002 .08738 L
.74009 .08379 L
.77864 .08066 L
.81964 .07763 L
.85913 .07496 L
.8971 .07259 L
.93752 .07028 L
.97619 .06822 L
s
.02381 .60332 m
.03279 .55457 L
.04262 .51274 L
.06244 .45056 L
.08426 .40214 L
.10458 .36803 L
.14357 .3199 L
.18502 .28341 L
.22495 .2567 L
.26336 .23613 L
.30423 .21812 L
.34358 .20356 L
.38141 .19154 L
.4217 .18041 L
.46047 .17101 L
.5017 .16217 L
.54141 .1546 L
.5796 .14803 L
.62025 .14172 L
.65938 .13619 L
.70096 .13083 L
.74102 .12611 L
.77957 .12192 L
.82058 .11781 L
.86007 .11414 L
.89804 .11085 L
.93846 .10759 L
.97619 .10474 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{227.875, 140.75},
  ImageMargins->{{102.562, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000L2000`400?l00000o`00003o]_ooool0
0;Kooooo000_ooooo`?o00007oooool00ol0003oooooooooo`0Kooooo`;o00007Oooool3o`0001_o
oooo0ol00003ooooo`03o`000?oooooooooo007ooooo000`ooooo`03o`000?oooooooooo01cooooo
0ol0000Looooo`03o`000?oooooo000001gooooo00?o0000ooooool000007?ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool0037ooooo00?o0000ooooooooool06oooool00ol0003o
ooooo`00000Looooo`?o00007_ooool00ol0003oooooooooo`0Kooooo`07o`000?oooooooooooooo
ool0003oooooo`000002ooooo`00<Oooool00ol0003oooooooooo`0Looooo`;o00007?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooo000001cooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000;ooooo000_ooooo`?o00007oooool00ol0003oooooooooo`0Kooooo`;o00007Oooool3
o`0001_ooooo0_l00004ooooo`03o`000?oooooooooo007ooooo000@ooooo`03o`000?oooooooooo
0:?ooooo000@ooooo`03o`000?oooooooooo0:?ooooo000<ooooojWo00000Oooool0013ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo000@
ooooo`03o`000?oooooooooo0:?ooooo000@ooooo`03o`000?oooooooooo0:?ooooo000@ooooo`03
o`000?oooooooooo0:?ooooo000@ooooo`;o0000Y?ooool0013ooooo00?o0000ooooooooool0Xooo
ool0013ooooo00?o0000ooooooooool0Xoooool0013ooooo00?o0000ooooooooool0Xoooool0013o
oooo00?o0000ooooooooool0V_ooool4o`0000Gooooo000@ooooo`;o0000QooooolDo`0000Wooooo
000@ooooo`03o`000?oooooooooo07Wooooo3Ol0000Mooooo`004?ooool00ol0003oooooooooo`1/
ooooo`go0000:_ooool0013ooooo00?o0000ooooooooool0IOooool7o`0003Oooooo000@ooooo`03
o`000?oooooooooo05kooooo1ol0000nooooo`004?ooool2o`0005Sooooo1ol0000looooo`Co0000
1Oooool0013ooooo00?o0000ooooooooool0DOooool6o`0003Kooooo3Ol00009ooooo`004?ooool0
0ol0003oooooooooo`1:ooooo`Oo0000=Oooool7o`0000oooooo0ol00004ooooo`004?ooool00ol0
003oooooooooo`13ooooo`Oo0000;oooool=o`0000Kooooo0ol0000=ooooo`?o00001?ooool00003
ooooool0003ooooo00?ooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo
03kooooo1Ol0000_ooooo`Oo00000oooool3o`0000gooooo0ol0000=ooooo`?o00001?ooool00003
o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool2o`0003cooooo0ol0000^ooooo`Ko
00002_ooool3o`0000gooooo0ol0000Dooooo`0000?o0000ooooool000002Oooool01Ol0003ooooo
oooooooooooo000003[ooooo0ol0000Zooooo`[o00003Oooool3o`0002Cooooo00000ol0003ooooo
o`000009ooooo`05o`000?ooooooooooooooool00000=oooool3o`0002Kooooo1ol00007ooooo`?o
0000=?ooool00003ooooool0003ooooo00Oooooo0ol00003ooooo`03o`000?oooooooooo037ooooo
1?l0000Rooooo`So00003Oooool3o`0003Cooooo000@ooooo`03o`000?oooooooooo02kooooo0ol0
000Pooooo`Ko00001Oooool3o`0004Cooooo000@ooooo`;o0000;?ooool3o`0001cooooo1ol0000;
ooooo`?o0000A?ooool0013ooooo00?o0000ooooooooool0:?ooool3o`0001[ooooo1Ol00002oooo
o`?o0000E?ooool0013ooooo00?o0000ooooooooool09_ooool2o`0001[ooooo0ol00007ooooo`?o
0000E?ooool0013ooooo00?o0000ooooooooool09?ooool2o`0001Sooooo1?l0000:ooooo`?o0000
E?ooool0013ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Eooooo`Co0000I?oo
ool0013ooooo0_l0000Rooooo`;o00005Oooool3o`000004ooooool0003o0000o`0006Cooooo000@
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool3o`0000Cooooo0ol0001T
ooooo`004?ooool00ol0003oooooooooo`0Nooooo`;o00004Oooool4o`0006kooooo000@ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool3o`0007;ooooo000@ooooo`03o`00
0?oooooooooo01_ooooo0_l0000>ooooo`Co0000M?ooool0013ooooo0_l0000Kooooo`03o`000?oo
oooooooo00_ooooo0ol000001?oooooo0000o`000?l0001dooooo`004?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00[ooooo0_l00004ooooo`?o0000M?ooool0013ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`09ooooo`;o0000OOooool0013ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07gooooo00000ooooooo
0000ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000Hoooo
o`03o`000?oooooooooo00Sooooo0_l00020ooooo`0000?o0000ooooool000001oooool3o`0000?o
oooo0_l0000Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0P?ooool00003o`00
0?oooooo000000Oooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Gooooo1?l00023ooooo`0000?o0000ooooool000002?ooool2o`0000?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`?o0000Q?ooool00003ooooool0003o
oooo00Wooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Kooooo1?l0
0024ooooo`004?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo0_l00028
ooooo`004?ooool2o`0001;ooooo00?o0000ooooooooool00oooool2o`0008[ooooo000@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2:ooooo`00
4?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Roooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08cooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2=ooooo`004?ooool2o`0000kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2>ooooo`004?ooool00ol0003oooooooooo`0=ooooo`05o`000?oooooooooooooo
ool00000TOooool0013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08oooooo000@ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooo
ooooo`00002Booooo`004?ooool2o`0000cooooo00Go0000ooooooooooooooooo`00002Cooooo`00
4?ooool00ol0003oooooooooo`0;ooooo`Co0000U?ooool0013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooo`000002o`0009Cooooo000@ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooool000000_l0002Dooooo`0000?oooooo`000?ooool00oooool00ol0003oooooooooo`02oooo
o`;o00000oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0009Kooooo00000ol0
003oooooo`000007ooooo`03o`000?oooooo000000?ooooo0_l00009ooooo`04o`000?oooooooooo
o`0009Oooooo00000ol0003oooooo`000007ooooo`?o00000oooool00ol0003oooooooooo`08oooo
o`04o`000?ooooooooooo`0009Oooooo00000ol0003oooooo`000007ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0002Hooooo`0000?oooooo`00
0?ooool02?ooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00002Ioooo
o`004?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0009Wooooo000@ooooo`;o
00001oooool00ol0003oooooo`00002Jooooo`004?ooool00ol0003oooooooooo`06ooooo`;o0000
Voooool0013ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00002Kooooo`004?ooool0
0ol0003oooooooooo`05ooooo`;o0000W?ooool0013ooooo00?o0000ooooooooool01Oooool2o`00
09cooooo000@ooooo`;o00001Oooool00ol0003oooooo`00002Looooo`004?ooool00ol0003ooooo
ooooo`04ooooo`;o0000WOooool0013ooooo00?o0000ooooooooool01?ooool2o`0009gooooo000@
ooooo`03o`000?oooooooooo00Cooooo0_l0002Mooooo`004?ooool00ol0003oooooooooo`03oooo
o`;o0000W_ooool0013ooooo0_l00004ooooo`;o0000W_ooool0013ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2Mooooo`004?ooool00ol0003oooooooooo`02ooooo`;o0000Wooo
ool0013ooooo00?o0000ooooooooool00_ooool2o`0009oooooo00000ooooooo0000ooooo`03oooo
o`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo09kooooo00000ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo0_l00002oooo
o`;o0000X?ooool00003o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`000:3ooooo00000ol0003oooooo`000007ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`00002Qooooo`0000?oooooo`000?ooool01oooool3o`0000?o
oooo00?o0000ooooooooool00_l0002Qooooo`004?ooool00ol0003oooooooooo`02o`000:7ooooo
000@ooooo`;o000000?oooooo`000?ooool0XOooool0013ooooo00Co0000oooooooooooo0000X_oo
ool0013ooooo00Co0000oooooooooooo0000X_ooool0013ooooo00Co0000ooooool0003o0000X_oo
ool0013ooooo00?o0000ooooool00000Xoooool0013ooooo0ol0002Sooooo`004?ooool00ol0003o
ooooo`00002Sooooo`004?ooool00ol0003oooooo`00002Sooooo`004?ooool3o`000:?ooooo000@
ooooo`?o0000Xoooool0013ooooo0_l0002Tooooo`004?ooool2o`000:Cooooo000@ooooo`;o0000
Y?ooool0013ooooo0_l0002Tooooo`002_ooool3o`0000;ooooo0ol0002Tooooo`002oooool01?l0
003oooooooooooooool3o`000:Cooooo000;ooooo`04o`000?ooooooooooooooo`?o0000Y?ooool0
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Sooooo`002_ooool2o`000:[o
oooo0000\
\>"],
  ImageRangeCache->{{{200.938, 382.188}, {508.562, 397}} -> {-13.6293, \
3.92944, 0.0501108, 0.0081081}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Dans le cas d'un syst\[EGrave]me d'\[EAcute]quations ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`F\_i\)], "Informal"], "Informal"],
  StyleBox["[", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\)], "Informal"], "Informal"],
  StyleBox[",\[MediumSpace]a", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["k", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["]==0", "Informal",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" o\[UGrave] ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  StyleBox[" d\[EAcute]signe le vecteur des inconnues ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  StyleBox[", la d\[EAcute]riv\[EAcute]e de Fr\[EAcute]chet se ram\[EGrave]ne \
au jacobien J et la r\[EAcute]currence s'exprime ainsi\[NonBreakingSpace]:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`J[x\_n, a\_k]\^\(-1\) . F[x\_n, a\_k]\)]]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1],

Cell["\<\
Cette formule se traduit par un algorithme it\[EAcute]ratif \
analogue au pr\[EAcute]c\[EAcute]dent. Nous allons l'appliquer \[AGrave] une \
recherche d'extremum\[NonBreakingSpace]; en effet, chercher un extremum de \
fonction diff\[EAcute]rentiable revient \[AGrave] d\[EAcute]terminer les z\
\[EAcute]ros de sa d\[EAcute]riv\[EAcute]e\[NonBreakingSpace]; illustrons \
cette id\[EAcute]e avec la fonction de Rosenbrock.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell["Rosenbrock[p_,x_,y_]:=(x-1)^2+p(x^2-y)^2", "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{Plot3D[
              Rosenbrock[10, x, y], {x, \(-1.2\), 1.3}, {y, \(-0.5\), 1.5}, 
              Ticks \[Rule] None, DisplayFunction \[Rule] Identity], 
            ContourPlot[
              Rosenbrock[10, x, y], \[IndentingNewLine]{x, \(-1.2\), 
                1.3}, {y, \(-0.5\), 1.5}, 
              FrameTicks \[Rule] {{\(-1\), 0, 1}, {0, 1}, None, None}, 
              ContourShading \[Rule] False, 
              DisplayFunction \[Rule] Identity]}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.68874 0 m
.96935 .42924 L
s
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.652 .743 .917 r
.38196 .61113 .40416 .63124 .44104 .62772 .41932 .60085 Metetra
.497 .628 .909 r
.41932 .60085 .44104 .62772 .47842 .6367 .45695 .60403 Metetra
.438 .556 .877 r
.45695 .60403 .47842 .6367 .51676 .65117 .49538 .61361 Metetra
.46 .538 .85 r
.49538 .61361 .51676 .65117 .55622 .66523 .53486 .6237 Metetra
.519 .55 .827 r
.53486 .6237 .55622 .66523 .59673 .674 .57535 .62952 Metetra
.585 .574 .807 r
.57535 .62952 .59673 .674 .63801 .67387 .61665 .62755 Metetra
.643 .598 .788 r
.61665 .62755 .63801 .67387 .67968 .66271 .65843 .61571 Metetra
.69 .62 .773 r
.65843 .61571 .67968 .66271 .72134 .64002 .70031 .59356 Metetra
.726 .639 .762 r
.70031 .59356 .72134 .64002 .76267 .60708 .74201 .56231 Metetra
.751 .657 .757 r
.74201 .56231 .76267 .60708 .8035 .56675 .7834 .52479 Metetra
.765 .674 .762 r
.7834 .52479 .8035 .56675 .84397 .52338 .82461 .48526 Metetra
.764 .69 .781 r
.82461 .48526 .84397 .52338 .88457 .48257 .86615 .44925 Metetra
.732 .703 .824 r
.86615 .44925 .88457 .48257 .92621 .45105 .90896 .42352 Metetra
.609 .692 .902 r
.90896 .42352 .92621 .45105 .97039 .4369 .95457 .4163 Metetra
.713 .778 .903 r
.35908 .59285 .38196 .61113 .41932 .60085 .39702 .57574 Metetra
.565 .677 .914 r
.39702 .57574 .41932 .60085 .45695 .60403 .435 .57311 Metetra
.489 .599 .889 r
.435 .57311 .45695 .60403 .49538 .61361 .47361 .57782 Metetra
.492 .569 .861 r
.47361 .57782 .49538 .61361 .53486 .6237 .51316 .584 Metetra
.537 .572 .838 r
.51316 .584 .53486 .6237 .57535 .62952 .5537 .58691 Metetra
.594 .589 .816 r
.5537 .58691 .57535 .62952 .61665 .62755 .59507 .58312 Metetra
.646 .609 .797 r
.59507 .58312 .61665 .62755 .65843 .61571 .63698 .57061 Metetra
.69 .629 .782 r
.63698 .57061 .65843 .61571 .70031 .59356 .67911 .54896 Metetra
.723 .647 .772 r
.67911 .54896 .70031 .59356 .74201 .56231 .7212 .51937 Metetra
.746 .664 .769 r
.7212 .51937 .74201 .56231 .7834 .52479 .76314 .4846 Metetra
.757 .68 .777 r
.76314 .4846 .7834 .52479 .82461 .48526 .80509 .44884 Metetra
.75 .696 .8 r
.80509 .44884 .82461 .48526 .86615 .44925 .84756 .4176 Metetra
.702 .706 .851 r
.84756 .4176 .86615 .44925 .90896 .42352 .89152 .39768 Metetra
.524 .672 .931 r
.89152 .39768 .90896 .42352 .95457 .4163 .93856 .39752 Metetra
.764 .804 .885 r
.33542 .57645 .35908 .59285 .39702 .57574 .37409 .55239 Metetra
.626 .719 .913 r
.37409 .55239 .39702 .57574 .435 .57311 .41251 .54393 Metetra
.539 .64 .898 r
.41251 .54393 .435 .57311 .47361 .57782 .45138 .54379 Metetra
.524 .6 .872 r
.45138 .54379 .47361 .57782 .51316 .584 .49108 .54607 Metetra
.555 .594 .848 r
.49108 .54607 .51316 .584 .5537 .58691 .53172 .54611 Metetra
.603 .605 .826 r
.53172 .54611 .5537 .58691 .59507 .58312 .5732 .54053 Metetra
.65 .621 .807 r
.5732 .54053 .59507 .58312 .63698 .57061 .61528 .52735 Metetra
.69 .638 .793 r
.61528 .52735 .63698 .57061 .67911 .54896 .65768 .50619 Metetra
.721 .655 .784 r
.65768 .50619 .67911 .54896 .7212 .51937 .70017 .4782 Metetra
.741 .671 .783 r
.70017 .4782 .7212 .51937 .76314 .4846 .74267 .44613 Metetra
.747 .687 .793 r
.74267 .44613 .76314 .4846 .80509 .44884 .78536 .41411 Metetra
.731 .702 .823 r
.78536 .41411 .80509 .44884 .84756 .4176 .82875 .38762 Metetra
.661 .706 .881 r
.82875 .38762 .84756 .4176 .89152 .39768 .87386 .37355 Metetra
.407 .632 .946 r
.87386 .37355 .89152 .39768 .93856 .39752 .92232 .38058 Metetra
.805 .823 .865 r
.31091 .56196 .33542 .57645 .37409 .55239 .35044 .53083 Metetra
.681 .755 .907 r
.35044 .53083 .37409 .55239 .41251 .54393 .38941 .51648 Metetra
.587 .678 .903 r
.38941 .51648 .41251 .54393 .45138 .54379 .42864 .51148 Metetra
.557 .632 .881 r
.42864 .51148 .45138 .54379 .49108 .54607 .46856 .5099 Metetra
.574 .617 .858 r
.46856 .5099 .49108 .54607 .53172 .54611 .50936 .50709 Metetra
.613 .622 .836 r
.50936 .50709 .53172 .54611 .5732 .54053 .551 .49972 Metetra
.654 .634 .818 r
.551 .49972 .5732 .54053 .61528 .52735 .59328 .48588 Metetra
.69 .649 .804 r
.59328 .48588 .61528 .52735 .65768 .50619 .63598 .46517 Metetra
.717 .664 .796 r
.63598 .46517 .65768 .50619 .70017 .4782 .67888 .43877 Metetra
.734 .679 .797 r
.67888 .43877 .70017 .4782 .74267 .44613 .72195 .40935 Metetra
.735 .695 .812 r
.72195 .40935 .74267 .44613 .78536 .41411 .76536 .38103 Metetra
.708 .707 .847 r
.76536 .38103 .78536 .41411 .82875 .38762 .80967 .3593 Metetra
.606 .701 .911 r
.80967 .3593 .82875 .38762 .87386 .37355 .85592 .35115 Metetra
.252 .563 .936 r
.85592 .35115 .87386 .37355 .92232 .38058 .90581 .36556 Metetra
.838 .836 .844 r
.28545 .54946 .31091 .56196 .35044 .53083 .326 .51108 Metetra
.729 .784 .897 r
.326 .51108 .35044 .53083 .38941 .51648 .36564 .49077 Metetra
.634 .714 .905 r
.36564 .49077 .38941 .51648 .42864 .51148 .40531 .48089 Metetra
.591 .663 .889 r
.40531 .48089 .42864 .51148 .46856 .5099 .44553 .47544 Metetra
.595 .641 .867 r
.44553 .47544 .46856 .5099 .50936 .50709 .48656 .4698 Metetra
.623 .639 .846 r
.48656 .4698 .50936 .50709 .551 .49972 .5284 .46065 Metetra
.658 .648 .828 r
.5284 .46065 .551 .49972 .59328 .48588 .57093 .44614 Metetra
.689 .66 .816 r
.57093 .44614 .59328 .48588 .63598 .46517 .61394 .42587 Metetra
.713 .674 .81 r
.61394 .42587 .63598 .46517 .67888 .43877 .65727 .40102 Metetra
.726 .688 .814 r
.65727 .40102 .67888 .43877 .72195 .40935 .7009 .37422 Metetra
.72 .702 .833 r
.7009 .37422 .72195 .40935 .76536 .38103 .74504 .34959 Metetra
.677 .711 .874 r
.74504 .34959 .76536 .38103 .80967 .3593 .79026 .33264 Metetra
.53 .686 .938 r
.79026 .33264 .80967 .3593 .85592 .35115 .83764 .3305 Metetra
.062 .46 .884 r
.83764 .3305 .85592 .35115 .90581 .36556 .88896 .35251 Metetra
.865 .845 .823 r
.25894 .539 .28545 .54946 .326 .51108 .30067 .49318 Metetra
.77 .808 .883 r
.30067 .49318 .326 .51108 .36564 .49077 .34112 .46681 Metetra
.677 .746 .904 r
.34112 .46681 .36564 .49077 .40531 .48089 .38133 .452 Metetra
.624 .694 .895 r
.38133 .452 .40531 .48089 .44553 .47544 .42193 .44269 Metetra
.616 .666 .876 r
.42193 .44269 .44553 .47544 .48656 .4698 .46325 .4342 Metetra
.634 .658 .856 r
.46325 .4342 .48656 .4698 .5284 .46065 .50535 .42329 Metetra
.662 .662 .84 r
.50535 .42329 .5284 .46065 .57093 .44614 .54815 .4081 Metetra
.689 .672 .828 r
.54815 .4081 .57093 .44614 .61394 .42587 .59151 .38826 Metetra
.708 .684 .825 r
.59151 .38826 .61394 .42587 .65727 .40102 .63528 .36492 Metetra
.715 .697 .832 r
.63528 .36492 .65727 .40102 .7009 .37422 .67948 .34073 Metetra
.7 .71 .855 r
.67948 .34073 .7009 .37422 .74504 .34959 .72434 .31978 Metetra
.636 .713 .902 r
.72434 .31978 .74504 .34959 .79026 .33264 .77046 .30765 Metetra
.426 .655 .955 r
.77046 .30765 .79026 .33264 .83764 .3305 .81896 .31166 Metetra
0 .328 .785 r
.81896 .31166 .83764 .3305 .88896 .35251 .87171 .34154 Metetra
.886 .851 .803 r
.23126 .53068 .25894 .539 .30067 .49318 .27435 .47719 Metetra
.805 .826 .868 r
.27435 .47719 .30067 .49318 .34112 .46681 .31574 .44462 Metetra
.716 .775 .899 r
.31574 .44462 .34112 .46681 .38133 .452 .35661 .42483 Metetra
.656 .723 .898 r
.35661 .42483 .38133 .452 .42193 .44269 .39768 .41161 Metetra
.637 .691 .884 r
.39768 .41161 .42193 .44269 .46325 .4342 .43935 .40029 Metetra
.646 .678 .866 r
.43935 .40029 .46325 .4342 .50535 .42329 .48176 .3876 Metetra
.666 .678 .852 r
.48176 .3876 .50535 .42329 .54815 .4081 .52489 .37172 Metetra
.687 .685 .842 r
.52489 .37172 .54815 .4081 .59151 .38826 .56861 .35229 Metetra
.702 .695 .841 r
.56861 .35229 .59151 .38826 .63528 .36492 .61284 .33046 Metetra
.702 .707 .851 r
.61284 .33046 .63528 .36492 .67948 .34073 .65762 .30886 Metetra
.675 .717 .88 r
.65762 .30886 .67948 .34073 .72434 .31978 .70319 .2916 Metetra
.581 .709 .93 r
.70319 .2916 .72434 .31978 .77046 .30765 .75021 .28436 Metetra
.289 .6 .951 r
.75021 .28436 .77046 .30765 .81896 .31166 .79982 .29467 Metetra
0 .186 .653 r
.79982 .29467 .81896 .31166 .87171 .34154 .854 .33275 Metetra
.903 .854 .784 r
.20229 .52461 .23126 .53068 .27435 .47719 .24695 .46314 Metetra
.834 .841 .851 r
.24695 .46314 .27435 .47719 .31574 .44462 .28943 .42422 Metetra
.752 .8 .891 r
.28943 .42422 .31574 .44462 .35661 .42483 .33107 .39937 Metetra
.688 .751 .9 r
.33107 .39937 .35661 .42483 .39768 .41161 .37271 .38221 Metetra
.659 .716 .891 r
.37271 .38221 .39768 .41161 .43935 .40029 .41481 .36803 Metetra
.658 .699 .876 r
.41481 .36803 .43935 .40029 .48176 .3876 .45758 .35356 Metetra
.671 .695 .864 r
.45758 .35356 .48176 .3876 .52489 .37172 .50106 .33698 Metetra
.685 .699 .857 r
.50106 .33698 .52489 .37172 .56861 .35229 .54518 .31794 Metetra
.694 .707 .858 r
.54518 .31794 .56861 .35229 .61284 .33046 .58989 .2976 Metetra
.686 .717 .873 r
.58989 .2976 .61284 .33046 .65762 .30886 .63524 .27859 Metetra
.642 .722 .906 r
.63524 .27859 .65762 .30886 .70319 .2916 .68153 .26506 Metetra
.507 .696 .954 r
.68153 .26506 .70319 .2916 .75021 .28436 .72942 .2628 Metetra
.12 .515 .911 r
.72942 .2628 .75021 .28436 .79982 .29467 .78014 .2796 Metetra
.481 0 0 r
.78014 .2796 .79982 .29467 .854 .33275 .83574 .32626 Metetra
.917 .856 .766 r
.17187 .52089 .20229 .52461 .24695 .46314 .21833 .45113 Metetra
.859 .851 .834 r
.21833 .45113 .24695 .46314 .28943 .42422 .26208 .40566 Metetra
.784 .821 .881 r
.26208 .40566 .28943 .42422 .33107 .39937 .30462 .37563 Metetra
.718 .777 .899 r
.30462 .37563 .33107 .39937 .37271 .38221 .34691 .35449 Metetra
.681 .741 .896 r
.34691 .35449 .37271 .38221 .41481 .36803 .38952 .33742 Metetra
.671 .72 .886 r
.38952 .33742 .41481 .36803 .45758 .35356 .43272 .32114 Metetra
.675 .712 .876 r
.43272 .32114 .45758 .35356 .50106 .33698 .4766 .30385 Metetra
.683 .714 .872 r
.4766 .30385 .50106 .33698 .54518 .31794 .52115 .28519 Metetra
.683 .719 .877 r
.52115 .28519 .54518 .31794 .58989 .2976 .56634 .26634 Metetra
.664 .726 .895 r
.56634 .26634 .58989 .2976 .63524 .27859 .61227 .24993 Metetra
.599 .724 .932 r
.61227 .24993 .63524 .27859 .68153 .26506 .65926 .24018 Metetra
.408 .668 .967 r
.65926 .24018 .68153 .26506 .72942 .2628 .70803 .243 Metetra
0 .4 .829 r
.70803 .243 .72942 .2628 .78014 .2796 .75983 .26653 Metetra
.593 .055 0 r
.75983 .26653 .78014 .2796 .83574 .32626 .81686 .32222 Metetra
.929 .856 .749 r
.13984 .51968 .17187 .52089 .21833 .45113 .18836 .44123 Metetra
.88 .859 .816 r
.18836 .44123 .21833 .45113 .26208 .40566 .23356 .38899 Metetra
.813 .838 .87 r
.23356 .38899 .26208 .40566 .30462 .37563 .27715 .35366 Metetra
.747 .801 .896 r
.27715 .35366 .30462 .37563 .34691 .35449 .32021 .32844 Metetra
.703 .766 .901 r
.32021 .32844 .34691 .35449 .38952 .33742 .3634 .30845 Metetra
.683 .742 .895 r
.3634 .30845 .38952 .33742 .43272 .32114 .40709 .29034 Metetra
.679 .731 .889 r
.40709 .29034 .43272 .32114 .4766 .30385 .45142 .27232 Metetra
.679 .729 .888 r
.45142 .27232 .4766 .30385 .52115 .28519 .49641 .25404 Metetra
.671 .732 .896 r
.49641 .25404 .52115 .28519 .56634 .26634 .54211 .23666 Metetra
.637 .735 .919 r
.54211 .23666 .56634 .26634 .61227 .24993 .58862 .22288 Metetra
.542 .72 .956 r
.58862 .22288 .61227 .24993 .65926 .24018 .63631 .21696 Metetra
.28 .619 .959 r
.63631 .21696 .65926 .24018 .70803 .243 .68593 .22502 Metetra
0 .269 .712 r
.68593 .22502 .70803 .243 .75983 .26653 .73881 .25557 Metetra
.673 .142 0 r
.73881 .25557 .75983 .26653 .81686 .32222 .79724 .32082 Metetra
.938 .856 .734 r
.10601 .52115 .13984 .51968 .18836 .44123 .15688 .43355 Metetra
.897 .865 .8 r
.15688 .43355 .18836 .44123 .23356 .38899 .20375 .37428 Metetra
.837 .853 .857 r
.20375 .37428 .23356 .38899 .27715 .35366 .24853 .33347 Metetra
.773 .823 .891 r
.24853 .33347 .27715 .35366 .32021 .32844 .29248 .3041 Metetra
.724 .789 .904 r
.29248 .3041 .32021 .32844 .3634 .30845 .33635 .28112 Metetra
.697 .764 .904 r
.33635 .28112 .3634 .30845 .40709 .29034 .38059 .26116 Metetra
.684 .751 .902 r
.38059 .26116 .40709 .29034 .45142 .27232 .42541 .24238 Metetra
.674 .746 .905 r
.42541 .24238 .45142 .27232 .49641 .25404 .4709 .22446 Metetra
.654 .746 .917 r
.4709 .22446 .49641 .25404 .54211 .23666 .51711 .20858 Metetra
.602 .742 .943 r
.51711 .20858 .54211 .23666 .58862 .22288 .5642 .19745 Metetra
.466 .707 .973 r
.5642 .19745 .58862 .22288 .63631 .21696 .61258 .19546 Metetra
.126 .543 .919 r
.61258 .19546 .63631 .21696 .68593 .22502 .66303 .20893 Metetra
.407 0 0 r
.66303 .20893 .68593 .22502 .73881 .25557 .71695 .24683 Metetra
.729 .21 0 r
.71695 .24683 .73881 .25557 .79724 .32082 .77678 .32227 Metetra
.945 .855 .721 r
.07017 .52548 .10601 .52115 .15688 .43355 .12372 .42822 Metetra
.911 .868 .783 r
.12372 .42822 .15688 .43355 .20375 .37428 .17249 .36159 Metetra
.859 .864 .843 r
.17249 .36159 .20375 .37428 .24853 .33347 .21865 .31513 Metetra
.798 .842 .885 r
.21865 .31513 .24853 .33347 .29248 .3041 .26361 .28148 Metetra
.745 .812 .905 r
.26361 .28148 .29248 .3041 .33635 .28112 .30826 .25545 Metetra
.71 .787 .912 r
.30826 .25545 .33635 .28112 .38059 .26116 .35313 .23359 Metetra
.687 .771 .915 r
.35313 .23359 .38059 .26116 .42541 .24238 .39849 .21404 Metetra
.668 .763 .921 r
.39849 .21404 .42541 .24238 .4709 .22446 .44449 .19648 Metetra
.634 .758 .938 r
.44449 .19648 .4709 .22446 .51711 .20858 .49123 .18209 Metetra
.557 .745 .964 r
.49123 .18209 .51711 .20858 .5642 .19745 .53891 .17367 Metetra
.37 .68 .978 r
.53891 .17367 .5642 .19745 .61258 .19546 .58796 .17572 Metetra
0 .441 .843 r
.58796 .17572 .61258 .19546 .66303 .20893 .63921 .19481 Metetra
.528 0 0 r
.63921 .19481 .66303 .20893 .71695 .24683 .69414 .24046 Metetra
.735 .213 0 r
.69414 .24046 .71695 .24683 .77678 .32227 .75456 .3163 Metetra
.921 .82 .73 r
.03435 .51739 .07017 .52548 .12372 .42822 .08868 .42538 Metetra
.923 .87 .768 r
.08868 .42538 .12372 .42822 .17249 .36159 .13962 .35102 Metetra
.877 .873 .829 r
.13962 .35102 .17249 .36159 .21865 .31513 .18735 .29868 Metetra
.82 .859 .876 r
.18735 .29868 .21865 .31513 .26361 .28148 .23347 .26062 Metetra
.765 .834 .904 r
.23347 .26062 .26361 .28148 .30826 .25545 .279 .23145 Metetra
.723 .809 .918 r
.279 .23145 .30826 .25545 .35313 .23359 .32458 .20764 Metetra
.691 .791 .927 r
.32458 .20764 .35313 .23359 .39849 .21404 .37054 .1873 Metetra
.659 .78 .938 r
.37054 .1873 .39849 .21404 .44449 .19648 .41708 .17008 Metetra
.608 .77 .958 r
.41708 .17008 .44449 .19648 .49123 .18209 .46436 .15722 Metetra
.5 .742 .981 r
.46436 .15722 .49123 .18209 .53891 .17367 .51262 .15157 Metetra
.25 .633 .961 r
.51262 .15157 .53891 .17367 .58796 .17572 .56232 .15779 Metetra
0 .324 .735 r
.56232 .15779 .58796 .17572 .63921 .19481 .61434 .18277 Metetra
.616 .066 0 r
.61434 .18277 .63921 .19481 .69414 .24046 .67024 .23663 Metetra
.576 0 0 r
.67024 .23663 .69414 .24046 .75456 .3163 .72925 .28152 Metetra
.853 .77 .769 r
0 .48963 .03435 .51739 .08868 .42538 .05153 .4252 Metetra
.933 .872 .754 r
.05153 .4252 .08868 .42538 .13962 .35102 .10494 .34268 Metetra
.893 .88 .814 r
.10494 .34268 .13962 .35102 .18735 .29868 .15446 .2842 Metetra
.84 .873 .867 r
.15446 .2842 .18735 .29868 .23347 .26062 .20191 .24156 Metetra
.784 .854 .902 r
.20191 .24156 .23347 .26062 .279 .23145 .24844 .20916 Metetra
.736 .831 .924 r
.24844 .20916 .279 .23145 .32458 .20764 .2948 .18334 Metetra
.694 .812 .938 r
.2948 .18334 .32458 .20764 .37054 .1873 .34142 .16217 Metetra
.648 .798 .955 r
.34142 .16217 .37054 .1873 .41708 .17008 .38854 .1453 Metetra
.575 .779 .976 r
.38854 .1453 .41708 .17008 .46436 .15722 .43638 .134 Metetra
.426 .729 .989 r
.43638 .134 .46436 .15722 .51262 .15157 .48521 .1312 Metetra
.11 .564 .916 r
.48521 .1312 .51262 .15157 .56232 .15779 .53553 .14175 Metetra
0 .205 .612 r
.53553 .14175 .56232 .15779 .61434 .18277 .58827 .17292 Metetra
.68 .141 0 r
.58827 .17292 .61434 .18277 .67024 .23663 .64509 .23556 Metetra
.167 0 0 r
.64509 .23556 .67024 .23663 .72925 .28152 .70298 .24544 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.480769 0.384615 0.259615 0.480769 [
[.09615 -0.0125 -6 -9 ]
[.09615 -0.0125 6 0 ]
[.48077 -0.0125 -3 -9 ]
[.48077 -0.0125 3 0 ]
[.86538 -0.0125 -3 -9 ]
[.86538 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09615 0 m
.09615 .00625 L
s
[(-1)] .09615 -0.0125 0 1 Mshowa
.48077 0 m
.48077 .00625 L
s
[(0)] .48077 -0.0125 0 1 Mshowa
.86538 0 m
.86538 .00625 L
s
[(1)] .86538 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .25962 m
.00625 .25962 L
s
[(0)] -0.0125 .25962 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(1)] -0.0125 .74038 1 0 Mshowa
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.98077 .21768 m
.95756 .15659 L
.93695 .08791 L
.91556 .01923 L
s
.01923 .16434 m
.0226 .15659 L
.04705 .08791 L
.06885 .01923 L
s
.98077 .26286 m
.96456 .22527 L
.94334 .15659 L
.92302 .08791 L
.91209 .05395 L
.90018 .01923 L
s
.01923 .21361 m
.04127 .15659 L
.06277 .08791 L
.08513 .01923 L
s
.98077 .31073 m
.9719 .29396 L
.94829 .22527 L
.92906 .15659 L
.91209 .1017 L
.90749 .08791 L
.88261 .01923 L
s
.01923 .26641 m
.03673 .22527 L
.05825 .15659 L
.07958 .08791 L
.08791 .06316 L
.10367 .01923 L
s
.55873 .98077 m
.5 .9577 L
.43132 .95826 L
.37519 .98077 L
s
.98077 .36183 m
.95142 .29396 L
.9334 .22527 L
.91333 .15659 L
.91209 .15272 L
.88946 .08791 L
.86225 .01923 L
s
.01923 .32362 m
.03387 .29396 L
.0557 .22527 L
.07579 .15659 L
.08791 .1192 L
.09887 .08791 L
.12537 .01923 L
s
.63028 .98077 m
.56868 .93095 L
.53291 .91209 L
.5 .90157 L
.43132 .90159 L
.39846 .91209 L
.36264 .93095 L
.30131 .98077 L
s
.98077 .41687 m
.95168 .36264 L
.93544 .29396 L
.91748 .22527 L
.91209 .20766 L
.89473 .15659 L
.86806 .08791 L
.84341 .03031 L
.83909 .01923 L
s
.01923 .38661 m
.03407 .36264 L
.05589 .29396 L
.07413 .22527 L
.08791 .18069 L
.09612 .15659 L
.12203 .08791 L
.15116 .01923 L
s
.68047 .98077 m
.63736 .92926 L
.62321 .91209 L
.56868 .86998 L
.51295 .84341 L
.5 .83993 L
.43132 .83922 L
.41508 .84341 L
.36264 .8678 L
.30533 .91209 L
.29396 .92544 L
.24734 .98077 L
s
.98077 .47698 m
.9458 .43132 L
.93397 .36264 L
.91956 .29396 L
.91209 .26764 L
.89815 .22527 L
.87184 .15659 L
.84341 .09022 L
.84253 .08791 L
.81317 .01923 L
s
.01923 .45754 m
.04229 .43132 L
.06045 .36264 L
.07514 .29396 L
.08791 .24951 L
.0959 .22527 L
.12149 .15659 L
.15047 .08791 L
.15659 .07422 L
.18013 .01923 L
s
.72504 .98077 m
.70604 .95076 L
.67938 .91209 L
.63736 .86176 L
.62213 .84341 L
.56868 .80178 L
.51347 .77473 L
.5 .77091 L
.43132 .76918 L
.40974 .77473 L
.36264 .7965 L
.30183 .84341 L
.29396 .85267 L
.24341 .91209 L
.22527 .93744 L
.19759 .98077 L
s
.98077 .5439 m
.96714 .5 L
.92595 .43132 L
.91907 .36264 L
.91209 .33437 L
.89935 .29396 L
.87302 .22527 L
.84341 .15695 L
.84328 .15659 L
.81443 .08791 L
.77901 .01923 L
s
.01923 .54051 m
.03169 .5 L
.0727 .43132 L
.07948 .36264 L
.08791 .32915 L
.09905 .29396 L
.12491 .22527 L
.15415 .15659 L
.15659 .15109 L
.1833 .08791 L
.21796 .01923 L
s
.76847 .98077 m
.72986 .91209 L
.70604 .87396 L
.6855 .84341 L
.63736 .78402 L
.63 .77473 L
.56868 .72309 L
.53955 .70604 L
.5 .69101 L
.43132 .68768 L
.3755 .70604 L
.36264 .71288 L
.29396 .7666 L
.28587 .77473 L
.22886 .84341 L
.22527 .84841 L
.18454 .91209 L
.15659 .95721 L
.15036 .98077 L
s
.98077 .62064 m
.96462 .56868 L
.94249 .5 L
.91568 .43132 L
.91209 .41083 L
.89779 .36264 L
.87042 .29396 L
.84341 .23333 L
.8407 .22527 L
.8113 .15659 L
.77473 .08815 L
.77463 .08791 L
.73733 .01923 L
s
.01923 .6452 m
.02159 .63736 L
.04227 .56868 L
.06386 .5 L
.08716 .43132 L
.08791 .4274 L
.10754 .36264 L
.13506 .29396 L
.15659 .24412 L
.16347 .22527 L
.19351 .15659 L
.22527 .09508 L
.22865 .08791 L
.26678 .01923 L
s
.81215 .98077 m
.77974 .91209 L
.77473 .90028 L
.74362 .84341 L
.70604 .78055 L
.7023 .77473 L
.65182 .70604 L
.63736 .68955 L
.58435 .63736 L
.56868 .6268 L
.5 .59238 L
.43132 .58589 L
.36264 .60725 L
.31292 .63736 L
.29396 .6555 L
.24611 .70604 L
.22527 .73032 L
.21079 .77473 L
.15659 .83023 L
.14825 .84341 L
.10909 .91209 L
.08791 .93143 L
.06439 .98077 L
s
.98077 .71343 m
.97848 .70604 L
.957 .63736 L
.93457 .56868 L
.91209 .50317 L
.91095 .5 L
.89217 .43132 L
.86096 .36264 L
.84341 .32545 L
.83376 .29396 L
.8002 .22527 L
.77473 .18056 L
.7647 .15659 L
.72096 .08791 L
.70604 .06894 L
.67152 .01923 L
s
.01923 .8114 m
.02967 .77473 L
.04824 .70604 L
.06782 .63736 L
.08791 .57056 L
.0886 .56868 L
.11079 .5 L
.13035 .43132 L
.15659 .3722 L
.15871 .36264 L
.18513 .29396 L
.21916 .22527 L
.22527 .2134 L
.2527 .15659 L
.29396 .09072 L
.29556 .08791 L
.34629 .01923 L
s
.98077 .84095 m
.96025 .77473 L
.93813 .70604 L
.91488 .63736 L
.91209 .62922 L
.89015 .56868 L
.86354 .5 L
.84341 .45092 L
.83468 .43132 L
.80305 .36264 L
.77473 .30702 L
.76729 .29396 L
.73076 .22527 L
.70604 .19692 L
.67312 .15659 L
.63736 .12081 L
.58731 .08791 L
.56868 .0815 L
.5 .07827 L
.46013 .08791 L
.43132 .1034 L
.37672 .15659 L
.36264 .17052 L
.33101 .22527 L
.29833 .29396 L
.29396 .30617 L
.27523 .36264 L
.27532 .43132 L
.29396 .43991 L
.36264 .43147 L
.36381 .43132 L
.43132 .42969 L
.44686 .43132 L
.5 .44758 L
.56868 .48989 L
.58244 .5 L
.63736 .55766 L
.64624 .56868 L
.69664 .63736 L
.70604 .65188 L
.73428 .70604 L
.77473 .77337 L
.77545 .77473 L
.7954 .84341 L
.83819 .91209 L
.84341 .92157 L
.86721 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{411.812, 158.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000590000OR000`400?l00000o`00003ooooooom:
ooooo`00oooooom:ooooo`00oooooom:ooooo`00KOooool2o`000=[ooooo001Zooooo`?o000000?o
ooooo`000?ooool0fOooool006Sooooo0_l00004ooooo`;o0000G?ooool3o`0002Kooooo00?o0000
ooooooooool09oooool3o`0002Oooooo001Uooooo`?o00001_ooool00ol0003oooooo`00001Foooo
o`Co00000_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000002Wooooo00?o0000oooo
ooooool09_ooool006;ooooo0ol00009ooooo`03o`000?oooooo000005cooooo00?o0000oooooooo
ool09?ooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo02Kooooo001Pooooo`;o0000
3?ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool0
0000:Oooool00ol0003oooooooooo`0Vooooo`00GOooool3o`0000kooooo00Go0000oooooooooooo
ooooo`00001Iooooo`;o00009oooool00ol0003oooooooooo`0Wooooo`;o0000:?ooool005_ooooo
0_l0000Aooooo`05o`000?ooooooooooooooool00000e_ooool005Sooooo0ol0000Cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0B_oooomao`0001Sooooo001Eooooo`?o00005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Fooooo`00Doooool2o`0001[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`09o`000?oooooo0000
ooooool0003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool05_ooool0053ooooo0ol0
000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`05ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000009ooooo`03
o`000?oooooooooo01Kooooo001>ooooo`;o00007oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool01Oooool2o`000004ooooool0003oooooo`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000002?ooool00ol0003oooooooooo`0Fooooo`00Boooool3o`00027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Cooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Sooooo00?o0000oooo
ooooool05_ooool004Sooooo0ol0000Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`04ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`;o
00002?ooool00ol0003oooooooooo`0Fooooo`00A_ooool2o`0002Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000
ooooool00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000Oooooo00?o0000ooooooooool05_ooool004?ooooo
0ol0000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`04ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000Oooooo00?o0000oooooooo
ool05_ooool0047ooooo0_l0000/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Aooooo`co00003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo
0_l00007ooooo`03o`000?oooooooooo01Kooooo000nooooo`?o0000;_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool00oooool2o`000004ooooool0
003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool4o`0000cooooo0_l0000<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000Kooooo00?o0000ooooooooool0
5_ooool003_ooooo0ol0000?ooooo`Ko00007?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool00oooool2o`000004ooooool0003oooooo`0000;ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Wo0000
ooooool0003oooooo`000?oooooo0000ooooool000001_ooool00ol0003oooooooooo`0Fooooo`00
>Oooool2o`0000_ooooo1ol00005offjo@Go00006?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool02Ol0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool01Oooool00ol0003o
ooooooooo`0Fooooo`00=_ooool3o`0000Sooooo1Ol00005oi?7n@03o`000?m]^_goKK[m00GoKK[m
00Co0000oab@j_lLT>[o793Z0ol0000Eooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool03?l0003oooooooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`0000Gooooo00?o0000ooooooooool05_ooool003Cooooo0_l0
0008ooooo`?o00000_nUc?@00ol0003oTlOioi?7n@06oi?7n@03o`000?m]^_goKK[m00;oKK[m2?l0
00000olLT>[o0000o`00000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`06o`000?oooooo0000o`000?oooooo00001Oooool00ol0003oooooooooo`0Fooooo`00<Ooo
ool3o`0000Sooooo0_l00006ojG<m003o`000?nCaoWoTlOi00CoTlOi1_l00005ognmn`03o`000?lo
X_Ko?j;f00Go00004Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo043ooooo00go
0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000oooooooooooo0000ooooool0003o
oooo00;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`0Fooooo`00;_ooool3o`00
00Wooooo0ol00008ojG<m003o`000?nCaoWoTlOi00?o00000onKaOD00ol0003oOkgkognmn`06ognm
n`03o`000?loX_Ko?j;f00?o?j;f0ol0000?ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0?oooool03Ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooooooo
ool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo01Ko
oooo000/ooooo`;o00002Oooool3o`0000?o/Lo`00?o0000ojG<m?nUc?@01?nUc?@4o`0000OoVlGe
00?o0000ognmnomo_O/01?mo_O/7o`000003ocnRm_l0003o05:l00;o00003Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03oooooo00Co0000oooooooooooooooo0_l000001?oooooo
0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00000
1Ooooooo0000oooooooooooo000000;ooooo00Ko0000ooooool0003o0000ooooool00004ooooo`03
o`000?oooooooooo01Kooooo000Yooooo`?o00002Oooool2o`0000Oo/Lo`00?o0000ojG<m?nUc?@0
0ol00003ojS7l003o`000?nKaOGoVlGe00KoVlGe00?o0000ognmnomo_O/00ol00003ohjnmP04o`00
0?mN[_[oGZkjoej^nPCo000000?o[R@0o`000?ooool02oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03kooooo00co0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0Fooooo`009ooo
ool2o`0000[ooooo0ol00008ok7?l0?o00001onXao000ol0003oVlGeoi_5m@04oi_5m@Co00001on>
__H00ol0003oGZkjoej^nP04oej^nP04o`000?n^903o0000o`0000[ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooooooo
ool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo01Ko
oooo000Tooooo`?o00002_ooool2o`0000?o_=C/0_l00004ok7?l0;o00000on`b^d00ol0003oZ<O`
ojS7l005ojS7l003o`000?nKaOGoVlGe00?o00000onR`_000ol0003oS[kfohjnmP06ohjnmP03o`00
0?mN[_[oGZkj00CoGZkj00?o0000ojhT0?n^90000_l00009ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0?Oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool2o`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`000003ooooool0
003ooooo00;o00001?ooool00ol0003oooooooooo`0Fooooo`008Oooool3o`0000cooooo00?o0000
okcDk?nle>`01Onle>`01?l0003o/Lo`o`000?l00006ok3:k@03o`000?nXao3oZ<O`00CoZ<O`0ol0
0007oj;2l003o`000?n>__KoS[kf00CoS[kf2_l00002ojhT00?o00001oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03cooooo00_o0000ooooooooooooooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Oo0000oooooooooooo
0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0Foooo
o`007oooool2o`0000gooooo0_l00008okcDk0;o00002On`b^d00ol0003oZ<O`ojS7l003o`0000;o
Zl?[00?o0000oj;2l?nR`_001_nR`_000ol0003oS[kfohjnmP03o`0000?oV[ga00?o0000ogNdnOmg
]?T01?mg]?T01Ol0003o[R@0ojhT0?l0003oWA0000;o00001Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03_ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?oo
oooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`08o`000?oooooo0000oooo
ool0003oooooo`000?ooool2o`0000?ooooo00?o0000ooooooooool05_ooool001cooooo0ol0000=
ooooo`?o00001onle>`2o`0000;o^Lo[00?o0000ok3:kOn`b^d01_n`b^d3o`0000KoZl?[00?o0000
oj;2l?nR`_001?nR`_04o`0000OoV[ga00?o0000ogNdnOmg]?T00omg]?T01_l0003o[R@0ojhT0?n^
903o0000oid@00?o00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_l00003ooooo`03o`000?oo
oooooooo01Kooooo000Jooooo`;o00003_ooool2o`0000?ob=[V0_l00004okcDk003o`000?nicn_o
^Lo[00?o^Lo[00?o0000ok3:kOn`b^d00_n`b^d3o`000003ojo5j_l0003oZl?[00OoZl?[00?o0000
oj;2l?nR`_000ol00003ojNnjP03o`000?nJ_O7oV[ga00KoV[ga00?o0000ogNdnOmg]?T00_mg]?T2
o`0000?o[R@000?o0000oid@0?l000000_l00002ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02
o`000005ooooool0003oooooooooool000006?ooool001Oooooo0ol0000?ooooo`03o`000?o8f^Ko
b=[V00Gob=[V00Co0000okcDk?l0003o00001onicn/01?l0003o/<[]o`000?l00005ojo5jP03o`00
0?n[`n_oZl?[00GoZl?[0ol00007ojNnjP03o`000?nJ_O7oV[ga00CoV[ga1_l00002ohZhm005o`00
0?n^903o[R@0ojhT0?l000000_nM4004o`0001?ooooo00?o0000ooooooooool0>Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`0F
ooooo`005?ooool3o`00013ooooo0_l00008olSJiP?o00002?nicn/2o`0000So[lGZ00Co0000oj_3
jon[`n_oZl?[0ol00002ojbni`03o`000?nW_^[oYkkZ00KoYkkZ00?o0000oiZmlOnJ_O400ol00002
oj>lj`03o`000?n:^?CoR[Sd00CoR[Sd00Go0000ojhT0?n^903o[R@0o`000002oid@0004o`000?n7
003o0000o`0001;ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Wo0000ooooool0003ooooo
o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`0Fooooo`004_ooool2o`0001;o
oooo0_l00007olSJiP;o00000oo3eNL00ol0003o^Lo[okW?j`02okW?j`?o00000_nebNT00ol0003o
[lGZojo5jP05ojo5jP04o`000?n[`n_o0000o`0000Ko[;kW00?o0000ojNnj_nW_^X01?nW_^X4o`00
00KoXkc[00?o0000ohZhm?n:^?@01?n:^?@;o`0001;ooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;o000000Koooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooooooo01Ko
oooo000?ooooo`?o00004oooool00ol0003oemoMomOOg@02o`0000Cob=[V00?o0000ol?Eioo3eNL0
1?o3eNL01?l0003o^Lo[o`000?l00006okG9j@03o`000?n_aN[o[lGZ00Co[lGZ0_l00009ojbni`03
o`000?nW_^[oYkkZ00?o00000_n[^nD00ol0003oXkc[oj>lj`06oj>lj`03o`000?n:^?CoR[Sd00?o
00000_nI^Nh00ol0003oJ:_gofR[m`04o`000004ok`f0?l0003o0000o`00017ooooo00?o0000oooo
ooooool0<oooool01Ol0003ooooooooooooooooo000000;ooooo00So0000oooooooooooo0000oooo
ool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool02Ol0003oooooo`000?oooooo
0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo01Kooooo000>ooooo`;o00005?oo
ool00ol0003oemoMomOOg@03omOOg@04o`000?o8f^Ko0000o`0000Oo`mGW0_l00009okG9j@03o`00
0?n_aN[o[lGZ00?o00000_n_`>H00ol0003o[;kWojbni`06ojbni`?o00001_n[^nD00ol0003oXkc[
oj>lj`04oj>lj`Co00001_nI^Nh6o`0000;o_3H000?o0000okXe0?l000004?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooo000000;ooooo0_l000002Ooooooo0000oooooooooooo0000oooo
ool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00co0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool00002ooooo`03o`000?oooooooooo01Kooooo000>ooooo`03o`000?oooooo000001;ooooo00?o
0000omOOgOoGgmd01?oGgmd3o`0000Oo`mGW00Co0000okk?ionncnOo00002?nebNT3o`0000Ko[l3V
00?o0000ojbnion/_^L00_n/_^L3o`000003ojfjhol0003oZk_U00OoZk_U00?o0000oj>ljonS_>/0
0ol00002ojVii@03o`000?nI^NkoVKW^00?oVKW^1?l00003ofR[m`;o00000_nl=P000ol0003o^SD0
o`000002o`0000kooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooo000000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
00001_oooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool05_ooool000kooooo
00Co0000oooooooooooo00004?ooool00ol0003oemoMomOOg@04omOOg@04o`000?oAfn3odM_Pom7K
h0;o00000oo3eNL2o`0000Co_/oW00?o0000okG9jOnebNT00_nebNT3o`000003ok;3iol0003o[l3V
00Oo[l3V00Co0000ojbniol0003o00001On]^^<00ol0003oZk_Uoj^ki@05oj^ki@?o00001_nY^ND0
0ol0003oVKW^o`000002o`0000;oVKW^2?l00002ok`f00;o00000_n/9002o`0000gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool00_l000001?oooooo0000ooooool00004ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
emoMomOOg@04omOOg@03o`000?oAfn3odM_P00CodM_P00?o0000ol?Eiol000001onncnL01?l0003o
]LWYo`000?l00005ok;3i`03o`000?n_`>Ko[l3V00Go[l3V0_l00008ojfjh`03o`000?n[^nGoZk_U
00;oZk_U0_l000000on^^>3o0000ojVii@05ojVii@?o00000_nI^Nh3o`0000;oY;SW00?o0000oh6b
m?n1/_@00on1/_@00ol0003o_3H0ok`f0002o`0000;o[2@00_l0000<ooooo`03o`000?oooooooooo
037ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo0000ooooool000000_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`0F
ooooo`003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000omOO
gOoGgmd01?oGgmd00ol0003odM_Pom7Kh005om7Kh0;o00002?nncnL2o`0000So//?W00?o0000ojo0
i_n_`>H00_n_`>H2o`000003ojfkhol0003o[K[S00So[K[S00Co0000oj^kiOl0003o00001?n^^>00
0ol0003oZKWUojVii@03o`0000;oZKWU0ol00006ojBhi`03o`000?n1/_CoPK;d00;oPK;d0_l00000
1?nl=P3o0000okXe0?l00002oj`T00?o00002oooool00ol0003oooooooooo`0dooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l000001?oo
oooo0000ooooool00003ooooo`03o`000?oooooooooo01Kooooo000=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool2o`0000GoemoM00?o0000om7Kh?oAfn001OoAfn001?l0
003oc=ORolcGh_l00006okk?i`04o`000?nibNOo^LWWo`0000So//?W00Co0000ojo0i_l0003o0000
1?n]^n<00ol0003o[K[Sojfjh`06ojfjh`;o00001_n^^>03o`0000?oZKWU0_l00002ojngg`03o`00
0?nT^>OoY;SW00GoY;SW00?o0000oh6bm?n1/_@00_n1/_@01_l0003o_3H0ok`f0?l0003o^SD0o`00
00;o[2@000?o0000oiL>0?l000002oooool00ol0003oooooooooo`0cooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l000001?oooooo0000
ooooool00003ooooo`03o`000?oooooooooo01Kooooo000=ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oi>7@o`000002o`000003omOOgOl0003odM_P00GodM_P
0_l00004olcGhP04o`000?nncnOo_/oWokk?i`;o00001?nibNL00ol0003o//?Wok;3i`04ok;3i`?o
00001on]^n<00ol0003o[K[Sojfjh`02ojfjh`?o000000?o[[KOo`000?n^^>000on^^>02o`0000;o
[[SP00Co0000ojViiOl0003o00001On_]ml00ol0003oY;SWojBhi`04ojBhi`Go000000OoU;G^o`00
0?nl=P3o_3H0o`000?nj=@3o000000;o[2@000Co0000oiL>0?l0003o00002Oooool00ol0003ooooo
ooooo`0cooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0
003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01Kooooo000=
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oi>7@onCQd003
onCQd0;o00001OoAfn000ol0003oc=ORolcGhP05olcGhP03o`000?nncnOo000000Oo^LWW00?o0000
ok;3ionb`nL00ol00003ojjmi@03o`000?n]^n?o[K_S00Go[K_S00Co0000ojfjhol0003o00001On^
]]l4o`0000Co[[SP0_l00008ojngg`03o`000?nT^>OoY;SW00?o00000_n/]n400ol0003oU;G^oiBe
kP02oiBekP03o`000?nl=P3o000000;o^SD000Go0000oj`T0?n/903o0000oiL>0002o`0000Wooooo
00?o0000ooooooooool0<_ooool00ol0003oooooo`000003ooooo`05o`000?oooooo0000ooooool0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool01ol0
003oooooo`000?oooooo0000ooooool000001?ooool00ol0003oooooooooo`0Fooooo`003Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000onCQd?oThM001?oThM00
0ol0003oh=oDo`000002o`000003om7Kh?l0003oc=OR00Ooc=OR0ol00007okW9i`?o00001on^_ND0
0ol0003o[K_Sojfkh`04ojfkh`;o00001On^]]l4o`0000?o[[SP0ol000000ona]=_o0000ojngg`07
ojngg`?o00001_n/]n401?l0003oU;G^oiBek_nD]Nh2o`000005ok`f0?l0003o^SD0okXe0?l00000
0_n/90001?l0003oU`h0o`000?l00009ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool00oooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Cooooo
00?o0000ooooooooool05_ooool000gooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000000Koi>7@00?o0000on3Oe?oPgm@00ooPgm@2o`0000Koc=OR0_l00003olGBi003o`00
0?nibNOo^LWW00;o^LWW0_l000000onca>Ko0000ojjmi@08ojjmi@03o`000?n]^n?o[K_S00?o0000
00Co[;KPo`000?n^]]oo[[KO0ol00003ojjfg`04o`000?n^^>3o0000o`0000Go/KCK00?o0000ojng
gon_]ml00on_]ml2o`000003ok>dfOl0003o[;OQ00Oo[;OQ00?o0000oiBek_nD]Nh01Ol00002okXe
0005o`000?n/903o[2@0o`000?nG3P000ol00007ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`05
o`000?ooooooooooooooool000006?ooool000gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooo`000006onCQd003o`000?oPgmCoh=oD00?oh=oD00Co0000om_MeooKgMOo00001?o<en800ol0
003oaM;TolGBi004olGBi004o`000?nibNOo0000o`0000Co/lCV00?o0000ojjmiOn^_ND01_n^_ND3
o`0000Co[;KP0ol00006ojjfg`;o00002?na]=/01Ol0003o[kOOojnggon_]moo000000Co/kCI00?o
0000ojbghOn/]n401On/]n43o`0000;oX[KV00?o0000oj:fi_nR]^H02Ol000000omk003o0000oooo
o`06ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000ooooool0003o00000_ooool01Ol0003ooooooooooooooooo000001Sooooo000<
ooooo`03o`000?oooooooooo00_ooooo00?o0000onCQd?oThM001?oThM000ol0003oh=oDon3Oe003
on3Oe003o`000?oKgMOofmgG00;ofmgG00Co0000olcGh_l0003o00001oo5d^@2o`0000Oo/lCV00?o
0000ojjmiOn^_ND00_n^_ND3o`000004oj^hh_l0003o[;KPojbfh0?o00000_n/]^000ol0003o[[KO
ojjfg`02ojjfg`;o000000?o[k;Ko`000?na]=/01ona]=/01?l0003o[kOOo`000?l00006ok>df@04
o`000?n/]n7o[;OQojbgh@?o000000?o/kGJo`000?nR]^H00_nR]^H01Ol0003oX[KVoj:fi_nR]^Ko
000000KoKJOd1?l00007ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo01Ko
oooo000<ooooo`03o`000?oooooooooo00[ooooo00?o0000onCQd?oThM001?oThM000ol0003oh=oD
on3Oe003on3Oe003o`000?oKgMOofmgG00CofmgG0_l00007olGBi004o`000?nocNGo_lgUo`0000Oo
/lCV00Co0000ojjmiOl0003o00001?n[^>83o`0000Ko[;KP00Co0000ojjfgol0003o00001?n_/]/0
0ol0003o/KCKok6df`05ok6df`;o00002?nc]=T01?l0003o[;OQo`000?l00005ok>efP05o`000?nR
]^KoX[KVoj:fi_l000000_nR]^H:o`000003o`1Cb?l0003o000000Gooooo00?o0000ooooooooool0
;oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool2o`000005ooooool0003ooooo
ooooool000000_ooool00ol0003oooooooooo`0Fooooo`003?ooool00ol0003oooooooooo`09oooo
o`;o00001OoThM000ol0003oh=oDon3Oe003on3Oe003o`000?oKgMOofmgG00CofmgG00?o0000omKJ
fooFf]/00_l00003olGBi0;o00001?nocND00ol0003o/lCVok?4iP04ok?4iP;o00001?n[^>82o`00
00;oZkSR00?o0000ojbfh?n/]^000on/]^03o`0000Oo[k;K00?o0000ok6dfona]=/00_na]=/2o`00
0003ok>aeol0003o/kCI00Oo/kCI0_l00008ok>efP03o`000?nR]^KoX[KV00?o000000?o[KKOo`00
0?n7[o001_n7[o06o`0000Cooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo01Kooooo000<
ooooo`03o`000?oooooooooo00Wooooo00?o0000onkO`Ol000000_l000000ooThM3o0000on3Oe004
on3Oe003o`000?oKgMOofmgG00CofmgG00?o0000omKJfooFf]/00ooFf]/00ol0003oaM;To`000007
oko=i@03o`000?nca>Ko/lCV00?o00000_n^_ND4o`0000CoZkSR00?o0000ojbfh?n/]^000ol00002
oj^ag@03o`000?n_/]_o[k;K00Ko[k;K00Co0000ok6dfol0003o00001?nc/ML00ol0003o/kCIok>d
f@03ok>df@;o000000?o]k;Do`000?nc]MX01onc]MX3o`0000;o[KKO00Co0000ojffgon]]]oo0000
1on7[o000ol0003o3gGRo`mehP03o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00oooool01_l0003ooooo
oooooooooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Kooooo000<ooooo`03o`000?oooooooooo00Sooooo00?o0000onkO`Oo^gl400oo^gl44o`0000;o
h=oD00?o0000om_MeooKgML01?oKgML00ol0003oe][KomKJf`04omKJf`?o00001onocND3o`0000?o
[[gU1?l00006oj^hhP?o00001_n[/Md00ol0003o[k;Kojnbf`05ojnbf`;o00001onc/ML01Ol0003o
/kCIok>dfOnc]=Wo000000Co]k;D00?o0000ok>ef_nc]MX00onc]MX2o`000003okRceOl0003o[KKO
00;o[KKO00Go0000ojffgon]]]oo[KKOo`000004ohN_l0Ko00000_l?MN801Ol0003ooooooooooooo
oooo000002oooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`0000Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?o
oooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000004ooooo`03o`00
0?oooooooooo01Kooooo000<ooooo`03o`000?oooooooooo00Oooooo00?o0000onkO`Oo^gl401?o^
gl401?l0003ok=k4oncNa?o/g/@3o`0000GofmgG00?o0000omKJfooFf]/01?oFf]/01Ol0003od=KN
om3Fg_o@e]ko000000Co_lgU0_l00002okO6iPCo00001?n^_ND00ol0003oZkSRoj^hhP03o`000003
ojRbh?l0003oZk7M00OoZk7M00Co0000ojnbfon_/]_o[k;K0ol000000on_[mOo0000ok>ae`06ok>a
e`04o`000?nc]=Wo0000o`0000Ko]k;D00Go0000ok>ef_nc]M[o/kGJo`000004okRce@05o`000?n]
]]oo[KKOojffgol000000_n]]]l5o`0000CoVk?Y00?o0000od2@kol000000ol00003ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00Go0000
ooooooooooooooooo`00000Hooooo`003?ooool00ol0003oooooooooo`07ooooo`03o`000?o^gl7o
k]o100?ok]o100?o0000oncNa?o/g/@00oo/g/@00ol0003ojMk8o`000002o`000003om_Meol0003o
e][K00Coe][K0_l00005om3FgP04o`000?nocNGo0000o`0000;o]lKV1?l00006ojjmi@?o00001OnX
/^000ol0003oZk7Moj^ag@05oj^ag@04o`000?n_/]_o0000o`0000Go[joG00?o0000ok>aeonc/ML0
1?nc/ML2o`0000So]k;D00Co0000ok>ef_l0003o00001_nh/mD01?l0003o[KKOojffgon]]]l2o`00
0003okFdf?l0003oVk?Y00OoVk?Y00Co0000od2@kom0T>oo@93_0ol00002ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_l000001Ooooooo0000oooooooooooo000000?ooooo00?o
0000ooooooooool05_ooool000_ooooo00?o0000ooooooooool01oooool00ol0003ok]o1onkO`@03
onkO`@03o`000?o/g/Cok=k400?ok=k400?o0000onWNb?oYg/P00ooYg/P2o`0000Coe][K00?o0000
om3Fg_o@e]h01Oo@e]h2o`000004okO6i_l0003o0000o`0000Co]lKV00?o0000ojjmiOn^_ND00ol0
00000onX]nCo0000ojRbh006ojRbh003o`000?n[/MgoZk7M00CoZk7M0_l00008ojn_e`04o`000?nc
/MOo/k7Gok>ae`;o000000?o]JoCo`000?ng/]@01ong/]@2o`0000So^;?E00Ko0000ojffgol0003o
0000okFdf?l00002okFdf003o`000?nK/nWoVk?Y00CoVk?Y1ol000001?m0T>oo0000ooooool0000]
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Ko
oooo000;ooooo`03o`000?oooooooooo00Oooooo00?o0000onkO`Oo^gl400oo^gl400ol0003ok=k4
oncNa002oncNa003o`000?oYg/SojMk800CojMk800Ko0000onGMc?l0003o0000omKJfol00007om3F
gPCo00001onga^H3o`0000GoZ;OT00?o0000ojRbh?nX/^001OnX/^000ol0003oZk7Moj^ag@03o`00
0003ojZ]f_l0003o[joG00Oo[joG00Co0000ok>aeol0003o00001?ne[m<00ol0003o]k;DokNbe004
okNbe003o`000?ni/=3o000000So^;?E0_l00003okFdf005o`000?ne]=So]KCHokFdf?l000000_nK
/nT3o`0000;oZKCQ00?o0000ofRQl_mXXO800_mXXO83o`000003ooooool0003ooooo02_ooooo00?o
0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o0000oooooooo
ool03Oooool2o`0000Cooooo4?l0000Xooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0
003o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo000;ooooo`03
o`000?oooooooooo00Kooooo00?o0000onkO`Oo^gl400oo^gl400ol0003ok=k4oncNa003oncNa003
o`000?oYg/SojMk800?ojMk800?o0000onGMc?oUgL`00_oUgL`2o`0000God=KN0ol00003olSBh@03
o`000?nga^Ko]lKV00;o]lKV0_l000000on``>Ko0000ojRgi006ojRgi003o`000?nX/^3oZ;;P00Co
Z;;P0ol00005ojZ]fP03o`000?n_[mOo[joG00Go[joG0_l00007okF_d`04o`000?ng/]Co]k;DokNb
e0;o00000oni/=000ol0003o^;?EokRce@03okRce@;o000000?o_;7?o`000?ne]=P00one]=P00ol0
003o]KCHokFdf003o`0000KoZKCQ00?o0000ofRQl_mXXO801?mXXO800ol0003oooooo`00000[oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00oooooo1?l0000@ooooo`?o00009Oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
0000o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`002oooool0
0ol0003oooooooooo`05ooooo`03o`000?o^gl7ok]o100?ok]o100?o0000oncNa?o/g/@00oo/g/@0
0ol0003ojMk8onWNb003onWNb003o`000?oUgLcoiMg<00?oiMg<00?o0000on7Kd?l000000_o@e]h2
o`0000Oob=;Q00Co0000okO6i_l0003o00001?n``>H00ol0003oZ;OTojRgi005ojRgi003o`000?nX
/^3oZ;;P00?o000000?oYJgMo`000?nZ[MX01_nZ[MX00ol0003o[joGojn_e`02ojn_e`;o000000?o
/:cCo`000?ne[m<01one[m<00ol0003o]k;Do`000006okV`d005o`000?nh/mGo^;?EokRceOl00000
1?nl/Ll00ol0003o]KCHokFdf002okFdf0;o000000?o^k?Bo`000?nY]>401_nY]>4:o`0002_ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo02Ko
oooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool000_ooooo00?o0000ooooooooool0
1Oooool00ol0003ok]o1onkO`@03onkO`@03o`000?o/g/Cok=k400;ok=k400?o0000onWNb?oYg/P0
0ooYg/P00ol0003oiMg<onGMc003onGMc003o`000?oQfm3ohM_@00Co00002?o8d^42o`0000Oo/<3V
00?o0000ojRgi?nX]n@00onX]n@4o`0000GoYJgM00?o0000ojZ]f_nZ[MX01OnZ[MX01?l0003o[joG
o`000?l00004ok2/d`03o`000?ne[m?o]JoC00Go]JoC0_l00007okV`d004o`000?nh/mGo0000o`00
00Ko_;7?00?o0000okFdf?ne]=P00ol00002ok^cdP03o`000?nY]>7oZKCQ00;oZKCQ0_l000000onc
]=Wo0000ohJ/kP06ohJ/kP;o0000:_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000006?oo
ool000_ooooo00?o0000ooooooooool01?ooool00ol0003ok]o1onkO`@03onkO`@03o`000?o/g/Co
k=k400;ok=k400?o0000onWNb?oYg/P00ooYg/P00ol0003oiMg<onGMc003onGMc0Co00000_oQfm02
o`0000Gob=;Q0ol00002ol3<i003o`000?n``>Ko/<3V00Co/<3V00?o0000ojRgi?nX]n@00ol00002
oj>`hP03o`000?nU[MgoYJgM00GoYJgM00?o0000ojZ]f_nZ[MX00onZ[MX3o`0000Ko/:cC00?o0000
okF_done[m<00one[m<2o`000003okJ/col0003o^K3@00Ko^K3@0_l00008okbac`03o`000?ne]=So
000000;o^k?B00Ko0000ok^cd_nk/m;o^k?Bo`000?nY]>42o`0000Co/kCI00?o0000ohJ/k_n6[>h0
1On6[>h2o`0002Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo02[ooooo0_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000006?ooool000_ooooo00?o0000oooo
ooooool01?ooool00ol0003ok]o1onkO`@03onkO`@03o`000?o/g/Cok=k400;ok=k400?o0000onWN
b?oYg/P00ooYg/P01?l0003oiMg<onGMc?oUgL`3o`0000CohM_@00?o0000om_IeOoKfMD00_l00000
0oo8d^7o0000o`000006ol3<i004o`000?n``>Ko/<3Vok30iPGo00001_nS/>800ol0003oYJgMojF]
g@04ojF]g@03o`000?nZ[M[oZZgJ00?o00000_nYZML00ol0003o/:cCok2/d`05ok2/d`05o`000?ne
[m?o]JoCokF_dol000001?nf[<l00ol0003o^K3@okV`d003okV`d003o`000?nk[Lco000000So_;7?
0_l00004ok^cdP03o`000?nk/m;o^k?B00;o00001onc]=T00ol0003oQZc^ohJ/kP02ohJ/kPCo0000
:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
;?ooool2o`00023ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`00
00;ooooo00Co0000oooooooooooo00006?ooool000[ooooo00?o0000ooooooooool01?ooool00ol0
003ok]o1onkO`@03onkO`@03o`000?o/g/Cok=k400;ok=k400?o0000onWNb?oYg/P00ooYg/P00ol0
003oiMg<o`000003o`0000GohM_@00?o0000om_IeOoKfMD00ooKfMD2o`0000Oo`<cT1?l00004ojNi
i@03o`000?nS/>;oXk3R00GoXk3R00?o0000ojF]gOnU[Md00onU[Md3o`0000KoZJWG00?o0000ok2/
don`[=<01?n`[=<01?l0003o]JoCo`000?l00005okJ/c`03o`000?ni/=3o^K3@00;o^K3@00Go0000
ok^]c?nk[Lco^jg<o`000006okbac`03o`000?no[l_o000000Go^k?B0_l000000ono//co0000ok>d
f@06ok>df@Go00000onK/NH2o`0002Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`0Foooo
o`002_ooool00ol0003oooooooooo`03ooooo`oo00000_oYg/P3o`0000;oiMg<00?o0000on7Kd?oQ
fm000ooQfm000ol0003ofmWEom_Ie@03om_Ie@04o`000?oEemWoeMOIo`0000Co`<cT0_l000000ong
a^Ko0000ojNii@06ojNii@03o`000?nS/>;oXk3R00CoXk3R00?o0000ojF]gOnU[Md00ol000000onR
Z=_o0000ojVYe`06ojVYe`03o`000?n`[=?o/:cC00Co/:cC0_l00008okJ/c`04o`000?ni/=3o^K3@
o`0000Co^jg<00?o0000okbaconl/Ll00_nl/Ll2o`0000?o_jo;00?o0000ok^cd_nk/m800_nk/m80
1Ol0003o_k;<oknbc?no//co000000Go/kCI00?o0000ok^cd_l000001onK/NH2o`0002Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`002_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oJaLCof/G400?of/G400?o0000on_A^_o[dKX00_o[dKX00ol0003olMZhoo7J
^005o`0000;oiMg<00?o0000on7Kd?oQfm000ooQfm000ol0003ofmWEom_Ie@03om_Ie@03o`000?oE
emWoeMOI00;oeMOI00Co0000ol3<i?l0003o00001?nga^H00ol0003oYkWUojNii@05ojNii@04o`00
0?nS/>;oXk3Roj>`hPGo00001OnRZ=/00ol0003oZJWGojVYe`05ojVYe`04o`000?n`[=?o/:cCok2/
d`;o000000?o/:S@o`000?nf[<l01onf[<l00ol0003o^K3@o`000006ok^]c004o`000?nl/Loo_;7?
o`0000Ko_jo;00Ko0000ok^cd_nk/m;o0000oknbc?l00003oknbc003o`000?nc]=Wo/kCI00;o0000
0onk/m800ol0003oVk7Voi^aiP03oi^aiP?o00009oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooo
ooooool000006?ooool000[ooooo00?o0000ooooooooool00_ooool00ol0003of/G4om[5a003om[5
a003o`000?o[dK[ojm6j00;ojm6j00Co0000oo7J^?l0003o00000_oaf[P00ol0003ol=^koo3K^`05
o`0000;ohM_@00?o0000om_IeOoKfMD00ooKfMD00ol0003oeMOIomGGf@03omGGf@;o00001onga^H0
0ol0003oYkWUojNii@04ojNii@Co00000onMZ^000ol0003oXZSKoj:Xf`05oj:Xf`03o`000?nYZMOo
ZJWG00CoZJWG00Co0000ok2/dol0003o00001?n`Z=000ol0003o]Zc?okJ/c`05okJ/c`;o00001onk
[L`00ol0003o_;7?o`000007okn_b`03o`000?nk/m;o000000?o_k;<00Ko0000oknbc?no//co0000
ok>dfOl00005ok^cdP03o`000?nK/NKoVk7V00?o00000_ooool00ol0003oooooooooo`0Uooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`00000Hooooo`002_ooool01Ol0003ooooooooooooo
oooo000000Gof/G400?o0000on_A^_o[dKX00_o[dKX3o`0000?olMZh00?o0000oo3K^oo`fk/00_o`
fk/01?l0003okM^oongK_oo]fkl3o`0000CofmWE00?o0000omGGfOoEemT00ooEemT01?l0003oc]?N
olkCg_l00007okO6iP03o`000?nW^NGoYkWU00?o000000?oWk7Uo`000?nMZ^001OnMZ^000ol0003o
XZSKoj:Xf`04oj:Xf`03o`000?nYZMOoZJWG00CoZJWG0_l00007ok2Xd003o`000?nf[<oo]Zc?00;o
]Zc?0_l000000ongZL_o0000ok^]c006ok^]c0;o00002?no[l/2o`0000Go_k;<00Co0000oknbc?l0
003o00001_nk/m83o`0000Gooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo
00?o0000ooooooooool05_ooool000[ooooo00Co0000oooooooooooo00001_oJaL@00ol0003ojm6j
o`000003o`0000ColMZh00?o0000oo3K^oo`fk/00_o`fk/00ol0003okM^oongK_`03ongK_`06o`00
0?oZflCo0000o`000?oKfMGo00001OoEemT00ol0003oc]?NolkCgP02olkCgP03o`000?nga^Ko]lKV
00Co]lKV0ol00005oinai@03o`000?nMZ^3oWJ[P00CoWJ[P00?o0000oj:XfonRZ=/01?nRZ=/00ol0
003oZJWGojVYe`03o`000003ojRUdol0003o/:S@00Oo/:S@00Co0000okJ/col0003o00001?ngZL/0
0ol0003o^jg<ok^]c003ok^]c003o`000?nmZlSo000000Oo_jo;00?o0000ol6^a_l000001Ono//`2
o`000003ol>`aol0003o^k?B00Co^k?B00?o0000ooooooooool01_ooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0001Sooooo000:ooooo`03o`000?oooooo000000Kof/G4
0ol00002on_A^P03o`000?oaf[SolMZh00?olMZh00Go0000oo3K^oo`fk_ol=^ko`000005ongK_`03
o`000?oZflCoj]_400;oj]_40_l00004omGGf@03o`000?o>dmkoc]?N00Coc]?N00?o0000okO6i_ng
a^H00ol00002ojfni`03o`000?nO/NGoWk7U00CoWk7U00?o0000oifZh?nMZ^001?nMZ^001?l0003o
XZSKoj:XfonRZ=/5o`0000GoZ:GC00?o0000ok2Xd?n`Z=001On`Z=02o`0000Oo]jW;00?o0000ok^]
c?nk[L`00_l00003okf[b003o`000?no[l_o_jo;00;o_jo;0_l00003ol6^aP04o`000?no//co_k;<
oknbc0?o00000_o3/<L01Ol0003o^k?Bok^cd_nk/m;o000000[ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0000Hooooo`002Oooool01?l0003oooooooooool00003om[5a0Co
00001?o[dKX00ol0003olMZhoo7J^002oo7J^003o`000?o`fk_ol=^k00;ol=^k00?o0000ongK_oo]
fkl00_o]fkl00ol0003oj]_4on[Ka003on[Ka006o`000?oWf/So0000o`000?oEemWo00001oo>dmh3
o`0000Ko[KkW00?o0000oinaiOnO/ND00onO/ND00ol0003oWJ[PoifZh002oifZh0Ko00000onOXmP0
0ol0003oZ:GCojRUd`04ojRUd`03o`000?n`Z=3o/:S@00?o/:S@0_l000000on`Y/go0000okNYb`06
okNYb`03o`000?nk[Lco000000Ko_J_800Co0000okn_bono[l_o00001Oo1[/H01?l0003o_k;<oknb
c?l00003ol>`a`03o`000?o3/<Oo000000;o^k?B00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool00ol0003oooooooooo`0Fooooo`002Oooool01?l0003o
ooooo`000?oJaL@3o`0000;of/G400?o0000on_A^_o[dKX00_o[dKX00ol0003olMZhoo7J^003oo7J
^005o`000?o`fk_ol=^koo3K^ol000001Oo]fkl00ol0003oj]_4on[Ka002on[Ka003o`000?oWf/So
im[800;oim[80_l00006olkCgP05o`000?o5c^;oaLkRolG>h_l000001_n]_^L01?l0003oWk7Uoina
iOnO/ND6o`0000?oV:CM00?o0000oinSf?nOXmP01?nOXmP00ol0003oZ:GCojRUd`04ojRUd`05o`00
0?n`Z=3o/:S@ok2Xd?l000001?n`Y/d00ol0003o]jW;okNYb`04okNYb`;o00001onmZlP00ol0003o
_jo;o`000006ol6^aP03o`000?no//co000000Go`k370_l000000onk/m;o0000ooooo`0;ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Fooooo`002Oooool4o`0000Co
f/G400?o0000on_A^_o[dKX00oo[dKX00ol0003olMZhoo7J^002oo7J^005o`000?o`fk_ol=^koo3K
^ol000001Oo]fkl00ol0003oj]_4on[Ka002on[Ka003o`000?oWf/Soim[800?oim[800?o0000on;I
cOl000000oo>dmh2o`0000GoaLkR00Co0000ojfnion]_^Oo[KkW1_l00002oiNYh`03o`000?nHY=go
V:CM00GoV:CM00?o0000oinSf?nOXmP00onOXmP00ol0003oZ:GCojRUd`04ojRUd`04o`000?n`Z=3o
0000o`0000Go/:K=00?o0000okNYbongZL/00ongZL/00ol0003o^:O8o`000007okf[b0;o00002?o1
[/H00ol0003o`k37ol>`a`04ol>`a`03o`000?o3/<Oo000000gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Fooooo`002Oooool2o`0000Kof/G400?o0000on_A^_o[dKX00_o[
dKX00ol0003olMZhoo7J^002oo7J^003o`000?o`fk_ol=^k00;ol=^k00?o0000ongK_oo]fkl00_o]
fkl00ol0003oj]_4on[Ka003on[Ka003o`000?oWf/Soim[800;oim[800Oo0000on;IcOoRfLgoh]W=
o`000?o>dmko000000OoaLkR1?l00003oj:fi`03o`000?nGZN?oUjWS00?oUjWS00?o0000oiRTgOnH
Y=d01?nHY=d00ol0003oWj?HoinSf004oinSf003o`000?nXYM?oZ:GC00?oZ:GC0_l00008ok2Vc@05
o`000?ngZL_o]jW;okNYbol000000onhYlP00ol0003o_J_8okf[b003okf[b003o`000?nnZLCo0000
00Oo`Jk60_l00007ol>`a`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Kooooo000;ooooo`03o`000?oJaLCof/G400;of/G400?o0000on_A
^_o[dKX00oo[dKX00ol0003olMZhoo7J^002oo7J^005o`000?o`fk_ol=^koo3K^ol000001Oo]fkl0
0ol0003oj]_4on[Ka002on[Ka003o`000?oWf/Soim[800;oim[800?o0000on;IcOoRfLd00ooRfLd2
o`0000GoaLkR0_l000000onjb>Go0000oj:fi`05oj:fi`03o`000?nGZN?oUjWS00?oUjWS00?o0000
oiRTgOnHY=d01?nHY=d00ol0003oWj?HoinSf003oinSf003o`000?nXYM?oZ:GC00?o000000?oYj;A
o`000?n`Y/d01on`Y/d01?l0003o]jW;okNYbol00004okRWb003o`000?nmZlSo_J_800;o_J_800Go
0000okjYa?nnZLCo_ZW4o`000005ol6^aP04o`000?o3[<?o`jc3o`0000Go`k3700?o0000ooooool0
00003Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05_ooool000co
oooo00Go0000om[5a?oJaLCof/G4o`000004on_A^P03o`000?oaf[SolMZh00;olMZh00?o0000oo3K
^oo`fk/00_o`fk/00ol0003okM^oongK_`02ongK_`03o`000?oZflCoj]_400;oj]_400?o0000onOJ
b?oWf/P00_oWf/P00ol0003oh]W=on;Ic@03on;Ic@03o`000?oMf=;ogMSB00;o000000?oaLkRo`00
0?l000001?njb>D00ol0003oX[KWoj:fi`04oj:fi`03o`000?nGZN?oUjWS00?oUjWS00?o0000oiRT
gOnHY=d00onHY=d01?l0003oWj?HoinSf?nOXmP5o`0000GoYj;A00?o0000ok2VcOn`Y/d01On`Y/d0
0ol0003o]jW;o`000006okRWb004o`000?nmZlSo_J_8o`0000Co_ZW400?o0000ol6^a_o1[/H00_o1
[/H01Ol0003o`jc3ol>/`oo3[<?o000000Co`k3700Go0000ooooooooooooooooo`00000<ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo027ooooo3?l0000?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Kooooo000=ooooo`03
o`000?oJaLCo000000Cojm6j00?o0000oo7J^?oaf[P00ooaf[P01Ol0003ol=^koo3K^oo`fk_o0000
00GokM^o00?o0000on[Ka?oZfl@00_oZfl@00ol0003oim[8onOJb002onOJb003o`000?oRfLgoh]W=
00;oh]W=00?o0000omgHd_oMf=800ooMf=800ol0003o^/SUok[8i@05ok[8i@04o`000?nR]^OoX[KW
oj:fia;o00000onLWmH00ol0003oYj;AojNRd@05ojNRd@03o`000?n`Y/go/:K=00Co/:K=0_l00007
okRWb003o`000?nmZlSo000000Ko_ZW400Co0000ol6^a_o1[/Ko00001Oo3[<<01?l0003o`k37ol>`
aol00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool07oooool3o`0000cooooo0_l0000>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool05_ooool000kooooo1?l00002on_A^P03o`000?oaf[SolMZh00;o
lMZh00?o0000oo3K^ol000001Ol00002ongK_`03o`000?oZflCoj]_400;oj]_400?o0000onOJb?oW
f/P00_oWf/P00ol0003oh]W=on;Ic@02on;Ic@03o`000?oMf=;ogMSB00?ogMSB00?o0000omKFf?l0
00001_njb>D4o`0000?oUZgW00?o0000ohjQhOn>XN400on>XN400ol0003oTYgKoi:Mf`03oi:Mf`03
o`000?nLWmKoW9oF00CoW9oF00?o0000ojNRdOnWX]401?nWX]400ol0003o/:K=ok2Vc@02ok2Vc@;o
000000?o/:?;o`000?nhYlP01_nhYlP2o`0000Oo_ZW400?o0000ol6^a_l000001_o3[<<00ol0003o
`k37o`000006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool07?ooool3o`00017ooooo0_l0000=oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo01Kooooo000?ooooo`;o000000?oooooo`000?l000001ol00006oooo
o`Wo00000_oWf/P00ol0003oh]W=on;Ic@02on;Ic@03o`000?oMf=;ogMSB00?ogMSB00Go0000omKF
f?oFe]Soe]KHo`000002ok[8i@?o00000_n^`NP00ol0003oUZgWoiJ]i`03oiJ]i`03o`000?n>XN7o
SZ7Q00?oSZ7Q00?o0000oi:MfonBWM/00onBWM/00ol0003oW9oFoibOeP03oibOeP03o`000?nWX]7o
Yj;A00GoYj;A00Co0000ok2VcOl0003o00001?n`Xl/00ol0003o^:O8okRWb003okRWb003o`000?ni
YLGo000000So_ZW400?o0000ol>/`oo3[<<01_o3[<<00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool06_ooool2o`0001Kooooo0_l0000<ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Ko
oooo000Aooooo`03o`000?oooooooooo01Kooooo1?l00002on;Ic@03o`000?oMf=;ogMSB00?ogMSB
00?o0000omKFf?oFe]P00ooFe]P2o`0000Ko[/7X00?o0000oiJ]ionF[NL00onF[NL00ol0003oSZ7Q
ohjQh@03ohjQh@03o`000?nBWM_oTYgK00?oTYgK00?o0000oibOe_nLWmH00onLWmH00ol0003oYj;A
ojNRd@03ojNRd@?o00001_n`Xl/00ol0003o^:O8okRWb002okRWb005o`000?niYLGo^JG5okVUaOl0
00001_nnZL@2o`0000Oo`jc300?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Ioooo
o`;o00006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo000Booooo`03o`000?oooooooooo
01Wooooo0ol00004omgHdP03o`000?oFe]Soe]KH00?oe]KH00Co0000olkBgOo>d]go00001_n^`NP0
0ol0003oUZgWoiJ]i`02oiJ]i`03o`000?n>XN7oSZ7Q00?oSZ7Q00?o0000oi:MfonBWM/00onBWM/0
0ol0003oW9oFoibOeP03oibOeP03o`000?nWX]7oYj;A00?o00000_nVW/h00ol0003o/:?;ok2Sb`05
ok2Sb`04o`000?nhYlSo^:O8o`0000Co^JG500?o0000okjYa?nnZL@00onnZL@01?l0003o`:S1ol2X
`Ol00005ol>/``03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Sooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool001?ooooo
00?o0000ooooooooool06oooool2o`000003omgHd_l0003oe]KH00Coe]KH00?o0000olkBgOo>d]d0
0_o>d]d01?l0003o[/7Xojk1j?n^`NPLo`0000KoYYk>00?o0000ok2Sbon`Xl/01?n`Xl/00ol0003o
^:O8o`000006okVUa@05o`000?nnZLCo_ZW4okjYa?l000000oo0Z<400ol0003o`jc3ol>/``02ol>/
``03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool001Cooooo00?o0000oooooooo
ool07?ooool2o`0000Coe]KH00?o0000olkBgOo>d]d00oo>d]d4o`0000?oX;SY00?o0000ohVSiOn9
XnD00_n9XnD00ol0003oQYWOohJIg`03ohJIg`03o`000?n>V=WoSYSI00?oSYSI00?o0000oiZJdonJ
V]<00onJV]<00ol0003oYYk>ojJNcP05ojJNcP03o`000?n`Xl_o/:?;00Co/:?;0_l00007okVUa@04
o`000?nnZLCo_ZW4o`0000Go`:S100Co0000ol>/`oo3[<?o00003oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0E
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Fooooo`005Oooool2
o`0001kooooo0_l000000ooFe]So0000olkBg@04olkBg@03o`000?o3cN;o000000KoX;SY00?o0000
ohVSiOn9XnD00_n9XnD00ol0003oQYWOohJIg`03ohJIg`03o`000?n>V=WoSYSI00?oSYSI00?o0000
oiZJdonJV]<00onJV]<00ol0003oYYk>ojJNcP05ojJNcP04o`000?n`Xl_o/:?;ok2Sb`;o000000?o
/:78o`000?niYLD01_niYLD00ol0003o_ZW4o`000006ol2X`@03o`000?o3[<?o0000013ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
6?ooool001Oooooo00?o0000ooooooooool07Oooool2o`0000?oc];M0_l00003ol?=hP03o`000?nP
^>WoX;SY00CoX;SY00?o0000ohVSiOn9XnD00_n9XnD00ol0003oQYWOohJIg`02ohJIg`03o`000?n>
V=WoSYSI00?oSYSI00?o0000oiZJdonJV]<01?nJV]<00ol0003oYYk>ojJNcP04ojJNcP04o`000?n`
Xl_o0000o`0000Co/:7800?o0000okVUaOniYLD01?niYLD2o`0000So`:S100?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Hooooo`006?ooool00ol0003oooooooooo`0Nooooo`03o`000?o>d]go000000Ko`lgR
00Co0000oj2hjOnP^>WoX;SY1ol000000on9XnGo0000ohJIg`03ohJIg`03o`000?n>V=WoSYSI00?o
SYSI00?o0000oiZJdonJV]<00onJV]<00ol0003oYYk>ojJNcP04ojJNcP;o00001_n`XLP00ol0003o
^JG5okVUa@03okVUa@03o`000?niXl?o000000Oo`:S100?o0000ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Eooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Foooo
o`006Oooool00ol0003oooooooooo`0Nooooo`;o00001_o3cN84o`0000?oT:gY00Co0000ogfIhomm
VN?oOIWS1ol00005ohjHf@03o`000?nJV]?oVY[C00CoVY[C00?o0000ojJNc_nVW/h00ol000000onU
Vlco0000ok2Qb006ok2Qb003o`000?niYLGo^JG500;o00000oniXl<00ol0003o`:S1ol2X`@03ol2X
`@03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>oooo
o`_o00003Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo01Kooooo000Jooooo`;o00008?ooool2o`00
0004ol?=h_l0003o0000o`0000?o]/OW00?o0000oi2]jOn@[NT00_n@[NT00ol0003oOIWSogfIh`02
ogfIh`04o`000?mmTMcoOI7LogfAg13o00001OnUVl`00ol0003o/:78ok2Qb004ok2Qb003o`000?ni
YLGo000000Go^J?300?o0000ol2X`Oo0Z<400_o0Z<400ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03?ooool3o`0000_ooooo0_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Sooooo000Looooo`03o`000?oooooooooo01oooooo00?o0000okK7ionfanL01Onf
anL00ol0003oT:gYoi2]j@02oi2]j@03o`000?mmVN?oOIWS00;oOIWS00Go0000ogfAg?mmTMcoOI7L
o`000005ohVBeP03o`000?nHU]3oV9K@00CoV9K@00?o0000ojFKc?nUVl`01?nUVl`00ol0003o/:78
ok2Qb004ok2Qb0;o00001oniXl<01?l0003o`:S1ol2X`Ol0000Iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02oooool2o`00013ooooo0_l0000;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool05_ooool001gooooo00?o0000ooooooooool07oooool00ol0003o]/OWokK7i`04okK7i`Ko
00001OmmVN<01Ol0003oOI7LogfAg?mmTMco000000GoRI;F00?o0000oiRFd?nHU]001?nHU]000ol0
003oYI_<ojFKc004ojFKc003o`000?n`XLSo/:7800;o/:7800?o0000ok2NaOl000001oniXl<00ol0
003o`:S1o`00000Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool2o`00
01Cooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05_ooool001kooooo00?o0000oooo
ooooool07oooool00ol0003o]/OWokK7i`03o`000003ojJnj_l0003oOj3X00;oOj3X1Ol000000omm
VN?o0000ogfAg003ogfAg003o`000?n9T]KoRI;F00;oRI;F00?o0000oiRFd?nHU]001?nHU]000ol0
003oYI_<ojFKc004ojFKc003o`000?n`XLSo/:7800;o00000on`W/D00ol0003o^J?3okVS``04okVS
``;o00007Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oooooooooo
01oooooo0_l00005ojJnjP05o`000?moX>SoOj3XognPj?l000000om`S^05o`000003ogfAg?l0003o
RI;F00CoRI;F00?o0000oiRFd?nHU]001?nHU]000ol0003oYI_<ojFKc003ojFKc003o`000?n`XLSo
000000Go/9k500?o0000okVS`oniXl<00oniXl<00ol0003oooooooooo`0Mooooo`05o`000?oooooo
ooooooooool000007oooool3o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o00008?ooool00ol0003oY[kZojJnjP04
ojJnjP05o`000?moX>SoOj3XognPj?l000001?m`S^000ol0003oMHWIogF9f@03o`0000GoRI;F00?o
0000oiRFd?nHU]000onHU]001?l0003oYI_<ojFKc?nUVl`4o`0000Oo/9k500Go0000okVS`oniXl?o
^J?3o`00000Qooooo`04o`000?ooooooooooo`00023ooooo00Co0000oooooooooooooooo0_l00003
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool2o`0001cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Fooooo`008_ooool00ol0003oooooooooo`0Noooo
o`04o`000?nV_^[oY[kZojJnjPGo00000_moX>P00ol0003oL8kPog2>h002og2>h003o`000?meRMWo
MHWI00;oMHWI1?l000000on9T]Ko0000oiRFd002oiRFd0Ko00000onTVLT00ol0003o/9k5ok2Na@05
ok2Na@04o`000?niXl?o^J?3o`0002?ooooo00?o0000ooooool000008?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`008ooo
ool00ol0003oooooooooo`0Nooooo`?o00001Oooool3o`0000CoL8kP00?o0000ogF9fOmeRMT00_me
RMT01?l0003oQ8cCohB<don4S=<5o`0000?oUI;>00?o0000ojBIbOnTVLT01?nTVLT00ol0003o/9k5
ok2Na@04ok2Na@03o`000?niXl?o000002Cooooo00Co0000oooooooooooo00007oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Foooo
o`009?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo0ol00002og2>h003
o`000?meRMWoMHWI00;oMHWI00?o0000ohB<don4S=<00_n4S=<00ol0003oUI;>oiFBcP04oiFBcP03
o`000?nTVLWoY9W900?oY9W900?o0000ok2NaOn`W/D01?n`W/D2o`0002Kooooo00?o0000ooooool0
00007_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool:o`0000cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[o
oooo0ol00004ogF9f@03o`000?n4S=?oQ8cC00?oQ8cC00?o0000oiFBc_nET/h00onET/h00ol0003o
Y9W9ojBIb@04ojBIb@03o`000?n`W/Go/9k500;o/9k500?o0000ooooooooool09oooool2o`0002?o
oooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool2o`0000[ooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Foooo
o`009_ooool2o`0001gooooo00?o0000ooooooooool03Oooool3o`0000;oMHWI00?o0000ohB<don4
S=<00_n4S=<00ol0003oUI;>oiFBcP04oiFBcP03o`000?nTVLWoY9W900?oY9W900?o0000ok2NaOn`
W/D00_l0000Yooooo`?o00008oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`?o00003_ooool3o`0000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Fooooo`00:?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo017ooooo0ol00005ohB<d`03o`000?nET/koUI;>00?oUI;>00?o0000ojBIbOnT
VLT00onTVLT00ol0003o/9k5o`00000Wooooo`Co00009_ooool01?l0003oooooooooool0000Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0001Cooooo0_l00008oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool002Wooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Dooooo`Co000000?oQ8cCo`000?nET/h01?nET/h01?l0003o
Y9W9ojBIbOnTVLT4o`0002Gooooo0ol0000Zooooo`04o`000?ooooooooooo`00017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo0_l00007
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`05o`000?ooooooooooooooool000006?ooool002[ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Hooooo`_o00009Oooool4o`0002gooooo00?o0000ooooool000004Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0000Kooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo017ooooo00Go0000ooooooooooooooooo`00000Hooooo`00:oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04Cooooo1?l0000aooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo0_l00006
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`05o`000?ooooooooooooooool000006?ooool002cooooo0_l0000Fooooo`03o`000?oooooo
oooo047ooooo0ol0000eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooool0000Hooooo`00;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo03gooooo1?l0000hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo3_l0000;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo00006?ooool002oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0iooooo`Co0000??ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`;o00003_ooool3
o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`00<?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Gooooo1?l00010ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04Oooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Fooooo`00<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000Fooooo`;o00001Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Kooooo000booooo`;o00004?ooool00ol0003ooooo
ooooo`0^ooooo`Co0000Aoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo
000dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:_ooool4o`0004_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09oooool3o`0004oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0F
ooooo`00=_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo1?l0001Boooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool<o`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo000gooooo`;o
00002oooool00ol0003oooooooooo`0Oooooo`Co0000E_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Oooooo0ol0000<ooooo`?o00002?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool003Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Looooo`?o0000F_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo0_l0000Booooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05_ooool003[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Hooooo`Co0000GOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo0_l0000Fooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05_ooool003_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Eooooo`Co0000HOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`00??ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo1?l0001Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool003go
oooo0_l00004ooooo`03o`000?oooooooooo00kooooo0ol0001Yooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`co00002Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Fooooo`00?oooool01Ol0003ooooooooooooooooo000000cooooo1?l0001/ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`?o
00003?ooool3o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool0043ooooo00Co0000oooooooooooo
00002?ooool4o`00073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05_ooool0047ooooo00?o0000ooooool000001Oooool3o`0007Cooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Fooooo`00@_ooool2o`000003ooooool0003o000000;o0000Mooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01Kooooo0013ooooo`;o0000Noooooma
o`0001Sooooo003ooooood[ooooo003ooooood[ooooo0000\
\>"],
  ImageRangeCache->{{{118.938, 447.375}, {413.562, 287.812}} -> {-0.826509, \
1.83723, 0.00516043, 0.00516043}, {{128.125, 275.75}, {410.562, 290.75}} -> \
{-0.826774, 1.90236, 0.00516226, 0.00516226}, {{290.5, 438.125}, {410.562, \
290.75}} -> {-8.53767, 4.62576, 0.0187015, 0.0149612}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["derivatives=Map[D[Rosenbrock[p,x,y],#]&,{x,y}]", "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({2\ \((\(-1\) + x)\) + 
        4\ p\ x\ \((x\^2 - y)\), \(-2\)\ p\ \((x\^2 - y)\)}\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[BoxData[
    \(\(iterator[{x_, y_}] = {x, y} - 
          Inverse[Outer[D, derivatives, {x, y}]] . derivatives;\)\)], "Input",\

  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[iterator, {0, 0}, 2] // Simplify\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \({{0, 0}, {1, 0}, {1, 1}}\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve[derivatives==0,{x,y}]", "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{y \[Rule] 1, x \[Rule] 1}}\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell["\<\
La fonction de Rosenbrock est utilis\[EAcute]e pour tester les \
algorithmes d'optimisation\[NonBreakingSpace]; il se trouve qu'en partant de \
l'approximation initiale {0,0}, la m\[EAcute]thode de Newton converge vers la \
solution exacte en deux \[EAcute]tapes.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Un avantage connu de la m\[EAcute]thode de Newton tient \[AGrave] \
ce qu'elle converge sous des hypoth\[EGrave]ses assez peu restrictives (crit\
\[EGrave]re de convexit\[EAcute]) et b\[EAcute]n\[EAcute]ficie d'une \
convergence quadratique, donc rapide\[NonBreakingSpace]: peu \
d'it\[EAcute]rations suffisent en g\[EAcute]n\[EAcute]ral \[AGrave] une bonne \
approximation. Elle se g\[EAcute]n\[EAcute]ralise d'ailleurs aux \
\[EAcute]quations op\[EAcute]ratorielles en espaces de Banach. Bien entendu, \
l'int\[EAcute]r\[EHat]t de la m\[EAcute]thode symbolique vient de ce que l'on \
acc\[EGrave]de \[AGrave] une forme litt\[EAcute]rale de l'approximation, plus \
commode qu'une solution purement num\[EAcute]rique pour les raisonnements ou \
calculs ult\[EAcute]rieurs.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["M\[EAcute]thode de Galerkin", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[TextData[{
  StyleBox["La m\[EAcute]thode de Galerkin r\[EAcute]sout (par approximation) \
les probl\[EGrave]mes de valeurs aux limites couramment rencontr\[EAcute]s en \
physique des milieux continus. Nous nous restreindrons aux probl\[EGrave]mes \
elliptiques lin\[EAcute]aires du second ordre (\[EAcute]quations de Laplace g\
\[EAcute]n\[EAcute]ralis\[EAcute]es, qui d\[EAcute]crivent des ph\[EAcute]nom\
\[EGrave]nes statiques) \[AGrave] conditions aux limites homog\[EGrave]nes, \
tout en restant conscients de la plus grande port\[EAcute]e de ces \
id\[EAcute]es. La m\[EAcute]thode est g\[EAcute]n\[EAcute]ralement \
pr\[EAcute]sent\[EAcute]e sous l'angle des formulations faibles, qui \
conduisent d'une part \[AGrave] des th\[EAcute]or\[EGrave]mes d'existence, \
unicit\[EAcute] et convergence et d'autre part \[AGrave] des techniques \
d'approximation. Sch\[EAcute]matiquement, en partant d'une \[EAcute]quation \
diff\[EAcute]rentielle ou aux d\[EAcute]riv\[EAcute]es partielles assortie de \
conditions aux limites, symboliquement not\[EAcute]e Au=f, on obtient \
l'approximation en deux \[EAcute]tapes\[NonBreakingSpace]: d'abord, une \
formulation faible (multiplier par une fonction test puis int\[EAcute]grer) \
conduit \[AGrave] une formulation int\[EAcute]grale du probl\[EGrave]me \
initial, impliquant un op\[EAcute]rateur bilin\[EAcute]aire et un \
op\[EAcute]rateur lin\[EAcute]aire\[NonBreakingSpace]: \
a[u,v]=<Au,v>=<f,v>=l[v]\[NonBreakingSpace]; ensuite, on cherche une \
approximation sous forme d'une combinaison lin\[EAcute]aire de fonctions pr\
\[EAcute]alablement choisies : ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\_j\)]],
  StyleBox[" c",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" w",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" o\[UGrave] les c",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" sont les inconnues\[NonBreakingSpace]; cela conduit \[AGrave] un \
syst\[EGrave]me d'\[EAcute]quations alg\[EAcute]briques que l'on \
r\[EAcute]sout par les techniques d'alg\[EGrave]bre lin\[EAcute]aire.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1,
  AspectRatioFixed->True],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\_j\)]],
  StyleBox[" c",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j ",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["<Aw",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",w",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[">=<f,w",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[">, ou encore\[NonBreakingSpace]: ",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\_j\)]],
  StyleBox[" c",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j ",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["a[",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",w",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["]=l[",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["]",
    CellMargins->{{156, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1],

Cell["\<\
La m\[EAcute]thode des \[EAcute]l\[EAcute]ments finis consiste \
\[AGrave] choisir des fonctions de base dont le support est d\[EAcute]termin\
\[EAcute] par un maillage du domaine, ce qui conduit \[AGrave] des \
approximations affines ou polynomiales par morceaux ; mais on a loisir de \
choisir d'autres types de fonctions, selon la g\[EAcute]om\[EAcute]trie du \
domaine, des consid\[EAcute]rations d'orthogonalit\[EAcute] ou encore en \
s'inspirant de constatations exp\[EAcute]rimentales. D'un c\[OHat]t\[EAcute], \
on aboutit \[AGrave] des approximations purement num\[EAcute]riques par r\
\[EAcute]solution de grands syst\[EGrave]mes lin\[EAcute]aires \[AGrave] \
matrices creuses\[NonBreakingSpace]; de l'autre c\[OHat]t\[EAcute], on acc\
\[EGrave]de \[AGrave] des approximations symboliques par r\[EAcute]solution \
de petits syst\[EGrave]mes, si bien que des expressions litt\[EAcute]rales \
avec des param\[EGrave]tres sont possibles. Toutes sortes \
d'interm\[EAcute]diaires sont imaginables, par exemple des ondelettes.\
\>", \
"Text",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1,
  AspectRatioFixed->True],

Cell["\<\
La proc\[EAcute]dure est enti\[EGrave]rement d\[EAcute]termin\
\[EAcute]e par les op\[EAcute]rateurs lin\[EAcute]aire et bilin\[EAcute]aire \
ainsi qu'une famille de fonctions de base, ce qui conduit \[AGrave] un \
programme fonctionnel compact\[MediumSpace]\[Ellipsis]\
\>", "Text",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \)\(GalerkinApproximation[a_, l_, 
        basis_] := \n\ \ \ Dot[\[IndentingNewLine]LinearSolve[\
\[IndentingNewLine]Transpose[
            Outer[a, basis, basis]]\ , \[IndentingNewLine]Map[l, 
            basis]\[IndentingNewLine]], basis]\)\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell["\<\
Appliquons-la \[AGrave] l'\[EAcute]quation -u\"+ku=x, u[0]=u[1]=0\
\[NonBreakingSpace]; les op\[EAcute]rateurs bilin\[EAcute]aire et \
lin\[EAcute]aire sont respectivement\[NonBreakingSpace]: a[u,v]=\[Integral]u'\
\[MediumSpace]v' et l[v]=\[Integral]x\[MediumSpace]v.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[BoxData[
    \(\(exactSolution = 
        u[x] /. DSolve[{\(-\(u''\)[x]\) + k\ u[x] == 
                x, \[IndentingNewLine]u[0] == 0, u[1] == 0}, u[x], 
            x];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[{
    \(a[u_, v_] := 
      Integrate[D[u, x]\ D[v, x], {x, 0, 1}] + 
        k\ Integrate[u\ v, {x, 0, 1}]\), "\n", 
    \(l[v_] := Integrate[x\ v, {x, 0, 1}]\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \(trigBasis[n_] := Sin[Range[n] Pi\ x]\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(GalerkinApproximation[a, l, trigBasis[2]]\)\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \(\(2\ Sin[\[Pi]\ x]\)\/\(\[Pi]\ \((k + \[Pi]\^2)\)\) - 
      Sin[2\ \[Pi]\ x]\/\(\[Pi]\ \((k + 4\ \[Pi]\^2)\)\)\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{\[IndentingNewLine]Plot[
              Evaluate[{exactSolution, 
                    GalerkinApproximation[a, l, trigBasis[1]]} /. 
                  k -> 1], {x, 0, 1}, DisplayFunction -> Identity, 
              PlotStyle -> {Dashing[{}], 
                  Dashing[{0.02, 0.02}]}], \[IndentingNewLine]Plot[
              Evaluate[{exactSolution, 
                    GalerkinApproximation[a, l, trigBasis[2]]} /. 
                  k -> 1], {x, 0, 1}, DisplayFunction -> Identity, 
              PlotStyle -> {Dashing[{}], Dashing[{0.02, 0.02}]}]\n}], 
        DisplayFunction -> $DisplayFunction];\)\)], "Input",
  CellMargins->{{21, Inherited}, {Inherited, Inherited}},
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 10.0498 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11521 -24 -4.5 ]
[.01131 .11521 0 4.5 ]
[.01131 .21571 -24 -4.5 ]
[.01131 .21571 0 4.5 ]
[.01131 .31621 -24 -4.5 ]
[.01131 .31621 0 4.5 ]
[.01131 .41671 -24 -4.5 ]
[.01131 .41671 0 4.5 ]
[.01131 .5172 -24 -4.5 ]
[.01131 .5172 0 4.5 ]
[.01131 .6177 -24 -4.5 ]
[.01131 .6177 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11521 m
.03006 .11521 L
s
[(0.01)] .01131 .11521 1 0 Mshowa
.02381 .21571 m
.03006 .21571 L
s
[(0.02)] .01131 .21571 1 0 Mshowa
.02381 .31621 m
.03006 .31621 L
s
[(0.03)] .01131 .31621 1 0 Mshowa
.02381 .41671 m
.03006 .41671 L
s
[(0.04)] .01131 .41671 1 0 Mshowa
.02381 .5172 m
.03006 .5172 L
s
[(0.05)] .01131 .5172 1 0 Mshowa
.02381 .6177 m
.03006 .6177 L
s
[(0.06)] .01131 .6177 1 0 Mshowa
.125 Mabswid
.02381 .03481 m
.02756 .03481 L
s
.02381 .05491 m
.02756 .05491 L
s
.02381 .07501 m
.02756 .07501 L
s
.02381 .09511 m
.02756 .09511 L
s
.02381 .13531 m
.02756 .13531 L
s
.02381 .15541 m
.02756 .15541 L
s
.02381 .17551 m
.02756 .17551 L
s
.02381 .19561 m
.02756 .19561 L
s
.02381 .23581 m
.02756 .23581 L
s
.02381 .25591 m
.02756 .25591 L
s
.02381 .27601 m
.02756 .27601 L
s
.02381 .29611 m
.02756 .29611 L
s
.02381 .33631 m
.02756 .33631 L
s
.02381 .35641 m
.02756 .35641 L
s
.02381 .37651 m
.02756 .37651 L
s
.02381 .39661 m
.02756 .39661 L
s
.02381 .43681 m
.02756 .43681 L
s
.02381 .45691 m
.02756 .45691 L
s
.02381 .47701 m
.02756 .47701 L
s
.02381 .49711 m
.02756 .49711 L
s
.02381 .5373 m
.02756 .5373 L
s
.02381 .5574 m
.02756 .5574 L
s
.02381 .5775 m
.02756 .5775 L
s
.02381 .5976 m
.02756 .5976 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .0754 L
.10458 .14091 L
.14415 .20115 L
.18221 .25733 L
.22272 .31461 L
.26171 .36668 L
.30316 .41805 L
.34309 .46298 L
.3815 .50138 L
.42237 .53633 L
.46172 .56359 L
.49955 .58325 L
.51896 .59064 L
.52979 .59393 L
.53984 .59644 L
.54994 .59841 L
.55528 .59923 L
.56097 .59993 L
.56358 .60019 L
.5664 .60042 L
.56888 .6006 L
.57151 .60074 L
.57388 .60083 L
.57523 .60087 L
.57649 .6009 L
.57764 .60092 L
.5787 .60093 L
.57991 .60093 L
.58106 .60092 L
.5822 .60091 L
.58343 .60089 L
.58459 .60086 L
.58565 .60082 L
.58812 .60072 L
.59072 .60057 L
.59562 .60018 L
.60097 .59959 L
.61052 .5981 L
.61939 .59621 L
.62992 .59333 L
.63985 .58996 L
.65844 .5819 L
.67845 .57062 L
.6969 .55774 L
.73631 .52188 L
.77419 .47609 L
.81453 .41435 L
.85336 .34148 L
.89464 .24862 L
Mistroke
.9344 .14328 L
.97264 .02637 L
.97619 .01472 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .01472 m
.06244 .08953 L
.10458 .16969 L
.14415 .24228 L
.18221 .30846 L
.22272 .3738 L
.26171 .43065 L
.30316 .48353 L
.34309 .52621 L
.3815 .55892 L
.40095 .57218 L
.42237 .58412 L
.44268 .59283 L
.45178 .59589 L
.46172 .59863 L
.4671 .59986 L
.4721 .60083 L
.47727 .60167 L
.48196 .60228 L
.48658 .60274 L
.4887 .60291 L
.49093 .60306 L
.49332 .60318 L
.49438 .60322 L
.49552 .60326 L
.49675 .60329 L
.49789 .60331 L
.49859 .60331 L
.49925 .60332 L
.50049 .60332 L
.50163 .60331 L
.50286 .60329 L
.50401 .60327 L
.50508 .60324 L
.50754 .60314 L
.51014 .60299 L
.51268 .6028 L
.51504 .6026 L
.5204 .60199 L
.5293 .60057 L
.53882 .5985 L
.54906 .59563 L
.56016 .59177 L
.58032 .58278 L
.62123 .55688 L
.66064 .5226 L
.69852 .48155 L
.73886 .42986 L
.77769 .37317 L
.81897 .30648 L
Mistroke
.85873 .23712 L
.89697 .16678 L
.93767 .08931 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 9.72557 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11197 -24 -4.5 ]
[.01131 .11197 0 4.5 ]
[.01131 .20923 -24 -4.5 ]
[.01131 .20923 0 4.5 ]
[.01131 .30648 -24 -4.5 ]
[.01131 .30648 0 4.5 ]
[.01131 .40374 -24 -4.5 ]
[.01131 .40374 0 4.5 ]
[.01131 .50099 -24 -4.5 ]
[.01131 .50099 0 4.5 ]
[.01131 .59825 -24 -4.5 ]
[.01131 .59825 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11197 m
.03006 .11197 L
s
[(0.01)] .01131 .11197 1 0 Mshowa
.02381 .20923 m
.03006 .20923 L
s
[(0.02)] .01131 .20923 1 0 Mshowa
.02381 .30648 m
.03006 .30648 L
s
[(0.03)] .01131 .30648 1 0 Mshowa
.02381 .40374 m
.03006 .40374 L
s
[(0.04)] .01131 .40374 1 0 Mshowa
.02381 .50099 m
.03006 .50099 L
s
[(0.05)] .01131 .50099 1 0 Mshowa
.02381 .59825 m
.03006 .59825 L
s
[(0.06)] .01131 .59825 1 0 Mshowa
.125 Mabswid
.02381 .03417 m
.02756 .03417 L
s
.02381 .05362 m
.02756 .05362 L
s
.02381 .07307 m
.02756 .07307 L
s
.02381 .09252 m
.02756 .09252 L
s
.02381 .13142 m
.02756 .13142 L
s
.02381 .15087 m
.02756 .15087 L
s
.02381 .17032 m
.02756 .17032 L
s
.02381 .18978 m
.02756 .18978 L
s
.02381 .22868 m
.02756 .22868 L
s
.02381 .24813 m
.02756 .24813 L
s
.02381 .26758 m
.02756 .26758 L
s
.02381 .28703 m
.02756 .28703 L
s
.02381 .32593 m
.02756 .32593 L
s
.02381 .34538 m
.02756 .34538 L
s
.02381 .36484 m
.02756 .36484 L
s
.02381 .38429 m
.02756 .38429 L
s
.02381 .42319 m
.02756 .42319 L
s
.02381 .44264 m
.02756 .44264 L
s
.02381 .46209 m
.02756 .46209 L
s
.02381 .48154 m
.02756 .48154 L
s
.02381 .52044 m
.02756 .52044 L
s
.02381 .5399 m
.02756 .5399 L
s
.02381 .55935 m
.02756 .55935 L
s
.02381 .5788 m
.02756 .5788 L
s
.02381 .6177 m
.02756 .6177 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .07344 L
.10458 .13684 L
.14415 .19514 L
.18221 .24951 L
.22272 .30494 L
.26171 .35533 L
.30316 .40504 L
.34309 .44852 L
.3815 .48568 L
.42237 .5195 L
.46172 .54588 L
.49955 .5649 L
.51896 .57206 L
.52979 .57525 L
.53984 .57767 L
.54994 .57958 L
.55528 .58037 L
.56097 .58105 L
.56358 .5813 L
.5664 .58153 L
.56888 .58169 L
.57151 .58183 L
.57388 .58192 L
.57523 .58196 L
.57649 .58199 L
.57764 .58201 L
.5787 .58201 L
.57991 .58202 L
.58106 .58201 L
.5822 .582 L
.58343 .58198 L
.58459 .58195 L
.58565 .58192 L
.58812 .58181 L
.59072 .58167 L
.59562 .58129 L
.60097 .58072 L
.61052 .57928 L
.61939 .57745 L
.62992 .57466 L
.63985 .5714 L
.65844 .56361 L
.67845 .55269 L
.6969 .54022 L
.73631 .50552 L
.77419 .46121 L
.81453 .40146 L
.85336 .33094 L
.89464 .24108 L
Mistroke
.9344 .13913 L
.97264 .02599 L
.97619 .01472 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .01472 m
.06244 .06783 L
.10458 .12584 L
.14415 .1804 L
.18221 .23283 L
.22272 .28827 L
.26171 .34076 L
.30316 .39474 L
.34309 .44394 L
.3815 .48748 L
.42237 .52827 L
.46172 .56068 L
.49955 .5841 L
.51896 .59276 L
.52986 .59654 L
.53984 .59929 L
.5446 .60036 L
.54968 .60132 L
.55408 .602 L
.55882 .60258 L
.56174 .60285 L
.56442 .60305 L
.56698 .60319 L
.56828 .60324 L
.569 .60326 L
.56969 .60328 L
.57098 .60331 L
.57215 .60332 L
.57342 .60332 L
.57413 .60331 L
.57479 .60331 L
.57589 .60329 L
.5771 .60325 L
.57836 .60321 L
.57955 .60315 L
.58198 .603 L
.58424 .60283 L
.58938 .60228 L
.59438 .60155 L
.59973 .60055 L
.60943 .59816 L
.61824 .59534 L
.63742 .58702 L
.65822 .5746 L
.67809 .5594 L
.69914 .53976 L
.73702 .49539 L
.77736 .43602 L
.81619 .36814 L
.85746 .2861 L
Mistroke
.89722 .19948 L
.93547 .1113 L
.97617 .01477 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{393.938, 115.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004k0000G2000`400?l00000o`00003oooooooll
ooooo`00oooooollooooo`00oooooollooooo`00oooooollooooo`00oooooollooooo`00;oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00003?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol0000?ooooo`?o0000Yoooool002kooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Oooooo0ol0000:ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooool000002oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo0000013ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooooooo`?o00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
0_l0000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0000?ooooo`?o
00003?ooool002kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool000002_ooool00ol0003oooooo`000007ooooo`?o0000
2oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
=?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000
1oooool3o`0000[ooooo00?o0000ooooool000001oooool00ol0003oooooo`00000;ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`0;ooooo`00;_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002?oo
ool2o`0000[ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooool000001oooool3o`0000_ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo000Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool3o`0000cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`03o`000?oooooo
oooo00Kooooo0ol0000?ooooo`;o0000=_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooool000002?ooool2o`0000[ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000004?ooool0
0ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo
00Kooooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`?o00003oooool2o`00
00gooooo000Joooooggo00008Oooool00ol0003oooooooooo`20ooooo`007Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0000Qoooooggo00002Oooool001gooooo0_l0
001cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo000Mooooo`?o0000LOooool2o`0002Gooooo0_l0001c
ooooo`03o`000?oooooooooo00_ooooo000Mooooo`03o`000?oooooo0000077ooooo00?o0000oooo
ooooool09?ooool3o`0007;ooooo00?o0000ooooooooool02oooool001gooooo1?l0001_ooooo`;o
00009_ooool01?l0003oooooo`000?l0001aooooo`03o`000?oooooooooo00_ooooo000Mooooo`04
o`000?ooooooooooo`0006oooooo0_l0000Vooooo`;o000000?oooooo`000?l00000Koooool00ol0
003oooooooooo`0<ooooo`007Oooool01Ol0003ooooooooooooooooo000006kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02o`0006oooooo00?o0000ooooooooool03?ooool001go
oooo0_l00003ooooo`03o`000?oooooooooo06[ooooo0_l0000Wooooo`04o`000?oooooooooooooo
o`;o0000K_ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooool000009oooool2o`0000?ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`0=ooooo`007Oooool2o`0000?ooooo0_l0001Zooooo`;o0000
:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000006_ooooo00?o0000ooooooooool0
3Oooool001gooooo00?o0000ooooooooool00oooool2o`0006[ooooo00?o0000ooooooooool09_oo
ool2o`0000Cooooo0_l0001Zooooo`;o00003oooool000[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo00005Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`03
o`000?oooooooooo00Cooooo0_l0001Zooooo`03o`000?oooooooooo00gooooo0009ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool000000oooool01?l0003oooooooooooooool2o`0000Ko
oooo00?o0000ooooooooool0I?ooool00ol0003oooooo`00000Eooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooool000000oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000oooo
ooooool0I_ooool2o`00013ooooo0009ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool0
00000oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0001Uooooo`04o`000?oooooooooo
o`0001Gooooo00?o0000ooooool000001oooool00ol0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00001Vooooo`;o00004?ooool000Wooooo00?o0000
ooooool000001oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001Ooo
ool00ol0003oooooo`00001Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0006Gooooo
00?o0000ooooool000004?ooool000[ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00001Rooooo`04o`00
0?ooooooooooo`0001Oooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`00
00?ooooo0_l00008ooooo`;o0000I?ooool2o`00017ooooo000Mooooo`;o00002?ooool00ol0003o
ooooooooo`1Pooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool00000H?ooool01Ol0003ooooooooooooooooo000002[ooooo0_l00009oooo
o`03o`000?oooooo0000067ooooo00?o0000ooooool000004Oooool001gooooo00?o0000oooooooo
ool01oooool00ol0003oooooo`00001Oooooo`04o`000?ooooooooooo`0002_ooooo00?o0000oooo
ooooool02Oooool2o`00067ooooo0_l0000Booooo`007Oooool2o`0000Wooooo00?o0000ooooool0
0000HOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool0
0000Goooool00ol0003oooooo`00000Booooo`007Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05_ooooo00Go0000ooooooooooooooooo`00000[ooooo`;o00002oooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo013ooooo000Mooooo`;o00002_ooool00ol0003ooooo
o`00001Looooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool02_ooool01?l0003o
ooooooooool0001Looooo`03o`000?oooooo000001?ooooo000Mooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo0000F_ooool01Ol0003ooooooooooooooooo000002cooooo0_l0000<
ooooo`03o`000?oooooo000005cooooo00?o0000ooooool000004oooool000[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooo000005kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0
0002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000F_ooool00ol0003oooooo`00
000Dooooo`002Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo00Co0000
oooooooooooooooo0_l0000>ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000ooo
ool01?l0003oooooooooooooool2o`0000gooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
o`00000Dooooo`002Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo00Co
0000oooooooooooo00004?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00003oooool01?l0003oooooooooool0001Iooooo`03o`000?oooooooooo
01?ooooo0009ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`02o`0000cooooo00Go0000ooooooooooooooooo`00001Dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05oooool00ol0003oooooo`000007ooooo`03o`000?oooooo0000
00Cooooo00Co0000oooooooooooo00004?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooo
000001Gooooo000:ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol00002
ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000FOooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol00002ooooo`;o0000
4?ooool00ol0003oooooo`00001Fooooo`03o`000?oooooo000001Gooooo000Mooooo`03o`000?oo
oooooooo00cooooo00Go0000ooooooooooooooooo`00001Booooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooool000005_ooool001gooooo0_l0000Booooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`;o00004_ooool2o`0005Kooooo00?o
0000ooooooooool05?ooool001gooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo0000053ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooool00000D_ooool00ol0003oooooo`00000Gooooo`007Oooool2
o`0000oooooo00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo0000057ooooo00?o
0000ooooool000005oooool001gooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooo
oooo000005?ooooo00?o0000ooooooooool0;_ooool2o`0001Cooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooo`00000Hooooo`007Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Cooooo0_l0001?ooooo`03o`000?oooooo000001Sooooo000Mooooo`;o00004Oooool01Ol0
003ooooooooooooooooo000004_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_
ooooo`;o00005Oooool00ol0003oooooo`00001=ooooo`03o`000?oooooo000001Wooooo000:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3
o`0000;ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000004Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooo`00001<ooooo`03o`000?oooooo000001Wooooo0009ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02o`0001;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool000001oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;o00005ooo
ool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0001Wooooo0009ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000001Sooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooool000001oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00006?ooool00ol0003oooooo`00001<ooooo`03o`000?oooooooooo01Sooooo0009ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool000001?ooool01?l0003oooooooooool0000Eooooo`05
o`000?ooooooooooooooool00000A_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooool000001oooool00ol0003oooooo`000004ooooo`04o`000?oooooooooo
o`0001Wooooo00?o0000ooooool00000B?ooool01?l0003oooooooooool0000Jooooo`002_ooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`?o00000_ooool2o`0001Cooooo00Go
0000ooooooooooooooooo`000015ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`?o00000_ooool2o`0001Wo
oooo00?o0000ooooool00000Aoooool00ol0003oooooo`00000Kooooo`007Oooool00ol0003ooooo
ooooo`0Dooooo`05o`000?ooooooooooooooool00000B_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0000Koooo
o`007Oooool2o`0001[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03?ooooo0_l0000Kooooo`;o0000Aoooool00ol0003oooooooooo`0Jooooo`00
7Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01_ooooo0_l00013ooooo`04o`00
0?ooooooooooo`0001cooooo000Mooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooool00000@_ooool00ol0003oooooo`00000Mooooo`007Ooo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo03Cooooo0_l0000Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooool000007_oo
ool001gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01gooooo0_l00012ooooo`03o`000?oooooooooo01cooooo000Mooooo`;o00007_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool2o`00
01oooooo0_l00010ooooo`03o`000?oooooooooo01gooooo000Mooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Qooooo`;o0000??ooool01?l0
003oooooooooool0000Oooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool000000_ooool3o`0000;ooooo0_l0000Qooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooool000008?ooool000Wooooo00?o0000ooooool000001oooool00ol0
003oooooo`000002ooooo`?o00000_ooool2o`0001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`0Pooooo`;o0000>_ooool01?l0003oooooooooool0000Pooooo`002Oooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000oooool2o`00
00;ooooo00?o0000ooooooooool08Oooool2o`0003_ooooo00?o0000ooooooooool07oooool000Wo
oooo00?o0000ooooool000001oooool00ol0003oooooo`000003ooooo`;o00000_ooool2o`0001co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_l0000Sooooo`;o0000=oooool00ol0003oooooo`00000Rooooo`00
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool0
00008oooool001gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`;o0000
9Oooool2o`0003Cooooo00?o0000ooooool000008oooool001gooooo0_l0000Uooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`007Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooo000002Gooooo000Mooooo`;o00007oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>oooool2o`00
02Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00000Uooooo`007Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooo000002Kooooo000Mooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0??ooool2o`0002Wooooo0_l0000^ooooo`03o`000?oooooooooo02Gooooo
000Mooooo`;o00008oooool00ol0003oooooooooo`04ooooo`;o00008oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003oooooooooo`0Yooooo`;o0000
:oooool2o`0002Sooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
o`000007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_l0000/ooooo`03o`00
0?oooooooooo02Oooooo0_l0000Yooooo`002Oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool00_l0000]ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000000_ooool3o`0000;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Uooooo`;o0000:_ooool000Wooooo00?o0000ooooool000001oooool00ol0003oooooo`000002
ooooo`?o00000_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06oooool2o`0000Oooooo0_l0000^ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Zooooo`002Oooool00ol0003oooooo`000007oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Kooooo0_l0000Sooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooooooool3o`0000;ooooo0_l0000_ooooo`;o00008_ooool0
0ol0003oooooooooo`0[ooooo`002_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
ooooo`?o00000_ooool2o`0002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0^
ooooo`Co00007oooool2o`0002gooooo000Mooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0A?ooool2o`00037ooooo00?o0000ooooool000007Oooool2o`0002kooooo000Mooooo`;o
0000:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03?ooooo0_l0000Jooooo`03
o`000?oooooooooo02kooooo000Mooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
1_ooool2o`0000oooooo0_l00009ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`03o`0001Gooooo0ol0000`ooooo`007Oooool00ol0003ooooooooo
o`0/ooooo`;o00001oooool3o`0000_ooooo00?o0000ooooooooool01oooool2o`0004Wooooo0_l0
000dooooo`;o00000oooool2o`00017ooooo1?l0000aooooo`007Oooool2o`0002oooooo00?o0000
ooooooooool01oooool2o`00013ooooo0ol0001;ooooo`03o`000?oooooooooo03[ooooo0ol0000;
ooooo`?o0000=Oooool001gooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo0_l00003oooo
o`?o00001_ooool2o`0004kooooo0_l0000gooooo`;o00001Oooool;o`0000;ooooo0_l0000doooo
o`007Oooool2o`0003?ooooo0_l00004ooooo`03o`000?oooooooooo00go0000?Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;o
oooo00?o0000ooooooooool0>?ooool2o`0000oooooo00?o0000ooooooooool0=?ooool000[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo03Gooooo1?l000000ooooooo0000ooooo`18ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`;o0000
??ooool3o`0000Oooooo0ol0000hooooo`002Oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000000_ooool2o`0008Gooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`000002ooooo`?o00000_ooool00ol0003oooooooooo`10ooooo`?o000000?o
ooooo`000?ooool0>_ooool000Wooooo00?o0000ooooool000001oooool00ol0003oooooo`000002
ooooo`?o00000_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo083ooooo0009oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00021oooo
o`002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0003oooooob7o
oooo003ooooooccooooo003ooooooccooooo003ooooooccooooo0000\
\>"],
  ImageRangeCache->{{{118.938, 433.062}, {234.875, 143.312}} -> {-0.862969, \
0.952625, 0.00539991, 0.00539991}, {{127.812, 268.938}, {232.688, 145.438}} -> \
{-1.26487, 0.106598, 0.00681163, 0.000645512}, {{283, 424.125}, {232.688, \
145.438}} -> {-2.58622, 0.109151, 0.00681163, 0.000667032}}]
}, Open  ]],

Cell[BoxData[
    \(polynomialBasis[n_] := x^Range[n] \((1 - x)\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(GalerkinApproximation[a, l, 
      polynomialBasis[2]]\)\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[BoxData[
    \(\(\((70 - k)\)\ \((1 - x)\)\ x\)\/\(\((10 + k)\)\ \((42 + k)\)\) + \(7\ \
\((1 - x)\)\ x\^2\)\/\(42 + k\)\)], "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{\[IndentingNewLine]Plot[
              Evaluate[{exactSolution, 
                    GalerkinApproximation[a, l, polynomialBasis[1]]} /. 
                  k -> 1], {x, 0, 1}, DisplayFunction -> Identity, 
              PlotStyle -> {Dashing[{}], Dashing[{0.02, 0.02}]}], 
            Plot[Evaluate[{exactSolution, 
                    GalerkinApproximation[a, l, polynomialBasis[2]]} /. 
                  k -> 1], {x, 0, 1}, DisplayFunction -> Identity, 
              PlotStyle -> {Dashing[{}], Dashing[{0.02, 0.02}]}]\n}], 
        DisplayFunction -> $DisplayFunction];\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 10.0907 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11562 -24 -4.5 ]
[.01131 .11562 0 4.5 ]
[.01131 .21653 -24 -4.5 ]
[.01131 .21653 0 4.5 ]
[.01131 .31744 -24 -4.5 ]
[.01131 .31744 0 4.5 ]
[.01131 .41835 -24 -4.5 ]
[.01131 .41835 0 4.5 ]
[.01131 .51925 -24 -4.5 ]
[.01131 .51925 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11562 m
.03006 .11562 L
s
[(0.01)] .01131 .11562 1 0 Mshowa
.02381 .21653 m
.03006 .21653 L
s
[(0.02)] .01131 .21653 1 0 Mshowa
.02381 .31744 m
.03006 .31744 L
s
[(0.03)] .01131 .31744 1 0 Mshowa
.02381 .41835 m
.03006 .41835 L
s
[(0.04)] .01131 .41835 1 0 Mshowa
.02381 .51925 m
.03006 .51925 L
s
[(0.05)] .01131 .51925 1 0 Mshowa
.125 Mabswid
.02381 .0349 m
.02756 .0349 L
s
.02381 .05508 m
.02756 .05508 L
s
.02381 .07526 m
.02756 .07526 L
s
.02381 .09544 m
.02756 .09544 L
s
.02381 .1358 m
.02756 .1358 L
s
.02381 .15599 m
.02756 .15599 L
s
.02381 .17617 m
.02756 .17617 L
s
.02381 .19635 m
.02756 .19635 L
s
.02381 .23671 m
.02756 .23671 L
s
.02381 .25689 m
.02756 .25689 L
s
.02381 .27707 m
.02756 .27707 L
s
.02381 .29726 m
.02756 .29726 L
s
.02381 .33762 m
.02756 .33762 L
s
.02381 .3578 m
.02756 .3578 L
s
.02381 .37798 m
.02756 .37798 L
s
.02381 .39816 m
.02756 .39816 L
s
.02381 .43853 m
.02756 .43853 L
s
.02381 .45871 m
.02756 .45871 L
s
.02381 .47889 m
.02756 .47889 L
s
.02381 .49907 m
.02756 .49907 L
s
.02381 .53943 m
.02756 .53943 L
s
.02381 .55962 m
.02756 .55962 L
s
.02381 .5798 m
.02756 .5798 L
s
.02381 .59998 m
.02756 .59998 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .07565 L
.10458 .14142 L
.14415 .20191 L
.18221 .25832 L
.22272 .31584 L
.26171 .36812 L
.30316 .41969 L
.34309 .46481 L
.3815 .50336 L
.42237 .53846 L
.46172 .56582 L
.49955 .58556 L
.51896 .59299 L
.52979 .59629 L
.53984 .59881 L
.54994 .60079 L
.55528 .60161 L
.56097 .60231 L
.56358 .60257 L
.5664 .60281 L
.56888 .60298 L
.57151 .60313 L
.57388 .60322 L
.57523 .60326 L
.57649 .60329 L
.57764 .60331 L
.5787 .60332 L
.57991 .60332 L
.58106 .60331 L
.5822 .6033 L
.58343 .60328 L
.58459 .60325 L
.58565 .60321 L
.58812 .60311 L
.59072 .60296 L
.59562 .60257 L
.60097 .60197 L
.61052 .60048 L
.61939 .59858 L
.62992 .59569 L
.63985 .5923 L
.65844 .58422 L
.67845 .57289 L
.6969 .55995 L
.73631 .52395 L
.77419 .47797 L
.81453 .41598 L
.85336 .34281 L
.89464 .24958 L
Mistroke
.9344 .1438 L
.97264 .02642 L
.97619 .01472 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .01472 m
.06244 .10398 L
.10458 .19272 L
.14415 .26788 L
.18221 .3327 L
.22272 .39365 L
.26171 .44448 L
.30316 .49008 L
.34309 .5258 L
.3815 .55255 L
.40095 .56325 L
.42237 .57281 L
.44268 .57975 L
.45178 .58217 L
.46172 .58435 L
.4671 .58532 L
.4721 .58608 L
.47727 .58675 L
.48196 .58723 L
.48658 .5876 L
.4887 .58773 L
.49093 .58785 L
.49332 .58794 L
.49438 .58797 L
.49552 .588 L
.49675 .58803 L
.49789 .58804 L
.49859 .58805 L
.49925 .58805 L
.50049 .58805 L
.50163 .58805 L
.50286 .58803 L
.50401 .58801 L
.50508 .58799 L
.50754 .58791 L
.51014 .58779 L
.51268 .58765 L
.51504 .58748 L
.5204 .587 L
.5293 .58588 L
.53882 .58424 L
.54906 .58197 L
.56016 .5789 L
.58032 .57174 L
.60019 .56267 L
.62123 .55089 L
.65912 .52403 L
.69946 .48746 L
.73829 .44449 L
.77956 .39044 L
Mistroke
.81932 .33024 L
.85757 .26478 L
.89827 .18701 L
.93745 .10421 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 10.0552 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11527 -24 -4.5 ]
[.01131 .11527 0 4.5 ]
[.01131 .21582 -24 -4.5 ]
[.01131 .21582 0 4.5 ]
[.01131 .31637 -24 -4.5 ]
[.01131 .31637 0 4.5 ]
[.01131 .41692 -24 -4.5 ]
[.01131 .41692 0 4.5 ]
[.01131 .51747 -24 -4.5 ]
[.01131 .51747 0 4.5 ]
[.01131 .61803 -24 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11527 m
.03006 .11527 L
s
[(0.01)] .01131 .11527 1 0 Mshowa
.02381 .21582 m
.03006 .21582 L
s
[(0.02)] .01131 .21582 1 0 Mshowa
.02381 .31637 m
.03006 .31637 L
s
[(0.03)] .01131 .31637 1 0 Mshowa
.02381 .41692 m
.03006 .41692 L
s
[(0.04)] .01131 .41692 1 0 Mshowa
.02381 .51747 m
.03006 .51747 L
s
[(0.05)] .01131 .51747 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.06)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .03483 m
.02756 .03483 L
s
.02381 .05494 m
.02756 .05494 L
s
.02381 .07505 m
.02756 .07505 L
s
.02381 .09516 m
.02756 .09516 L
s
.02381 .13538 m
.02756 .13538 L
s
.02381 .15549 m
.02756 .15549 L
s
.02381 .1756 m
.02756 .1756 L
s
.02381 .19571 m
.02756 .19571 L
s
.02381 .23593 m
.02756 .23593 L
s
.02381 .25604 m
.02756 .25604 L
s
.02381 .27615 m
.02756 .27615 L
s
.02381 .29626 m
.02756 .29626 L
s
.02381 .33648 m
.02756 .33648 L
s
.02381 .35659 m
.02756 .35659 L
s
.02381 .3767 m
.02756 .3767 L
s
.02381 .39681 m
.02756 .39681 L
s
.02381 .43703 m
.02756 .43703 L
s
.02381 .45714 m
.02756 .45714 L
s
.02381 .47725 m
.02756 .47725 L
s
.02381 .49736 m
.02756 .49736 L
s
.02381 .53758 m
.02756 .53758 L
s
.02381 .55769 m
.02756 .55769 L
s
.02381 .5778 m
.02756 .5778 L
s
.02381 .59791 m
.02756 .59791 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .07543 L
.10458 .14098 L
.14415 .20125 L
.18221 .25746 L
.22272 .31477 L
.26171 .36687 L
.30316 .41826 L
.34309 .46322 L
.3815 .50164 L
.42237 .53661 L
.46172 .56388 L
.49955 .58355 L
.51896 .59095 L
.52979 .59424 L
.53984 .59675 L
.54994 .59873 L
.55528 .59954 L
.56097 .60024 L
.56358 .6005 L
.5664 .60074 L
.56888 .60091 L
.57151 .60105 L
.57388 .60115 L
.57523 .60119 L
.57649 .60121 L
.57764 .60123 L
.5787 .60124 L
.57991 .60124 L
.58106 .60124 L
.5822 .60122 L
.58343 .6012 L
.58459 .60117 L
.58565 .60114 L
.58812 .60103 L
.59072 .60088 L
.59562 .60049 L
.60097 .5999 L
.61052 .59841 L
.61939 .59652 L
.62992 .59364 L
.63985 .59026 L
.65844 .58221 L
.67845 .57092 L
.6969 .55803 L
.73631 .52215 L
.77419 .47634 L
.81453 .41457 L
.85336 .34165 L
.89464 .24875 L
Mistroke
.9344 .14335 L
.97264 .02638 L
.97619 .01472 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .01472 m
.06244 .07439 L
.10458 .13934 L
.14415 .19947 L
.18221 .25585 L
.22272 .31357 L
.26171 .36622 L
.30316 .41828 L
.34309 .46389 L
.3815 .50289 L
.42237 .53837 L
.46172 .566 L
.49955 .58584 L
.51896 .59326 L
.52979 .59655 L
.53984 .59903 L
.54994 .60097 L
.55528 .60177 L
.56097 .60243 L
.56358 .60268 L
.5664 .6029 L
.56888 .60306 L
.57024 .60313 L
.57151 .60318 L
.57275 .60323 L
.57388 .60326 L
.57514 .60329 L
.57583 .6033 L
.57649 .60331 L
.57762 .60332 L
.57868 .60332 L
.57983 .60331 L
.58106 .6033 L
.5822 .60328 L
.58344 .60324 L
.58474 .6032 L
.58595 .60315 L
.59043 .60288 L
.59299 .60268 L
.59532 .60246 L
.60053 .60184 L
.60994 .6003 L
.61881 .59834 L
.63883 .59205 L
.65728 .58391 L
.67604 .57325 L
.69668 .55866 L
.73702 .5211 L
.77585 .47307 L
.81712 .40848 L
Mistroke
.85688 .33234 L
.89513 .24555 L
.93583 .13786 L
.97501 .01856 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  ImageSize->{397.938, 116.938},
  ImageMargins->{{3.1875, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004n0000GB000`400?l00000o`00003ooooooolo
ooooo`00ooooooloooooo`00ooooooloooooo`00ooooooloooooo`00ooooooloooooo`00c?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00003?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol0000?ooooo`?o00003?ooool002oooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool3o`0000cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o
00004?ooool3o`0003Gooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooo000000Oooooo0ol0000;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool0
00002oooool00ol0003oooooo`000007ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool02oooool002kooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooo000000Oooooo0ol0000;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000
2oooool00ol0003oooooo`000007ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000
1oooool00ol0003oooooo`00000;ooooo`03o`000?oooooo000000Oooooo0ol0000;ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`00;_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`00000;ooooo`03o`000?oooooo000000Oooooo0ol0000;ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008ooooo`;o00002ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo00_ooooo000^ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008ooooo`;o00002oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001oooool0
0ol0003oooooo`00000Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`?o00003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01oooool2o`0000cooooo00?o0000ooooooooool01_ooool3
o`0000oooooo0_l0000=ooooo`00;oooool00ol0003oooooooooo`06ooooo`?o00003?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool2o`00
00cooooo00?o0000ooooooooool01_ooool3o`00013ooooo0_l0000Uooooo`03o`000?oooooooooo
087ooooo000Mooooo`03o`000?oooooooooo09OoooooO_l00009ooooo`007Oooool00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`006_oooomno`0002;ooooo0_l0001dooooo`;o00003?ooool001gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooool00000Loooool00ol0003oooooooooo`0;ooooo`007Oooool2o`0007Cooooo0_l0000Uoooo
o`03o`000?oooooo000007?ooooo00?o0000ooooooooool02oooool001gooooo0ol0001cooooo`03
o`000?oooooooooo02Cooooo00Co0000oooooooooooo0000LOooool00ol0003oooooooooo`0<oooo
o`007Oooool3o`0007;ooooo0_l0000Vooooo`04o`000?ooooooooooo`00077ooooo00?o0000oooo
ooooool03?ooool001gooooo1?l0001aooooo`;o00009_ooool01Ol0003ooooooooooooooooo0000
06oooooo0_l0000>ooooo`007Oooool01?l0003oooooooooool0001aooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00gooooo000Mooooo`03o`000?oooooooooo00;o0000Koooool2o`0002Oooooo00?o0000oooooooo
ool00_ooool2o`0006gooooo00?o0000ooooooooool03Oooool001gooooo0_l000001?oooooo0000
ooooool0001^ooooo`;o00009oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool03Oooool001gooooo00Co0000oooooooooooooooo0_l0001]ooooo`;o
0000:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool03Oooool001gooooo0_l00002ooooo`03o`000?oooooo000006gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
oooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0>ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
J_ooool2o`0001Cooooo00?o0000ooooool000001oooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`0006Wooooo00?o0000ooooooooool0
3_ooool000Wooooo00?o0000ooooool000001oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01?l0003oooooooooool0001Yooooo`;o00005?ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`;o0000Ioooool00ol0003oooooooooo`0?ooooo`002Oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooo000006Sooooo00?o0000ooooool000005Oooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool03oooool000Wooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Toooo
o`;o00004Oooool000[ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`00
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo0000
02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
013ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000IOooool00ol0003o
ooooo`00000Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0HOooool2o`0001;o
oooo000Mooooo`;o00001_ooool01?l0003oooooooooool0001Sooooo`03o`000?oooooo000002_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Pooooo`;o00004_ooool001gooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool0001Tooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo017o
oooo000Mooooo`;o00002oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo017ooooo
000Mooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000H?ooool00ol0003ooooo
o`00000/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`0Booooo`007Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
G_ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo01;ooooo000Mooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000005gooooo00?o0000ooooool000006?ooool00ol0003oooooo`000007oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool2o`0000kooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Booooo`002_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`002Oooool00ol0003oooooo`000007oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l0000>ooooo`03o`000?oooooo
oooo05Sooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000001?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Cooooo`002Oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000Cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05Oooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool04oooool000Wooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000004ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Eooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool05?ooool000[ooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooooooool3o`0000;ooooo0_l0000;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo013ooooo0_l0001Hooooo`03o`000?oooooooooo01Cooooo000Mooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0Doooool01Ol0003ooooooooooooooooo000002oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Gooooo000Moooo
o`;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05;ooooo00Go0000oooo
ooooooooooooo`00000_ooooo`03o`000?oooooooooo017ooooo0_l0001Fooooo`03o`000?oooooo
oooo01Gooooo000Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Aooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo05?ooooo0_l0000Gooooo`007Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooooooo
0000033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo01Kooooo000Mooooo`;o00005?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1@ooooo`;o00006?ooool001go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04ko
oooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oooooooooo01Cooooo0_l0001Aoooo
o`03o`000?oooooooooo01Oooooo000Mooooo`;o00003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`00
00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
01Oooooo000Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooooooo0_l0000Goooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool06?ooool000[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool06oooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Fooooo`;o0000C_ooool00ol0003oooooooooo`0Hooooo`002Oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_l0000Gooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo0000
01Wooooo0_l0001<ooooo`;o00006_ooool000Wooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Iooooo`002Oooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_l0000Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18oooo
o`;o00006oooool000[ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool3o`00
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0_l0000Looooo`007Oooool2o`0001Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06oooool001gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Looooo`007Oooool2o`0001Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11
ooooo`;o00007_ooool001gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool001gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0oooooo`;o00007oooool001gooooo0_l0000Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`?o00000oooool2o`00023o
oooo00?o0000ooooooooool0?Oooool2o`00023ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool08Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03co
oooo0_l0000Pooooo`002Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo
0ol00002ooooo`;o00008?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo
0_l00003ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool2o`00027ooooo
0009ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo023ooooo0009ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000ooo
ool2o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Pooooo`002_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l0000K
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool2o`0003Sooooo00?o0000
ooooooooool08Oooool001gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Toooo
o`;o0000=_ooool2o`0002?ooooo000Mooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03;ooooo0_l0000Tooooo`007Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02oooooo0_l0000Uooooo`007Oooool2
o`0002Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0]ooooo`;o00009_ooool0
01gooooo00?o0000ooooooooool07oooool2o`0000Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:Oooool3o`00
02cooooo0_l0000Wooooo`007Oooool2o`0002;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00003oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooool00000:oooool00ol0003oooooooooo`0Voooo
o`007Oooool00ol0003oooooooooo`0Zooooo`;o00008oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooool000001oooool00ol0003oooooo`000004ooooo`04
o`000?ooooooooooooooo`;o0000;?ooool00ol0003oooooo`00000Xooooo`;o0000:Oooool000[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`?o00000_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ool000000_ooool3o`0000?ooooo00?o0000ooooooooool0;Oooool2o`0002Kooooo0_l0000Zoooo
o`002Oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool00_l0000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool3o`0002?o
oooo00?o0000ooooooooool0:_ooool000Wooooo00?o0000ooooool000001oooool00ol0003ooooo
o`000002ooooo`?o00000_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06_ooool2o`0000Sooooo0_l0000_ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo02oooooo00?o0000ooooool0
00008Oooool00ol0003oooooooooo`0[ooooo`002Oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0002Sooooo0_l00006ooooo`;o0000
8oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo037ooooo0_l0000Oooooo`03o`00
0?oooooooooo02cooooo000:ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo
0ol00002ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0booooo`;o00007Oooool00ol0003oooooooooo`0]ooooo`007Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01;ooooo0_l00009ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0<oooool3o`0001Wooooo0_l0000`ooooo`007Oooool2o`0002cooooo0_l00006
ooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0=Oooool3o`0001Kooooo0_l0000aooooo`007Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0hooooo`?o00004?ooool3o`0003?ooooo000Mooooo`03
o`000?oooooooooo02oooooo0_l00005ooooo`?o00001oooool2o`0000cooooo0_l0001:ooooo`03
o`000?oooooooooo03[ooooo0_l0000<ooooo`Co0000=Oooool001gooooo0_l0000booooo`;o0000
00Coooooo`000?l0003o00000_ooool4o`000003ooooool0003o000000_ooooo0ol0001<ooooo`03
o`000?oooooooooo03cooooo3?l000000ooooooo0000ooooo`0fooooo`007Oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooo000000;o00003_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000
0oooool00ol0003oooooooooo`10ooooo`;o00000_ooool00ol0003oooooooooo`0jooooo`007Ooo
ool2o`0003gooooo3_l0000kooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000003ooooo`;o0000P_ooool001gooooo00?o0000ooooooooool0QOooool0
0ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo0ol00027ooooo`007Oooool00ol0
003oooooooooo`25ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`27ooooo`00Y_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo0_l00027ooooo`00ooooooloooooo`00ooooooloooooo`00ooooooloooooo`00\
\>"],
  ImageRangeCache->{{{121.438, 438.75}, {113.562, 21.0625}} -> {-0.871439, \
0.12601, 0.00534518, 0.00534518}, {{130.375, 272.938}, {111.312, 23.25}} -> \
{-1.27185, 0.00638602, 0.00673226, 0.000635404}, {{287.188, 429.75}, \
{111.312, 23.25}} -> {-2.59148, 0.00784327, 0.00673226, 0.000637647}}]
}, Open  ]],

Cell[TextData[StyleBox["Bien entendu, on peut introduire toutes sortes de \
raffinements pour \[EAcute]conomiser le temps de calcul. La d\[EAcute]marche, \
valable en dimension quelconque, se g\[EAcute]n\[EAcute]ralise aux probl\
\[EGrave]mes spectraux (\[EAcute]quations de Helmholtz \
g\[EAcute]n\[EAcute]ralis\[EAcute]es) dans le cas de \
ph\[EAcute]nom\[EGrave]nes stationnaires et aux \[EAcute]quations \
d'\[EAcute]volution. La discr\[EAcute]tisation conduit alors respectivement \
\[AGrave] un syst\[EGrave]me aux valeurs propres ou un syst\[EGrave]me diff\
\[EAcute]rentiel.",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell[TextData[{
  StyleBox["\[Sum] c",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i ",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["<Aw",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",w",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[">=\[Lambda]\[MediumSpace]\[Sum] c",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["<w",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",w",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[">",
    CellMargins->{{91, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1],

Cell[TextData[{
  StyleBox["\[Sum] c",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i ",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["(t)<Aw",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",w",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[">=D",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["t",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["\[Sum] c",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i ",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["(t)<w",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",w",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["j",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[">",
    CellMargins->{{137, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextAlignment->Center,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discussion\[NonBreakingSpace]: vers une analyse fonctionnelle \
algorithmique", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell["\<\
Comme les calculs formels exacts, ceux-ci requi\[EGrave]rent un \
contr\[OHat]le permanent de l\[CloseCurlyQuote]utilisateur. En un sens, ces m\
\[EAcute]thodes sont naturellement \[LeftGuillemet]\[MediumSpace]adaptatives\
\[MediumSpace]\[RightGuillemet] : on affine l\[CloseCurlyQuote]approximation \
en poursuivant une it\[EAcute]ration ; si bien que l\[CloseCurlyQuote]on peut \
choisir tout interm\[EAcute]diaire entre des approximations \
grossi\[EGrave]res et rapides et des approximations plus pr\[EAcute]cises \
mais aussi plus co\[UHat]teuses en calculs. Ce n'est pas tout \[AGrave] fait \
exact pour Galerkin, mais on peut l'adapter pour \[EAcute]viter de refaire \
tous les calculs \[AGrave] chaque nouvelle approximation.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell["\<\
Entre les solutions symboliques exactes et les solutions num\
\[EAcute]riques approch\[EAcute]es, il y a donc place pour des solutions \
symboliques approch\[EAcute]es. Les m\[EAcute]thodes fonctionnelles s\
\[CloseCurlyQuote]av\[EGrave]rent une approche unitaire pour l\
\[CloseCurlyQuote]\[EAcute]tude et le traitement des \[EAcute]quations \
fonctionnelles : non seulement elles fournissent des outils \
th\[EAcute]oriques pour les d\[EAcute]monstrations \
d\[CloseCurlyQuote]existence, unicit\[EAcute] et convergence, mais surtout \
elles conduisent \[AGrave] des proc\[EAcute]d\[EAcute]s \
d\[CloseCurlyQuote]approximation symbolique efficaces. Il \
s\[CloseCurlyQuote]agit donc en un sens de m\[EAcute]thodes constructives, si \
l\[CloseCurlyQuote]on accepte d\[CloseCurlyQuote]appliquer ce terme \[AGrave] \
des approximations. De plus, on peut en tirer des programmes g\[EAcute]n\
\[EAcute]riques, \[AGrave] savoir applicables \[AGrave] des familles de probl\
\[EGrave]mes. On peut s\[CloseCurlyQuote]attendre \[AGrave] une renaissance \
prochaine des travaux trop vite oubli\[EAcute]s des Poincar\[EAcute], \
Volterra, Timoshenko\[Ellipsis] Et l'on peut anticiper la constitution d'une \
analyse fonctionnelle algorithmique, support de la mod\[EAcute]lisation comme \
le fut l'analyse pendant des si\[EGrave]cles.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic],

Cell["\<\
Le but du calcul formel n'est pas tant d'obtenir des formules \
exactes que des expressions symboliques, g\[EAcute]n\[EAcute]riques, \
susceptibles d'interpr\[EAcute]tation et autant que possible pouvant \
\[EHat]tre raffin\[EAcute]es \[AGrave] volont\[EAcute]. Ce type \
d'approximations, nagu\[EGrave]re couramment pratiqu\[EAcute]es mais \
aujourd'hui oubli\[EAcute]es au profit de techniques purement \
num\[EAcute]riques, conna\[IHat]tra sans aucun doute et gr\[AHat]ce au calcul \
formel et \[AGrave] la programmation symbolique, un regain d'int\[EAcute]r\
\[EHat]t dans les ann\[EAcute]es \[AGrave] venir. Malheureusement, les exc\
\[EGrave]s du tout num\[EAcute]rique encourag\[EAcute]s par des int\[EAcute]r\
\[EHat]ts peu scientifiques ont fini par laisser croire qu'une approximation \
est forc\[EAcute]ment num\[EAcute]rique et font encore sous-estimer le \
potentiel des approximations symboliques. Parions que Mathematica sera \
l'artisan d'une renaissance ici anticip\[EAcute]e.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  TextJustification->1],

Cell["\<\
Post-scriptum\[NonBreakingSpace]: j'ai pr\[EAcute]sent\[EAcute] ces \
id\[EAcute]es il y a quelques ann\[EAcute]es \[AGrave] la communaut\[EAcute] \
du calcul formel et de Mathematica en particulier. J'y ai peu travaill\
\[EAcute] ces derniers temps, \[EAcute]tant accapar\[EAcute] par d'autres \
activit\[EAcute]s\[NonBreakingSpace]; c'est dommage et j'esp\[EGrave]re bien \
y revenir.  L'id\[EAcute]e suscite manifestement peu  d'int\[EAcute]r\[EHat]t\
\[NonBreakingSpace]: d'une part, la communaut\[EAcute] du calcul scientifique \
est partitionn\[EAcute]e entre ceux qui font du calcul formel \"strict\" \
(calcul exact) et ceux qui calculent des approximations num\[EAcute]riques, \
laissant entre les deux cet assez vaste no man's land qui ne les \
int\[EAcute]resse pas\[NonBreakingSpace]; ce qui n'est pas balis\[EAcute] par \
les mandarins attire peu, carri\[EGrave]re oblige\[NonBreakingSpace]; d'autre \
part, chercher \[EAcute]tant \[EAcute]puisant, les scientifiques \[AGrave] \
l'image des ing\[EAcute]nieurs ne s'int\[EAcute]ressent plus qu'aux solutions \
\"cl\[EAcute]s en mains\"\[NonBreakingSpace]\[NonBreakingSpace]; \
curieusement, un domaine de recherche o\[UGrave] il y a encore du travail ne \
les int\[EAcute]resse pas beaucoup. Et les travaux dans ce domaine se r\
\[EAcute]duisent \[AGrave] des approches isol\[EAcute]es, au cas par cas. Au \
d\[EAcute]but des ann\[EAcute]es soixante, Landin avait imagin\[EAcute] un \
langage fonctionnel avec une syntaxe math\[EAcute]matique, une sorte de Lisp \
ressemblant \[AGrave] Mathematica\[NonBreakingSpace]; il a fallu trente ans \
pour que cette id\[EAcute]e devienne r\[EAcute]alit\[EAcute]\
\[NonBreakingSpace]; compte tenu de l'acc\[EAcute]l\[EAcute]ration \
exponentielle du temps biologique, il me reste quelque espoir de voir ces id\
\[EAcute]es aboutir d'ici une vingtaine d'ann\[EAcute]es\[MediumSpace]\
\[Ellipsis]\
\>", "SmallText",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{551, 651},
WindowMargins->{{137, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingStartingPageNumber->27,
PrintingPageRange->{35, 35},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{133.875, 133.875}, {252, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
ShowCellLabel->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 188, 5, 64, "Subtitle",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[1967, 60, 408, 14, 64, "Subsubtitle",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[2378, 76, 619, 12, 76, "SmallText",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[3022, 92, 127, 3, 47, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[3152, 97, 1237, 21, 166, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[4392, 120, 1217, 20, 166, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[5612, 142, 706, 13, 109, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[6355, 160, 161, 3, 47, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[6519, 165, 374, 9, 53, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[6896, 176, 378, 15, 33, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[7277, 193, 1096, 29, 110, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[8376, 224, 962, 24, 132, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[9341, 250, 427, 9, 90, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[9793, 263, 142, 3, 30, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[9938, 268, 256, 5, 50, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[10209, 276, 350, 8, 70, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[10584, 288, 213, 6, 30, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[10800, 296, 12977, 462, 100, 5198, 360, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[23792, 761, 1322, 29, 116, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[25117, 792, 231, 6, 32, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[25373, 802, 147, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[25523, 808, 173, 4, 22, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[25733, 817, 392, 10, 43, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[26128, 829, 39945, 964, 153, 7995, 563, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[66088, 1796, 492, 12, 51, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[66583, 1810, 539, 18, 37, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[67125, 1830, 264, 6, 32, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[67414, 1840, 140, 3, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[67557, 1845, 168, 4, 28, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[67762, 1854, 561, 12, 88, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[68326, 1868, 24279, 625, 151, 5477, 387, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[92654, 2499, 151, 3, 42, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[92808, 2504, 2303, 60, 113, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[95114, 2566, 408, 16, 26, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[95525, 2584, 1116, 32, 77, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[96644, 2618, 357, 8, 55, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[97026, 2630, 158, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[97187, 2636, 157, 4, 29, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[97381, 2645, 567, 13, 111, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[97951, 2660, 12913, 408, 118, 4370, 296, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[110879, 3071, 1345, 40, 56, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[112227, 3113, 387, 15, 25, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[112617, 3130, 561, 11, 64, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[113181, 3143, 183, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[113389, 3151, 704, 15, 99, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[114096, 3168, 87470, 1737, 133, 23226, 938, "GraphicsData", \
"PostScript", "Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[201603, 4910, 189, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[201795, 4916, 210, 5, 22, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[202020, 4924, 226, 6, 32, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[202271, 4934, 167, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[202441, 4940, 151, 4, 22, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[202629, 4949, 170, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[202802, 4955, 155, 4, 22, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[202972, 4962, 437, 10, 51, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[203412, 4974, 913, 16, 103, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[204362, 4995, 142, 3, 42, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[204507, 5000, 2830, 62, 225, "Text",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[207340, 5064, 3409, 104, 30, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[210752, 5170, 1222, 22, 142, "Text",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[211977, 5194, 458, 11, 51, "Text",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[212438, 5207, 377, 8, 77, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[212818, 5217, 408, 9, 38, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[213229, 5228, 284, 7, 32, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[213516, 5237, 279, 7, 43, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[213798, 5246, 162, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[213985, 5254, 181, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[214169, 5260, 238, 5, 30, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[214444, 5270, 818, 16, 122, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[215265, 5288, 31554, 976, 98, 10386, 709, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[246834, 6267, 171, 4, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[247030, 6275, 194, 5, 22, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[247227, 6282, 232, 5, 31, "Output",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[247496, 6292, 732, 14, 122, "Input",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[248231, 6308, 31065, 964, 99, 10283, 702, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[279311, 7275, 759, 14, 77, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[280073, 7291, 2328, 70, 30, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[282404, 7363, 2658, 80, 30, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[285099, 7448, 192, 4, 42, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[285294, 7454, 874, 15, 103, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[286171, 7471, 1463, 24, 168, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[287671, 7500, 125, 3, 42, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[287799, 7505, 1134, 19, 142, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[288936, 7526, 2018, 30, 140, "SmallText",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

