(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    447467,       9377]*)
(*NotebookOutlinePosition[    517968,      11784]*)
(*  CellTagsIndexPosition[    517924,      11780]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Pseudo Tableaux de Mondrian", "Subtitle",
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic,
  TextAlignment->Center],

Cell[TextData[{
  "Thierry Verdel\n",
  StyleBox["Thierry.Verdel@mines.u-nancy.fr",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}]
}], "SmallText",
  CellMargins->{{16, 11}, {Inherited, Inherited}},
  PageBreakAbove->Automatic,
  TextAlignment->Center,
  FontSize->10,
  FontWeight->"Bold"],

Cell[TextData[{
  "Travail pr\[EAcute]sent\[EAcute] succintement dans mon livre \"L'essentiel \
de ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3\" (Ed. Global Design, 1996) mais repris ici dans une version optimis\
\[EAcute]e et beaucoup mieux document\[EAcute]e."
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["1. Introduction", "Section",
  PageBreakAbove->Automatic],

Cell["\<\
Certains tableaux de Mondrian ont cette caract\[EAcute]ristique \
qu'ils semblent corres-pondre \[AGrave] une construction math\[EAcute]matique \
qu'on peut imaginer de mod\[EAcute]liser. Il s'agit de figures g\[EAcute]om\
\[EAcute]triques construites par des recoupements successifs, par des lignes \
horizontales et verticales, conduits de mani\[EGrave]re plus ou moins r\
\[EAcute]cursive \[AGrave] partir d'un rectangle initial. Les cases ainsi \
constitu\[EAcute]es sont ensuite color\[EAcute]es \[AGrave] partir d'une \
palette limit\[EAcute]e \[AGrave] quelques couleurs. \
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Sur un plan algorithmique, on peut imaginer de reproduire ce \
processus de fa\[CCedilla]on pseudo-al\[EAcute]atoire par l'appel successif \
\[AGrave] un d\[EAcute]coupage vertical ou horizontal appliqu\[EAcute] \
\[AGrave] chaque rectangle issu d'un d\[EAcute]coupage \
pr\[EAcute]c\[EAcute]dent. Le choix de la position de d\[EAcute]coupage sera \
pseudo-al\[EAcute]atoire ainsi que le choix entre un d\[EAcute]coupage \
horizontal ou vertical ou encore de celui des couleurs.\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Ce document montre donc une certaine fa\[CCedilla]on de faire des repr\
\[EAcute]sentations graphiques r\[EAcute]cursives \[AGrave] caract\[EGrave]re \
al\[EAcute]atoire qui pr\[EAcute]sentent un air de parent\[EAcute] avec des \
tableaux de Mondrian. Outre le r\[EAcute]sultat graphique qu'on pourra \
\[EAcute]ventuellement appr\[EAcute]cier, c'est ici l'occasion de mettre en \
oeuvre quelques concepts int\[EAcute]ressants de la programmation en ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"]
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[GraphicsData["PICT", "\<\
OP8000000B`0e`0A0_l<0?on0000B00004P000000001;03G0000000N00402P00
0001;03G09X0003oPe`000000B`0e`0000@0000004P000180000400P00<02000
00055F4d000000000001;03G0000004/0=L0000j1`0k00H01003P@2h00d:4P00
<`00>`0600@00h40^00=2Q8003<003/01P0400>10;P01@XB000c000m0T_ZhOko
0OWoPOfio@WTkOKXgM`KBn[Qo_l1nOn1oKWm2NC]m^SMg1];j^7no`7ioh7m^Od6
i>gfj=gL6`0[1`3;iooWm^CXPOnco`P:0<_WonOfi>R1ok?o20X0bnOoioKTj87o
/ol02P0j01gno`3]o_n1l;W`1nKOi>ckm@LMo_l0kOkoPO2il0OVgnC/noD77Oko
0>gnoh7`^O06i]oTk?_e1`0d1`3Tm>kFooobPOnfo`_ko_HD0>Cdk]Kooo:1okKo
2o_nmQ@0i?C^e_oolX7o]_l3nokf500j1`GXooocoo_VPO:hlPgeo_[fi@05j?oo
lookiX7b^?8=mOkjm^D01NSooo?onnJ1l[Sb1OGnn_KU000m1aK`ooohonSUPOni
o`k[kOWooo/>5_3oooSoj>F1okWo3^_]nOoon`hFl?oon?oXiH7o^Ol6jngioook
3P0m1`oRn_oYlo?oPO^in`koo?OioolD3n;jonWclon1nkWk3_olmoWooa@?h_[o
jO?coh7k^O/6oocgnOoo500d1@3olOolo87o]_l0o_ko1o@=0?oaooclPOnfo`3n
o_l7m0d0oo7oo?b1okKo0?kno`7d3@0d1@3olOolo87o]_l0o_ko1o@=0?oaoocl
POnfo`3no_l7m0d0oo7oo?b1okKo0?kno`7d3@0d1@3olOolo87o]_l0o_ko1o@=
0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`7d3@0d1@3olOolo87o]_l0
o_ko1o@=0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`7d3@0d1@3olOol
o87o]_l0o_ko1o@=0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`7d3@0d
1@3olOolo87o]_l0o_ko1o@=0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kn
o`7d3@0d1@3olOolo87o]_l0o_ko1o@=0?oaooclPOnfo`3no_l7m0d0oo7oo?b1
okKo0?kno`7d3@2N1@3olOolo?So0?kjnogl_?kYo`?no_cloO/0o>;nhOl4o?_l
o?keo`3no_l7m0d0oo7oo?bGo`GnooknookGoo3n3Oonookoo_onookoo_onn?ol
o_go0?kno`Od3@3olOolo?;o0OgknoX2no_m/_l5oO_jno_mn_lAoOgknogmoogo
oOomoogooOomb_l2oOgko_gko`3no_l1m0d11`D0oo7oo?cho`ckl>c/l?;bm?;c
loCeoOOinL[h0O[mn_kho`onoo[ol?o`o?SdmOCblO;hhoT1o?_coPSmoO_mnogk
oO_jo`Omio;ckOcooO_o1?kmo?ono_l7m0d0oo7oo?cXo`3nnOojo]3onOkjo`Sn
o?;mlOg/o_7Io`3dlo<Rm?Sin?WhnOSio?gloOcmo?kdooogoooho__kn_[knocm
ookno`Od3@3olOolo??o0oghm>knj@C[kNo`m/3on_kjoaoklNKcj_[[ooGoookm
noSfm_[koO_mnogkoO_mnogkoO3o0?_bnOWlnOl6n_oon?okl_kf0OWko?l0o_ko
0O@=0@H50?oaoocln?l;o>o/ko;emoShnocno?l0no[j^?l9m_ojooGoo>gXi?kR
0]kNi_[ZnNgij_[]0?3ao`3nn_cjn@OdkN__j?SgkO[o0ogmookno`Od3@3olOol
o?Oo0Ognlol0no[j^Ol;lnKlk?g`o_odmOSmoOl0oO[jnOd0n?[gn_XAnOglnock
o?_lnocko?_lnognn_ojo03no_l4mooij_clnPCknocoo_ko1o@=0?oaooclmOl>
o?WdkNKPgMcLgN7Si>[an_Sjo@7kn=?f0OC_lndAk=c=j]odkOooo?_in?Wfl_3e
n_OjnP3mc_l8n_ofhoCdm_Sko?l0o_ko0O@=0?d50?oaooclmol5nO_moOknY_l?
nOojomc`knWWi>7Pg=SKh_[VnNWii_[Y4NcZkNo]kng_kNo]kng_kNo/jo?Z1nOM
i=WIm?W`n_l3o_goo_ko1o@=0?oaooclmol?n?Wjno_loOgoo_kmo?_jn_WfnOGA
m_Wen_<:l_WSoN[meO3dm__Koa3in?OhmoSgn?OhmoSgn?Oio??m2OklooObooob
o__nn_kk0_coo_ko1o@=0?oaoocln?l9oO?]jNCJdlc6`_k01<;4a/W;n/ojcP7<
bM?70LG2n/3j_PW1c[kMdNg;k_Sn]ol8nOookoWhn?Wko?l0o_ko0O@=0EP50?oa
oocllol7o?OinoOgn_[moOWob_T1nokjoo[k1oSokOoYiXF0oWX6NgMaJfM[M?Yh
nGciN?Yl4Gn<SXn>Shj?SXn>Shj?SXn>S?Z;nY/7VHbGTZOTm?;io`;nookno`Od
3@3olOolo?So3?kgmoG_inCTin3PgmomgOWQn]/1g=cCg@7Lg?[KnML@l=;]eMQo
PhF>Uj:XZJV[ZjGjXoVW8::RXJ:QXZ6RYJJUYZFVYJB^[Jb][:f/[Jb][:f/[Jb]
[oZ`n/0:`KS4^<Sloo[ono_mnP?knoono_l7m0d0oo7oo?choa3jj=oHb[Z/XijB
T8j>T92BT_VHnY81T8cCRQb9QH>5PhF3QH>1Oh5oPGn1R;2M_k2mKgb7UjFc]ojh
0;Oi]?Zh4;Zj^kfk_K^m^l6o`Ko1_l6olL[iboWK2m7KcMOoooconoWinoco0?kn
o`7d3@5G1@3olOolo??o2oS]ko?`l??cm_Kgm_W`b_H1n?Wjno[g4OCleO;G^bd:
01`N81dB2@H<5_XKnAoi6oTO42PX:BPY:2TX:BPY:2TX:BPTnR;j:0TZ;c/kIkoV
h^kmnOl0o_ko1o@=0?oaoocln?l@oOKel>;Ab<S>b<W8b<K6aLKia?W:d<_jb_[6
4LGG]=C0[BT@3cQ7EUeKFEaOF?YFnEXOEUIEEUEFEEIIFUUJFEYIFEmOGUmNGeiO
GUmNGeiOGUoiH?UV2F]cKY7Po_7coO_nnPCkn__no_ko1o@=0?oaoocln?l:m^7D
bK>FPWUeJFCmHP9THU_jFOYO0EeJdePQEU=ADe5CDE=ACde?CDm=CeUoKIJ<QPh4
3dAKL7UkNWeoN?YdnWP@NWQhNWQjN7YhOWanO7ilOWkaQ_V5nH/8SiB;ZO?on?Oo
o_/0oOgo0?kno`7d3@511@3olOolo??o2oCVj_;cloKfnOWjnOWjb_/QoOknooko
o_onoogooOomoo[ne?W/aAh001TN91h?104;5?XJnAgi6_TMlP/12PKj1OX72PXF
7AeC^NORi_[nn_l0o_ko1o@=0?oaoocln?lQo?KekM_4^;[4`/?2`/71`<76alK7
a/O6alO8alS7b<O8b=?9n<Siaa3C[]WC]a/41Se@I6aWI6Y]IoYUnFSiIOYX06Ob
E`5HE_YGnUT;F5mPFHKSooG`o_ckoOX2nokno_l7m0d0oo7oo?cho`_dg<o2YhA[
IFAKEECmDQ5@CTY<BTa:C4Y=Bde;CD]=BdSCAP54@_Y1nT0ABVeIS9>60007BfV7
TiFDVYjCnXoiT_V?nY81U8SbROV7nXT>R8Z:OZGkoooioogmnogmo_l0o_ko0O@=
0Bd50?oaoocllol7lnO_noOgn_[moOWobO`7o_koo_onookjo`cnomSoomX[0006
2a@>o03j1_T9n@Kj2@473_8=n@Sj40XD61dID/CSj^SgoO[o0?kno`Od3@3olOol
o?So3?cclnkJ`kVocLK7a/Ona@36nLoib<o97/S9b<W8bL[;b/_:bl[:fK3PiL/Y
21P_AUeUGeaQIeojGOUPnEkiHO5]nF_jLa9bJfMLS_?oooKno?_jn_Winokno_l7
m0d0oo7oo?cho`_dfm;5ZHE^JfmOFEKmE15BEeEGEEMEEeE@CU1>D4i@CT[BBOU7
nTTAD6Y>RI^D0`0I@FJ8VYZKXJNInY?jUP6ET?Z>nY41UJGbYoVTnZ`4Z9nFQk;k
o`;moO_no@7oo_ko0O@=0IX50?oaoocllom9l>Oboo7cm?Ggn?Sgl>k`k_3^l>kc
lO?alo7clO?alo7clO?alo7clO?alo7clO?alo7clO?alo7clO?alo7clO?alo7c
lO?alo7gloWg2oS7l?3<7P001`lG4O`0nPOi2_T7nPX01n402@L;1DBlh>CMmocj
o`3no_l7m0d0oo7oo?cho`Sll?;ag/W0bm[mbD78alO8`L;1`/72`L;4aLC5a<G4
aLC6aLK5a/G6aLK5a/G6aLK5a/G6aLK5a/G6aLK5a/G6aLK5a/G6aLK5a/G6aLKg
aOW94<bPcMJm70DK=TeWKfUSJ75YnVOiJ_UXnV/@K6MXIfQWJ6MXIfQWJ6MXIfSi
IOYX2fIPFDj4k_ookokmnokj0oWjo_kno`Od3@3olOolo?So3?KNfLjdTWenPfYU
HF3mG_UInU`1FUSAEQmEEUEFEEIEFUUJFEYIFUYO>G>;Q0007dYbV:bZZkFjZ_ZT
nZL1YYojWOZP0JBSlZOiY?ZW1:6HRW^Zo_l0noko1_gknogmookno`7d3@6/1@3o
lOolo??o2<CIn<_Ui^SYjOk[?nGTiNCUi>GTm_oYl_WJn=g_k^o^knk_k_;al_7b
lO;aj^WZjN[Yj^WZjN[Yj^WZjNOVinKWi^OVk^g^kNk]k^gbjPc]n=Wee/8j1@08
4143_@093P`[B/oAj>kgo?[o0?kno`Od3@3olOolo?So2?gjl_[]ZkoN/?k:o/T1
b<Si`eSDhLOAekWF_Lk?c/o>clk?dM;Ad]7BdM;9b/W:bL[9b/W:bL[9b/W:a/O6
alK7a/O=c/g>cLk=c/_;b/_:bl[;b/_:bl[;b/[@/m>n]CXB23MAHV9TKVmVIOYS
nEoiH?YM45iVIfIWIVMVIf1QH61NGeeMnFKjJP]YIeYdR_oiooonoO_nnP?in_kn
o_l7m0d0oo7oo?cho`_klnGVch><XFUkMgCnLP9dMWWjO0R=VX2:T7:?M87jOoV2
lG[iMoUn87]kOG]mNgekOG]mNgekOGI`D7afP1P8455iUj:/^[ncZ?ZSnYl1WI_j
V_ZG0IRUnZSnXPBQX:2OWoVXnZ`4Yin;XK3jo`Kmno_moOono_l1m0d19@D0oo7o
o?cgoa3`injZ<1lh4QlO8R8S8b@T9oXV1a@K51LQ530RnAOi8_T/nC7i<_TZnBWj
:P`^=bQ:>Th6100:4Q<5o03j0LT02ALC<DkDe^W`mogjo`3no_l7m0d0oo7oo?ch
oa3ni]cTWR@B:`D@4A0@3`l>3OT@2005004;01X=0_X3n@ki6?TMnAkj5P0EnAOi
610F12dU@`HC4CUAHf5SKFmUI_YUlF;jH`5UJOYZoF_nJP5XI_YUnVHBI6aMM8[o
n_ono_ckn_[inO_no_ko1o@=0?oaooclmol4im[KSPZR00`F00hLEGbHX:Zf_:nX
nZ?jX06NW_ZMnYh1WjSjZOfZoZT0Z?VVnZL4XZ:<Wjkko`;moO_no@7oo_ko0O@=
0Bl50?oaoocln?l@o_WioZL=0A841PH820X;3@_i2PL/;PXZ8PdO6?TLnA_i2_T<
nA3j3@4;3_X=nPP<3b`P<A8I00@02Q@F2Od0007j1O43nPL01OD0o@7i2?X72P`F
3bi@f=g`mO[nn_l0o_ko1o@=0?oaooclmol6nOcoZ@l34_h40`<30P7g00PO8@0M
5@0B313j4OT@n@3i0OT5nP800oT7nP8A0A816@0@0Q<E=DeMGEiVJEmTnV;aH?YT
06GiIoeXoFWiK?Y[2fURDVZ3oocoooklnogj0__no_ko1o@=0?oaooclm?l1Y0;^
00HF600D3009^P0:5RMEN96IWZV[X9ojVo6InYd1Wj;jY?fUoJKiZ_ZY1::CO8nR
o?l4oOgkoOgno`3no_l1m0d1]PD0oo7oo?cho`gli>SeV`D07QHF5aPJ6ohM1aLF
5aHG5QLFoP@e9QH310<>3@h=3Pd>3@D41@@510D46aXK6Q/J6aXC4Q<B4a8C4QDD
5A@E51DD6API61TH6APGnQKj2A4@7Ahf3Ad06P/>6AdA1`L200[j3O4<nPlA3@/8
2PP:20X80`440`H51`LBnQ?j3`TC5`h[D=kVm?WmnOl0o_ko1o@=0?oaooclmol6
k?;nY@h49OhK3AXI61LF5A4A414@4A0AoP018@on0008nPWi0?TFn@ki4?TDnAOj
2Q492`PS01L1:2DdC5]JFV9SFF;jH?5OnF8?IFIUIVEVIFINGemQHF=RH_UXnV@:
HeQ6GW[oo_onoO_nnPCkn__no_ko1o@=0?oaooclmol@mokoYPT04`D40P@52@/<
4Q?j5`P41@@W5P@40PSj1_T0nA?i2oT=nQ4?4aTI6aTK6A/I3P`>30h<3_`030L0
=CiHMhb?T9VJSiCjT_VA09?jUOVH8iZJW9ZLVYbJUI>FUIRGVINQWj6OXInQWifK
WI^MVifFP6MkT_coo_/0oOgo0?kno`7d3@6a1@3olOolo?So3OcejNZ@000?0083
10H6oPM00`430@<10`4@80bKW9Z=Vi:@TY2BT9:@Ti6CTI>ATi5nO7ilOWanO7Id
MWAfM7IdM79dLWAbM79aKg5_LFmaKf[jJ?YP4FA]KX]JE@`701TW:alG61@:6OXJ
lA_j614G71XL6Q`J71XE51LF6QTL7ASj6_XG21/a93aLj^oim_[o0_koo_ko1o@=
0?oaooclmol<oOGdVPX45`<61@@20_H020XM1YRFUhNHSOZ>nHoiN_UbnG3iKOU[
nF<?HV20DE<@5PDiDF1LG6=SFOURnV<0H_UQnUh@GfIWIVMVIfIWGf5QHfAVIVOi
G_YK2UYVDF9mookom__koOX3no_oo_ko1o@=0?oaooclmOl4oI`600[l00<31`X<
n@L852H@XJ2PTInAnXoiT?UknG?iLOY^8G1`LWAbM79dLVaZK6Y/JVaQD4I^B5HL
;BAONhZ8QX^<P8_jR_Z;0HbBnYCiTB>ETiFCUI>EThj=T8nCTYFDShf?SHn=Shf<
RXb:S8Z<QHEXMhcno`CfnoWinoco0?kno`7d3@931@3olOolo?So3Okin?RS60<R
1@`=3a0@oQ9051<D4a@C51<77Q7Ce^76hMOFemKGe]OFeMCEe=GDeMCSh^?Rhn;S
h^GTiNCUi>GThN3Qh>7PhN3Sh^?Rhn;Sh=[jf?[K<=kOdNk0W1X001XY;bDN7aX@
6QXL6Q`J71XN71hL7Q`N71hL7Q`N71hL6QPJ61XH6QSh7ahP8B@V:2X];2d^;Bh]
;Rd/:b`[;2//;dPcAfKdm_cbnol3o_goo_ko1o@=0?oaooclm?m<Zb4:9`P=30X9
20H51P`>3@h=3Pd>01T:c/oL_mcAd]7BdM;Ad/o@cm3?d<o@gMkMg]gNgMkOh=oP
gn3Oh=_LfmcKg=_LgMkMg]gNgMkifoWN;m[:j;fN8042=TaKEeALFU5IFEQIF5UH
FEYKFU]JFeYKFEUHFEQIF5UDEEAEE5EDEOQM7eiOHVAVJ6USHV5RHF9QHUmPGf1O
H5mOLEMUOoono^oko_[nn`;lookno`Od3@3olOolo?Co3JdN0b001`P>4ALL7a`I
nQAo1alAe=KRa^3Acm7?dLoAclo=clg?cLo=gM_MfmgKgM_OgMoMgmgOgM_IfmWK
fM_IgM_MfmgKgMoOh>;Ph^3Rh>GSiN?UhnGPe/CXa:dh8BMMM89lMWUfKGQhNWQj
N7YhO7YlNWajO7j5QXR6R8J8QXB2Q8:4PXB1QX:4PXB2Q88SQ8>6Qh^;Shj<RXb:
S8Z<RXZ8RXR:R8Z3QfM`Q_oonn[hn?Wko?l0o_ko0O@=0T@50?oaoocln?l=o_7X
jiL@01h53@l@4A7n4d0D4a@C51<D4`lO2=W>fK3EemKGe]OFemK?c/o>clk?c[^j
^kZk^[^j`L31`<70`L30_l2o`;o0_lS7b<O8alS6`_[0nL<`/IC3_:LL0@D24a/A
2P`700<10`430@<11P@610H41P@610H41P@610D31@<50`D52OT:7P/=3a8E5aXO
8B8Q8R4R8B@S92<T8b@V:QL`F>kjoo_ko`?moOono_l7m0d0oo7oo?cgo`cdjnnK
4P4N0PP61@<2oP001oX9=P@E0<o3cjG<cLk=c/g>cLk5a/G6aLK5a[6b/K:a/[6b
]kRg^;Nh]kRf]kJg][Nf]kjo_[nn_kkh_o[2<<6^T/:mZb8=5aTa?CPf?3Xb=cLf
=cHg=SLi>STj>CXi>CLg=SLf=cHg=CHe=SDf=CKh>ahl?T13ATQ8BTU8BDQ9B4U:
BdY;BT]:BdTbA6Oho?odo?X4no_lookno`Od3@3olOolo?Oo4?W`l9X=01H010L=
4QTN8Q`>nPMo0Q<0cL7=XlO4`lC3a<?4`kbk_;^l^kbkZ:NXYjRWZ:N^[Jj][Zf^
[Jf/[Jb][:f/]KBe];Fd]KNj^kfk_K^m^l2n`;k0_/32]IgBd/I4<cm2Ef1GCe9;
A4e?DDmACe5?E59DDUABE5QOHVARI69THV=QHf5SHF=OGU]LFeaKG5/SG5aOH6AV
JFU]K6e/KFa]K6m^Kfi_KVmXFc];J_Oin>cdm_Sko?l0o_ko0O@=0Gd50?oaoocl
mol@mOGnYa816`L@4Q<C51@F513j3`LH8`OMc=fbh?W?nM?acOW@n/TKb<S6b<K8
a/S6`Ko1_l6o`KoT/]?<Z`T00`001KX00`Xni?_jo`CnoOcoo_ko1o@=0?oaoocl
mol@m_KoYa<0608;2@P71@@31@Cj1PP?6P3D`mBYelKjaoW;lLGib?W1nLGi_RkS
/MC>[`h03P4?6aLC5aH<410?40l@3a0C51<D4a@C4a8B4A8A4Q4B51DD5A@E5?PE
20d>41<F6A/M4_XAnADA3`DHB>Slo_kkno[jno_loOono_l7m0d0oo7oo?cgob3h
n?nU3P0A00P<41<J7R4J200100400@0:4`3=_/fTd;gj_?W0lK[i_OZf0KNnn/3j
^A6ljkoVhlP[7RhP:S</8b8O5R3j8_XV0BT^nS;j=BLa;RX/:R`Z;2XT8bLX;Bhb
<R/Y:bT[:B/Y;bd_;Bl];bXJ2A]9ioOho_H1nO_lo`3no_l1m0d1Z@D0oo7oo?cg
o`Wnoo2f0@LB20/;l`d?1`l3c][0f<;3al_9a<;6b][77LG5a<G4aLC5a;o1alW:
a/:naLS1_;L>10D610@30od29P0200800P0200800P0200800P0200800P020080
0P881`@30`@72?T25`L2000620@03AD92`00:P0I001>cooohoSo0?kno`Od3@3o
lOolo?Oo2Okol;H11a472PWm20472?T93`<;0<[F_=Bn_l?7aL2n`/KJ`oS45;k1
a/W9a/6naLO2_;LA1PT:2`/<3?h=l0`f3@`=30d<3@`=30d<3@`<4Q8>3Pd?4A<<
3@`=30d<3A0;1`T?4@d85QhB50D2<`@Q0@5BdOooh_cnoOl0o_ko1o@=0?oaoocl
molWo_o`]P053`D82P`<3`lA3`X620H81PP60PP0amFidk^l`<C2_K^o`mW0nL8H
_;o4alO4_kk7c<O4_aXB51DE4a<A4@lA5_8HlAHW6aPG51HE6QTE4aDC5A<E4aTB
410H61H?7bDK6`h9?0`T109Cd?gmg_kmnol0o_ko0O@=0D450?oaooclmol7o_o`
]P474@Oa2Pl4303;ekgE_l34b<K1_l?7dL@?`L?4a/K4`l75b<:m^1472MT:1a0?
30/;30l@n@X73PT51`d?2`Kn00`R500B00l66V?4oookn?l0o_ko1o@=0?oaoocl
mol7o_o`]P474@Oa2Pl4303;ekgE_l34b<K1_l?7dL@?`L?4a/K4`l75b<:m^147
2OT:l@Wa2PL@3``;2``?4?T:1`h91@L=3`/6oP0<8Q@04P0?1QYSa?oonoSo0?kn
o`Od3@3olOolo?Oo1okol;H11a47l@X?10`0bmNmeKo0a<S6`Ko3am743l73a<K6
a<?1aLS2_KPA1`Wj2P4<3o<A0@l<lPX740l<2`/<3a3i2PL>2@D73@l;1_h0328D
01803`HJHlCooo_ho`3no_l1m0d1?PD0oo7oo?cgo`Onoo2f0@LA1o4:3`@<0<_G
_MFo`<C8a/6o`lOAa0o6a<?1`L?4a/G8`[fh4@L9f@X740l<2`/<3a3i2P/>2@D7
3@l;1Q`QB]kmo`ORhnSanO[fl?So0?kno`Od3@3olOolo?Oo1okol;H11a47l@X?
10`0bmNmeKo0a<S6`Ko3am743lK4`l71`lC6aLS2_KPA1`Wi2_49l@X740l<2`/<
3a3i2P/>2@D73@l;1Q`QB]kmo`ORhnSanO[fl?So0?kno`Od3@3olOolo?Oo1oko
l;H11a47l@X?10`0bmNmeKo0a<S6`Ko3am743lK4`l71`lC6aLS2_KPA1`Wj2P4<
3o<A0@l<lPX740l<2`/<3a3i2P/>2@D73@l;1Q`QB]kmo`ORhnSanO[fl?So0?kn
o`7d3@4h1@3olOolo?Oo1okol;H11a47l@X?10`0bmNmeKo0a<S6`Ko3am743lW6
`Kjn`LK9aLS2_KPA1`WI2PL@3``;2``?4?T:3`h91@L=3`/6000Ag_ogmo;lo`7h
noOo0?kno`Od3@3olOolo?Oo1okol;H11a47l@X?10`0bmNmeKo0a<S6`Ko3am74
3lW6`Kjn`LK9aLS2_KPA1`Wi2_49l@X740l<2`/<3a3i2Pl>2@D73@l;1P004Mko
moObo?l1n?_go`3no_l7m0d0oo7oo?cgo`Onoo2f0@LA1o4:3`@<0<_G_MFo`<C8
a/6o`lOAa0o9a/6n_/76bLG8`[fh4@L9nPX130oc4@4?3?8:1a0?30/;30l@n@X?
3PT51`d?2`H0017NooOgl_co0OSkmol0o_ko0O@=0Ch50?oaooclmol7o_o`]P47
4@Oa2Pl4303;ekgE_l34b<K1_l?7dL@?bLK1_[k1a/W5b<:m^1472MT:1a0?30/;
30l@n@X:3PT51`d?2`HT3Akno`S/m=cVlOCalOWgo`3no_l7m0d0oo7oo?cgo`On
oo2f0@LA1o4:3`@<0<_G_MFo`<C8a/6o`lOAa0o9a/6n_/76bLG8`[fh4@L9n@[a
2O4:1a0?30/;30l@n@X:3PT51`d?2`HT3Akno`S/m=cVlOCalOWgo`3no_l7m0d0
oo7oo?cgo`Onoo2f0@LA1o4:3`@<0<_G_MFo`<C8a/6o`lOAa0o9a/6n_/76bLG8
`[fh4@L9nPX130oc4@4?3?8:1a0?30/;30l@n@X:3PT51`d?2`HT3Akno`S/m=cV
lOCalOWgo`3no_l1m0d1;`D0oo7oo?cgo`Onoo2f0@LA1o4:3`@<0<_G_MFo`<C8
a/6o`lOAa0o6a<?1`L?4a/G8`[fh4@L9f@X740l<2`/<3a3i2P/>2@D73@l;1P80
0_Kho`;ilo3ho`3no_l7m0d0oo7oo?cgo`Onoo2f0@LA1o4:3`@<0<_G_MFo`<C8
a/6o`lOAa0o6a<?1`L?4a/G8`[fh4@L9n@[a2O4:1a0?30/;30l@n@X;3PT51`d?
2`H200;fn?l2nO?`n?l0o_ko1o@=0?oaooclmol7o_o`]P474@Oa2Pl4303;ekgE
_l34b<K1_l?7dL@?a/C3`L73a<K5b<:m^1472OX:0@`?la413`cb2PL@3``;2``?
4?T:2`h91@L=3`/60P02m_So0_Wcl?So0?kno`7d3@4h1@3olOolo?Oo1okol;H1
1a47l@X?10`0bmNmeKo0a<S6`Ko3am743l73a<K6a<?1aLS2_KPA1`WI2PL@3``;
2``?4?T:50h91@L=3`/65ALCn^;igO7^l?;fnoGo0?kno`Od3@3olOolo?Oo1oko
l;H11a47l@X?10`0bmNmeKo0a<S6`Ko3am743l73a<K6a<?1aLS2_KPA1`Wi2_49
l@X740l<2`/<3a3i2Q@>2@D73@l;1QDG4o[RnMgak_3bm__eo`3no_l7m0d0oo7o
o?cgo`Onoo2f0@LA1o4:3`@<0<_G_MFo`<C8a/6o`lOAa0o1`lC6a/C3`LG8`[fh
4@L9nPX130oc4@4?3?8:1a0?30/;30l@n@XD3PT51`d?2`HE5a?jh_WMlNk`l_Kk
mOl0o_ko0O@=0Ch50?oaooclmol7o_o`]P474@Oa2Pl4303;ekgE_l34b<K1_l?7
dL@?_/76bLW6`Kk5b<:m^1472MT:1a0?30/;30l@n@XF3PT51`d?2`H361Soi_od
ookooogfloSgo`3no_l7m0d0oo7oo?cgo`Onoo2f0@LA1o4:3`@<0<_G_MFo`<C8
a/6o`lOAa0nn`LK9bLK1_/G8`[fh4@L9n@[a2O4:1a0?30/;30l@n@XF3PT51`d?
2`H361Soi_odookooogfloSgo`3no_l7m0d0oo7oo?cgo`Onoo2f0@LA1o4:3`@<
0<_G_MFo`<C8a/6o`lOAa0nn`LK9bLK1_/G8`[fh4@L9nPX130oc4@4?3?8:1a0?
30/;30l@n@XF3PT51`d?2`H361Soi_odookooogfloSgo`3no_l1m0d16PD0oo7o
o?cfo`Kho[405@<=l@X72@T0e;gH_/_aa`G:b/W7a/Gga0Nm_l73`l6o_NW41kk7
aKnf3PP@d@X71`T;3@d;2@Oi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1_Sn
/@0E0`ga2PL92@3D_MRnbo771L[:bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>213i
2_49j@X71`T;3@d;2@Oi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1_Sn/@0E
0`ga2PL92@3D_MRnbo771L[:bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>213j2P4<
3o<A0@l<jPX71`T;3@d;2@Oi2PL65@3on_ooo_3o0?kno`7d3@4J1@3olOolo?Ko
1_Sn/@0E0`ga2PL92@3D_MRnbo771L[:bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>
213A2PL72@/=3@/91oT:1`HE0?ojooonl?l0o_ko1o@=0?oaooclm_l6n?ja01D3
3O4:1`T90=Bmf;k;lLL5b/[9alK5ml@7_Ko1`l?1_kgYa0NnalFo]Ph84?T:l@WY
2PL72@/=3@/91oT:1`HE0?ojooonl?l0o_ko1o@=0?oaooclm_l6n?ja01D33O4:
1`T90=Bmf;k;lLL5b/[9alK5ml@7_Ko1`l?1_kgYa0NnalFo]Ph84?X:0@`?la41
3`cZ2PL72@/=3@/91oT:1`HE0?ojooonl?l0o_ko0O@=0AX50?oaooclm_l6n?ja
01D33O4:1`T90=Bmf;k;lLL5b/[9alK5ml@7_Ko1`l?1_kgYa0NnalFo]Ph84=4:
1`L92`d=2`T7n@X71QD0oo[oook`o`3no_l7m0d0oo7oo?cfo`Kho[405@<=l@X7
2@T0e;gH_/_aa`G:b/W7a/Gga0Nm_l73`l6o_NW41kk7aKnf3PP@n@[a2NT:1`L9
2`d=2`T7n@X71QD0oo[oook`o`3no_l7m0d0oo7oo?cfo`Kho[405@<=l@X72@T0
e;gH_/_aa`G:b/W7a/Gga0Nm_l73`l6o_NW41kk7aKnf3PP@nPX130oc4@4?3>X:
1`L92`d=2`T7n@X71QD0oo[oook`o`3no_l1m0d16PD0oo7oo?cfo`Kho[405@<=
l@X72@T0e;gH_/_aa`G:b/W7a/Gga0Nm_l73`l6o_NW41kk7aKnf3PP@d@X71`T;
3@d;2@Oi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1_Sn/@0E0`ga2PL92@3D
_MRnbo771L[:bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>213i2_49j@X71`T;3@d;
2@Oi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1_Sn/@0E0`ga2PL92@3D_MRn
bo771L[:bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>213j2P4<3o<A0@l<jPX71`T;
3@d;2@Oi2PL65@3on_ooo_3o0?kno`7d3@4J1@3olOolo?Ko1_Sn/@0E0`ga2PL9
2@3D_MRnbo771L[:bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>213A2PL72@/=3@/9
1oT:1`HE0?ojooonl?l0o_ko1o@=0?oaooclm_l6n?ja01D33O4:1`T90=Bmf;k;
lLL5b/[9alK5ml@7_Ko1`l?1_kgYa0NnalFo]Ph84?T:l@WY2PL72@/=3@/91oT:
1`HE0?ojooonl?l0o_ko1o@=0?oaooclm_l6n?ja01D33O4:1`T90=Bmf;k;lLL5
b/[9alK5ml@7_Ko1`l?1_kgYa0NnalFo]Ph84?X:0@`?la413`cZ2PL72@/=3@/9
1oT:1`HE0?ojooonl?l0o_ko0O@=0AX50?oaooclm_l6n?ja01D33O4:1`T90=Bm
f;k;lLL5b/[9alK5ml@7_Ko1`l?1_kgYa0NnalFo]Ph84=4:1`L92`d=2`T7n@X7
1QD0oo[oook`o`3no_l7m0d0oo7oo?cfo`Kho[405@<=l@X72@T0e;gH_/_aa`G:
b/W7a/Gga0Nm_l73`l6o_NW41kk7aKnf3PP@n@[a2NT:1`L92`d=2`T7n@X71QD0
oo[oook`o`3no_l7m0d0oo7oo?cfo`Kho[405@<=l@X72@T0e;gH_/_aa`G:b/W7
a/Gga0Nm_l73`l6o_NW41kk7aKnf3PP@nPX130oc4@4?3>X:1`L92`d=2`T7n@X7
1QD0oo[oook`o`3no_l1m0d16PD0oo7oo?cfo`Kho[405@<=l@X72@T0e;gH_/_a
a`G:b/W7a/Gga0Nm_l73`l6o_NW41kk7aKnf3PP@d@X71`T;3@d;2@Oi2PL65@3o
n_ooo_3o0?kno`Od3@3olOolo?Ko1_Sn/@0E0`ga2PL92@3D_MRnbo771L[:bLO6
aOO41kfo`L?3`KnmjL@7_/O5_kH>213i2_49j@X71`T;3@d;2@Oi2PL65@3on_oo
o_3o0?kno`Od3@3olOolo?Ko1_Sn/@0E0`ga2PL92@3D_MRnbo771L[:bLO6aOO4
1kfo`L?3`KnmjL@7_/O5_kH>213j2P4<3o<A0@l<jPX71`T;3@d;2@Oi2PL65@3o
n_ooo_3o0?kno`7d3@4J1@3olOolo?Ko1_Sn/@0E0`ga2PL92@3D_MRnbo771L[:
bLO6aOO41kfo`L?3`KnmjL@7_/O5_kH>213A2PL72@/=3@/91oT:1`HE0?ojooon
l?l0o_ko1o@=0?oaooclm_l6n?ja01D33O4:1`T90=Bmf;k;lLL5b/[9alK5ml@7
_Ko1`l?1_kgYa0NnalFo]Ph84?T:l@WY2PL72@/=3@/91oT:1`HE0?ojooonl?l0
o_ko1o@=0?oaooclm_l6n?ja01D33O4:1`T90=Bmf;k;lLL5b/[9alK5ml@7_Ko1
`l?1_kgYa0NnalFo]Ph84?X:0@`>l`l13PcZ2PL72@/=3@/91oT:1`HE0?ojooon
l?l0o_ko0O@=0?`50?oaooclmol7o_goR0T71Pga2PL67P3Q`/O<bNW7nL@7b<S6
a<?1_koYa0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3no_l7m0d0
oo7oo?cgo`OnoOn82@L63O4:1`HN0>72alc9jLOia0O8b<K4`l6o_nW41l79al2e
3@H=l@X71`T;3@d;2@OI2PL3503ooOooo?3o0?kno`Od3@3olOolo?Oo1okmohP9
1`H=l@X71Qh0hL;7c<WYaoW41lS8a/C3`KnojL@7`LW7`;D=1Pgi2_T<1`T;3@l?
3@/9f@X70a@0oogoooc`o`3no_l1m0d100D0oo7oo?cgo`OnoOn82@L63O4:1`HN
0>72alc9lLOiaOW41lS7a/C3`L2ojL@7`LW7`;D=1Pga2PL72@/=3@/91mT:1`<D
0?omoooll?l0o_ko1o@=0?oaooclmol7o_goR0T71Pga2PL67P3Q`/O<bO77nLGi
a0O8alK4`l70_nW41l79al2e3@H=l@X71`T;3@d;2@OI2PL3503ooOooo?3o0?kn
o`Od3@3olOolo?Oo1okmohP91`H=l@X71Qh0hL;7c<WaaoW5nL@7b<O6a<?1`;oY
a0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3no_l1m0d100D0oo7o
o?cgo`OnoOn82@L63O4:1`HN0>72alc9lLOi`_W41lK6aLC3`/71jL@7`LW7`;D=
1Pga2PL72@/=3@/91mT:1`<D0?omoooll?l0o_ko1o@=0?oaooclmol7o_goR0T7
1Pga2PL67P3Q`/O<bO77nL;ia0O6a/G4`l;1`NW41l79al2e3@H=l@X71`T;3@d;
2@OI2PL3503ooOooo?3o0?kno`Od3@3olOolo?Oo1okmohP91`H=l@X71Qh0hL;7
c<WaaoW2nL@7a/K5a<?2`L7Ya0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogo
ooc`o`3no_l1m0d0j`D0oo7oo?cgo`OnoOn82@L63O4:1`HN0>72alc9lLOi`?G4
oL?Ya0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3no_l7m0d0oo7o
o?cgo`OnoOn82@L63O4:1`HN0>72alc9lLOi`?G4oL?Ya0O1bLO0]@d63O4:1`L9
2`d=2`T7f@X70a@0oogoooc`o`3no_l7m0d0oo7oo?cgo`OnoOn82@L63O4:1`HN
0>72alc9lLOi`?G4oL?Ya0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`
o`3no_l1m0d0j`D0oo7oo?cgo`OnoOn82@L63O4:1`HN0>72alc9lLOi`?W4oL?U
a0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3no_l7m0d0oo7oo?cg
o`OnoOn82@L63O4:1`HN0>72alc9lLOi`?W4oL?Ua0O1bLO0]@d63O4:1`L92`d=
2`T7f@X70a@0oogoooc`o`3no_l7m0d0oo7oo?cgo`OnoOn82@L63O4:1`HN0>72
alc9lLOi`?W4oL?Ua0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3n
o_l1m0d100D0oo7oo?cgo`OnoOn82@L63O4:1`HN0>72alc9lLOi`_W41l71`/?4
aLK6jL@7`LW7`;D=1Pga2PL72@/=3@/91mT:1`<D0?omoooll?l0o_ko1o@=0?oa
ooclmol7o_goR0T71Pga2PL67P3Q`/O<bO77nL;ia0O1`L;3a<G6a^W41l79al2e
3@H=l@X71`T;3@d;2@OI2PL3503ooOooo?3o0?kno`Od3@3olOolo?Oo1okmohP9
1`H=l@X71Qh0hL;7c<WaaoW2nL@7`L72`lC5a/KYa0O1bLO0]@d63O4:1`L92`d=
2`T7f@X70a@0oogoooc`o`3no_l1m0d100D0oo7oo?cgo`OnoOn82@L63O4:1`HN
0>72alc9lLOiaOW41ko0`L?4a/O8jL@7`LW7`;D=1Pga2PL72@/=3@/91mT:1`<D
0?omoooll?l0o_ko1o@=0?oaooclmol7o_goR0T71Pga2PL67P3Q`/O<bO77nLGi
a0No`<73a<K7b>W41l79al2e3@H=l@X71`T;3@d;2@OI2PL3503ooOooo?3o0?kn
o`Od3@3olOolo?Oo1okmohP91`H=l@X71Qh0hL;7c<WaaoW5nL@7_l31`lC6alSY
a0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3no_l1m0d0nPD0oo7o
o?cgo`OnoOn82@L63O4:1`HN0>72alc9jLOia0No_l73a<K8b>W41l79al2e3@H=
l@X71`T;3@d;2@OI2PL3503ooOooo?3o0?kno`Od3@3olOolo?Oo1okmohP91`H=
l@X71Qh0hL;7c<WYaoW41kno`L?4a/S8jL@7`LW7`;D=1Pga2PL72@/=3@/91mT:
1`<D0?omoooll?l0o_ko1o@=0?oaooclmol7o_goR0T71Pga2PL67P3Q`/O<bNW7
nL@7_ko1`lC6b<SYa0O1bLO0]@d63O4:1`L92`d=2`T7f@X70a@0oogoooc`o`3n
o_l1m0d1E`D0oo7oo?cfo`Kkoh493@X?n@XG1`T;3@d;2@L>00[:f<_2_l?6b/g=
b/K3lLKiaOW9nLKabPo9_L_?[PH?2`d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D7
3@l;1_T=n@X71QD0oo[oook`o`3no_l7m0d0oo7oo?cfo`Kkoh493@X?n@XG1`T;
3@d;2@L>00[:f<_2_l?6b/g=b/K3lLKiaOW9nLKabPo9_L_?[PH?2`d;2@L72@/=
n@X71`T;3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0oo[oook`o`3no_l7m0d0oo7o
o?cfo`Kkoh493@X?n@XG1`T;3@d;2@L>00[:f<_2_l?6b/g=b/K3lLKiaOW9nLKa
bPo9_L_?[PH?2`d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0
oo[oook`o`3no_l1m0d1FPD0oo7oo?cfo`Kkoh493@X?n@XG1`T;3@d;2@LA00c8
e/o;b[Vl_l;2_kbinL[i`oW=nLKi`o323[O3aJP85A4=2`T71`T;3OT:1`L92`d=
2`T7l@X73PT51`d?2`Ki3OT:1`HE0?ojooonl?l0o_ko1o@=0?oaooclm_l6non1
2@d:3oT:5`L92`d=2`T74@0<b=K?blZi_;o2`[nl^OW:nL?icOW6nL?``Pjg`lFX
21DA3@/91`L92`gi2PL72@/=3@/91o4:1`h91@L=3`/6n@gi2PL65@3on_ooo_3o
0?kno`Od3@3olOolo?Ko1__oP@T=2Poi2QL72@/=3@/91a403<SFcl_:^Kbo`/:o
_;Wib_W3nLgia_W3l<8>]l?5Z0PE4@d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D7
3@l;1_T=n@X71QD0oo[oook`o`3no_l1m0d1H`D0oo7oo?cfo`Kkoh493@X?n@XG
1`T;3@d;2@L>0Pk3cL[9a];DemSHemCBnLCi`oW5nLOiaOW8nLX?dLK<ajL73P8=
2`T71`T;3OT:1`L92`d=2`T7l@X73PT51`d?2`Ki3OT:1`HE0?ojooonl?l0o_ko
1o@=0?oaooclm_l6non12@d:3oT:5`L92`d=2`T73P8>`lg:bLKBe=OHf=ODd_W4
nL?iaOW7nLGib?W:3m76c<NW1`h23@/91`L92`gi2PL72@/=3@/91o4:1`h91@L=
3`/6n@gi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1__oP@T=2Poi2QL72@/=
3@/91`h23/?=b/W6d]CGf=SGe=;ia?W3nLGiaoW5nLSibPoAa/c7Y`L>0Pd;2@L7
2@/=n@X71`T;3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0oo[oook`o`3no_l1m0d1
G@D0oo7oo?cfo`Kkoh493@X?n@XG1`T;3@d;2@L511K6c/_8`Kno`<71`;nonL?i
`_VolLGi`oW63l>nbLFY3Pl03@/91`L92`gi2PL72@/=3@/91o4:1`h91@L=3`/6
n@gi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1__oP@T=2Poi2QL72@/=3@/9
1`D45/K>blS1_ko0`L70_koi`oW2nKoaaOW3nLH?`kk9aJT>3`0=2`T71`T;3OT:
1`L92`d=2`T7l@X73PT51`d?2`Ki3OT:1`HE0?ojooonl?l0o_ko1o@=0?oaoocl
m_l6non12@d:3oT:5`L92`d=2`T71@@Fa/k;b<6o_l31`L2o_oW3nL;i_o75nL?i
aPo3_/W5Z@h?00d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0
oo[oook`o`3no_l1m0d1H0D0oo7oo?cfo`Kkoh493@X?n@XA1`T;3@d;2@L02bCB
f=_Jclc;oLX1blcidoW<nMGicoW@nL?ia`nd]lO6/b0M00d;2@L72@/=n@X71`T;
3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0oo[oook`o`3no_l7m0d0oo7oo?cfo`Kk
oh493@X?n@XA1`T;3@d;2@L02bCBf=_Jclc;oLX1blcidoW<nMGicoW@nL?ia`nd
]lO6/b0M00d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0oo[o
ook`o`3no_l7m0d0oo7oo?cfo`Kkoh493@X?n@XA1`T;3@d;2@L02bCBf=_Jclc;
oLX1blcidoW<nMGicoW@nL?ia`nd]lO6/b0M00d;2@L72@/=n@X71`T;3@d;2@Oa
2PL>2@D73@l;1_T=n@X71QD0oo[oook`o`3no_l1m0d1H`D0oo7oo?cfo`Kkoh49
3@X?n@XG1`T;3@d;2@L342;0_lS>a=7@cL_;cM3AnLGicOWBnM7idoWDnMT?emKI
b;8S7P0=2`T71`T;3OT:1`L92`d=2`T7l@X73PT51`d?2`Ki3OT:1`HE0?ojooon
l?l0o_ko1o@=0?oaooclm_l6non12@d:3oT:5`L92`d=2`T70a0R`;o8c/CAd<g;
blg@dOW5nLgid_WAnM?ie?WI3mOFfLRb8ah03@/91`L92`gi2PL72@/=3@/91o4:
1`h91@L=3`/6n@gi2PL65@3on_ooo_3o0?kno`Od3@3olOolo?Ko1__oP@T=2Poi
2QL72@/=3@/91`<@8/2ob<k4dM3=bl_=d=7iaOW=nM;idOWCnMCif@oGe]W8/R<N
00d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D73@l;1_T=n@X71QD0oo[oook`o`3n
o_l1m0d1H`D0oo7oo?cfo`Kkoh493@X?n@XG1`T;3@d;2@L<301jHVMaJVERGeaL
Gf9UnFkiOOUinH3iPoV?nIH?Y9jHPgX55`0=2`T71`T;3OT:1`L92`d=2`T7l@X7
3PT51`d?2`Ki3OT:1`HE0?ojooonl?l0o_ko1o@=0?oaooclm_l6non12@d:3oT:
5`L92`d=2`T730`0NV9WLFYUHUmLG5mRIOU^nGgiNOV0nH?iSoVF3jBNV8=j1AL0
3@/91`L92`gi2PL72@/=3@/91o4:1`h91@L=3`/6n@gi2PL65@3on_ooo_3o0?kn
o`Od3@3olOolo?Ko1__oP@T=2Poi2QL72@/=3@/91``<07YRIg5ZIF9OG5aOHVGi
K_UmnGWiP?V3nHoiUPnTWYR3NPDG00d;2@L72@/=n@X71`T;3@d;2@Oa2PL>2@D7
3@l;1_T=n@X71QD0oo[oook`o`3no_l1m0d1K`D0oo7oo?cfo`Kloh051P84o@04
0P<3107n0a<2004140@1=080100I5a<@41<G6_T<n@Gi3?T8n@ci2?T>40l=3`lZ
01/>30P610@620X9nPX71`T;3@d;2@Oa2`L>2@D73@l;1_T=n@X41QH1oo_]o`3n
o_l7m0d0oo7oo?cgo`Onn_j12Pl<4_d=o@`G2@/>414?30TD100`0@080AXG4a0@
4aLJn@ci1OT<n@Si3?T8n@h@3`lA4B`17A0>30X820X<3P_j2PL72@/=3@/91o49
1`h91@L=3`/6n@gi2@L5503nnOknoO3o0?kno`Od3@3olOolo?Ko1__oQQ0H5Qgn
61`F5A<A3`/=4QHH5Q8<5@80;@022`@L5a<@41<G6_T<n@Gi3?T8n@ci2?T>3`l>
410[01`?3@d;2@T;3@oi2PL72@/=3@/91o4:1`h91@L=3`/6n@d23Ph?o0h42QL2
ooc]o`3no_l1m0d1B0D0oo7oo?cgo`Ccn^J42Nh01P8G1Rh300?h0?T2l@060P0F
02H63nP020440P0J01T01oh6oPD11POc2@4:4?TA1`l=2`/=3a0:lPT?1PH720X;
3@d:6`?oo_ooo_3o0?kno`Od3@3olOolo?So2?kZlNB:60@A2?h@5@l?3Pd<2P/<
3@l>30X<600U004=0P7j0?T2l@060P0F02H63nP01`<91`8P0R88nA3b2`4:3?T;
1`T71@D72@`:l`/A2PH51PL92P/;1aD0o?OlnoWnlOl0o_ko1o@=0?oaooclmolP
kOK_V2dP<2/c<c0Z9B0L5`l@6B0V9QlF3Q<07P045``4nP3i0_401P805P0V1PoW
00P50`0N02473a7m4P8D4P[b2?P;1PT71@D72@_b20D<41<F5AOn608B7`O[o`3n
o_l1m0d1K0D0oo7oo?ceo`CdUAh02o`01PH:3Q4?2`?n00X1300E4XE]NG]WH_YV
nEoiCoU41de6C`@90352nDCb?P`m?3]2@D`03@051@<3oP810`Kc1`493?X=214?
3@/;3@l@2O873`<31@H82@`=2QT3ookoook`o`3no_l7m0d0oo7oo?chob7nm?_c
X3DQ>S8f=cHf=3@b<S0a<cDf=C<_3AH9NfQlRGEWnVKiGoU?nD@7CDI?10T0<D;i
A?8n23ln@4Q7DP<F0oTAlP`12`Sj1`P;2@L51@L930_c30D;1`H61`Wn2`P65P3l
m__jnOkao`3no_l7m0d0oo7oo?cgob3joondE4MVHFQVHeaECDQ3>Ca7D5MGCT8B
4@1aIH6FPV_jI_UOnDoiA0M=ATl42@0a@_U4lCh:>ca4@e005@8A4A;m504B3?88
n@L72`T71@D72@_b20/>4aLH6A/J6aTD8@W[o`3no_l1m0d1H0D0oo7oo?ceoakh
XC@K:aXH5QPJ82@X:bPT7AHA51dY00LTgNc`jnGcn_Kimo7o1nKRdD/Q6IWTj_lA
o^[Li>2n51H61@D30`8200<3l`H11`Kj1`P>30X820X<3@Oc1Q0400010PD62@X8
5`3ooOooo?3o0?kno`Od3@3olOolo?So2Okho?^`CT9NEUOnF1=FEEADDeEFF5UH
EU8@2agCio7glOWfnOOao`OVh]5;8AVIi>Wo1ncQjNK47Al@oA7n4P4A3O<<0@/6
nPD830X81PH82Pd;lP`?2@P92P/<3@`85`3mmocln_3o0?kno`Od3@3olOolo?Co
7LM_Jhf8S8b8PGYcKFQSIW5jPGmdIQL:4l[SmOoono[fnOOao`OVh]5;8AVIi>Wo
2^WMiN;26Qh?3a4Ao1803?8:n@H73@/91`L92`gb2P/>4QDF5ALH6APD8@W[o`3n
o_l1m0d1PPD0oo7oo?cgob3go>jJ<al^7ATH6A`Q9RXZ9b8K5A8E7bd001cmoooh
mocboo7g1oookD@11:OonOOao@3no_`0dOh01PH51@<30P;n0`h40`@310<40`@3
10<410Gj1aL<2PP61PP:2P@310<40`@310<40`@310?n00`10`D71`DD0?kjookk
l?l0o_ko1o@=0?oaooclmol=m?ce[UA<J5iPHF1PGeknG@5OHOiR1UmK60<Elog^
oo7g1oookD@11:OonOOaoOgo6mD50P<@4A4B4A8B4@d>3@h=3Pd>3@h=3Pd>3@gi
2AL>30X820X<3Pd>3@h=3Pd>3@h=3Pd>3@gn2P0;o@h72QT0o_WnoO[`o`3no_l7
m0d0oo7oo?cgoackooo9MgJJU9RHU8n6PGahMg^5SY>@QGDT0PgZn^kolOL7ooo]
A044Yooimngm0m@30P;m3odA00cb2_T81`d;2@L72@/=lPX;3PhB4a@D5AHF41l7
jol0o_ko0O@=0H050?oaooclmolPm_CSTBdG8a0?3PlB5Q/M7AXE3PP62aHU1P0<
n?oljoOfn_OilO7o1ocoh34009_kjOl:l=W/nLH000/71PKl1A020P<20`830P<2
0`830P<32?X95`X81P@41PP90`830P<20`830P<20`830_d030441@H24@3im__j
n?kao`3no_l7m0d0oo7oo?cgo`Ofn_:ZDd]TF?eN05gnG0mNH69SHf9OFR<31nkn
n_;onOOilO7o1ocoh34009_kjOl8l]_^oLX20Q@@nQ4@3Ph=3Pd>3@h=3Pd>3@h=
3@kj3BL>30X820X<3`d>3@h=3Pd>3@h=3Pd>3@h;30`=3`l@40`K0_okoooll?l0
o_ko1o@=0?oaooclm?lMb7YjVY:IVINBRhAoOh>8TIRNV8aj<`D1iOSkn_okn_Oi
lO7o1ocoh34009_kjOl7lM[]o<T0017i3O4<n@h73`d;2@T;3@o_30P=3Q0A4Q8>
7@G[o`3no_l1m0d1P`D0oo7oo?chob7nnoGQSb/G80L:1`P;3a@F5A4:0`001A4Q
100>m_oik?[nl_oin?Wc1ooolTL=6K3onO?alPOnk?[ne1<I8o/:0@T9lP@A1P/;
3@/=2`d;30P810H62PX6l`@00oh03@4310H60A00n??hmoGnlOl0o_ko1o@=0?oa
ooclmOlMmJiHDFMGGf5PH5mNGEiRI6IWIVEQGB@32ncmmNonlOoin?Wc1ooolTL=
6K3onO?alPOok_coeQLM:?/?0A0@lPdA30l?3Pl>3`h?3@`920L:2`h<l`d53P/;
30d?oQ073A`4oogooog`o`3no_l7m0d0oo7oo?cdoa_=PH>OU:2PWiVBSHN7TIRQ
YZVRU84i2@KSn?Cfl?oin?Wc1ooolTL=6K3onO?alPSokO_oeAHL90_j2CX:2P`:
30X<2P`:30X<2P`:40h@3Q0>40h?2`/72@T=3@`:30X<2P`:30X<2P`:30X71`P;
3@h?3`/L1>_o0?kno`7d3@601@3olOolo?So4_cil]b;:ALL0@D20PD93Q0?2@;m
00X>7`006O[oooOll_[cnO[ao`OWo>Hh00VQlNWo2_kan>jm1P403Q0@oQ424a4;
lPX?30`>30h<3P`@30`82PX>3_8:4@T610D61`P71`8@0?G`mOCdo?7o0?kno`Od
3@3olOolo?Go2_B_G5I[FF9SI6=RoV41IfSnJ`YYI60J0aS`o?_hooWcnO[ao`OW
o>Hh00VQlNSo1_Gikkl60@7n3O`<l0X>2`X;2P/:2``;20L62@X=lPX@2`T92P/>
3a0@3A`4ookoook`o`3no_l7m0d0oo7oo?cdoagAQh^VVJNWYJ2JUI2AWJJ]/[B]
WHXa31CWm_SlooGjloWjlOl7iocV>009XO7Xo`Ofno6n1P002Oh8@0H610H620X8
2PP:20X82PP:20X82`T;2@/92`T=2@T51`L;2`X82PP:20X82PP:20X82PP20P<5
1`P;2`TH0_onkOl0o_ko0O@=0Gl50?oaoocln?l7o?CZe8@V4aWl00<210T6n`09
1aX002;looohn_7onO_io`KaooI000b/n?obna7jnoOlll/Q6@HD5aXK71hN71Gb
50lA4A8A4Q4B4APE514B4aHGlACn3`d@3`l>30HB0?G_m?7ao?7o0?kno`Od3@3o
lOolo?Oo7ockkZYKEV]IHF9SHf9RH65VJ6Y[JVQTGP`48O;lnoOklOoinoWo1_7o
mT003:choo;k3?conoodbb0E00X920Sm1o463`<30P<20`8320L40`851PWa1PX5
1@H72``>3`/K1>_o0?kno`Od3@3olOolo?Co6lj7RjNLZ:ZXXijHUIJT[KBh^K2Q
RbH>7nWfn?c`ooWknOl6lOof@00<[?SolO/ooocom//N4P081P@40P410P<51PD6
1@H51PD61@H51PD30P<20`830PT61@8310L81PD61@H51PD61@H51PD60od02`85
1PP55P3oo?oooO3o0?kno`7d3@4V1@3olOolo?So2?cej^9c9Ah03O`00P440O/0
10PK00T1o_l1oOcPo`KnnBX@0;;gj_lAo__]n__<4Q8A3aXU:BTW:b`RnQoi6`dO
7AlM7adO7AlM7adO7OLOnB@@71/I61DA3PX<603gko;`l?_ao`3no_l7m0d0oo7o
o?cfoa7moYaKI5=/I6EUIVETHfARHfOnJPUWH@dK0?ggn__mh?l6o_TZ402bmnSo
2_Gno<X<1P4000<3e@3i0_X00`496@?[o`3no_l7m0d0oo7oo?cdoa^lQiRA/:f^
[JNRWIVMXjbe^kbeYi8V9@3dkoGngol6o_TZ402bmnSo2_Ooo//<1P400042e@06
0`430@<10oP01`8C0?gjoooml?l0o_ko0O@=0EX50?oaoocln?l8o?K[hg<U7@0;
l`041aX02@7no`7mo>3o1_ki:Q00/_OZoa7ln>cinlhF61XQ;Sa1@496B4_jB?Y5
0DA7ldD1AdOjB?Tk44Q8AD8n>3<]51h0nO3bknkklOl0o_ko1o@=0?oaooclm_l9
oOjLG6ADK6EVIoiV16EUHVAWoVX9IV8=6`3mmo[koN3o1_ki:Q00/_OXo`[fo_c:
2P@000851Od000_j3?X90@X<lPgi3?T02PT92P/=3a8D1AL1jol0o_ko1o@=0?oa
ooclm?lK^XFHTK2][Zf[YZ2MWj>]]K^l]JJB9RD0m>oeo]oo1_ki:Q00/_OXo`[g
ook;2PD000<81Oh0@04<30h<3P`>30/92`T;2@/93P`>30h<3P`>30h<3P`>30h<
3P`>30h<0@0100400@040P@620T;3`0A0?_hoooml?l0o_ko0O@=0EH50?oaoocl
n?l8o_O/i7HV7P0;l`041aT02P7no`7mo>3o1_ki:Q00/_OZoa7lmNWfnllI7R9m
SI^SYZN]/9CjTOV?lHkiTOZN4InEUI:>Qh1gKalV1_kcl^o^no7o0?kno`Od3@3o
lOolo?Oo2?kmoY]LI5A]IOeW4VIVIFAUIfUYJ6EP31/0oOOjnogPo`KnnBX@0;;g
j?l?moolb@T104U<D4i7@T97=_XgnCGa>?TgnT@=@c<c=3Hi?41301<0ook]o`3n
o_l7m0d0oo7oo?cdoa^ePYF=[Z^][J^VX9fOXZVc]kZbXh`V9@3dlOOngol6o_TZ
402bmnSoC_Soo//:1@1=DUECCDQ:C3Lg>CLi=cTg=cDg=CLe=cDi=cTg>CLi=cTg
>CLi=cTg>CLi=cTg>CM6A4I4ATA6A38b=3@g>Ce000d0n_Sooog`o`3no_l1m0d1
>`D0oo7oo?cho`SnnNoWMbLP0@gc00@86P0:0Oko0Oclh?l6o_TZ402bmn[o4O_d
iOGidA`S:I2R/kk1a/c?b?[6n/D1`l7c`071a?[6n/0A`/c=bL:k/JJL:bh=ooKd
knkklOl0o_ko1o@=0?oaooclmol8o_cmVeaTE6eVo6LAIVIUIVMXJ6ISG@`K0?gg
n_cmh?l6o_TZ402bmnSo3oWooLP8001=Ce9?Ad92Ad[jBoY:0D]=ldh1CDcjBoY5
3DA7ATQ;CU=HG00?0?omkOl0o_ko1o@=0?oaooclm?lK/GjARZZWZj^YYZ2MWJ2V
[K:e[Yb88b<0m?7go]oo1_ki:Q00/_OXo`kjook;2PD0EUMKF59?Ce7iC_U=jDkj
B017oT`<Ce5DF5`0303hm_gnoO3o0?kno`7d3@4k1@3olOolo?Oo1occjWXZ8`<>
n@0110;m00@;700<0oko0_cjo^7o1_ki:Q00/_OZoa7klN;bnM8P9c6=X[K2b<cD
e]CcdP7@cO?<0Lg@n];jc17@gMgId<Jk[j8f>1ConOG`k__ao`3no_l7m0d0oo7o
o?cgo`_nnobKFfACKFEWIfSnIoiU3FIWIVAPG0/K0?cgn__mh?l6o_TZ402bmnSo
3o[ooLL5000k?3di<B/[;cOc>@4j>o<l0C/jnSWj<`da<c<e>Ce2B4d02P3lnngo
0?kno`Od3@3olOolo?Oo7OgmojaiS8JWYZVYYjBOViVJWZN/[JJGPR4R0?Cammko
1_ki:Q00/_OXo`ojooo;2P<0AdU<BD@m?T0nfSci=Pll?T12ADU<D00:0?SfoOkk
l?l0o_ko0O@=0DP50?oaooclmol7o_K]OBdT1@oj00/12`/300023Ad03@?no`;k
nOkQo`KnnBX@0;;gj_lAnNkQl?SB8R`gYKcAgnK[mOWVn^?ji@7RgO?L0MgQn^?j
l17dlO7/hmS<_Zi0?aWonoS`k__ao`3no_l7m0d0oo7oo?cgoaomnobJFfACKFAW
IfQWIfIUIVEVIVARGET;6P3lmo_lo^3o1_ki:Q00/_OXo`okoog71@00AdM8@cXc
<cP^nS3j<P4d<o<d0C<anS3j?@dk:b/]<CHk@TT01`3jn^go0?kno`Od3@3olOol
o?So7_gimonXMHR3Xj:VYZBRWI^FUIVQYJNOT7dN803clOSNo`KnnBX@0;;gj?l?
n_oob`X305EGFUQ@Bde=>?XdnCKY=?Y144<j?3doADQ<C`080?Senokkl?l0o_ko
0O@=0D<50?oaooclm_l6n>in;RL64OX02`@B4PX40@D?7P0?1?ko0_Wio^7o1_ki
:Q00/_OZoa7ikMk_n=8S<3^N]<cKh^Wbm_[jmo[j0OWclo01l_Kjmo[Z0?3no`gj
k^3@`4M57OonnO7`no7o0?kno`Od3@3olOolo?Oo7ogko9YKHe=]I6IXJ6MWIVAV
I6ETHemKEPXJ0?cgnocnh?l6o_TZ402bmnSo3ocooLL4000e=C@_9QhM8S7j<oTf
03Gb=_TcnRH=8Rh/;c<i?dI>00D0nOW]o`3no_l7m0d0oo7oo?choakmm_CmYG:5
Oj2OY:BRX9^IU9:CVZ2RVhai71h0lo7hg_l6o_TZ402bmnSo3o[ool/:0@16B4]7
?c/k>C_j=oTjjCOj:Q0/?d=5ATa?DeH01P3fmO_nno3o0?kno`7d3@5N1@3olOol
o?Oo2?kfjgXW808?0O`04P4551H=1P@641l03`?ooogfm_cQo`KnnBX@0;;gj_lA
no7Rl?KA82dk[/OOk_Ciooobn_7jmA7ckN_]jng[kN_]jng[kN_]kNojlO[g4O_o
oogejmg<^TE26OomnOKco?7o0?kno`Od3@3olOolo?Oo1ogkoIaNIeE]oF@BIFIV
IFIUIFASH5YF2aX0o_WloMoo1_ki:Q00/_OXo`ojooo81P00A492?3@_;S<YnR[j
;Q4_;2d/;B`];2d/;B`];2d/;2_j:_X`3BhX9bP/<3HnAP060?[jkOl0o_ko1o@=
0?oaoocln?lNoOSgojIbQgnPWj:RX9fGU8n<S9>HViF7MAXL0??an]ko1_ki:Q00
/_OXo`ojook92@00DU=GDT]7AdHanRgi<NT]nS<@=CLj?3i3AdY?00H0m_Gmo__`
o`3no_l1m0d1C`D0oo7oo?cgob3jmnIU4AH020d?4Q8>2@@63Q4<2@XB7bh03P3o
noccl?_Qo`KmmRH>0;Klj_lAo__^n?S852DjVl?LhN;Zj^3XlnT>j>SVj>KXi^SV
j>KXi^SVo^SjjOW]3nCZl?7Yg<bi>cL>ooOinoS`o`3no_l7m0d0oo7oo?cgoack
oonKG75PK6]YIF=SI6ITGEeQIVQZJVLB70;onmgo1_gf9Ph0]_cXo`ofooo91@00
<cdn<R`b<R/alc0><C4b<C8a<S4b<C8a<S4boS7j<?Td3b/a=CLg>T=>00`0ooco
ooc`o`3no_l7m0d0oo7oo?cdoaZWLI2:X:RXYj:JThf6Ngf8TY^JTH8L703clogN
o`KmmRH>0;Klj?l3n?ol`oh01cY8C44i?3X`fCGi>@l`=ci2ADM=E0060?SfoOom
l?l0o_ko0O@=0BP50?oaooclmolPn_GQG`X?00D<4QLG4P`41A0A30X93aX[00/0
oo[klO3khOl6oOHV3P2fo>So3o?kn<D@8SNK`mkQgnCQf>;Jho[V4>GJg^SZimc:
]SLa1ocdnOkll?l0o_ko1o@=0?oaooclmolLnoooWEmdHVeZIF9QHFAVIV5PI6MY
JVQT4ah2oo_Mo`KmmRH>0;KljOl@o_Cool/8000d?Chc;SHg<3CJ<oXf43Lb=SLi
>Ca4C`0?0?onookjl?l0o_ko1o@=0?oaooclm?lJ[7BBS::XZJJRVYB=QgioRY>K
VHio71`0lo?mg_l6oOHV3P2fo>So0oKon/7n00LhA4Xm=SPh;mTfnCT?<CDm@D=6
CE801P3hm_oooO3o0?kno`7d3@4[1@3olOolo?Oo8?_ghf8:40042PhC4`h70P8>
40X710PF900;0?oknoCao>7o1_gf9Ph0]_cXo`ocnoS5428gVl?NhMoThMSRf^?j
iA3Tg=kVjNSNb[@g<@Olm?Wno?3o0?kno`Od3@3olOolo?Oo7o[ooiaOLf9]JFEQ
H69UJFQWIFMYJFQUHA<M0_okooonh?l6oOHV3P2fo>Wo4?kdooo;2000=3dn<bhf
=c0dfS?j=A0f=3He>3XnA4d03`3oo_onn_3o0?kno`Od3@3olOolo?Co6ZYdTXbT
ZJbYY:2IUXj9RY>JWiZ>OR0M0??aoMko1_gf9Ph0]_cXo`?foo[1oP07>4A:?CHh
>2oI=_Th3c<e>d14B4e@00H0n?Kooog`o`3no_l1m0d1;`D0oo7oo?cgob3nnNIS
310010P<3`l;10003@d60@0441l02P3onocflocQo`KmmRH>0;Klj?l?lo_haA0R
=i_3g^7Oi>7Hh][Sn^@@hmoMhnOZhL^b=c47o?Cio_c`o`3no_l7m0d0oo7oo?ch
oa;nnOooVeicHVeWI65QI6M[JfYXoVX:If9N4ah2oo_oookPo`KmmRH>0;KljOl@
o_Cool/8000d?Chc;SHg<3CJ<oXd43Dg=C8f?455B`0?0?onookjl?l0o_ko1o@=
0?oaooclmolMoOooZ7BBSZJ[[ZfZYZ:LUi>DW:6TWY5o8Ql0lo7kg_l6oOHV3P2f
o>So0oKon/7n00LhA4Xm=SPh;mTfnCL?=S@h?TI;CTh01P3hm_oooO3o0?kno`7d
3@4X1@3olOolo?Ko4OcXI@dA00@420/<1`4000L80Oh02P`M00X0ookon?ClhOl6
oOHV3P2fo>So3o?kn<D@8SNK`mkQgnCQf>;Cha3RhMgPi^cTc:lg<@Olm?Wno?3o
0?kno`Od3@3olOolo?So8?khoonKGW9QKFERH69UJFi^JfY/Jf]YI5lC7@;on_oo
oN3o1_gf9Ph0]_cYoa3nm?oob`P003@m?S<^=SL`==<c43@i=Ble?TA6B00?0?on
ookjl?l0o_ko1o@=0?oaooclmolMnoooYg>BSZN//;2_ZjRUX9bKY:R[XiJ29B40
lo7kg_l6oOHV3P2fo>So0oKon/7n00LhA4Xm=SPh;m4f3cPd=Ce8CTm;00H0n?Ko
oog`o`3no_l1m0d1:`D0oo7oo?ceo`[[J10C00@21PT81Od0007m00@=7P0:0?ko
0_[eo^7o1_gf9Ph0]_cXo`ocnoS5428gVl?NhMoThMSRf^?jhQ3Qi=cMi>gWc:dg
<@Olm?Wno?3o0?kno`Od3@3olOolo?So8?kho_nJGG9PKF=QGf5UJVmaJVUZK6]Z
If8C7@7onOooo>3o1_gf9Ph0]_cYoa3nm?oob`P003@m?S<^=SL`==XcnS8@<c`d
;3<oAdI600l0ookoo_[`o`3no_l7m0d0oo7oo?cgoagioonULI:@YjZ`/[6_[ZbW
WZ2Y[K6ZW8TW8`3clO[No`KmmRH>0;Klj?l3m_oj`Oh01cQ4BSdf>3P_fCKi=@lk
<c8kBE5?B@060?Sfoooml?l0o_ko0O@=0BT50?oaooclmOl:kVXC50050`D:2PKi
00D142802P3no`;kmokQo`KmmRH>0;Klj?l?lo_haA0R=i_3g^7Oi>7Hh][Sn^4@
h>GLfn?_jLf[=c47o?Cio_c`o`3no_l7m0d0oo7oo?chob3nmogoVE]aH6aQGUmP
IV]_LFEUJ6]/K6UU4ad1o_SooocPo`KmmRH>0;KljOl@o_Cool/8000d?Chc;SHg
<3CJ<oXa438m=2Xb@DU7A00?0?onookjl?l0o_ko1o@=0?oaoocln?lNoOOooj=a
T8jWZJjb/k:a[ZbNWjZ`]K2QSbTS0??an]ko1_gf9Ph0]_cXo`?foo[1oP07>4A:
?CHh>2oI=_Td3c`c<3Y;De1700H0n?Kooog`o`3no_l1m0d1:PD0oo7oo?ceo`_a
KAHG00P420`=2@Gj00D45BL02`7no`;mmokQo`KmmRH>0;Klj?l?lo_haA0R=i_3
g^7Oi>7Hh][Sn^0@gnKLf^;_j/fZ=c47o?Cio_c`o`3no_l7m0d0oo7oo?chob3m
m_coV5Y`Gf]OGEeOIFY_LF5RIFU[KF]X4Q`0oOSno_cPo`KmmRH>0;KljOl@o_Co
ol/8000d?Chc;SHg<3CJ<oX`434n=2Ta@DY7@`0?0?onookjl?l0o_ko1o@=0?oa
oocln?lNoOOmoj5_SXbVYZf_/K2^[Z^KWJJ_/k6TT2TS0?Canmko1_gf9Ph0]_cX
o`?foo[1oP07>4A:?CHh>2oI=_Tc3cdc;cU;E51600H0n?Kooog`o`3no_l1m0d1
I`D0oo7oo?ceoakgORDT2Q@A4Q@@30L210P80`022ALW01@3ookjo_cmn_kin_7n
1oooma<50;_lj?l?k?7i[2LIBJO3g>KThN3Sh^;S7nSXi^CShMoOin;OhNKXi=kT
inoakMk6[CLa1ocdnOkll?l0o_ko1o@=0?oaoocln?lPoNokojAVMfEaIF5MG5iU
JfiXIfU[KFaZI@PQ0?gcmOoonOkin_7n1oooma<50;_ljOl@o^ggok8O00Q0?C`h
<c<f>cCR<alh>3Hd<c4_;cLb;c4f>3@`?3ln@3ln@4H03`3oo_onn_3o0?kno`Od
3@3olOolo?So7_g_oOn_N9FBZZ^^[:ZWYJBRVinY[k>_X8`N:@3dkO;noo[nnO[a
oPOoooLC1@2ko>So3^oenjPD00A4A4Q2>cDg>^4f7c/k>CLf=38b>SDb=3Tk=c8k
?TA8BDQ9B@060?Sfoooml?l0o_ko0O@=0F`50?oaooclmolPo_ofMb0Q2A@@4aDC
3`/6210@2@H63AX[00P4ookclo7jn__Yo`Ofnod/5PFkoO7dnOL@ooGknJlY6DFW
`mcVi>7Phn;RhaoXinKThn7PgnSSgn7WjNGOinS^kN[Mb;4g<@Olm?Wno?3o0?kn
o`Od3@3olOolo?So8?gZm?nIGG5MJEiIEE=FG69UI6=VJ6UZIV<74@3lln[cm?Wk
jOl7m__m;1H5^ogam?Wg4?kfoone8@04@3dl>3<c=S/dhS<O>3Lf=3<a<2lh<bla
=cTe<Cm0?C`l?D9:00l0ookoo_[`o`3no_l7m0d0oo7oo?chob7mjoOoXfn<RJ2P
XInKUYBCTI:EWjNZYiR871P0m>o[nogon__Yo`Ofnod/5PFkoO7dnOL?ooSonj/F
0014A4Q2>cDg>^4f7c/j>CLf=3<b>cHb=3Xl>3<n?d=4ATM;C@060?Sfoooml?l0
o_ko0O@=0G050?oaooclmOlNmGHR9@hI7b<W9B8N6adE5@h:2PlK:`D;1ooom^_[
oO[nnOgiooWj1o7jm2h50:[jjOl@mn[knJPZ6D:W`mcVi>7Phn;RhaoVi^GThn;Q
hNWTh>;Xj^KPj^W[j>GLbkLg<@Olm?Wno?3o0?kno`Od3@3olOolo?So8?g_m_bF
FfmMIf=NFUQKH6IYFEYLGf1PGUTL403knng[koWnnOgiooWj1o7jm2h50:[jjOl@
mN_oojhR0050?C`h<c<f>cCR<alf=SDd<c8a<CTd<38h>SHb@T4j=cLlAE003`3o
o_onn_3o0?kno`Od3@3olOolo?So8OganOnQKXZ4V:2PW9NBT8f=OX>=UI^GRg/^
503dn?3gn_ojo_WmnOoinPOan_@^1@2Zn^Wo3o[]oo^T5`00A4A8@S/e=c[Q=Qli
>CPg=SDd=3`g<cDk?CTd@D10?d56CU<01P3hm_oooO3o0?kno`7d3@5U1@3olOol
o?Go7_Um:RlE7C8f>S/i=S8c9bHO6QTL:CH100[kooccnokjooWinOcinPOooo8i
002Xoo7dnNh@ookknJ/f6D2W`mcVi>7Phn;RhogToN<Gj^GRi>W[in7/j>SUh]_>
_3La1ocdnOkll?l0o_ko1o@=0?oaoocln?lOoOWioi]RMEiTJfMQH69VKVmJFemQ
Hf9PGA400>[km_GhooWinOcinPOooo8i002Xoo7dnNh0o_ko3;4^0010?C`h<c<f
>cCR<oddoC<G>SDb=3Tk=c=4@3Ld=3]8E@0?0?onookjl?l0o_ko1o@=0?oaoocl
n?lNoO_oojIcSX6BXZ6LUI2:RXMeNhF=U9>9NR040>?jn_OonOWio?Wj1ooolST0
0:SolOCik_ko3?^W8`00A4A8@S/e=c[Q=_dgoCHG?CPe=c`n>SE3?cdl?TEAF006
0?Sfoooml?l0o_ko0O@=0Dl50?oaooclmOlNnGh^;`lB9B`a<c8`;Rd`;bPR8B<]
>B@E?>koo_Oin_[kjOl7l_3@AA0HU^;Yoa3lnO_WUSLJ>JO3g>KThN3Sh]kSoN@G
k>OSiN[/j>?ZinOThmc?_SLa1ocdnOkll?l0o_ko1o@=0?oaoocln?lPoOSioiYQ
L55@EE1;B4Y@EEMDE5MJG5eKEbhA:]_hmo[onO_Yo`Obl=1541RFh^Wo4?[joo6L
;`00@3dl>3<c=S/dgS?m=1Ll=c<e>S`h=D8o=S<e?4UG00l0ookoo_[`o`3no_l7
m0d0oo7oo?cgoagmoonULXIcNHF2O7E/JFASHVMcOHB5OFlh4RKEn?knoo[kjOl7
l_3@AA0HU^;Xo`klonVB9000A4A8@S/e=c[M=_dg5clj=SPm?c/g@Chl>cm6DUX0
1P3hm_oooO3o0?kno`7d3@5e1@3olOolo?Go7_Ah:BD000<9418B4@l?4Pl70@02
2AD01`i5>B`K3BWj;?T]nC3i=PMFHETJ00@mGo54nD/@HV=ZI44H6C>W`mcVi>7P
hn;RhaoQhN;Si>GVi^gXi>K[k^[TiNCXinKOd;`g<@Olm?Wno?3o0?kno`Od3@3o
lOolo?So6?gcm_RDFV8g;2XT7a`N8bP[9bLZ;Bl`;R_n00@`:bDN5?T/nBgi<?Tf
1eIQFAX013eOlDCiBa1PI71^Aa00040m?3Pc<cHk=>8c7c4a<S<d=CHf?CPd=S/n
>SHm?3Lf>3m:E@0?0?onookjl?l0o_ko1o@=0?oaooclmolPn_goWfUgEU9EDDPo
=S4];2`a?DQ@DT]02@00:b/]<BHanRci;OT`nCH7EV5I6P04?EoaA?U;3fEVKVHm
1@00A4A8@S/e=c[Q=Qld=3Df=cPi>D0k=cTn@Cdh?3/m?T99DeP01P3hm_oooO3o
0?kno`7d3@581@3olOolo?Go0oAl:b7l00@30`800_T022XR@S4=2P001?X7n@3i
0oT7h@000Oh030897CVW`mcVi>7Phn;RhaoOh>7Si>KWj>kYiNO/k^_Ugn7Yk>_R
ckTg<@Olm?Wno?3o0?kno`Od3@3olOolo?So8?gam?RGFU/U4A4;1P<42@lA10D8
2`d>3@X[5bhL00@00?T7n@3i0oT7g`0>0PP80@00@3dl>3<c=S/dhS<O;c0a<c@f
=cPn>CDg?3hk=cLi>3/m@TUB00l0ookoo_[`o`3no_l7m0d0oo7oo?cgob3ho_nR
JVm2=CXc:QlF3``:0@LD82X[9AX`5BLG00hC4`kj1oT0n@?i1n400@@2n`07A4A8
@S/e=c[Q=Qlb<c@f=cTj>d4l>3Xo@Chi=SPn@dM<DUD01P3hm_oooO3o0?kno`7d
3@5Z1@3olOolo?Co7Hm2>@0020lD5QHG5QHI5a4;1PH;4PH;=Ph84A/50_X5n@Wa
30LF400;52PF1_4Bn@/@:ah>2A0N<4>W`mcVi>7Phn;RhaoOgn7Si>KXj>kYi^S]
kn_UfmoZknoSc[Hg<@Olm?Wno?3o0?kno`Od3@3olOolo?So8?ghnOjNH5XN210:
1P<420d@2`d@4aHG5Q@0024000hQ3OT5n@Wa30LF400;52PF1_4Bn@/@:AlD4aHF
3@90?C`h<c<f>cCb<o4b7bl_<C<d=SPh?STf>3do>cLc=cTn@D=8C`0?0?onookj
l?l0o_ko1o@=0?oaooclm?l7VeI?5P8B3PKi00d430l@3`007P005blJ2_X5n@Wa
30LF400;52PF1_4Bn@/?;R4B2``;1`14A4Q2>cDg>_4flCPO<S8d=SLi>c]1?3Tk
@48n>C8f?dI;CE5B00H0n?Kooog`o`3no_l1m0d1O`D0oo7oo?ceoaklg<G3`ko6
b/o@d<o<c<2o_;Re/[:a4Qd=jlg0]K6ln[giYo6G1inIX`0A1I:]nIOaS12:OXR=
P0LaBjk4fNCVi=kLi_[WnN3ahaoPh^CVi^CRh>[Xi^CTi^SYjn[]jnOKak8g<@Ol
m?Wno?3o0?kno`Od3@3olOolo?So8OgfnO3D_kZdZJFRWijOXJBTU9FHVijPX9h0
2`3Na[nj]kkj_OVWlIL7WiVS0145TZgiUo6<48QoSYN600h:Achi=SDf=3@hnSOj
<00_lC8O;c8d=SHd<S0j>3Hd=3Hh>d=2?3Xi>d5;00l0ookoo_[`o`3no_l7m0d0
oo7oo?ceoagT/8=_HEIHG5mOG5I?CdU;BT]>EV9c0040ilk5_KOi_OVWlIL7WiVS
0145TZgiUo6<3hf1S8ml00P6BdE5@3dh=C?i>_Xc0CDjlc`P>SDe=cTi=cDc?C/i
=cLi>ce2@D92@dE:CP060?Sfoooml?l0o_ko0O@=0G`50?oaooclm?l4jmoSjNKi
oa3lo?[hm_;_jA`X2oobkng^l_[cnOKao0O[i^DX8a:ahOWllOd@ongVdZL98c2^
a=WTi^CNg>Gji_WQlN<Ojng_lO7_kN_Zj>KTi>KXjNCTjN[Yglfi=c47o?Cio_c`
o`3no_l7m0d0oo7oo?chob7nl_[aelG5`[W;bLK6alS9b/72a<W;cLg<11@0n^c`
l_?dn_?im_7l1n_ViBPS4[7QnOcaoA3nk^cL[@4004Ln>CHe=S@d=oXfnS41<3;c
<B0b>Sdo@D4o?C/j>3Hd=3Hh>c`l>3Tk?dMB00l0ookoo_[`o`3no_l7m0d0oo7o
o?ceoakKXW1GBCaGGFAUI61KFeeNF5MHHWB:00T0ooSek^gan_?im_7l1n_ViBPS
4[7QnOcao@Col>[DXoh01d]5AD0m>3DcnCWj=04f??<m83a0@494A490?Sdk>CLg
>C/m>c/n@DE9D5D01P3hm_oooO3o0?kno`7d3@5Z1@3olOolo?Oo1ogooo7Zl_[j
lol:o?LE8@_ooOklo?kboo7j1ooooB`E1kconO[`o`onnnjl5BPc[/CIi>KTg]cT
n^Gih_3S7^CWj>SWi>?Zj>KTi>KXjMoPi^WZh]:n=c47o?Cio_c`o`3no_l7m0d0
oo7oo?choaknlOWdg]7De<gBd<g<cLo@d<o@d]KIg=[J00h0n_OnkooanPOoood/
5@NlooWjlOl@o_oon<8=1@17?STf=CHd=3Kj=OXb0C4blc4P<S8d=cPh=c@c>SPf
=3@f>3/g>3Dh?49<E`0?0?onookjl?l0o_ko1o@=0?oaooclm_lFo=ZTMf9GC5YO
I6QVHeeOJFUUHV=^P9Sn0?go0O_ml_oanPOoood/5@NlooWjk_l<l;P2001;ADE0
?CPe<oThnSD1=ccc?B0l>3Lj>c/j=cHm>cTg=cTk?CHg>d16C5EJ00H0n?Kooog`
o`3no_l1m0d1P`D0oo7oo?cgob3nooodkOKoo_Kio?cknOWhno_jmoGak^TE7`_o
m?Cfn?cjoOWflO/7ooCU5@D0_?oino7i4>cWl^Nl6C4o[/CIi>KTg]cSn^CYhaoN
h>;Ti>;Pg^[Xi^CTi^SYhN;XjNWPck/g<@Olm?Wno?3o0?kno`Od3@3olOolo?So
3_kcnoOReMWJd/?1_[fn`?k13l;5bL_=cL`0303hk_CjoOkjoOWflO/7ooCU5@D0
_?oino7i4>[Xn?724@h0Achi=SDf=3@enSCj<`4b<_<a838]<38d=38`;SXh=S@d
=SPk>CXg>3]0BE@03`3oo_onn_3o0?kno`Od3@3olOolo?Oo5o_heZ9eHEI;A4YA
De==B4YFFE=ADee`R?h01?olo?WinOgim_7k1oodiAD50;conO_an@o_j_KY^0H8
04]5AD0m>3DcnCOj=P4h??<m83`c<cDg=cDc<Cdk>CLg>C/m>3Tm@4E:DUL01P3h
m_oooO3o0?kno`7d3@5[1@3olOolo?Co1O?ZlOSgo?_o4OknoOcimoC`ja`Y2ooj
nOWkoO[nj?l5k]hG5A?4j?l@oO[klkhC9cB^a=WTi^CNg>;jhoWTlN<Oj^c^l?3^
k>[Zj>KTi>KXjNWXk>_Wg<Vc=c47o?Cio_c`o`3no_l7m0d0oo7oo?chob7nmogi
h]?Ee<c:b<G4a/O8b<C5al_=d<o>1AH0n_CioOoon_kXo`G^gQLE4lCXo`gknoom
a0/404Ln>CHe=_hdnS?j=04c<_<a838i?3i0@3hl>SXh=S@d=SPk@D0k>STl@d`0
3`3oo_onn_3o0?kno`Od3@3olOolo?Oo6__ad9Y[EdXoADYBDe9>BDYFF5=AE5i`
R0070?ko0OklnOkXo`G^gQLE4lCWo`?mooFjoP07BdE5@3dh=C?i=_Xg0CTllcdP
?3lo@D=3@Clm?C/i=cLi>ce0?d52@dI<C`060?Sfoooml?l0o_ko0O@=0F/50?oa
ooclm?l4lnS]lo7fo`Wln_KckADR2ooko_`0o_;olO<6ooOW8QlG__SclOD@ookk
n;`=8S:^a=WTi^CNg>7jh_WUlN<OiNOYjn_YinGZj>KTi>KXjNc[k^cWf/Na=c47
o?Cio_c`o`3no_l7m0d0oo7oo?cgoagko__Sd];@am3>bl_<cLk>alS;cm7Cd]00
3`3jmOc_oo7c1_ogib8O5kkhlo7e0?kno`c21@00Achi=SDf=3@cnS;j=@4d<_<a
838d=cTk>cTg=CXh=S@d=SPkA4<m>cTj@DX03`3oo_onn_3o0?kno`Od3@3olOol
o?So6?gik<bEHddn<d=8DE=ACTM:DeMCD5=MLH[n0?go0?gaoo7c1_ogib8O5kkh
lo7eo_l1n[Sn00M;ADE0?CPe<oTenSP1>Scc?A8l>SXl?Shl>SPm>cTg=cTk?D=2
oT<:A4Y=00H0n?Kooog`o`3no_l1m0d1N`D0oo7oo?cdo`Kdjo7hm__no_lCo_km
no_imoGak^PE7@_omOOio?_jo?WflOl7oOO`9A<6]_KYoa3fm__]]0XX?Zk4fNCV
i=kLh?[QnNKahaoMgn7Shn7OgN[Xi^CTi^SYinK[jnSMbkHg<@Olm?Wno?3o0?kn
o`Od3@3olOolo?Oo8?_ooNGFemO=c<W6a/O8bLW3a<K;cLk>c00:0?O_mogooO[l
nOKao`Ommo0U4`Jfm^Wo4?CgooNj0PD0Achi=SDf=3@bnS7j=P4e<_<a4S8/;c4c
<c4_;CXh=S@d=SPk?ckn>PXmADl03`3oo_onn_3o0?kno`Od3@3olOolo?So6?_d
i/VBHD`n<cPmATQ6@S/oBTe7B4YFJh?n007ooOkonOcim_7o1oggl2DC1[KfjOl4
nOWokk3n00M;ADE0?CPe<oTdnST1>ccc?B0l<S8d=SHd<S0m>cTg=cTk?Chm@494
AdiB00H0n?Kooog`o`3no_l1m0d1MPD0oo7oo?cdo`KfkoOoo__no_lCo_kmo_km
n_SdlN`R;Q3oo?[jnokboo7i1o7hnb/>0;oonOWao13noO_^/PPW?jk4fNCVi=kL
go[PnNOahaoXj^c^k^cZj>[Xi^CTi^SYh>3WjNWQdKdg<@Olm?Wno?3o0?kno`Od
3@3olOolo?Oo7_WooNSKg]kFc<[7a/O9b/[7b<_?dM;Ad0/K0?[en_k`oo7i1o7h
nb/>0;oonOW`o0onooRh00@0Achi=SDf=3@anS3j=`4f<_<a838g>S`n?S`j>3Xh
=S@d=SPk>3Pf>3]1BeH03`3oo_onn_3o0?kno`Od3@3olOolo?So6o_`hlJ@HTi1
>3@i@TA2?cPkB4a8ADQFJXH02P?mo`3nlOoan@Oan?/[3P2oooWilOcno`7`[_h0
1T]5AD0m>3Gh<oXj0C`llcdP?3dm?d51?cdk?C/i=cLi>cdg=ca0AD]DF@060?Sf
oooml?l0o_ko0O@=0H/50?oaooclm?l5kNG]moSlnolAo_ono?Sel>cV62<;ooon
o?Wnh_l6o_kb6``@bNOo5_Okl;H77cfac>C^j^KTi^KSgn7Vj>CPnN<7hN;Ui^KU
h^7ihaoXjNc]kNcYj?W[g]kVjnONiNGZj^SNc;La;@OlmoWooO3o0?kno`Od3@3o
lOolo?Oo7oWon=oAe=O@c/_8b<W:bl_9bL_=c/o=b`8A0?[io_omhOl6o_kb6``@
bNSo1?khooZloP0?BTI4@3Th>Shh<bla=SPd<?Xc238`<3<d=3<`;oXa6c8g>C`m
?C`i>4Tk;Rhf>cL`?Cdi>CXnAU002`3mo`3kl?l0o_ko1o@=0?oaoocln?lHnnkQ
_XIF@cL`<cU2@d8n=cY5Ad90@TiSO?h0oOl0o^7o1_knlQ/<4<WWo`?joo:boP0?
CTe@BT4j>cdj=S8d>C/g<oXf23Pj?3m0@3ll>oXm83`m?3m0@3ll>d`n<C4i?SXb
?3`o@DA8Ce<00P3hnOooo_3o0?kno`7d3@6;1@3olOolo?Co1NgUkOOho?_o4Oko
o_chmO3/iQPS2oooo_cio^;o1_knlQ/<4<WWoaKgno2f1alm[<SPj^KRh>;VhmoQ
i^STh?WT1n7RiNKViN;QnN@Oi^OZjn_ZinKaj^;Qi>SXiN;RinOUflVd<Bd7o?Oi
oog`o`3no_l7m0d0oo7oo?cgoaoiooSOdMCGd<k;b<S9b/_<bL[;c/o?c//24@3j
nOkooN7o1_knlQ/<4<WXo`Cnn?oj_?h03dE2@3`e=3Hj>3<_<CHh=33j=0Pc<30c
=3@c<2oj<Q/c=CLj>c/j=cI1>S8a=3Ph=cXj=SHg>d==00/0oOl0no3o0?kno`Od
3@3olOolo?So6?_^hKj6ET<g<3<i@T=2?SLi@T<n?3i:H7[n0?go0?kQo`Kno_8K
3139iol3n_ob/_h03dU9C4Hm=SLi>SHb=3Tk=c?j=`Pi>S`o@40o?3_j?Plm>cXm
?Shm>SU4?CDd=c/koST=?3i1ADa@0080n?Woook`o`3no_l1m0d1R`D0oo7oo?cd
o`G]iNggn?ckoa7nookln?G`k>HH8`_oooklnOkRo`Kno_8K3139iolFmo_`]PLO
?JW5gNKSg]gOi^?OhNKXi>3ii@OQh^GVi^GRhOWU7n?Ti^SXi^CSiNOXi^;SjNkO
gnCTh]S6/C4]1ocgnOoml?l0o_ko1o@=0?oaooclmolOn?ohgm7De]3=blS7b<[;
c<[:c<o@d<k<0Q40n_WnoogQo`Kno_8K3139j?l4o_Son[cn00m2?cdh<S0c=cPc
;c4f>3@`nSD8=30`<c@d<c0_nS<K=38d=SPh=S@c=CLh=S8c>D0g=c<c=3Q0BP0;
0?go0?_`o`3no_l7m0d0oo7oo?choaSkkn>nQUQ4>C8e>T=5@d0i>D10>STjAeih
oP3mo`3nhOl6o_kb6``@bNOo0o[ol[;n00m6ATU2>S8d=SXf<S@i>cLcnSP8>SXl
?d10?c`knSlP?SPg>C/k>CLf>3Xk>CDf?48f=STk?T99C@020?Siooonl?l0o_ko
0O@=0HL50?oaooclm?l5kNG]moSlnolAo_ono?Sel>cV62<;ooono?Wnh_l6o_kb
6``@bNOo5_Okl;H77cf[a]kXiN3OhNKSgn7Vj>CPnNH7hN;Ui^KUh^7iiQoPh^CV
i^CRh=_UkN[Rh>[dh^;WinGKbK@a;@OlmoWooO3o0?kno`Od3@3olOolo?Oo7oSo
mmo@e=K@cL[7alS9b/_:blg?d=7?c08A0?[ioOomhOl6o_kb6``@bNSo1?khooZl
oP0?A40n>S@b=CTh<bla=SPd<?Xf23D`<3<d=3<`;oXd6cD_<S@f=S@b<2/e?CXb
<3Y6>SXf=SLk@dd02`3mo`3kl?l0o_ko1o@=0?oaoocln?lHno7T`XMKASdc>Ci5
AdM2?3Xl>SLe>DEJMoh0g?l6o_kb6``@bNOo0o[ol[;n00m8AdY4?3@f>3Xf<S@i
>cLcnST8>cXl?d10?c`knT0P?cDe=cTi=cDc;SQ0?CDc?DPi>C`n@DE<D0020?Si
ooonl?l0o_ko0O@=0HL50?oaooclm?l5kNG]moSlnolAo_ono?Sel>cV62<;ooon
o?Wnh_l6o_kb6``@bNOo5_Okl;H77cf_bn?]jNGSiNKSgn7Vj>CPnNP7hN;Ui^KU
h^7ij1oPh^CVi^CRh=WTk^cThNWbj>S]kN_QckXa;@OlmoWooO3o0?kno`Od3@3o
lOolo?Oo7oSnm]k?dmG?c<W7a/O9b/_;c<k@dM7?c0<A0?[ioOomhOl6o_kb6``@
bNSo1?khooZloP0?B4E3?cPg>Cdh<bla=SPd<?Xh23L`<3<d=3<`;oXf6cL_<S@f
=S@b<2Td?S`d<CU4@40l?3e1BE<02`3mo`3kl?l0o_ko1o@=0?oaoocln?lHoO?X
aH]OBT0g?499BTY5@3`j=c<b=D=IMOh0g?l6o_kb6``@bNOo0o[ol[;n00m<C4m9
@3Tj?3Xf<S@i>cLcnS/8?CXl?d10?c`knT8P@CDe=cTi=cDc;3M1?cLd?4Ho?d94
Ad]BEP020?Siooonl?l0o_ko0O@=0HL50?oaooclm?l5kNG]moSlnolAo_ono?Se
l>cV62<;ooono?Wnh_l6o_kb6``@bNOo5_Okl;H77cfacNG^jnKUinKSgn7Vj>CP
nNT7hN;Ui^KUh^7ijAoSi>KXj>KThmoUjncXi^OXjn_`l>kTd[da;@OlmoWooO3o
0?kno`Od3@3olOolo?Oo7oOnm]g?d]C>blW6a/O8bL_;c<k@dM7?c@<A0?[ioOom
hOl6o_kb6``@bNSo1?khooZloP0?BTM5@3Xh>clh<bla=SPd<?Xi23P`<3<d=3<`
;oXg6cPb=3Hh>3Hd<ble>c`h=SLj@d<o?d14C5H02`3mo`3kl?l0o_ko1o@=0?oa
oocln?lHoOK/ahmPCD@j@4E<CTa9@chj=C0`<d9GLoh0g?l6o_kb6``@bNOo0o[o
l[;n00m>CU5:@SXl?SXf<S@i>cLcnS`8?SXl?d10?c`knT<P@SPg>C/k>CLf<SPn
?c/i>Sa2@TE7BTiEF@020?Siooonl?l0o_ko0O@=0HL50?oaooclm?l5kNG]moSl
nolAo_ono?Sel>cV62<;ooono?Wnh_l6o_kb6``@bNOo5_Okl;H77cf^bN7[j>?R
i>KSgn7Vj>CPnNX7hN;Ui^KUh^7ijQoVin[[jn[Wi^SVi^[]jnCLjNW^k^cRd;/a
;@OlmoWooO3o0?kno`Od3@3olOolo?So8?kgoOGMc];Dc/_8a/G6b<W:blg?dM7B
cld34@3jnOgoo>7o1_knlQ/<4<WXo`Cnn?oj_?h03dM3@Cdg=CPl>3<_<CHh=33j
>PPi<30c=3@c<2oj>1/i=CLj>c/j=cHh=SHj?C/d;T51?Cdn@TYD00/0oOl0no3o
0?kno`Od3@3olOolo?Oo5oS_bY9TCdHl@TM>DU1:AD0i<bh^<T1GLoh0g?l6o_kb
6``@bNOo0o[ol[;n00m;BTe7?cLi>cXf<S@i>cLcnSd8?cXl?d10?c`knT@P@c/j
?Chn?CXi>cTi?D0n=c10@4=5B4aCE`020?Siooonl?l0o_ko0O@=0HH50?oaoocl
m?l5kNG]moSlnolAo_ono?Sel>cV62<;ooono?Wnh_l6o_kb6``@bNOo5_Okl;H7
7cfZaMgWi=oMh>KSgn7Vj>CPnNX7hN;Ui^KUh^7ijQoXjNc]kNcYj>kWhnS`kn;D
iNGZj^SNc;La;@OlmoWooO3o0?kno`Od3@3olOolo?So8?kgoOGMc];Cc/[8aLG6
alW:b/c>d=7Acld34@3jnOkooN7o1_knlQ/<4<WXo`Cnn?oj_?h03d<o?CTc<C<h
>3<_<CHh=33j>PPi<34d=CDd<C3i>AXg>C`m?C`i>3hg<cQ0?c8V?Cdi>CXnAU00
2`3mo`3kl?l0o_ko1o@=0?oaooclmolGn>o:TVAAAci3BE1BD4a5@3`g<S0e@UUc
oP3Lo`Kno_8K3139iol3n_ob/_h03dM6BD<k<c@g>SHb=3Tk=c?j?@Po>3/n?cln
>c[j@b11?C`o@40o?3]1>SHk@d8e:3`l?d54B4mC0080n?Woook`o`3no_l1m0d1
MPD0oo7oo?cdo`Cdj_3gmOKo3Ocim?3Z62<;ooono?Wnh_l7o_[Z5@/AaokYoa3l
o_?iX1LJ?;76fNCXj>KUh_[S1nkZi>3Pi>[^nN<7jNKQg]kQi^WiiokP5>;Vjo3b
j^GTgmgHc;`g<@Olm?Wno?3o0?kno`Od3@3olOolo?So8?kkoO_TdmGDblo<b/W:
c<g>cLkAdmCDd]034@3kn_koo^7o1okjjQD;4LOnjOl@n_oiojH?001:@3Tf=cXl
?CCj<`Ln>S@`<3@j?_Tb1cPe<2d]<3DhnCOn<1@b=S]0A48m<bh_>4IE00l0ooko
o_[`o`3no_l7m0d0oo7oo?cgoaOlkm2IJE96>DI;DUABCTU6AT@m?Ci;H7_n0?go
0?[Qo`Onn^XE2a77o^Oo3OOkW0@004i7AD0o?3dlnCH7@Cdg<c<g?D7i>0Ln>cHc
<cHk?_TjoS<D=CTn@dI1?3Tf>D9?F0060?Sfoooml?l0o_ko0O@=0G/50?oaoocl
m?l4m>[`moGfo`glnOC`jQPS2oooo_cio^;o1okjjQD;4LOnjOl@o?kcnJ0G6Sb`
a]WTinOUiN;jh`OUi^SYjNSViOWS1nKThn7QhnCVnNLGi>?RhnGYkNoYiNCPg]S<
^cLa1ocdnOkll?l0o_ko1o@=0?oaooclmol9nogki=?Ee<_?c?k:4/c=c/g>cm;C
dm;@0Q40no[oookQo`Onn^XE2a77o^Wo4?[onOnV3`00BD0i=SHi>cddnS<7=CHh
>CTh=SGi<`Lf=3<a<C<d=_Tg5c@c<S<e>Ce1@Cdc;c0hAU@03`3oo_onn_3o0?kn
o`Od3@3olOolo?So6?glkM2GJE96>DI;D59BCDU7BDM2@49>HW_n0?ko0_ghoN;o
1okjjQD;4LOniol=mo^L1000CDM5@3hk?3ci=PLh>C/l?3/i>?Tf1cTg=S@d=SLi
nCXG=cHe=SPl@4=0?3Tg>T9?E`060?Sfoooml?l0o_ko0O@=0G/50?oaooclm?l4
m>[`moGfo`glnOC`jQPS2oooo_cio^;o1okjjQD;4LOnjOl@o?kcnJ0G6Sb_aMSS
i^KTi>;jh`ONhn[_kn[Sg_WS1n7Si>KVi>?QnNLGjNOUi>CVjNWXi>GQgmW;^SLa
1ocdnOkll?l0o_ko1o@=0?oaooclmol9nogki=?Ee<_?c?k:4/c=c/g>cm;Cdm;@
0Q40no[oookQo`Onn^XE2a77o^Wo4?[onOnV3`00B3lh=CDh>S`dnS<7;S<j?clj
<bki<`La<c@f=S@c<OTg5cTg=C@d=STk@3`d<34iAE<03`3oo_onn_3o0?kno`Od
3@3olOolo?So6?glkM2GJE96>DI;D59BCDU7BDM2@49>HW_n0?ko0_ghoN;o1okj
jQD;4LOniol=mo^L1000C4I4?cdj>c_i=PLa=Se2@Sdf<OTf1c@f=cTi=cHdnCXG
?3Xh=cLi?3do>cXh>d=>EP060?Sfoooml?l0o_ko0O@=0G/50?oaooclm?l4m>[`
moGfo`glnOC`jQPS2oooo_cio^;o1okjjQD;4LOnjOl@o?kcnJ0G6Sb^a=KRiNGS
h^;jh`ORiNW/k>WUh_WS1mkQi^WYi^7NnNLGk^_XiN?SiNGVhnGShMW:^3La1ocd
nOkll?l0o_ko1o@=0?oaooclmol9nogki=?Ee<_?c?k:4/c=c/g>cm;Cdm;@0Q40
no[oookQo`Onn^XE2a77o^Wo4?[onOnV3`00Achf=3@g>CXdnS<7<SDi?3`i=C;i
<`L^<CHi>CHa;_Tg5chk>3Dc<cDg?S/d<S<iA5403`3oo_onn_3o0?kno`Od3@3o
lOolo?So6?glkM2GJE96>DI;D59BCDU7BDM2@49>HW_n0?ko0_ghoN;o1okjjQD;
4LOniol=mo^L1000BdE2?S`i>SWi=PLe>3`o?c`h=OTf1c4d>C`l>C@anCX8@Chk
>3Hf>3TmoSX;?D==E0060?Sfoooml?l0o_ko0O@=0GX50?oaooclm?l4m>[`moGf
o`glnOC`jQPS2oooo_cio^;o1okjjQD;4LOnjOl@o?kcnJ0G6Sb]`]GPhnCQhN;j
h`O/jNGRh^GYk?WS1mkQi^WYi^7NnNLGl>gYiN?Rhn?ThnKUhm[:]SLa1ocdnOkl
l?l0o_ko1o@=0?oaooclmol9nogki=?Ee<_?c?k:4/c=c/g>cm;Cdm;@0Q40no[o
ookQo`Onn^XE2a77o^Wo4?[onOnV3`00AS`e<S8f=cTdnS<7?3Te<S8e>Cci<`L^
<CHi>CHa;_Tg5d0m>CDc<S<e?3/e=3DjA4l03`3oo_onn_3o0?kno`Od3@3olOol
o?So6?glkM2GJE96>DI;D59BCDU7BDM2@49>HW_n0?ko0_ghoN;o1okjjQD;4LOn
iol:mo^L1000BT=1?3[n>?Tf1cll>3De>3`onCH7<C@i?3`i=37i>QM3@3`h=SDf
=c/j>c`oA4eB00H0n?Kooog`o`3no_l1m0d1N`D0oo7oo?cdo`Cdj_3gmOKo3Oci
m?3Z62<;ooono?Wnh_l7o_[Z5@/AaokYoa3lo_?iX1LJ?:_1e=oRh^3Ph_[S1noZ
hmkNhn[_nN<7hN?Ti^KThn7iiaO^k>SUhn?Ti>;RinOUflVd=c47o?Cio_c`o`3n
o_l7m0d0oo7oo?cgo`WkoO_TdmGDblo<o/XBc<g>cLk?d]?Cd]024@3kn_ooo^7o
1okjjQD;4LOnjOl@n_oiojH?0014>c@a<C@f>3Cj<`Lo>S<^;S<j?oTc1c4c=3Hf
=3<anCLG?S`h=C<c=3Hj>SHf=c]3C@0?0?onookjl?l0o_ko1o@=0?oaoocln?lH
oOc]d9MYDTHiAT]@DU9=BDM9Ad90@TiRNoh0o_l2oOSmh_l7o_[Z5@/AaokWo`gg
ni`40018@T0k>CHg=oTf1d8m=S4a=Se2nCH7=3Hg>CTg=SCi>QM1?c/h=SHg>3Ti
?3i1ADa@00H0n?Kooog`o`3no_l1m0d1N@D0oo7oo?cdo`Cdj_3gmOKo3Ocim?3Z
62<;ooono?Wnh_l7o_[Z5@/AaokYoa3lo_?iX1LJ?:[0dmkQhMoOh_[S1nWXi^GU
i^SYnN<7i^CShN7Si>KiiaO/j^OTi>GVin3Qj>WWg<Rb=c47o?Cio_c`o`3no_l7
m0d0oo7oo?cgo`WkoO_TdmGDblo<o/XBc<g>cLk?d]?Cd]024@3kn_ooo^7o1okj
jQD;4LOnjOl@n_oiojH?0013>S<`<3<e=cCj<`Li>3He=CHh>OTc1cHd<c4a<c@f
nCLG?3Xg=3@e=STh>CLh>Ca2B`0?0?onookjl?l0o_ko1o@=0?oaoocln?lHoOc]
d9MYDTHiAT]@DU9=BDM9Ad90@TiRNoh0o_l2oOSmh_l7o_[Z5@/AaokWo`_gni`4
0017@Clj>3Gg=PLl>cTh>3Tk??Tf1cTg=S@d=SLinCXG?cdj=cLh>C/g>3e0@dI;
CP060?Sfoooml?l0o_ko0O@=0G/50?oaooclm?l4m>[`moGfo`glnOC`jQPS2ooo
o_cio^;o1okjjQD;4LOnjOl@o?kcnJ0G6SbZ_m;MhN7Og^;jh`OPi>[^k^[Th?WS
1nWVhMkNhNKYnNLGjNSVi>CVj>WOhNSYimc8/CLa1ocdnOkll?l0o_ko1o@=0?oa
ooclmol9nogki=?Ee<_?c?k:4/c=c/g>cm;Cdm;@0Q40no[oookQo`Onn^XE2a77
o^Wo4?[onOnV3`00@cTb;c0c=CHdnS<7<3@j?Shj=33i<`Li=S4^;S4f>OTg5cTh
=S@d=SPk=cTg>3Tl@TX03`3oo_onn_3o0?kno`Od3@3olOolo?So6?glkM2GJE96
>DI;D59BCDU7BDM2@49>HW_n0?ko0_ghoN;o1okjjQD;4LOniol=mo^L1000Ad0n
>CPe=SGi=PLc=ce1@Cdg<oTf1c`i=34a=3TlnCXG?3/i=cLi>cdf>3e0@dI;C@06
0?Sfoooml?l0o_ko0O@=0EX50?oaooclmol7o_ool>S_m_Gfo`WlnOC`jQDT2oom
o_`0o^;o1_col1076]?Xoa3lno_Z[@LW@ZNndn3Sh]kKh_[S1n3Tj^c[i=cGnN?a
iaGRinkdm_C_jn;RinOUflVd=2h7o?Cik_l0o_ko1o@=0?oaooclmol9m?gfh=7D
dl_?c?k:4<c=c/g>cm;Cdm;@0180noOmgol6o?o`40LJdnSo4?[looBc00@1@3Pc
<S8d=3<dnS<7<3@j?3/d;2Oi<o4g5c8g?TA6A3lm>SXf=SLk@dd0303oo_oooO3o
0?kno`Od3@3olOolo?So6?gekL^CIe55>DI;D59BCDU7BDM2@49>HW_n0?ko0_gk
oN;o1_col1076]?Wo`?nonbYoP07A3lo?3Xf=C;i=PLc=cdo?SL_:_TflCXD=CY1
AdU7@Sli>C`n@DE<D0030?SfkOl0o_ko0O@=0EP50?oaooclmol7o_ool>S_m_Gf
o`WlnOC`jQDT2oomo_`0o^;o1_col1076]?Xoa3lno_Z[@LW@ZRoe>7Th]kLh_[S
1n3TjNcZi=gHnN?aiaG[jn[Zjnc^kn;RinOUflVd=2h7o?Cik_l0o_ko1o@=0?oa
ooclmol9m?gfh=7Ddl_?c?k:4<c=c/g>cm;Cdm;@0180noOmgol6o?o`40LJdnSo
3?[looBc00@1@CTd<c?m=?Xc1c0d>C`j=2dXnC?a=aLk>cXj>c`n@CXj=SHg>d==
00`0ookooog`o`3no_l7m0d0oo7oo?choaSmmNg;TfMAACU6Be1BDTe9AdU7@T12
CV9koP3no`;mnogRo`Kloo0@1a[Ciol3o_o/ZOh01dE0@3dk=SDcnCH7<cLl?cdg
<2_i=_4j53hn?Cdn?d53>CTl?T55C5000`3hm^go0?kno`7d3@5J1@3olOolo?Oo
1okooo3XkoKem_l9o?Wdl>XE90_ooOkl0?kRo`Kloo0@1a[Cj?l@o?_kjZd79d:Y
`=GRiN?OgN;jh`OPhnOZjNCOfoWSlNLElnkVhN3Tj^kRh^OWiM_9]3@^1ocdnNko
0?kno`Od3@3olOolo?Oo2OCmm^3Ae=?;clcnbQ3<cLk=c/oBdm?Bd00B0?_goMoo
1_col1076]?Xo`cjo?od/`040D8j=C@doSD0=?Xc1c0c=cXi=2l[nC?a=aM3?SHa
<3@j@3Xj=SHg>d==00`0ookooog`o`3no_l7m0d0oo7oo?choaSmmNg;TfMAACU6
Be1BDTe9AdU7@T12CV9koP3no`;mnogRo`Kloo0@1a[Ciol3o_o/ZOh01dI1@Chl
=cHdnCH7<cHj?C`g<Rki=_4j54I1>C@c=ce2>CTl?T55C5000`3hm^go0?kno`7d
3@5J1@3olOolo?Oo1okooo3XkoKem_l9o?Wdl>XE90_ooOkl0?kRo`Kloo0@1a[C
j?l@o?_kjZd79d:Z`MKSi^GPg^;jh`OQhnKXinGQgoWSlNLEl>gWhn7Ri>GRh^OW
iM_9]3@^1ocdnNko0?kno`Od3@3olOolo?Oo2OCmm^3Ae=?;clcnbQ3<cLk=c/oB
dm?Bd00B0?_goMoo1_col1076]?Xoa3jo?od/`040D<k=SDe=cHf=?Xc1c4c=SPg
=C4_nC?a=aM0?CLc<C8d=cXj=SHg>d==00`0ookooog`o`3no_l7m0d0oo7oo?ch
oaSmmNg;TfMAACU6Be1BDTe9AdU7@T12CV9koP3no`;mnogRo`Kloo0@1a[Ciol3
o_o/ZOh01dM2@Slm>CLenCH7=3Hi>cXh=3;i=_4j1T=0>SHd=COn>@Xl?T55C500
0`3hm^go0?kno`7d3@5D1@3olOolo?Oo1okooo3XkoKem_l9o?Wdl>XE90_ooOkl
0?kRo`Kloo0@1a[Cj?l@o?_kjZd79d:[`]STj>KRh>;jh`;Qh^Cni@3Tn>?`iaCY
jncZi^3Lh^;WinGKbK@d;POlm?W^o`3no_l7m0d0oo7oo?cgo`WdoOKPdMCCblo<
o/X@c<g>cLk?d]?Cd]004P3kmogOo`Kloo0@1a[Cj?l<n_com;<01054?3Pf=ohh
03Cj<`8a<SCn=@0dn3?`=aHi>c`j=S0^>SXf=SLk@dd0303oo_oooO3o0?kno`Od
3@3olOolo?So6?gekL^CIe55>DI;D59BCDU7BDM2@49>HW_n0?ko0_gkoN;o1_co
l1076]?Wo`?nonbYoP07B4=4@3lj>COi=P8d=COn>00gn3K`>Q<l?Slm>C<`>CTl
?T55C5000`3hm^go0?kno`7d3@5J1@3olOolo?Oo1okooo3XkoKem_l9o?Wdl>XE
90_ooOkl0?kRo`Kloo0@1a[Cj?l@o?_kjZd79d:]a=WVjNOShN;jh`OQhN;Si>GV
i_WSlNLEh^O]lO7[hmgRh^OWiM_9]3@^1ocdnNko0?kno`Od3@3olOolo?Oo2OCm
m^3Ae=?;clcnbQ3<cLk=c/oBdm?Bd00B0?_goMoo1_col1076]?Xo`cjo?od/`04
0DHn>CPhoST0=?Xc1c4a<S<d=CHfnC?a=aLb=ce1@C/c;cXj=SHg>d==00`0ooko
oog`o`3no_l7m0d0oo7oo?choaSmmNg;TfMAACU6Be1BDTe9AdU7@T12CV9koP3n
o`;mnogRo`Kloo0@1a[Ciol3o_o/ZOh01dY5AD90>cXhnCH7=3@e=SLh>CWi=_4j
53Dj@4A4?SHa>CTl?T55C5000`3hm^go0?kno`7d3@5D1@3olOolo?Oo1okooo3X
koKem_l9o?Wdl>XE90_ooOkl0?kRo`Kloo0@1a[Cj?l@o?_kjZd79d:^aM[Wj^ST
h^;jhogQ0n?Uj>Wiho7W5NSYjng^k^g[h^;WinGKbK@d;POlm?W^o`3no_l7m0d0
oo7oo?cgo`WdoOKPdMCCblo<o/X@c<g>cLk?d]?Cd]004P3kmogOo`Kloo0@1a[C
j?l<n_com;<01057?cXi>Ohj03Cj<oda0c<e>3Wi<o4g5cPi>cdn?Sdm>SXf=SLk
@dd0303oo_oooO3o0?kno`Od3@3olOolo?So6?gekL^CIe55>DI;D59BCDU7BDM2
@49>HW_n0?ko0_gkoN;o1_col1076]?Wo`?nonbYoP07BdI6@d4l>cWi=_dd0cHh
>cci=_4j53/l?T11@D0o>CTl?T55C5000`3hm^go0?kno`7d3@5N1@3olOolo?Oo
1o_ooo3Xl?Ogm_l9o?Wdl>XE90_ooOkl0?kRo`Kloo0@1a[Cj?l@o?_ijZd89dB_
am_YkNcWiN;jh`3Qo^03h^GYjoWSnNOiiQG_k>OUingdn>;RinOUflVd=2h7o?Ci
k_l0o_ko1o@=0?oaooclmol9mOkgh=7Cd/[=bok:4<c>c/g>cm;Cdm;@0180noOm
gol6o?o`40LJdnSo3?[looBc00@0AShi=cSn>@0dnS<0<Oh`0c8e>C_i<oTgnCPG
@Chi=cToAT/j>SHf=c]3C@0<0?onoooml?l0o_ko1o@=0?oaoocln?lHoOG]bi=W
DDDiAT]@DU9=BDM9Ad90@TiRNoh0o_l2oO_mh_l6o?o`40LJdnOo0okok:Wn00M;
ATI3@Cdk>OTf03Cn<`<e>3`nnCKa>QA3@3/i>d58CCTi?3i1ADa@00<0n?K]o`3n
o_l1m0d1S`D0oo7oo?cgo`Onooo/iO3jo?co3ocjn_kno?Sel>cV5B@;oogno03n
h_l6o?o]30DJenSo9oOnl_VG3a]2/=;Vj^kdl>7ThnK/lNoUg??_jNGVk?Cjk>CN
i>obj=cji`7ViO[S5nOSg]_Lh^S/hN7Vi^CJb;<g<@Olm?Wno?3o0?kno`Od3@3o
lOolo?Oo7OgonMo=clo7alG4a/O9c<c9b/_>clo>c00B0?_goMoo1_cok@`56]OX
obOfoo_oW@D004=5?S4`>CT^=3<f?44o=Ba3?cTe=Sa4BS`d;S@o@SP/nSL1>3Sj
>ALm>C@a<SPnA3Ti=CDf>T9<00l0ookoo_[`o`3no_l7m0d0oo7oo?choaSmnng;
TF=>A3U2Ada>CTU5@dE3?S`nBUigoP3no`;mnogRo`Klond<1A[Gj?l4noohni?n
01m9CTdo?40n<CLf>Cm4@SP_AT8l>3ToAddo=c4g@TDk;o4j5chj=C8c>Cm4>3Pk
?D14Bdl01P3hm_oooO3o0?kno`7d3@6A1@3olOolo?Oo1ocooncUlOgno?l?noOh
o?kln?G`k>HE90_ooOkl0?kRo`Klond<1A[Gj?lWmocbn9T?74>ae>W[lOObh^OP
f]_Qi>7Mj^OTh^?Wk?3Ri^[[j>KUi_[W0NKVn^DGg]oQhnGUi>CWjNk^k>;@^cLa
1ocdnOkll?l0o_ko1o@=0?oaooclmolMo_oiglg>c/O6aLC6al[=cL[:blk?clk<
0180noOmgol6o?o]30DJenSo9oKononL1@00@T@m<Bhh=bhd<2X[<C@a;CXg=38c
=ca0<SHj>cPf=CKj=`4h??Xm5cHg>C/m?C`l@T4m?Ci2BU@03`3oo_onn_3o0?kn
o`Od3@3olOolo?So6?gkkL^AHdi4>D97C4i>BDE3AD<n?3i:GWOn0?ko0_gkoN;o
1_cok@`56]OXo`CkooSkToh07dU>CCll@3ha>3<];S@g=30m>SLe=SXo@cDi?Chk
>CPinC[i?ALf=cTk?Cdl?410@dE8C5=G00H0n?Kooog`o`3no_l1m0d1S`D0oo7o
o?cgo`Olooo/iO7mo_co3o_gn?cno?Sel>cV5B@;oogno03nh_l6o?o]30DJenSo
5oOll_RI3aa3/MCYjo7gl^;^h]SEf^7Ti?kO3>3RhnCUf^Sdl>?Lhnkji`7Vho[R
5mSMiN_/jN;NinW^k^cRd;/g<@Olm?Wno?3o0?kno`Od3@3olOolo?Oo7OkonMo=
c/k7a/G4a/O:cLg:b/_>clo>c00B0?_goMoo1_cok@`56]OXoaOfoo_oW0D00494
?C4^>3L^>c8X9BXa=3Cn;```<S<d=BXhA40c;3<nnSL1>3Wj>QL`=Ce3A44j=T91
?Cdn@TYD00l0ookoo_[`o`3no_l7m0d0oo7oo?choaSmnng;TF=>A3U2Ada>CTU5
@dE3?S`nBUigoP3no`;mnogRo`Klond<1A[Gj?l4noohni?n00m9CTdo?40n<Cle
:bP]=3LgoS8<<cDf=cP]>dM3=Rlf@O4j5c0e?D=4@CXf@413ADQ<DeL01P3hm_oo
oO3o0?kno`7d3@6A1@3olOolo?Oo1ocooncUlOgno?l?noOho?kln?G`k>HE90_o
oOkl0?kRo`Klond<1A[Gj?lWmocbn9T?74>ae>W[lOObh_;XhN3Uj^[XfmgPhnCT
h^7Oino]i^7Tj_[W0NKMn]`GgN3UjN[XiN?OhNKVi=[8/cLa1ocdnOkll?l0o_ko
1o@=0?oaooclmolMo_oiglg>c/O6aLC6al[=cL[:blk?clk<0180noOmgol6o?o]
30DJenSo9oKononL1@00@T@m<Bhh=bho>34`=CXj>2/]<3<d=38a;cLo?CHa=3[j
=`4h<oXd5cDh?D52@3dk>STe=CHj@T`03`3oo_onn_3o0?kno`Od3@3olOolo?So
6?gkkL^AHdi4>D97C4i>BDE3AD<n?3i:GWOn0?ko0_gkoN;o1_cok@`56]OXo`Ck
ooSkToh07dU>CCll@3ha@c/d<cPm?C/^<3<f=cLe=38j@T0i=3LmnC[i=1Le>3e1
@T0m>cPh>ce0A4]?00H0n?Kooog`o`3no_l1m0d1T@D0oo7oo?cgo`Olooo/iO7m
o_co3o_gn?cno?Sel>cV5B@;oogno03nh_l6o?o]30DJenSo9oOll_RI3aa3/MCY
jo7gl^;Xi>GYknkVgmoQiNSYj>OVj^CQi^g_imoji`7VhO[P5nSUh^7Ri^_^gn7V
i^CJb;<g<@Olm?Wno?3o0?kno`Od3@3olOolo?Oo7OkonMo=c/k7a/G4a/O:cLg:
b/_>clo>c00B0?_goMoo1_cok@`56]OXobOfoo_oW0D00494?C4^>3L^=C@e>Cln
=Rl_<CDh>CPg=SXd<CHm?cL_nSL1>3Oj>1M0?CXi>Si3ASXi=CDf>T9<00l0ooko
o_[`o`3no_l7m0d0oo7oo?choaSmnng;TF=>A3U2Ada>CTU5@dE3?S`nBUigoP3n
o`;mnogRo`Klond<1A[Gj?l4noohni?n01m9CTdo?40n<CTg>3a2@CTb<S@h>c`k
>STm=c@i@48j<_TjnCPG@3dj>CXn@dHh>3/m@4A;C`060?Sfoooml?l0o_ko0O@=
0I450?oaooclmol7o?ook>GaoOklo`okmoSlo_chmO3/iQDT2oomo_`0o^;o1_co
k@`56]OXoaOgo?;hV@lL@k7DjN_amo;RgM_OiN_XgM?ni`cXj^_/kNkSg>?`m>SJ
n^L1i^_jjQO/j>;NgnK]lnOYk^k/h]2k=c47o?Cio_c`o`3no_l7m0d0oo7oo?cg
oagnooWOcLk>alK5a<K7b/g=b/[;c/o?c/`04P3kmogOo`Klond<1A[Gj?lGm_ok
oi`50012A3da;SPg;RX[;cDk>2dSoSL<>3Xk?3dn<b`c@4@h:_Xg0CQ1nT8GA40j
=SLnAD]2@Cdm?T9:E00?0?onookjl?l0o_ko1o@=0?oaoocln?lHoO_]bi5SCT@i
@TM<CTi9AD=5@chl?TYNMoh0o_l2oO_mh_l6o?o]30DJenSo1?_on?^CoP0?BDi=
?ca0?S4^;S8h?S/`9_hj33/m?Sm0@CH_=T=7>bgi>_U25dA0>SHg?TE;@413ADQ<
DeL01P3hm_oooO3o0?kno`7d3@6A1@3olOolo?Oo1ocooncUlOgno?l?noOho?kl
n?G`k>HE90_ooOkl0?kRo`Klond<1A[Gj?lWmocbn9T?74>ae>W[lOObh^CNg=oT
iN3JjnWUhnGYk_;ViNKXjn[Vh_[W0NKWn^H0iokV4nOYk>gWjNk^k>;@^cLa1ocd
nOkll?l0o_ko1o@=0?oaooclmolMo_oiglg>c/O6aLC6al[=cL[:blk?clk<0180
noOmgol6o?o]30DJenSo9oKononL1@00@T@m<Bhh=bha;R`_=3D`:S/i=C<e>Ci2
=SDf>3/j=S;j=`4h?OXn03on?Q<o@DA5@T4m?Ci2BU@03`3oo_onn_3o0?kno`Od
3@3olOolo?So6?gkkL^AHdi4>D97C4i>BDE3AD<n?3i:GWOn0?ko0_gkoN;o1_co
k@`56]OXo`CkooSkToh07dU>CCll@3ha=C4_<SLh<bdn?3Pf>3a1ACTh>C/n?CTe
nC[i?P0ooShC?d54AD10@dE8C5=G00H0n?Kooog`o`3no_l1m0d1T@D0oo7oo?cg
o`Olooo/iO7mo_co3o_gn?cno?Sel>cV5B@;oogno03nh_l6o?o]30DJenSo9oOl
l_RI3aa3/MCYjo7gl^;djN3MhnW[j^gXh]kOiNgcg>SbknCNi>cji`7Vg?[K5mkS
j^o`kNSUgn7Vi^CJb;<g<@Olm?Wno?3o0?kno`Od3@3olOolo?Oo7OkonMo=c/k7
a/G4a/O:cLg:b/_>clo>c00B0?_goMoo1_cok@`56]OXobOfoo_oW0D00494?C4^
>3L^@CT`;C<i>cXm>38^;cDm@b`h@Sld;S@lnSL1>3;j<aLf>d97B4E0?CXi=CDf
>T9<00l0ookoo_[`o`3no_l7m0d0oo7oo?choaSmnng;TF=>A3U2Ada>CTU5@dE3
?S`nBUigoP3no`;mnogRo`Klond<1A[Gj?l4noohni?n01m9CTdo?40n<DDl<c0f
?3hm@3/e<C8h@4H_>dE2=c4g?oTjnC<G=S]2AdQ5@3dh>3/m@4A;C`060?Sfooom
l?l0o_ko0O@=0I450?oaooclmol7m_ook^Wdo_kloa?kmoSlo_chmO3/iQXF5ooh
o^klo^;o1_gki@H47=CXoa3jo?3eUPdLA[3FkN_[lO;YjO[W1n7RiNKViN;QnN<W
kn[Vj>g_k>K[inCPg]kOh=SHfM[Kg=gNkNg`kNOJaJla;@OlmoWooO3o0?kno`Od
3@3olOolo?Oo7_SonN7AdLo7a/G4a/O:cLg:b/_>clo>c0@42?_boo?Po`KmnnD6
11cDj?l@nOoioiT30011AT4a:38g=CKj=`La<SDf=SDb<OTc8Slj=SPm?c`h@Cll
>3Hf=cP`<34b<c@e=TQ5?c`i>Sm800/0oOl0no3o0?kno`Od3@3olOolo?So8Oge
kL^CIe55>D97C4i>BDE3AD<n?3i:GWL000Goo?o_nogRo`KmnnD611cDj?l4o_of
n93n00M8D54o=SXn>?Tj1c@e>3Ti>3DdnCHW@Sdi>d12?cY2?c`h=SHg>30`<C8c
=3DfATA5A4=4B4/00P3hnOooo_3o0?kno`7d3@6A1@3olOolo?Oo1oKoonkYm?kn
o?lCnoOho?kln?G`k>HJ5QOon?k^o?kRo`KmnnD611cDj?l@n_c`mIH=74J`e^g[
jo7bjNWji`OQh^GVi^GRhOWS9nORg^3Vj>CNj>GRh=oPhN?Ph>7RhnCUi]_LhN3N
dl2[<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoakhooWQdM7?alK5a<K7b/g=b/[;
c/o?c/`410Skl_och?l6oO_U1P@Le>So4?WonOnI0`00@DI1<BPb=cDfnSL7<C8e
=SHe<S7i<b8g<Rh`=SPd<3hm>SPg>3Tk>3Pi>S/l?Chf=30_<3<jA00;0?go0?_`
o`3no_l7m0d0oo7oo?chob7mmNg;TfMAACU2Ada>CTU5@dE3?S`nBUig0005ooco
ko_mh_l6oO_U1P@Le>So1?kom_R@oP07B51A?cHj?SSi>PLd=CPi>CPe=?Tf9cXe
<C<i>cLb?cdj>3Lh>C/h>3Tj>c`m?S@c=SLj?D=70080n?Woook`o`3no_l1m0d1
T@D0oo7oo?cgo`Ofooo^jOCno_co4o_gn?cno?Sel>cV6QHGooSnk_cnh_l6oO_U
1P@Le>So4?[ll?FF3Aa6/=K]jn_al^WYn^L7hN;Ui^KUh^7ihbOWh]kPi^STg^CQ
h=oPh^GWhN7RhnCUi^ONh>KXimk=^C4]1ocgnOoml?l0o_ko1o@=0?oaooclmolN
n?oihM7AclO6aLC6al[=cL[:blk?clk<10@8no;oln3o1_gki@H47=CXoa3iooWo
V@<00456@C4X<SLe=_Xg1c4b=CHf=C8anC<R=c8^<3Hh=30j>CPg>3Xm?cTi>S/l
?Cho>CPe=cTnAe802`3mo`3kl?l0o_ko1o@=0?oaoocln?lQoOG]bi=WDDDi@TM<
CTi9AD=5@chl?TYNM`001OolonokoN;o1_gki@H47=CXo`CnooKhT?h01dQ@DClf
>ShhnCX7=3Dh>CTh=CCi=RLj=C4c>C/g<S/i>3Lh>Sdo>CTj>c`m?Slg=c/o@dQ@
E@020?Siooonl?l0o_ko0O@=0I450?oaooclmol7m_ook^Wdo_kloa?kmoSlo_ch
mO3/iQXF5ooho^klo^;o1_gki@H47=CXoa3jo?3eUPdLA[3FkN_[lO;YjO[W1n7R
iNKViN;QnN<Wkn[Vj>g_k>KQgmkNh>CWj][Kg=gNgn3QiNO/kN_QckXa;@OlmoWo
oO3o0?kno`Od3@3olOolo?Oo7_SonN7AdLo7a/G4a/O:cLg:b/_>clo>c0@42?_b
oo?Po`KmnnD611cDj?l@nOoioiT30011AT4a:38g=CKj=`La<SDf=SDb<OTc8Slj
=SPm?c`h=cLf=SPl?d8b<c@e=SLh>D0o>c`m@DUC00/0oOl0no3o0?kno`Od3@3o
lOolo?So8OgekL^CIe55>D97C4i>BDE3AD<n?3i:GWL000Goo?o_nogRo`KmnnD6
11cDj?l4o_ofn93n00M8D54o=SXn>?Tj1c@e>3Ti>3DdnCHW@Sdi>d12?cXh=cHf
>3`o@S8c=3Df=cPi?Si1A4M;DUH00P3hnOooo_3o0?kno`7d3@6A1@3olOolo?Oo
1oKoonkYm?kno?lCnoOho?kln?G`k>HJ5QOon?k^o?kRo`KmnnD611cDj?l@n_c`
mIH=74J`e^g[jo7bjNWji`OQh^GVi^GRhOWS9noZi^S]kncVhMoNg^3Tin[Lg=gN
gn7Qh^7RiN;NdKfW<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoakhooWQdM7?alK5
a<K7b/g=b/[;c/o?c/`410Skl_och?l6oO_U1P@Le>So4?WonOnI0`00@DI1<BPb
=cDfnSL7<C8e=SHe<S7i<b8o>SHh?Cll>3Lg=SHh?3m2=3@e=SLi>CXl>S@a<34g
@00;0?go0?_`o`3no_l7m0d0oo7oo?chob7mmNg;TfMAACU2Ada>CTU5@dE3?S`n
BUig0005oocoko_mh_l6oO_U1P@Le>So1?kom_R@oP07B51A?cHj?SSi>PLd=CPi
>CPe=?Tf9d8m>C]0@Slj>3Lf=SPl?d8d=3Df=cTi>SXi>STj>d130080n?Woook`
o`3no_l1m0d1T@D0oo7oo?cgo`Ofooo^jOCno_co4o_gn?cno?Sel>cV6QHGooSn
k_cnh_l6oO_U1P@Le>So4?[ll?FF3Aa6/=K]jn_al^WYn^L7hN;Ui^KUh^7ihbOW
h]kPi^STg^CQh=oPh^GWi>GVinSYj^_XjN_Wh]BoZC4]1ocgnOoml?l0o_ko1o@=
0?oaooclmolNn?oihM7AclO6aLC6al[=cL[:blk?clk<10@8no;oln3o1_gki@H4
7=CXoa3iooWoV@<00456@C4X<SLe=_Xg1c4b=CHf=C8anC<R=c8^<3Hh=30j>CPg
>3Xm?c`m?Sm0@D93@d4j=S@d>D802`3mo`3kl?l0o_ko1o@=0?oaoocln?lQoOG]
bi=WDDDi@TM<CTi9AD=5@chl?TYNM`001OolonokoN;o1_gki@H47=CXo`CnooKh
T?h01dQ@DClf>ShhnCX7=3Dh>CTh=CCi=QXj=C4c>C/g<S/i>3Lh>Sdo?3dn?d11
@T=1@43n?PU2A@020?Siooonl?l0o_ko0O@=0I450?oaooclmol7m_ook^Wdo_kl
oa?kmoSlo_chmO3/iQXF5ooho^klo^;o1_gki@H47=CXoa3jo?3eUPdLA[3FkN_[
lO;YjO[W1n7RiNKViN;QnN<Win;Nh>KXi=kXiN;Pgn3QhnGVinSYj^_/jng`kn_O
c;Ha;@OlmoWooO3o0?kno`Od3@3olOolo?Oo7_SonN7AdLo7a/G4a/O:cLg:b/_>
clo>c0@42?_boo?Po`KmnnD611cDj?l@nOoioiT30011AT4a:38g=CKj=`La<SDf
=SDb<OTc8SLb;S0f>3@`?Sdj>3Lh>C/m?Sm0@D93A4I5?chm?dI?00/0oOl0no3o
0?kno`Od3@3olOolo?So8OgekL^CIe55>D97C4i>BDE3AD<n?3i:GWL000Goo?o_
nogRo`KmnnD611cDj?l4o_ofn93n00M8D54o=SXn>?Tj1c@e>3Ti>3DdnCHF>SDa
<cTk=c8o?CXh=cPi>cdn?d11@T?nA0e5ATM9Ce800P3hnOooo_3o0?kno`7d3@6@
1@3olOolo?Oo1oKoonkYm?kno?lCnoOho?kln?G`k>HJ5QOon?k^o?kRo`KmnnD6
11cDj?l@noobn9H?74J`e^c[j?3`j>Kji@OOh>?Ti>?PgoWR9nkYiNO/k^_UjnOT
h=kNgn3Ngn3Qh^?TiMWLhN;Qf<Nc<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoakh
ooWQdM7?alK5a<K7b/g=b/[;c/o?c/`410Skl_och?l6oO_U1P@Le>So3oWon?nI
0P00@DI1<BXc>CGi>0Lb<cHg=cHc<_Td8T0k=cTn@3dh@Cll>3Hf=cPf=cPi>S/l
?C@d<34c>45<00/0oOl0no3o0?kno`Od3@3olOolo?So8OgekL^CIe55>D97C4i>
BDE3AD<n?3i:GWL000Goo?o_nogRo`KmnnD611cDj?l4o_ofn93n00M8D54o=SXn
>?Tj1c@e>3Ti>3DdnCHW@Sdi>d12?cY2?c`h=SHg>3Hg>3Tj>c`m<S<f>Ce2BTl0
0P3hnOooo_3o0?kno`7d3@5>1@3olOolo?Oo1ocooncUlOgnnolBnocooo_el^o]
jAXF5ooho^klo^7o1O_R1P/VfnOo3o_foXl@:T>/e]gRn_;Ok>;bh03Rn^?hjPKU
g]WIg^GZnMh?iN?WjnkTc;4a;@OlmoWooO3o0?kno`Od3@3olOolo?Oo7_konMo=
c/k7b/W8b/_>dM7=bl[;c<k?c`@42?_boo?Oo`GkhPH;9]_Yoa3nn_Khohl20@0m
BCD/@3T/@?0jnSWi@0M2?CHa<CHm@_Tf2T0k=SY0A4I:00/0oOl0no3o0?kno`Od
3@3olOolo?So8OgkkL^AHdi4>DI;D59BCDU7B4@m>C]9GgX000Goo?o_nogQo`Gk
hPH;9]_Wo`?jmo^7oP07A594>D/o<43Y>_U11d8m=S4a=Se2nCH??SXl@TY>Cdd0
0P3hnOooo_3o0?kno`7d3@5;1@3olOolo?Oo1ocooncUlOgnnolBnocooo_el^o]
jAXF5ooho^klo^7o1O_R1P/VfnOo3ochoi4B:T>af^3UoO?Qk^3bgoWRnMd6inCP
gMgPi?SW3n?RiNW/hl^_<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoaknooWOcLk>
al[9b<[;c]7AcL_:blc>cll410Skl_ocgol5nn862bKKjOlAo_Wfm_n>0@40@Tdj
<DDn<D@jlS_i>_Te1Sll>3De>3ch?`Xn>S@h?T=5B00;0?go0?_`o`3no_l7m0d0
oo7oo?chob7mnng;TF=>A3U6Be1BDTe9AdQ4?CTkBEmj0005oocoko_mhOl5nn86
2bKKiol3n_OkQoh01dUFB3e?@cA4jC[i=@Ho?3Pe=CPln3l??3Tj@4Q=CT/00P3h
nOooo_3o0?kno`7d3@541@3olOolo?Oo1ocooncUlOgnnolBnocooo_el^o]jAXF
5ooho^klo^7o1O_R1P/VfnOo3ochoi4B:T>dgN?YooKTlN?Zh_WJo^81hN7nh_W]
3n7PhnOZhLV]<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoaknooWOcLk>al[9b<[;
c]7AcL_:blc>cll410Skl_ocgol5nn862bKKjOlAo_Wfm_n>0@40AE0m=DQ1=4Li
jS[i<_hj0CTioS[iA@Xl>38f?453AP0;0?go0?_`o`3no_l7m0d0oo7oo?chob7m
nng;TF=>A3U6Be1BDTe9AdQ4?CTkBEmj0005oocoko_mhOl5nn862bKKiol3n_Ok
Qoh01daIBd5BASM7jC[i<_hj0CTioS[iA@lj=cPnAT]<B@020?Siooonl?l0o_ko
0O@=0E050?oaooclmol7o?ook>GaoOkkoa;ko?oonoGbkngY6QHGooSnk_cnhOl5
nn862bKKiol>o?SoTA8Z@k;Kh^OomN?alND0ho[RnN<7gn7SiNGShMoijPoPgn;V
jN38[34]1ocgnOoml?l0o_ko1o@=0?oaooclmolNo_oiglg>c/O:bLS:blkAdLg;
b/_<c/o?10@8no;olmoo1O_R1P/VfnWo4?kim_KoSP4104=>?3=7@3=5lCP0>OXj
nC/7=cTk?Cdk>COi@PXk=c4e>d12A@0;0?go0?_`o`3no_l7m0d0oo7oo?chob7m
nng;TF=>A3U6Be1BDTe9AdQ4?CTkBEmj0005oocoko_mhOl5nn862bKKiol3n_Ok
Qoh01dYGBSmAACI5jC[i>`Lg>C/m?C/i=oU23cTf=ce5BT]80080n?Woook`o`3n
o_l1m0d1D`D0oo7oo?cgo`Olooo/iO7mo__o4__loookmO;_kNTJ5QOon?k^o?kQ
o`GkhPH;9]_Wo`oln?nA4RY3[]OMh_[`g^kWlnT1in?jh_WX1moQhnGUhn7On>4>
h>CWjn79[C4]1ocgnOoml?l0o_ko1o@=0?oaooclmolNo_oiglg>c/O:bLS:blkA
dLg;b/_<c/o?10@8no;olmoo1O_R1P/VfnWo4Okim_KoSP4103m:=bi2>bi0=o<f
0CLinS[i@0Lg>C/m?C/i=oTi2S`h<cHm@D=600/0oOl0no3o0?kno`Od3@3olOol
o?So8OgkkL^AHdi4>DI;D59BCDU7B4@m>C]9GgX000Goo?o_nogQo`GkhPH;9]_W
o`?jmo^7oP07AU=5>Ta0<D7Y>_U01cLi>cdm>cTgnCT?>SLi?TM;C4T00P3hnOoo
o_3o0?kno`7d3@511@3olOolo?Oo1ocooncUlOgnnolBnocooo_el^o]jAXF5ooh
o^klo^7o1O_R1P/VfnOo3ochoi4B:T>/eM_Qn>kLk>[ck07YiNoR0N7Qo^;ig@oU
i>O[k^C</C4]1ocgnOoml?l0o_ko1o@=0?oaooclmolNo_oiglg>c/O:bLS:blkA
dLg;b/_<c/o?10@8no;olmoo1O_R1P/VfnWo4?kim_KoSP4103e8=Be0>B`nlSD1
=SS_>P4i>OhjnCD:@3`f>T14ATX02`3mo`3kl?l0o_ko1o@=0?oaoocln?lQoO_]
bi5SCT@iAT]@DU9=BDM8A3di>dUONP001OolonokoN7o1O_R1P/VfnOo0o[gnhOn
00M4DD<iBSh_?mhj0CTioS[i=@ln>ca2BTi?C@020?Siooonl?l0o_ko0O@=0E@5
0?oaooclmol7o?ook>GaoOkkoa;ko?oonoGbkngY6QHGooSnk_cnhOl5nn862bKK
iol?o?SoTA8Z@joHgnCll^3`k??^0NcUn^;ig`OWi>3MgN3TioWT3nWXjnobjM6e
<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoaknooWOcLk>al[9b<[;c]7AcL_:blc>
cll410Skl_ocgol5nn862bKKjOlAo_Wfm_n>0@40@4/i<4@m<40elc<1=CSj>_Tg
1cll>3De>3`onC`:A40j?TA9Bdh02`3mo`3kl?l0o_ko1o@=0?oaoocln?lQoO_]
bi5SCT@iAT]@DU9=BDM8A3di>dUONP001OolonokoN7o1O_R1P/VfnOo0o[gnhOn
00M7E4LlCT8c@^TjnCL7?c`h=CDh?3oi?0m2?d16CU=DD@020?Siooonl?l0o_ko
0O@=0Dd50?oaooclmol7o?ook>GaoOkkoa;ko?oonoGbkngY6QHGooSnk_cnhOl5
nn862bKKiol?o?SoTA8Z@k?LhnSom^CdkO?`0NcVl^87j^GNfMWNiN[hk0kZk_;e
jm>h<Bd7o?Oioog`o`3no_l7m0d0oo7oo?cgoaknooWOcLk>al[9b<[;c]7AcL_:
blc>cll410Skl_ocgol5nn862bKKjOlAo_Wfm_n>0@40A4lm=4Q1=4@dlc<1=CSb
>PM2?CHa<CHm@_U42TM2?D57BdeA00/0oOl0no3o0?kno`Od3@3olOolo?So8Ogk
kL^AHdi4>DI;D59BCDU7B4@m>C]9GgX000Goo?o_nogQo`GkhPH;9]_Wo`?jmo^7
oP07BeQ;@596=dKQ>PM2?CHa<CHm@_U43dE1@dUAEEID0080n?Woook`o`3no_l1
m0d1V@D0oo7oo?cgo`Omoo[YjOOooOco4o_gn?cno?Sel>cV6QHGooSnk_cnh?l5
eaH75??fiolNn_n93B]<[<gRi^_cknC^lNo]jn[Xio;_j^OWj^o^h_[N9nGShMoO
hN?UhN?Wj^[Whn7Ig>7Ti>7LfMSIhNS[g/:S<Bd7o?Oioog`o`3no_l7m0d0oo7o
o?ceoaccg=7DdLK6aLC6al[=cL[:blk?clk<10@8no;olmko1MLF1aCcm^[o8Okk
n_SoQP021Ce0?38c?Sld=C@b<2h]:bXe<RdZ:Rdb=cCj=R8m>cTg=cTk?CTk?d92
?c/i<C@i?3`i=34c<C0g?Chl?00;0?go0?_`o`3no_l7m0d0oo7oo?chob7mo>g5
SVMDAcQ2Ada>CTU5@dE3?S`nBUig0005oocoko_mh?l5eaH75??fj?lNo_WkO`00
0dA9BShm@d8f>c/i=cDd<S4l>C@a<C@i??Tf9cdk>CLg>C/m>C/o@T8o>cTa=3Tl
?3Td<C4`=Sm7B4Do0080n?Woook`o`3no_l1m0d1W0D0oo7oo?cgo`Omoo[YjOOo
oOco4o_gn?cno?Sel>cV6QHGooSnk_cnhOl6o]LF1aGdmnOo7_[oR@d[C:o@i>KZ
lNcQjng/jn_ZjNWal>k/k>k`knWjiROUhn7Ogn7SiN[Whn7QhnOZh>;TiNGTh^3Y
j_;ioO;G^C4]1ocgnOoml?l0o_ko1o@=0?oaooclmOlLlmcAe=76a/G4a/O:cLg:
b/_>clo>c0@42?_boo?Oo`KneaH75OCgj_lQo__jn?n60085@4<n<S8l?34d<S4`
<2l^;SHe<c4a<cDh??Xn8Sdk>CLg>C/m@Slk>CTk?d8h>S`m?C`j>4A2@DQ?DU5B
00/0oOl0no3o0?kno`Od3@3olOolo?So8OglkLF>IeA7>497C4i>BDE3AD<n?3i:
GWL000Goo?o_nogQo`KneaH75OCgj?lNo_WkO`000dM<C3hl@Clc>CTh=cLf=CDm
?3Xh>3Xl?OTn9cdk>CLg>C/m@Slk>CTk?d8h>S`m?C`j>491Ae1IG5YE0080n?Wo
ook`o`3no_l1m0d1W0D0oo7oo?cgo`Omoo[YjOOooOco4o_gn?cno?Sel>cV6QHG
ooSnk_cnhOl6oMHF1aKen>Oo7_[oR@d[C;?Ci^OYknWLi^SYj^[[k>c]ko7bl_7_
j^WjiROUhn7Ogn7SiO3ZhM[JhN[`j>OUhn?UinSOh>S_m>[A]C4]1ocgnOoml?l0
o_ko1o@=0?oaooclmOlLlmcAe=76a/G4a/O:cLg:b/_>clo>c0@42?_boo?Oo`Km
eQH75_Ghj_lQo__jn?n60085A4I0<c4j>Bha<C8c<c@e=CHh>S/k>SPg??Xn8Sdk
>CLg>C/mB48i<S8i@TQ0?cdk>cdo@3Xh=ci6BT]>00/0oOl0no3o0?kno`Od3@3o
lOolo?So8OglkLF>IeA7>497C4i>BDE3AD<n?3i:GWL000Goo?o_nogQo`KmeQH7
5_Ghj?lNo_WkO`000d]?CSlk?c`_=SHg>3Pi>SXk?Cm0@3lm>oTn9cdk>CLg>C/m
B48i<S8i@TQ0?cdk>cdo@3Pg?DI@E5AA0080n?Woook`o`3no_l1m0d1V`D0oo7o
o?cgo`Omoo[YjOOooOco4o_gn?cno?Sel>cV6QHGooSnk_cnhOl6o=DE1aOfn^Oo
7_[oR@d[C;KFj>SYkNKIhNCUinW[k>gUjNkalNkYhmojgROUhn7Ogn7SiNgXh]kN
h^S]j^ORg]kRin[De=[Qi]k7[34]1ocgnOoml?l0o_ko1o@=0?oaooclmOlLlmcA
e=76a/G4a/O:cLg:b/_>clo>c0@42?_boo?Oo`KleAD75oKjj_lQo__jn?n60085
AdU2=34h=R/a<C8d=SPi>S8f>chn>cHc=OXf8Sdk>CLg>C/mAD0j=SHj@4E2?cXf
=SXo@Rl/:C0h?T5500/0oOl0no3o0?kno`Od3@3olOolo?So8OglkLF>IeA7>497
C4i>BDE3AD<n?3i:GWL000Goo?o_nogQo`KleAD75oKjj?lMo_WkO`000diBD40k
?CT/=3Df>3Xl?Chf>Sm2@Sljn3HW?C/i=cLi>ce5@3Xf=SY0AD8o>SHf>Sm2;B/_
>498BTP00P3hnOooo_3o0?kno`7d3@6O1@3olOolo?Oo1ogon^WYmoomo?lCnoOh
o?kln?G`k>HJ5QOon?k^o?kRo`Omn]@E21Sho>Oo7_[oR@d[C;KFj>SYkNKHhN7S
iNOXj^_Mh>GXj>GPgMojgROUhn7Ogn7SiN?Ti^OWi^CSiN;Mf][Mh^GTh^K[l>SB
^34]1ocgnOoml?l0o_ko1o@=0?oaooclmOlLlmcAe=76a/G4a/O:cLg:b/_>clo>
c0@42?_boo?Po`Omn]@E21Sho>[o8Okkn_SoQP021DM9@S@a>3H/=3@f>3Xk?Ch`
<cPk>cPc<3Gj=R8m>cTg=cTk?C/l?Slo?S`k?CXe<S8e>Sdo>SDj@TQ<D@0;0?go
0?_`o`3no_l7m0d0oo7oo?chob7mo>g5SVMDAcQ2Ada>CTU5@dE3?S`nBUig0005
oocoko_mh_l7oO[D5@PHn?cXoaknnO]o0003CU9@@3/m>B`f=SPj?3do@38e>Sdm
>SDbnCHW?C/i=cLi>cdk?3ho?chl>cdj=C8b=CXm?CTk@TaBEE@00P3hnOooo_3o
0?kno`7d3@6M1@3olOolo?Oo1ogon^WYmoomo?lCnoOho?kln?G`k>HJ5QOon?k^
o?kRo`OlnM<E21WioNOo7O[oR@d[C;?Ci^OYknWIhn;ShnCUi^KLgMoPh=oMg?WV
9nGShMoOhN?Uh>?Xjn_Xhn3PgmgLg=gOh>gZjng`j=:h<Bd7o?Oioog`o`3no_l7
m0d0oo7oo?ceoaccg=7DdLK6aLC6al[=cL[:blk?clk<10@8no;oln3o1ocidaD8
6OWmj_lPo__jn?n60085A4I0<c4j>Bli>S/k?3dn?S@e=cPh=cDdnChR?C/i=cLi
>cdh>d13@d0k>3Pg=C@d=CLhB48j?498C5402`3mo`3kl?l0o_ko1o@=0?oaoocl
n?lQoOc]aHiWE4Lh@TM<CTi9AD=5@chl?TYNM`001OolonokoN;o1ocidaD86OWm
j?lNo_WkO`000d]?CSlk?c`_>SXk>c`m?Shd=CLh>3Le=?Tn9cdk>CLg>C/m>3]0
@d=0>cPh=cDd=3Dg>4I1@4A<DUED0080n?Woook`o`3no_l1m0d1VPD0oo7oo?cg
o`Omoo[YjOOooOco4o_gn?cno?Sel>cV6QHGooSnk_cnh_l6n_OB50PInnKo4o[o
R@d[C:o@i>KZlNcMiNCSh^7Qo^06gmgLg=gOh?WV9nGShMoOhN?Ui^KUi>CUi^KO
h>;Shn;PgncWiNCUg<F/<Bd7o?Oioog`o`3no_l7m0d0oo7oo?ceoaccg=7DdLK6
aLC6al[=cL[:blk?clk<10@8no;oln3o1_[gdQ@86O_YoaKnno[hohH00PE0@chb
<S`l<cm0?chm?Ohl1S/i>3Pi>cci?R8m>cTg=cTk?Chn?C`l?Chn=cPj>c/j>3M7
?c@c=c`oA@0;0?go0?_`o`3no_l7m0d0oo7oo?chob7mo>g5SVMDAcQ2Ada>CTU5
@dE3?S`nBUig0005oocoko_mh_l6n_OB50PInnOo5?kingl000=7C4`n?44o<clo
?Sdl??hk1SXh=cLh>S_i?RLm>cTg=cTk?Chn?C`l?Chn=cPj>c/j>3M5?SXk@DI8
B0020?Siooonl?l0o_ko0O@=0J/50?oaooclmOl5nnWYm_gko?lCo?[jo_kln?G`
k>HJ5QOon?k^o?kRo`Kim]8D2A_no?l4o_klo?k`oakiohL:946J^<[>dmkLc]KE
dm7?c/c;e]?>b/[>dmK:n/`Wdm7?cLg?dMCOfM?;cM7Kgm7Cf]_Mf=G?iMkHe=?;
]Z0Z:@OnmoWlno3o0?kno`Od3@3olOolo?Oo7_kolmcAeM;6alG4a/O9c<c9b/_>
clo>c0@42?_boo?Po`[kn=8D21[jo_koo__ol_hPoO[iohH01@U5B4Hl?DM7?DY:
B4I4@d50BdQ3?cm3B4/nnSdRA490?Si0@T==Achi>3m6CCa1ADU8AT0mE4]1?T54
AdT0303mo`3ll?l0o_ko1o@=0?oaoocln?lQoOc]aHiWE4Lh@TM<CTi9AD=5@chl
?TYNM`001OolonokoN;o1_[ed1866?WnoN[o7_cgnh400`Y<E5=9B51=@4e=BdU7
ATA3CT]6@T96Bdki@BM8ATA2@TA6AU1:@S`l@TY@@4A9C4a9A41IDdY9CU9@C`08
0?[kooonl?l0o_ko0O@=0K850?oaooclm?l4jn;]nOckoa;lo?kno?Sel>cV7BU4
HGV6SHn4nXGiT?VDnY/aV[NJCbT7:iRN/k:_[:VVYJFPXjBVZ:Z[[:VZ[:f_/K>d
Z[c2XUdS5BIiPh^DVIjPX:?bX_VOnZ0QXjVZZjZ[ZZ^Z[Zf^[Jj][Zf_ZZRYZjFG
QQ`S1ooin?Sfo_7o0?kno`Od3@3olOolo?Oo2O_nm=_;d=C?bLOnaQ?8b/[9b/_>
clo>c0LG=EMcQi:DQ_Z5nI3iToZJ<9^lWe8X0RB?TjVZZjb/[Jj^XZ>TYZRZZjbY
ZZb][k6c/jRk`Z9M7`T?E4m<B4E4@d?aB?U4nTDKA451@450@D11@dA3A4=4@d=6
@d98D5ACD@0=0>_o0?kno`Od3@3olOolo?So8OgkkLR>HDi7?T97C4i>BDE3AD<n
?3i:GWL0039OOH^>SX?jQOZ@0I:HnYWjX32O^9U;8`0NRY6WZ:Z^/K>e]Jj_/;:d
][Nh]KJh^K^m_k^Y]l2PFah=5EaKEeEBD4i>lE7iCOY>0Da:nTSjBa1?EeQGFf9U
H5/0403moOooo?3o0?kno`7d3@6<1@3olOolo?Co1N_Rk?Sjo?_o4Okoo_chmO3/
iQD?2`d>1`001_X7n@Ki1oX:<@TA4P041PPj5A<@3@X60`022P/>30l>40lA3a8A
518E5AXO9R8<00484QPO92/a=CDdlS?i=_Xd0CM2nTCiB11DD4a=Cd/o<Q@O1_oj
n?Gdo?7o0?kno`Od3@3olOolo?Oo2O[mlm_;dMG@blSnaP[8bL[9b/_>clo>c?h0
1@<820D22?X7l@Kj2AL:5aT21000;0@20`@51`L920X92PX;30cn3A0>3a0@4A4F
6b<R3@000@L40L`030T61P`D61DA00h0ook]o`3no_l7m0d0oo7oo?choaSmnng8
SV5>Aci2Ada>CTU5@dE3?S`nBUigoP052a8<0@05nPOj1P483?X>nQ423aDBo@00
8o`02P8620P<2P/;30d=oPhF3a0A4A8>3A0J6PP00PP?3`d;2@L610Kb1?T7nPD1
0`Cj0_X640XN7ahR:2TS70<D0?omoooll?l0o_ko0O@=0G450?oaooclm?l5jn;/
n?[lnolAo_ono?Sel>cV8AdK5Q8;1P<9nP[i1?T3nP4700081bLM4bWn3bH=2`L4
0`<;30h;30T;20l=3P/<2P/;2PX81PL642<A5A/O9RX^;2Gb8OTTnR018bkj<OXd
4CD^:bLX:BDK514L1?ojnOOeo?7o0?kno`Od3@3olOolo?Oo2O[mlm_;dMG@blSn
aPc8bL[9b/_>clo>c0/;o@`22`P;nP[i1?T2nP070@4>2BLG1aSl01<10P831@D4
10820@451P@40P<10Oh01`430`dM1P@1k03i0O40nP;g00<@0?onkOl0o_ko1o@=
0?oaoocln?lQoO_]b8iQCTLn@TM<CTi9AD=5@chl?TYNM`002A@F40L22?X:nP@1
1PSj2_X81`H430@O2`08hP0921d:30X:20H50o42n@Gj0@400_X0nP<@1P4200@9
2@<00a@0oogoooc`o`3no_l1m0d1L@D0oo7oo?cdo`G[h^chn_ckoa7nookln?G`
k>HO6AHC51@F6A?j5?TFnA;j4@P@0a0560/FECGn<BD`;B/Y:R`]:bTW9R@S:RXX
9R@S8B13<R/]7@H45Q0A5QXO8RHR5?8?n@_j2P4=3oXBnQ<A5S4`;2d`:b8G3A/3
oo[knOKnlOl0o_ko1o@=0?oaooclmol9n_gcfl_AeM3;b?k64lS9b/W:blk?clk<
2@L72@hE6ahEnQCi5_TAnA0Z2QP960<:@AhI6QXK71dN7QdM6aTG5Q@C6QXH5Q@C
4@lb81dR5P404@H50o/0lP7Q00`70@042P/70P0@0?onkOl0o_ko1o@=0?oaoocl
n?lQoO_]b8iQCTLn@TM<CTi9AD=5@chl?TYNM`00114H6ALH4_XDnQH161Oj6OTH
1Q0J210002KX00<40004oP082`D72@T71`D4d@0?4A4?4QLF40T3503ooOooo?3o
0?kno`7d3@6R1@3olOolo?Co1N_Rk?Sjo?_o3Okoo_chmO3/iRDK4PP3mP3i1_T2
nP@90@090088;[?<f?kI0=Sneb3Ce=;@c/g;b]3?c/c:b<O5]Zn_Wf0I2RS;blg@
e=OIe<Cb__VklKCj]a6mY:FQXZBQUhd:607oo?cknOkao`3no_l7m0d0oo7oo?cg
o`WjoO?Kbm7Ed<_8o/H=b<W:bL[;c/o?c/`?2@?n0082107j0?T6n@7j0c440Q81
0P0OWK2i^[^k_;fm_[Zj^;Jd/k6`][Fd/[2^[J^KUIR=DPh48/C3`Knm_;^n`O;3
nL3j^@2jnKKj^A2fSXN6R8f>QX404P3oo_oooO3o0?kno`Od3@3olOolo?So6?gk
kLR>HDi7?T97C4i>BDE3AD<n?3i:GWOn00861`Cg0?X60@P7nPWj2``=2aT20002
MX20NWEcoW8PKV1MFeUGEUACFEQGEE=AD5IDFV9M:`005[k1`lG5`l?1lKci^OZb
8;2YZ:VXZJRYZ:b[[:^/Zjb^TI6?TIFDS8D3503ooOooo?3o0?kno`7d3@6l1@3o
lOolo?Co1N_Rk?Sjo?_o4Okoo_chmO3/iRhV7aLC3`h?4OXBnA7i3oXA2Ph67A<H
2TOQoo;eoOH7mOGfm_Gdlo?mlPgalO3_kng`m_o_UC8SC?Wo0?Sbl_WenO4?jn[[
j^_Zjn[^kNk]k^g^l_[o2?/65@7oo?knno3o0?kno`Od3@3olOolo?Oo2O[mlm_;
dMG@blSnaQ?8bL[9b/_>clo>c1PD40d=41<D4oXBnA7i3_T@5@dW61D0=LO_c<g=
c/o?d=3AdM3?c/kmcAG<c<_:b/W;dnGFPB<JAOglno[in?SjhOl7o?gloOcmo?gj
o`7loOgk2_ckm@8C0?onoooml?l0o_ko1o@=0?oaoocln?lQoO_]b8iQCTLn@TM<
CTi9AD=5@chl?TYNM`003ADG50l>4?XBnQ414aCj5_XH5Q`M<a`>016D[h5hLFaZ
J6QUGeaKFUUIoEP@EeMFEEEKL8:LUT`003?bnO_noC;knoSgn?OhmoSgn?OhmoSg
n?Okn__jno[kn_OfmoKgm_Ofk>[/j^cZk>[_kNo]kng_lOglo`Wnm`<D0?omoool
l?l0o_ko0O@=0KT50?oaooclm?l5jn;/n?[lnolAo_ono?Sel>cV5@l;2@X92@X;
nPci1_T7nPD;0P0@10/;<L3RlOGho?T4o?cmoOkno`Cjno_loOkn4=oQl=j05`dh
o__jn__mo_[dl_3im?Wb7n_Zjn[[j^_Zknk_k^o^ko;fmo?dmoK^iP<D0?omoool
l?l0o_ko1o@=0?oaooclmol9n_gcfl_AeM3;b?k62/S9b/W:blk?clk<o@0410X>
3`gj3?46n@@70QT9200OX[gnaP77aok85l_;c<c=c/o?bL[:blc=cLja]l^oI`D0
<_gj0oWin?[@o`kimOKim^kV0a@0oogoooc`o`3no_l7m0d0oo7oo?choaSmnng8
SV5>Aci2Ada>CTU5@dE3?S`nBUigoP051`h>2PT:nPcj1P483?X>nP`341DZ3oh0
JF9]J5aCCTY8AdM8B4U9BT]<C4I7AdQ9BTY@@U=`KbD001[^mO[lo?[hn?WgnOOi
moWgnOOimoWgnOOmnogkoO_mno_inoWknO_il_3bl?;`l_3fm?Kdm_Cfn?[hm?Gh
m^kV0a@0oogoooc`o`3no_l1m0d1W@D0oo7oo?cdo`G[h^chn_ckoa7nookln?G`
k>HW8AhH4PT200gj3_T;n@kj20/500l34aMDgOKfnok[o`_moo2D:a]9oocin?Sm
nO;hl_D1m?7jko[b4?Cel_3`lo7[i00C0?omoooml?l0o_ko1o@=0?oaooclmol9
n_gcfl_AeM3;b?k64lS9b/W:blk?clk<4@l?3P`:1`@?nPki2oT=n@L921L640To
_Lo8ao_85lO7bL_=c]3AalS9blg?d=3?bmS;MQL=@_km1?knoOknd?l>o__ko?[a
j0@E0?omookkl?l0o_ko1o@=0?oaoocln?lQoO_]b8iQCTLn@TM<CTi9AD=5@chl
?TYNM`0031HF3P<03?X>nP/13A?j5OX?L1@O;0d700YdLUU=@Sdi>3Hh>S`n@493
ADHl?Ci0@TA5Be=HKg0]000Xl?Olo_kln_[moOomoogooOomoogooOomo?[ln_cj
o?[ln_cjo?[ln_OemoGgmOOen_Sjn?[hn_[mn_OgnOO_i`<D0?omoooll?l0o_ko
0O@=0Gh50?oaooclm?l5jnSbn?ClnolAo_olmo;alO;`7aTE40d91`L9h`X:1`L4
1AT>C>[jmocZo`ofo>f=8AM@oO_jn?SgmOKlhod1o?[cn@kgl?7akoOglMP04P3o
nok^o`3no_l7m0d0oo7oo?cgo`WkoO3KdMOEb/_8o/HCb<W:b/S6b<_@e=H91`H6
1`X<30_b2_491`d<21D0=/[AnlHKaLG7alK7a/O6alK7a/O6alK7a/7=`f`924Wk
oOco0Ocnhod0o^ko3?kooocQ0QH1ooWlo_k`o`3no_l7m0d0oo7oo?chob7mo>g5
SVMDAcQ2Ada>CTU5@dI1>CHjBfB100033Q4>20H8l`X130oc4A4F9B4?2P00MfQ=
?c@_:bT[;c[c?PY0@45IGa/002g^n?ko@?kjn?gmoogooOomoogooOomoogooOom
oogooOomoogooOomnOSin?WhnOSin?WhnOSinOSno?WoooSN01D0oo[mk_l0o_ko
0O@=0G`50?oaooclm?l5jnSbn?ClnolAo_omn??blO;_7aTE40d91`L9h`X:1`L5
1a/?C^ckn?kZo`_koo6A91]BoOWhmoGnm=;o3_cblO7^mOOaf00B0?oko^ko0?kn
o`Od3@3olOolo?Oo2O_ml=_AemG:blSnaQ?8bL[:bLO9c=3De@T71PH72P`<2o8:
l@T73@/75@0fb]7naak6a/G5a<K6aLK5a/G6aLK5a/G6aLK8`m36KP/:Bo_no?lQ
o_cjnO[in_WjnO[in_WjnO[in_WjnO[in_WjnO[in_Wjno?l0Okno?l9o>425P7o
nOcno_3o0?kno`Od3@3olOolo?So8OglkLF>IeA7>497C4i>BDE3AT8j=c];I800
00<>4@h81PSc2P4<3o<A4AHU8@l7001aHDHg;bTX:2T_>_=02Shl?5MM6P00<Noj
o_l3o_SfoN;o7O_inoWknO_inoWknO_ino_jo_ciooohgP0E0?ojoNko0?kno`7d
3@5N1@3olOolo?Co1N_Xl_Sdo?_o4OkooOWelo7`k1lI5A0=2@L72N<:2@T81PPL
4Do]noWYo`knooFD9aiEoOWgmoGdl_KAookd2_7hnO;J01@0oo_nk_l0o_ko1o@=
0?oaooclmol9nog`fm7GeL[;b?k64lS9b/W9b<_=d=;B2@L61PL:30`;lP[b2@X8
30/75@0fb];9b?k77<K5aLK6aLK5a/G6aLK5a/G6aLO<a]?9L@d<CO[mo?l1oO_R
mo;h4?_mooomoookh04F0?oio?knl?l0o_ko1o@=0?oaoocln?lQoOc]aHiWE4Lh
@TM<CTi9AD=5@S/i?4]RO@000`hA3PP62?<:0@`?la4A5RDO30D006aN@cLa;2h^
<CM0ld<:@3dkEV0M000hlOcno`;lmoGQoagmnogkoO_mnogkoO_mnogmn_klnOoo
n=h05@3on_g^o`3no_l1m0d1C`D0oo7oo?cdo`G[j?;hm?ckoa7nookkmoC`kNPO
6AD@3@T71`WS2PT92PT;7A5?k?_jjOl>o_ofURXPEogin?Ogm_CfdOl=nO[hmOcl
mMd05@3onok^o`3no_l7m0d0oo7oo?cgo`WkoO3KdMOEb/_8o/HCb<W:bL[:cLk?
clh91`H61`X<30_b2_893PP<2PHE03O;d/_:b/W9b?k76<S7b<O8alS7b<O8alS7
b<o9eL]c40e>nOglo`7nnn?hlOL@nO_oo__oooWO0AD0ooWlo_k`o`3no_l7m0d0
oo7oo?chob7mo>g5SVMDAcQ2Ada>CTU5@dE3?C/mBUmi00033Q4>20H8l`X130oc
4A0F8ah:0P00JUa7?3Le=cY0@_932D10?EYS8P00?OKmo`;jlo?Poo;m3O[no?Wo
ooSN01D0oo[mk_l0o_ko0O@=0E850?oaooclm?l5jnSbn?ClnolAo_oooOWfl>_T
7aTE40d91`L9h`X:2@d<31lBCncjnOgjo`cnookoo_onookoo_ono_l?oOoeU2TN
Eogkn_ShmoKfo];o3OkooocoooWO0AH1oo[mk_l0o_ko1o@=0?oaooclmol9nog`
fm7GeL[;b?k64lS9b/W;c<o@clg:2@L61PL:30`;lP[a2@`;2@HD03O;dlg<bl[9
o/P0bO;:2]79eL]b3`e=nO_noOl1o_cRn_;h3_WhoO_ho_kgg@0D0?kjoNko0?kn
o`Od3@3olOolo?So8OglkLF>IeA7>497C4i>BDE3AD@o?Cm:GGD000<>4@h81PSc
2P4<3o<A0aDQ6PKn00YZGTY1?d56Be5?AO=02Ci0@EiW:000@o[mo`;ilO7Ao`gj
o_ciooohgP0E0?ojoNko0?kno`7d3@571@3olOolo?Co1N_Xl_Sdo?_o0?kno`gl
n?3YhAlI5A0=2@L72N8:3`h=3R0BCn[hmocmo_kmoOcan`oon?o`TB@LEOgkn_Wk
n_Sgh_T0o>_o1ocR0aP1oo[mk_l0o_ko1o@=0?oaooclmol9nog`fm7GeL[;b?k6
4lS9b/W;c];Bcl_72@L61PL:30`;lP[b2A482`T6500hc=?>c/g;b/W8b/_bc@[>
b=C:L0`:B_Sko_go0Ogohoh1oO_bnPgfn_Senocfg00D0?kjoNko0?kno`Od3@3o
lOolo?So8OglkLF>IeA7>497C4i>BDE3ADA1@45:Fg8000<>4@h81PSc2P4<3o<A
0aDN60?n00YZH4i7Ad]BFF1I@o8j23m0GfTY0014o_go0_O^km7o3O[no?WoooSN
01D0oo[mk_l0o_ko0O@=0DT50?oaooclm?l5jnSbn?Clnol0o_ko3Ogil>ON7aTE
40d91`L9hPX93Pl?8QA?j_Ogn_kk0_[hn?;g2OSkm?c[S20HDOgnn`Clno_fln?`
0O?jlogio`SU1QT3oo[lo_k`o`3no_l7m0d0oo7oo?cgo`WkoO3KdMOEb/_8o/HC
b<W:bLc?dm??bL@91`H61`X<30_b2_894@P;2@HD03S<dlo?c/g;b/W<c_?A2lo=
aM77K@T7AoOjoMco0?gco0kkmOSfloWjm=X04`3nn_k^o`3no_l7m0d0oo7oo?ch
ob7mo>g5SVMDAcQ2Ada>CTU5@dE5@T52BUU_00033Q4>20H8l`X130oc4@<C71D1
oP0:JV5CCDmEGFI]Hd;c<PPe?45PJBX004Glo`;ek>kAo`gjo_ciooohgP0E0?oj
oNko0?kno`7d3@5W1@3olOolo?Co2^gXl?G`mo[kno[jo_P?n_[iln[PeQ/G4Ph:
1`@62N8:3`h?3b8BCn[gn?_lo_clno_`n0o`mnN97QI?oOcmo?cmo?Ocho0@loWj
o?[ln_cjo?[ln_cjo?kjo`ST11P1oo[lo_k`o`3no_l7m0d0oo7oo?cgob3mo_7J
dMKDb/c9b<O8bL[;bLcAdmC?b<<;2@L82@/=30_b2_894@P;2@DC03O;dm3@clg=
c<_=c_?@2lo<a<o4J`H4AOSjoOko0OkmhOlMo_kmo_gnoOkmo_gnoOkmo?Khm_Cj
noCK01@0oo[nk_l0o_ko1o@=0?oaoocln?lPn>_L^H]YGE55C59EEeECD4iCE5=D
EeaXM`000@X>3PX8lPX130kc3`<C71D3oP0:KVEFD51DFf1WGCkc<PPe>3mMJRd0
04Cmo`?mmo?cdOl=n_klnOoon=h05@3on_g^o`3no_l1m0d1A0D0oo7oo?cdo`GO
h?KNon_lk1;[jnk[j^GQgMSD5A<>30T61@H7h`X;2@X;3B8BD>_emo_lkOh:o?cb
n>N97AA<oogno?km0?cSn`klo_koo_onookoo_onooklo`[looohg04F0?ojoNko
0?kno`Od3@3olOolo?Oo2OgoolO8gL?_c<_mbP[;blg<cLc;b/W94?d?0a0A40_R
2PL92@LG03O9c__:0/W:bo?<2/gAbM?5J@<1@_cmo_h2oOcldOl=o?gln?knm=X0
503on_g^o`3no_l7m0d0oo7oo?cho`[]bKJaKfIfF8ARI?eV2FAVKW5aLWImQY?n
00462oh?l@[b314?6AL71@00LVECBD=2@T=5@ccc>@Xg=c]PKSH004?moOki0?_?
o`gmookioooef`0E0?ojoNko0?kno`7d3@4W1@3olOolo?Co1>S_m[kAnN`@iN?Q
gM_Dd/`A3P`91P<31@OS2PX920X<8Q5@joOho>co4?kml?SWR1`DC?omoOcmoOkn
dOl=oOonnOoomM/05@3on_g^o`3no_l7m0d0oo7oo?cgo`OkoOo?e]fU^?WC1<_;
b/[8o/Ol4@<B4A4;h@X72@PF03K8cLWmbP7;bo7:4LcAb]?4J@<1@_cnooonoO_k
o];o3Ogoo_WoooGK01D0oo[mk_l0o_ko1o@=0?oaoocln?l8k;f[[Wf4Re=VnX48
Ph23QXR=TYVOoP0510T=4A4<h`XA3aTG2@H007IWEDM0>CTg=cTjlc`=>C@gGW0j
0013nOSdm?W>o`gmookioooef`0E0?ojoNko0?kno`7d3@4[1@3olOolo?Co1>[a
ggQSnU/AGEIFDe1=AdA04@h<2@H30`D7h`X:2@P:328AD>_gn?c/oa3noO3hihPL
54cooOgloOgno]7o3Ogoo_WoooGK01D0oo[mk_l0o_ko1o@=0?oaooclmol7o?Wm
e=_9HTgjA@Q4?Shm?3/j>c[n40DA4A8B4@_Q2PL921H0=/S=bOg:0L_;lLXAc=7:
dlAY0`52o?koookmno_nd_l=oOonnOoomM/05@3on_g^o`3no_l7m0d0oo7oo?ch
o`SadL34Vj:@:ACj30P;0P841`T=51Sn00@42@d?3n8:4@lI5`T6001fIeE7@3Ti
=cLi>_<l3CTd=ei`>P00@oWhm?Cic_l=oOonnOoomM/05@3on_g^o`3no_l1m0d1
8PD0oo7oo?cdo`CVj;lc4_XM4AlU92<O6aPE414>30T61@<51n<:2PT82P`R4E3[
moSlk?l@o_g`n>N871A<oogmo?gmo_kAo`gmookioooef`0E0?ojoNko0?kno`Od
3@3olOolo?Oo4OginM;CZah020T82@P920P>3Oh<2`/:2Pl?414A4Q8A2n4:1`T8
5P0fb<g9oLX1bl_abQ7<dL[Ca6T30D;lo_ooo_gknokBo`gmookioooef`0E0?oj
oNko0?kno`Od3@3olOolo?So1_KTf=Za]8[]00D21PT;3@gR2Q4?6AL91P00MVME
Ad0i>CLg>C[c?0di=3MNL3X004?in?CdnLko3Ogoo_WoooGK01D0oo[mk_l0o_ko
0O@=0B050?oaooclm?l4hN>j;Pgj4a4D8R4P71XF50l@3@X91PD31POS2PX920X<
8Q5@joOho>co4?kml?SWR1`DC?omoOcmoOkndOl=oOonnOoomM/05@3on_g^o`3n
o_l7m0d0oo7oo?cho`Sno?Ohd=:Y7@3i0Q0<30X;2PX92Ph?410A4Q8A2n4:1`T8
5P0fb<g9oLX1bl_abQ7<dL[Ca6T30D;lo_ooo_gknokBo`gmookioooef`0E0?oj
oNko0?kno`Od3@3olOolo?So1o_fko78bj4Fk`060PH82@/;3N8:4@lI5`T6001f
IeE7@3Ti=cLi>_<l3CTd=ei`>P00@oWhm?Cic_l=oOonnOoomM/05@3on_g^o`3n
o_l1m0d1:`D0oo7oo?cdo`CKh]1YE?Y44DM<CD]9B4=0?10=2PL71PD61n<:2PT8
2P`R4E3[moSlk?l@o_g`n>N871A<oogmo?gmo_kAo`gmookioooef`0E0?ojoNko
0?kno`Od3@3olOolo?So2?kimOW@elENBOXi03Sn>@Lh=cHg>0d>3ohA0Q8A2n4:
1`T85P0fb<g9oLX1bl_abQ7<dL[Ca6T30D;lo_ooo_gknokBo`gmookioooef`0E
0?ojoNko0?kno`Od3@3olOolo?Oo1okmomSOcFIAnT4;>c<`;bh_;Rh_1PP8oPT1
2`_R2Q4?6AL91P00MVMEAd0i>CLg>C[c?0di=3MNL3X004?in?CdnLko3Ogoo_Wo
ooGK01D0oo[mk_l0o_ko0O@=0BL50?oaooclmol7n_coc]GLY;Ojd17Ce=ODd]7<
blL>30X71`H51POS2PX920X<8Q5@joOho>co4?kml?SWR1`DC?omoOcmoOkndOl=
oOonnOoomM/05@3on_g^o`3no_l7m0d0oo7oo?cgo`OgnOc;d]VQ]?[=4L_5a<C3
`/72``d>3a0@4A8A2n4:1`T85P0fb<g9oLX1bl_abQ7<dL[Ca6T30D;lo_ooo_gk
nokBo`gmookioooef`0E0?ojoNko0?kno`Od3@3olOolo?Co1=KMi:bon]P8e/c:
alK7aLG2n`/12@_R2Q4?6AL91P00MVMEAd0i>CLg>C[c?0di=3MNL3X004?in?Cd
nLko3Ogoo_WoooGK01D0oo[mk_l0o_ko0O@=0BP50?oaoocln?l8o__lo<71e[cX
n/dAd=;Cdm3>blW73@`:2@L61PL9h`X:2@P:328AD>_gn?c/oa3noO3hihPL54co
oOgloOgno]7o3Ogoo_WoooGK01D0oo[mk_l0o_ko1o@=0?oaooclmol7noooa<CI
_n_jd17>alG5a<?3a<D<3@h?414A40_Q2PL921H0=/S=bOg:0L_;lLXAc=7:dlAY
0`52o?koookmno_nd_l=oOonnOoomM/05@3on_g^o`3no_l7m0d0oo7oo?cdo`C=
cN;8m?WI2mODe=;Ac/_:4@l=3Od;hPXA3aTG2@H007IWEDM0>CTg=cTjlc`=>C@g
GW0j0013nOSdm?W>o`gmookioooef`0E0?ojoNko0?kno`7d3@5?1@3olOolo?So
2?kgnO?JbL[:a?[83<_Bclc?d]78`0T71PKn10462OX:1`d;2@L72@/=lPX:2@T6
1AlAEnkfn?c/oa3nno;kih8F55?ooOgloOgno]3o3OOoooWooLh21Pkomoo`kol0
o_ko1o@=0?oaooclmol7oOolhm;Cdlgjd@c?blK3a/_:a;l92P/<oPd130_j2PL=
2`T71`T;3O4:20/50A<0?L_<bOg:0L_;lLXAc<o<e/AS0059o?koookmno_ndOl=
mooonOomcP863_ogoo3_o`3no_l7m0d0oo7oo?cgo`OkooWPcm3@b_[>3M;KfmSI
gM[Baa4?3P`:oPSi2PL=2`T71`T;3O8:4@lJ4`83009iIUE7@3Ti=cLi>_<l3CTb
>F5`=000B_Whm?CicOl=mooonOomcP863_ogoo3_o`3no_l1m0d1C0D0oo7oo?ch
o`SnmOSbfLS9bL?ja`c8clc9c<o>a[l71`H6oP@11PWj2PL=2`T71`T;3O8:2PT9
1PDO4EO^m_Slk?l@o__bnnN25QACoogmo?gmo_k@o`ggoooioog>0PH>ooOol>oo
0?kno`Od3@3olOolo?Go1OkUe=GEco[C3=7=alC7c<_5_`X:2`_n3@4<2oX:1`d;
2@L72@/=l@X82`D14`0mblc9oLX1bl_abQ7<clcFa6<00DWlo_ooo_gknokAo`gg
oooioog>0PH>ooOol>oo0?kno`Od3@3olOolo?So2?gfn?;Ib<W9`o[73LkKgM[K
gmcCbA<A3`h<mPX73@/91`L92`gb2Q4?6Q<20`02NFIEAd0i>CLg>C[c?0di<SUQ
L3@004[in?CdnLgo3OOoooWooLh21Pkomoo`kol0o_ko0O@=0DP50?oaoocln?l8
o_Ghl]W8bLW3n/L8b<c:al[<blBmnPH11`Wj2PL=2`T71`T;3O8:2PT91PDO4EO^
m_Slk?l@o__bnnN25QACoogmo?gmo_k@o`ggoooioog>0PH>ooOol>oo0?kno`Od
3@3olOolo?Co1>KEe]K@n]@9d/o9a/W>cLK02_d;0``<2`_j2PL=2`T71`T;3O4:
20/50A<0?L_<bOg:0L_;lLXAc<o<e/AS0059o?koookmno_ndOl=mooonOomcP86
3_ogoo3_o`3no_l7m0d0oo7oo?cho`Skl?7[d/72`[cj`0o7f=_HfMgJd/TC4@l>
3P`<n0X73@/91`L92`gb2Q4?6Q<20`02NFIEAd0i>CLg>C[c?0di<SUQL3@004[i
n?CdnLgo3OOoooWooLh21Pkomoo`kol0o_ko0O@=0D<50?oaoocln?l8o_Oilm[9
b/[4nLP7blO4al_8`kcj1P472OX:1`d;2@L72@/=lPX:2@T61AlAEnkfn?c/oa3n
no;kih8F55?ooOgloOgno]3o3OOoooWooLh21Pkomoo`kol0o_ko1o@=0?oaoocl
m?l4i]GFe]3je0SCd<_8blo?al3i2oT:1`d;2@L72@/=l@X82`D14`0mblc9oLX1
bl_abQ7<clcFa6<00DWlo_ooo_gknokAo`ggoooioog>0PH>ooOol>oo0?kno`Od
3@3olOolo?So2?__knW@_l30^_Zn2/GDem?Ff]O@bA4AoPl33Ph<3?X:1`d;2@L7
2@/=lPXA3aXC0P<00WUVEDM0>CTg=cTjlc`=>C8iHG0d001:nOSdm?W=o`ggoooi
oog>0PH>ooOol>oo0?kno`7d3@571@3olOolo?So2?khnoGLblc<a_W:2LW4`LC8
al6j10Cm1P871`Wj2PL=2`T71`T;3O8:2PT91PDO4EO^m_Slk?l@o__bnnN25QAC
oogmo?gmo_k@o`ggoooioog>0PH>ooOol>oo0?kno`Od3@3olOolo?Oo1okooNCC
e=C>n=88c/_>d]79`P`<o@_g2PL=2`T71`T;3O4:20/50A<0?L_<bOg:0L_;lLXA
c<o<e/AS0059o?koookmno_ndOl=mooonOomcP863_ogoo3_o`3no_l7m0d0oo7o
o?cho`Skl_C^eLC5aKoj``[7dM3=d=CCc<D?3o`A0@l<nPX73@/91`L92`gb2Q4?
6Q<20`02NFIEAd0i>CLg>C[c?0di<SUQL3@004[in?CdnLgo3OOoooWooLh21Pko
moo`kol0o_ko0O@=0Dh50?oaooclmolIn_chgLk=clO=blg;cL_=b/S1`<?7al2i
10Cm1P471oT:1`d;2@L72@/=lPX:2@T61AlAEnkfn?c/oa3nno;kih8F55?ooOgl
oOgno]3o3OOoooWooLh21Pkomoo`kol0o_ko1o@=0?oaooclmol7o?okh]7Bd/cj
d0[Adm3=cm?Bb/<<3?h;mPX73@/91`L92`ga2PP;1@4C03g;c<WmbP7;bo7:4Lc?
c=K4H`01BOcnooonoO_ko]7o3OOoooWooLh21Pkomoo`kol0o_ko1o@=0?oaoocl
n?l8oOOjm=_:bl_5n/T:b/g9a/_?c/W43Pon4@<C4a4<nPX73@/91`L92`gb2Q4?
6Q<20`02NFIEAd0i>CLg>C[c?0di<SUQL3@004[in?CdnLgo3OOoooWooLh21Pko
moo`kol0o_ko0O@=0ED50?oaooclmolKnokiglo?d<W>cLk=c/g>blO0_/75a[ni
10@61_d7n@X73@/91`L92`gb2PX92@H57a5Gk_Kho>co4?kkl__WPQHDDoomoOcm
oOknd?l=mooonOomcP863_ogoo3_o`3no_l7m0d0oo7oo?cgob3kooSPc]3?b/g>
cLk=c/g?e=;>dMGCc<@<30/;2PT92PWj2PL=2`T71`T;3O4:20/50A<0?L_<bOg:
0L_;lLXAc<o<e/AS0059o?koookmno_ndOl=mooonOomcP863_ogoo3_o`3no_l7
m0d0oo7oo?cgo`OmoogTdmCDc_[B4Lk:a<76bl[5`0h?4A4C5ADC3_X:1`d;2@L7
2@/=lPXA3aXC0P<00WUVEDM0>CTg=cTjlc`=>C8iHG0d001:nOSdm?W=o`ggoooi
oog>0PH>ooOol>oo0?kno`7d3@591@3olOolo?Oo1o_onN3?d=3:n/h:blW3`<?8
al2j1PKm1`492OT:1`d;2@L72@/=lPX:2@P40ad?E^cdn?c/o`gnn?3hi80D4E?o
oOcloOknd?l?mooonOomcP873oohoo7ooo;n0Oono_l7m0d0oo7oo?cgo`Ojo_SO
c/o?bO[=2/oCdLk@e=;;```;o@X12@Wi2PL=2`T71`T;3O4:2@/60A@0?/_=bLW/
bQ3=dLoHafH00dWloOkoo_gmo=3o3OOoooWooLh21Pkomoo`kol0o_ko1o@=0?oa
ooclmOl5o^GDeMG?n]<Ad<[4`LK:b/G030h?3a4C4a4<nPX73@/91`L92`gb2Pd?
6Q<20`02NVQEBD0j>_hilSL@<bhfGF/]001:oO_im_Shnog@o`keooggoO_<008:
no?kk?_`o`3no_l1m0d1<`D0oo7oo?cgo`?noo_Po/h0ao[>4<g9c/g6bM36]0H8
2P`<2PT7hPX:1`L;31X>F_7^mo_/o`Wnm>S`fgTA4UKno_`1oOk?oa3nmokjlooo
``H:4?oiooOoo?[jnO`1o_kno`Od3@3olOolo?Oo0okonn3ncP37n/h@cl_Cd/_>
eLZf20T;3@d;20OQ2PL>4`dD04CBb?[90L[;ll`<cmC@f/UY10YAnocmo/co3_Wo
o?Cool861`comOo`ooWnn?l0o_ko1o@=0?oaooclmOl1oN;nd039n]0;c/S?c/O:
dLVe1`/=oPl13@WR2Q4?7R0?100:PVMIC4<n?S`n>C3b:`LY;U5M7P00C_ko1O_b
jnCXn=;o4?gdoOO_noZm0003m^[di_Kkn_gho`3no_l1m0d1CPD0oo7oo?cgo`?n
oo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2P/71PX:60eIkncenok]o`WnlNG]
fWH>4EGmo_`1o_k?oa3nmokjlooo``P:4?okooOoo?[in_/2o?kno_l7m0d0oo7o
o?cgo`?noo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2PT;41D?5P55dlW;o<X0
bOk:6LW:bL[9b/W:bL[9b/W>eM;Lbf/72e7knocnc?l?nOolm?oo``D83?oeoo7o
o_7o0?kno`Od3@3olOolo?Oo0okonn3ncP37nLh?b]7@bLcCbKD72@/=3@/91n8:
30hJ6`T000IoHEE9@3cn>QPi=C8c<S<b<c8c<S<b<c8c<2`^CUPI001>o_l5oO7T
f]oddolAoOgdnoO^n_Rk0001lnWaiOCin_gho`3no_l1m0d1C0D0oo7oo?cgo`?n
oo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2P/71`/:60eIkncen_c]o`WllNG]
fWH>4EGmo_`1o_k?oa3nmokjlooo``H:3ooiooGoo?[in_/2o?kno_l7m0d0oo7o
o?cgo`?noo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2PP;4AHA60A8eL_ncOg<
7<[7a/G6aLK5a/G6aLK5a/G:dm7KbV/62e7knocnc?l?nOomm?oo``H73?oeoo7o
o_7o0?kno`Od3@3olOolo?Oo0okonn3ncP37nLh?b]7@bLcCbKD72@/=3@/91n8:
0P`B4?d017AGBShgoC8H>DM<CTa>C4i<CTa>C4i<CTDe<U5K6`00C_ko1Ogai]_Q
m]?o4Ogmm?[fk_[h^`000oCZlnKfnO[mn?l0o_ko0O@=0CT50?oaooclmol3o_ok
h?k>0<OicPo:dM39c=?9]@L92`d=2`T7hPX;1`L;2QP=FNo/m?SloOkao`WklNG]
fWH>4EGmo_`1o_k?oa3nmokjlooo``H83OohooCon_[in_/2o?kno_l7m0d0oo7o
o?cgo`?noo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2P/<4QPC6PI9elg?clkn
c`;>blKca0g9d]3KbFX62e7knocmo/go3OWooOCool<620gomOoakol0o_ko1o@=
0?oaooclmol3o_okh?k>0<OicPo:dM39c=?9]@L92`d=2`T7hPX220X6o@04Je12
=c3n:`8/=dkcF@Q@?3MEGah004kmo`Cbj=gRm]?o4Ogkm?[fk_[h^`001OK/m^Sh
no[mn?l0o_ko0O@=0CT50?oaooclmol3o_okh?k>0<OicPo:dM39c=?9]@L92`d=
2`T7hPX;1`L;2QP=FNk[loOko_`2nocnlol9n_3UkMYf3Q5EoOkl0Oknc_l?n?ok
looo`PD73?oeoo7nn_[in_/2o?kno_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l[A
d<W<dlVe1`T;3@d;2@OR2PX<51TE6`M:fLoAdOc@0Lk9llH=b]7?fLQZ1PYAno_l
oOk=o`gioocdooo31PP=ooKol^oo0?kno`Od3@3olOolo?Oo0okonn3ncP37nLh?
b]7@bLcCbKD72@/=3@/91n8:0@H3o004ITXl<R_n9`8Y<dWcD`Q>@SiLHR80053m
o`Cdj^7Tm]?o4Ogklo[fk_[j_@001o[`n^ckno[mn?l0o_ko0O@=0C@50?oaoocl
mol3o_okh?k>0<OicPo:dM39c=?9]@L92`d=2`T7hPXA2@P<31P=F>k[loGhn_[h
n?[klo`9n?3UkMYf3Q5EoOkl0Oknc_l>n?oklooo`@@42Ocbo>klnOWjn`;lo_kn
o`Od3@3olOolo?Oo0okonn3ncP37nLh?b]7@bLcCbKD72@/=3@/91n8:2@/C6A@K
1d_Ic]3kd@7?c??:3LcAcMS7J@D:DO_ko?gncOl=nOolm?ooa0H93_ogoo?_o`3n
o_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2P460o`0
16I<@3D^oR/2;3=0lTD7@dEQJ2D0053mo`CfjnCVn=?o3ogklo[fk_[j_@432?_c
oNohoOSo0?kno`7d3@4c1@3olOolo?Oo0okonn3ncP37nLh?b]7@bLcCbKD72@/=
3@/91n8:30T830`H3ES^j_7dmOOmm@3jlo/9mo3UkMYf3Q5EoOkl0Oknc_l=nOol
loon_`832?__nN[hnO[k0_cno_ko1o@=0?oaooclmol3o_okh?k>0<OicPo:dM39
c=?9]@L92`d=2`T7hPX:2a8G4aX5BMO=clojd???3M3Ac=O6J0D:DO_ko?gmcOl=
nOolm?ooa0L93_ohooC_o`3no_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l[Ad<W<
dlVe1`T;3@d;2@OR2P882PKm00AaEDY0>_hg0STg<?<^23E3CVY_:@00D?go1?S_
j>[hdol@oO[an?C^n_^n0`D<ooOolooioOSo0?kno`7d3@4n1@3olOolo?Oo0oko
nn3ncP37nLh?b]7@bLcCbKD72@/=3@/91n8:4@T83PdJ3ES]j?3cm?Cclo7cmo?h
2OG^iNgJMPhAEOgno07no/ko3oWoo??no;h10@GhkOGWmoOjnO[k0_cno_ko1o@=
0?oaooclmol3o_okh?k>0<OicPo:dM39c=?9]@L92`d=2`T7h@X741@?5`=7eL_n
c@G>clk?cm3cd@o@d<[EaFL42E7knocmoOkncol=nOolm?ooa0L:3oohooG_o`3n
o_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l[Ad<W<dlVe1`T;3@d;2@OR2Q4<4a81
0002OfEID4Y7AdU:@c?c;0PgBUMaM2h005;mo`Cil^_]n]?o4OgjlOSdk_[k`0D9
4?ojooKooo[mn?l0o_ko0O@=0Gl50?oaooclmol3o_okh?k>0<OicPo;c/_7c]?2
Z00D50425aP5lA3i5?XA6100718B45WQk>[]k^k]kN_[m?Gdlo7`knojmPWekN?X
dFT;2UKooOh3oOooo^;mlOXGooOoooKjjkPC003Lm>;Dm=_kk?_jf__dn_T2n_kn
o_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l_>blO>dl:X01@D0@8G60Ga4?TDnA48
01lA2`97b<g7o/Snb@S:cm3?c/c;b/[jdA3@c<K?^eT00U;moOknoOgnon7mlOXG
ooCoooOll;hM1`kZoo?UonGol_ooh?ojn_l2o_ono_l7m0d0oo7oo?cgo`?noo_P
o/h0aoW>3l_>blO>dl:X01@D0@8G60Ga4?TDnQ4H5Q0`5`405hIkJF1KFE]KGEI:
@D0o?C`k>oY224]HH7Eb9@00Dogo1?_cko3ih_gbnQShn>_fn?7gk;`L1`o]oo[/
onKol?ong_ohnOd1ookno`7d3@5h1@3olOolo?Oo0okonn3ncP37nLh?blk;alkC
`ZP;5a8000P90?46n@;h01H<0@LAG>_onocmoOcknO_cm??bl>o^k_[Y4NSlnocI
M1TOF_cim_?emO[joo[nlO_Xo`okoooho?C3000?ho3^h?7hoO/2j?_en_T2n_kn
o_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l_>blO>dl:X2aLB00082@3a1_T2n007
2`000DO?h=Onf0_IfM[JcLg<blW8alOi`PoJg>71H`hGE_[hm_?cm?KhnOkannSo
3OWoooWon/`411kfooofnol2k_okn_l2o_ono_l7m0d0oo7oo?cgo`?noo_Po/h0
aoW>3l_>blO>dl:X2aLB00082@3a1_T2nP0:2AT[40<0:9nORH;nO@YoP7eZIVET
HV5PH?YK25ehPI:1=@0<Eoko1O_fkn_/n_[nlO_Zo`ckm^gfm_?km//41b?ln?l2
k?oinOd1ookno`7d3@6?1@3olOolo?Oo0okonn3ncP37nLh?blk;alkC`ZP>4`l7
2ADK6O4EnA7j3PT=5aL471TlY:^bo[@;/[6_/LO9b<O6aLC3n/dAbk:k_9YC7B=4
a/C2`LC6c<g@j/oieOWMn]THf^WIhN3Bg]^]020]cMkDc=oEg/Gcno7kmo[i0_[n
o_ko1o@=0?oaooclmol3o_okh?k>0<OicPo;c/_7c]?2Z0hC3`L95A/IlAGi4OX>
2`dF5@0?1bJ8S8n@T?fA292NVYVHUiJEU?ZN4:2=VYn1@A4J@<C3`/72aLO:jLoi
eOWMnMTGiMGNh=?ShKL;;d3Tm^oVmN3TboWomoomn_l2o_ono_l7m0d0oo7oo?cg
o`?noo_Po/h0aoW>3l_>blO>dl:X3Q<?1`TE6aWa5OTAnPhH6CPm72054F5FCDI2
@494B4eZK6]ZJFQWI_Y`4FToBEU86@0A@LoAc/_7`l73cN[?nMGigO[I6=GLb]GF
cMgO^0`dAncon_?oh^;9mooeoo_io@7oo_ko0O@=0Fl50?oaooclmol3o_okh?k>
0<OicPo;c/_7c]?2Z0T40PD610L=l@Ki2_X64@D:3PPZ618o9c4a<S4_;Rd^8?XS
nC08<c`m;QH;4AT6oP@420/B4`Wj2?4>nA7i5oXC61@[6alL420S000502lF72@e
AU9A[no_noOjn@;jo_kno`Od3@3olOolo?Oo0okonn3ncP37nLh?blk;alkC`ZP9
10851P@73O46n@[j1P`52@T07@H08`L?410AoQ803oT0nP4@10dJ7a@400PE10<4
10D93@oi2?4>nA7i5oTC5bLE6a`A9BT311P5BS8i@e1AF5NemOGooO[o0_koo_ko
1o@=0?oaooclmol3o_okh?k>0<OicPo;c/_7c]?2Z0T40PD610L=l@Ki2_X61A4[
<Qh^1=l02AH?4A0>30X:30Kj2?4>nA7i5oXC60lN2A0B2alW10LN45DnAeEKEEIE
/o?coo_io@7oo_ko0O@=0D/50?oaooclmol3o_okh?k>0<OicPc;c/_7c]?2Z0/0
0aDCkP3i1?X1600020<P3Q8g6adM7adK6API<38a<2l^;Bci<PLT8A`H4@h<1od0
10452`d1d`0<0@`610<000<06S<06_h020/0012Ajo3klO[i0_[no_ko1o@=0?oa
ooclmol3o_okh?k>0<OicPc;c/_7c]?2Z0/00aDCkP3i1?X11`001@0E000Oo@00
0Oh2200:1PD40`810?X600Sl00810`;l00831@WA0008oP0C0@D<0bU733H84b4W
108FUo7fooOjo`;nookno`Od3@3olOolo?Oo0okonn3ncP37nLh<blk;alkC`ZP;
00<E4nh0n@Cj0@@:6B@@6mh020H72``;1`H52<`04P4;1Bi>648H93De1`0DUNod
ooGio@7oo_ko0O@=0I050?oaooclmol3o_okh?k>0<OicPo;c/_7c]?2Z10;;VUn
J6=glF_iIoQT;fPn:@h`S7^3Q8B3P7mlOG9cLg5aKfm]KFa]K6e/KFfBQWYZA1lG
8e5?CDa?DEMHCoY>lDKi@?8l33e5=3Lf:CTk4@0601Cm00L64RN[noCkjo[i0_[n
o_ko1o@=0?oaooclmol3o_okh?k>0<OicPo;c/_7c]?2Z10;;VUnJ6=glF_iIoYT
66=RISPP01eeHfQYJFY[JfaZDe1?CTe<Bd[iB@U/HUY><A8>7U1?oT`3Ce5DCOY>
lDKi@?4l5d4^<c<Z?T@O11d7<@hC514D62faoo[olO[o0_koo_ko1o@=0?oaoocl
mol3o_okh?k>0<OicPo;c/_7c]?2Z10;;VUnJ6=glF_iIoYT66UgNd8K000o7AL@
3PhB51LM4aHE51<B4A3j3a0=;RPW9Q<12B9HFeYHEEACEOU>lDKi@?8l63Pf82PZ
93Y380/U4SlQ9bXQ5aH[[oohonoio@7oo_ko0O@=0Id50?oaooclmol3o_okh?k>
0<OicPo;c/_7c]?2Z0L=CkCRdLo/lM7icOW:1lkCQ3@=E=OAo]dUg=WGeMKYjN[W
j>GVi>g[kN_]jng]hN3Qa6TC653NfmSFemSMgM[jfO7EnM7ic?[@6=7JbLk>`<g;
W`0I05M2@SXm@DA=a?_`nngjn@;jo_kno`Od3@3olOolo?Oo0okonn3ncP37nLh?
blk;alkC`ZP73Dndh]7?k?7AnLgjbS79c]:1;@13`[_4aLK7alS9bM?Bd=3>c/c=
dmCCe=?Ddm6o^l6XE@H?BmgKemKDeMOIf?[IlMGidOW<nM0Gdl?:bl7BeJd9;aMg
IFIPG51:Dl[om_ocn_l2o_ono_l7m0d0oo7oo?cgo`?noo_Po/h0aoW>3l_>blO>
dl:X1`e?]>;AcncadOW=n/XHc]SHO1/03gmXJ65PGV5SIf=VH5mNGEaKFoYR46eg
QY:3>P0:CnGWiN;Og=_JnMWaeOWAnLcjd1S<bKFo`[_>e:h@>RB6NGagKUE8DLSo
m?oanOd1ookno`7d3@6E1@3olOolo?Oo0okonn3ncP37nLh?blk;alkC`ZP004Rg
i<Rmf?78nLcib@S<gX/U3Uoglnknl0_^kN[[jN_ZjNOViNGij`oTlOoTI@d;JmC?
bl[9bL_<nLWYd?W=n]@He^CEgMk?gMRY0040@S@`9c=:B4VimN;imOkl1_[inOOi
o_kno`Od3@3olOolo?Oo0okonn3ncP37nLh?blk;alkC`ZP004Rgi<Rmf?78nLci
b@W=gXLN0DgPfM7Bo]<:e=CEdM;Ad<k=c<cjdQ3?`/gUbE800fOCd/g:b<S9boW9
jM3iboWB6moAfM_?g]bc11L7IUeNG61VFec;ongon_knoOklo`3no_l7m0d0oo7o
o?cgo`?noo_Po/h0aoW>3l_>blO>dl:X0018]nC8_MSab?W<n/THbm7LN`803i9l
JF1NGEiPI5e;A4=2@3ln?_Y43e5QPJ:B:000I=WKfMC@cL[hbNW@nLcjda[AfLK@
d/OIfk@;8QUlNGmnPGaYHlgoioWdnogno`Cmno_oo_ko0O@=0JD50?oaooclmol7
n_oefLW;c/[icPo;clg:d]W8[`D0=lg7eKkBnL[iao7:2M79VP/MJNKgmOSnn`;j
n_SbmA3dmNgdfg8>4ekFc<K5b/c<b>W>2=3?c<_;c<oAdO[B1MCCd<o?d?kC5/GB
elkLejL5000o5C@L7BDk;KoOl_Kno_l6o_[gmOKlo_ko1o@=0?oaooclmol7n_oe
fLW;c/[icPo;clg:d]W8[`D0=lg7eKkBnL[iao7:2];8U00;D<K@bl_:oL/0c?7>
3m3>fL9P0PaLf=7;b/kAcl_YcPS@clc;blc?clgjc2C>cL[9bL[=cm;4cm;7eMBY
3PdLK4igJ6EPJeWUo?onoockn__noOl0o_ko1o@=0?oaooclmol7n_oefLW;c/[i
cPo;clg:d]W8[`D0=lg7eKkBnL[iao7:3=C4Q0003FmYEDa7ADGnA`15ld<AAD]?
J6DH001=eMGAd<o=b<C<j/h7d<o<bl_<cm3icR3@clc;blc?d=30b/boclnX4a/c
SGV[XZ2HVGK`n?S_loWmo`Cmm_Kmo_ko0O@=0J/50?oaooclmol7n_oefLW;c/[i
cPo;clg:d]W8[`D0=lg7eKkBnL[ic_7:2=78VP/OK>[kno[o0?ccna3hm^ogfg<?
4ekFc<C3bL_:a^W>2=3?c<_;c<oAd_[D7]KEd]7Ad]GDd/CBfLoMfjT8000k42/B
41X^9;SJl?Klo`Glmo?eo?kno`Od3@3olOolo?Oo1o[omMW9blk:nLh?blo=b];I
b:l503O=amFnd_W:nLkabPOBbI@02e35co_90/[:bo?<4LkCdM_6HP@>GMSAc<_?
d]3<cn[>2=3?c<_;c<o?c?[;7<g<bLS8bLc>d/C>d/KDdZP=3Aa]CgUZJ69^FnOn
o_l4n_Whn_gmo`3no_l7m0d0oo7oo?cgo`OjooGIbL_>b_W>3l_?cL[BfLR_1@0g
cLOE_];ib_W>lLX:e<>40007JV9<@Scm>B4j?T12@490@T12@490@T12?STkE5<:
0019dmC?c/g;a<3:j/h7d<o<bl_<cm3icR3@clc;blc?d=C4blboblfT4a/gTXBg
/K2/Zh;gn_K/l?Smo`Cmm?Cko_ko0O@=0JT50?oaooclmol7n_oefLW;c/[icPo;
clg:d]W8[`D0=lg7eKkBnL[ic_7:2M78VP/OJnWjn_kko`3nlo`@n_O_mm]c3a=N
e/c4`lW;b/KYcPS@clc;blc?dM;je1kFeM;AdM;Ee=;4d]W?gM^Y2000>a0[4Q0J
;RBhf_3fo?l5o?OcmOcno_l7m0d0oo7oo?cgo`OjooGIbL_>b_W>3l_?cL[BfLR_
1@0gcLOE_];ib_W>lLX9d/RD00]Aa]3:b^c;4LgBdM_5H@@>GMSAc<_?d]3<cn[>
2=3?c<_;c<o?c?[;7<g<bLS8bLc>d/C>d/KDdZP=3Aa]CgUZJ69^FnOno_l4n_Wh
n_gmo`3no_l7m0d0oo7oo?cgo`OjooGIbL_>b_W>3l_?cL[BfLR_1@0gcLOE_];i
b_W>l/X;c=K6Q0001fQPBT0goC<Q=C`n@3i0?T0n@3i0?T0n@3`k?EIE2`00BM?D
clk=blC0b^[>1m3?c<_;c<o@nLhPd<o<bl_<cm3Da<_<_l_=Y1<K=i:4]k6`[:^2
mo[fk?3hoOl4oOCdnokno`7d3@6N1@3olOolo?Oo1o[omMW9blk:nLh?blo=b];I
b:l503O=amFnd_W:nLObbP[9clNH2Qe[jO[jo^co4?cgkoOKL`lCG]K<a<?9bl[6
jLh8d<o<bl_<cm7Bn]@Ne]GBdM7BeMCBa=;IcmgKZ@P003/@:a8@6RhT^=[`m_co
1OcgloGlo_ko1o@=0?oaooclmol7n_oefLW;c/[icPo;clg:d]W8[`D0=lg7eKkB
nL[iao7:1m;9U04<DLKAo/_lc03;llXAc=;Af/EQ0`eMf=7;bloBd<c?j/h8d<o<
bl_<clo<n//LcLc9b<S9c<kBa<kBa]CBZ0d=76e?NFYXHViKiokno`CjnOSjoOgo
0?kno`Od3@3olOolo?Oo1o[omMW9blk:nLh?blo=b];Ib:l503O=amFnd_W:nLOb
bPc<elR80007J5m9?3<^oR`1<3Wa?0loFUP=001;eMGAc/g:a<3:j/h7d<o<bl_<
cm3icR3@clc;blc?d=C4blboblfT4a/gTXBg/K2/Zh;gn_K/l?Smo`Cmm?Cko_ko
0O@=0J450?oaooclmol7n_oefLW;c/[icPo;clg:d]W8[`D0=lg7eKkBnL[iao;:
2/W?aiP:7FWXnOSlk?l@o_W_mm]c3a=Ne/c4`lW;b/KYcPS@clc;blc?dM;je1kF
eM;AdM;Ee=;4d]W?gM^Y2000>a0[4Q0J;RBhf_3fo?l5o?OcmOcno_l7m0d0oo7o
o?cgo`OjooGIbL_>b_W>3l_?cL[BfLR_1@0gcLOE_];ib_W7lLX8d/RD0@]Aam;<
o/gncP7=b_?94L_Ad=W4H08=G=SAbl_?d]3<cn[>2=3?c<_;c<o?c?[;7<g<bLS8
bLc>d/C>d/KDdZP=3Aa]CgUZJ69^FnOno_l4n_Whn_gmo`3no_l7m0d0oo7oo?cg
o`OjooGIbL_>b_W>3l_?cL[BfLR_1@0gcLOE_];ib_W7l/XAc=W:R@001fIMACT`
:BLU9B/elSX@?T9MG14004gEeM7>cL[4`<[ZcPO@clc;blc?d?W>8=3?c<_;c<o@
e<C;c;o;cJ@C6cNBQ;Na/:b[P_Ojm^c`n?go1?gdm?_no_l1m0d1[PD0oo7oo?cg
o`OjooGIbL_>b_W>3l_?cL[BfLR_1@0gcLOE_];ib_W>l/X;bLk5U`PLJ>Kgmo_n
k?l?nNogfg<?4ekFc<C3bL_:a^W>2=3?c<_;c<oAd_[D7]KEd]7Ad]GDd/CBfLoM
fjT8000k42/B41X^9;SJl?Klo`Glmo?eo?kno`Od3@3olOolo?Oo1o[omMW9blk:
nLh?blo=b];Ib:l503O=amFnd_W:nLkabS3Bb9@135;8dlg>c/o?d=3?b/W8bLS9
b<W8bLS9b<W8bm3?fLAP0PeLf=7;bloBd<c?j/h8d<o<bl_<clo<n//LcLc9b<S9
c<kBa<kBa]CBZ0d=76e?NFYXHViKiokno`CjnOSjoOgo0?kno`Od3@3olOolo?Oo
1o[omMW9blk:nLh?blo=b];Ib:l503O=amFnd_W:nLkbbQ7>flf;0007IU]3=B`U
8b0R9c?c>A4j@4IQGQ@004oGem?>cL[2_/[ZcPO@clc;blc?d?W>8=3?c<_;c<o@
e<C;c;o;cJ@C6cNBQ;Na/:b[P_Ojm^c`n?go1?gdm?_no_l1m0d1Y@D0oo7oo?cg
o`OjooGIbL_>b_W>3l_?cL[BfLR_1@0gcLOE_];ib_W>l/X;bLk4U@LJI^GfmO[l
oOk`o`oikoOKL`lCG]K<a<?9bl[6jLh8d<o<bl_<cm7Bn]@Ne]GBdM7BeMCBa=;I
cmgKZ@P003/@:a8@6RhT^=[`m_co1OcgloGlo_ko1o@=0?oaooclmol7n_oefLW;
c/[icPo;clg:d]W8[`D0=lg7eKkBnL[ic_7:4=;9U@4<D/WCc/o?d=3AdLo:llPA
b]3>f<=O0@aLf=7;bloBdLc?j/h8d<o<bl_<clo<n//LcLc9b<S9c<kBa<kBa]CB
Z0d=76e?NFYXHViKiokno`CjnOSjoOgo0?kno`Od3@3olOolo?Oo1o[omMW9blk:
nLh?blo=b];Ib:l503O=amFnd_W:nLkbbQ7>gLn=0009J5e3=B/S8QhP9C;c>A4l
A4]THAP0053Gem?>cL[1_/[ZcPO@clc;blc?d?W>8=3?c<_;c<o@e<C;c;o;cJ@C
6cNBQ;Na/:b[P_Ojm^c`n?go1?gdm?_no_l1m0d1Y`D0oo7oo?cgo`OjooGIbL_>
b_W>3l_?cL[BfLR_1@0gcLOE_];ib_W7l/X;bLc2U0HIIN?dm?SkoO`0o_7o3oW_
mm]c3a=Ne/c4`lW;b/KYcPS@clc;blc?dM;je1kFeM;AdM;Ee=;4d]W?gM^Y2000
>a0[4Q0J;RBhf_3fo?l5o?OcmOcno_l7m0d0oo7oo?cgo`OjooGIbL_>b_W>3l_?
cL[BfLR_1@0gcLOE_];ib_W7lLX;dlVE0PeCbM?>cm3@o]41cl[cb179clgG`Uh1
35_Gd<_;cm?AcLoZcPS@clc;blc?clcjbac=c<W8b<W<c];4c];6e=:X3@dLKDmi
JVQRKU_Wo_ko1?[in?[moOl0o_ko1o@=0?oaooclmol7n_oefLW;c/[icPo;clg:
d]W8[`D0=lg7eKkBnL[iao;:4LkMchl000]XGdDg;2LS8R8W<o<j4Ci7CfQV6`00
D]WIdlk=b<6mb^[>1m3?c<_;c<o@nLhPd<o<bl_<cm3Da<_<_l_=Y1<K=i:4]k6`
[:^2mo[fk?3hoOl4oOCdnokno`7d3@661@3olOolo?Oo1ogolmO6b/o<nLh?blk;
alkC`ZP:04G1gl[<eoW8nKki`O[52l:meW8B3FWTho;fnOgj0?_boa3nmokXiV8W
4U_CbL2oa/S7`oW:j/h1cm;ce1OBd<_IeLWPgJ4:000R;A@64AXU7[oSk_;lo`Gl
mo?eo?kno`Od3@3olOolo?Oo1ogolmO6b/o<nLh?blk;alkC`ZP:04G1gl[<eoW8
nKki`O[54LK5gg@@0US;a<g>c/o?d=3>bO?74LS<flO<CAP:F=C=alO<d<k:bo[:
j/h1cLccbag<d<_Ec/3Ge:0?2B5DK69NJF9UENkooo_on_Whn_gmo`3no_l7m0d0
oo7oo?cgo`Omoo?Ga/[?c?W>3l_>blO>dl:X2P15`Mo:c=Oib?VnnL7jaA79d>I_
000BKU19>c4[:2HV:cSc?A51BV=NM@h0057He/o:b<>l^/Kjb]W>6=;;d/Ric/nL
5ALlNJ6PYK6/XWcnooCXlOSmo`Cmm?Cko_ko0O@=0HL50?oaooclmol7oOocelK:
clcicPo;c/_7c]?2Z1T2CL7Lal[DnM;ic?W;n/d;b/[LLA0;KO7hm?SkoOd0o_7o
3mo^g]eH7PmMdlW0_lK8al?ib^[>0LoBlm@Gd]3;fMG9h=fQ2P008RdD1Q4J9Ajo
hnkbo?l5o?OcmOcno_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?W>3l_>blO>dl:X6@9=
`Mc7b]Cid_W<nL_jc@S>e>Mf40=NfM[ndOgB0M7@n/kjba7=]/^l`d8?1e[DcLO7
c=3>b/_jb^[>0Lg<ll/Mc=3;eLk0emBP3`TQE6aRGVURIEG^oookoo[in?[moOl0
o_ko1o@=0?oaooclmol7oOocelK:clcicPo;c/_7c]?2Z1T2CL7Lal[DnM;ic?W;
n/d<dMk]L0006Gm/DdHm>?he0CQ6nTWjAQ5:>5MHK`P005GIf<o:b<>l^<Gjb]W>
6=;;d/Ric/nL5ALlNJ6PYK6/XWcnooCXlOSmo`Cmm?Cko_ko0O@=0H@50?oaoocl
mol7oOocelK:clcicPo;c/_7c]?2Z000=j_:_L?:nLOiaOW1n/0;_KS7H@L:G]kW
jNg`o?40m??e4??aooG^GQh@H]?9`;o6b<O3nL[ZcP7?d_?D5m;@bmWEbN3MX@X0
028]50HA6RDN_n?^l_co1OcgloGlo_ko1o@=0?oaooclmol7oOocelK:clcicPo;
c/_7c]?2Z000=j_:_L?:nLOiaOW1n/08`L;DJ0T3D<S:o<H3alK6`o?24L?7h=;C
B0h7G]?=alO=d<o:bo[:j/h1cLccbag<d<_Ec/3Ge:0?2B5DK69NJF9UENkooo_o
n_Whn_gmo`3no_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?W>3l_>blO>dl:X000gZlZm
`l[iaoW5nL7j`174bmYQ000?LV9@AChi>CLi>d;c@a57Cg9dQPl005_Kf<o:a/6j
^<Gjb]W>6=;;d/Ric/nL5ALlNJ6PYK6/XWcnooCXlOSmo`Cmm?Cko_ko0O@=0H45
0?oaooclmol7oOocelK:clcicPo;c/_7c]?2Z0T0D/;Od]7>nM3ic_W<n/P:aLOF
MRHOKN?[m__kooWjnOl?iokbjUTI3V?CbL2oa/S7`oW:j/h1cm;ce1OBd<_IeLWP
gJ4:000R;A@64AXU7[oSk_;lo`Glmo?eo?kno`Od3@3olOolo?Oo1ogolmO6b/o<
nLh?blk;alkC`ZP905;2gm;Ac_W@nLkic?[82/WDiH0Z6V;>cmCDnm?ic?WB4;kI
cli22@EOdlg7alg@cl[;n/[ZcP7=c??;7Lc@bmG>`=ODX0l98EA/HUiYHVEEk_oo
noojnOSjoOgo0?kno`Od3@3olOolo?Oo1ogolmO6b/o<nLh?blk;alkC`ZP905;2
gm;Ac_W@nLkic?[84<cLj7LC02AmKVQMF5ADEUIHnECjFQ5KC6meQ0h005kMfM7:
a/6j^<Gjb]W>6=;;d/Ric/nL5ALlNJ6PYK6/XWcnooCXlOSmo`Cmm?Cko_ko0O@=
0H/50?oaooclmol7oOocelK:clcicPo;c/_7c]?2Z0@2E[oHb/:dnLGi`?W2n[l;
^m7AJ1@:E]CTi^[^oO00k_W/nNd?e>[Nfe0D2EcCbL2oa/S7`oW:j/h1cm;ce1OB
d<_IeLWPgJ4:000R;A@64AXU7[oSk_;lo`Glmo?eo?kno`Od3@3olOolo?Oo1ogo
lmO6b/o<nLh?blk;alkC`ZP40UJof<[2]?W5nL3i`_Zo2/3Phg@I1dZnbLC4o/83
`L72`_[3n/@A`jc4^[hh0`1Hdlg7alg@cl_;n/[ZcP7=c??;7Lc@bmG>`=ODX0l9
8EA/HUiYHVEEk_oonoojnOSjoOgo0?kno`Od3@3olOolo?Oo1ogolmO6b/o<nLh?
blk;alkC`ZP40UJof<[2]?W5nL3i`_Zo4L?UhfX2011cL69IEE=CEEUGD_YAnU8A
DceOHWP8001IgMWAb/K1^;K5n/[IcQSBbm;8^Lk?W1DG?7VQX:Fa[:9lo_odj?7h
oOl4oOCdnokno`7d3@6O1@3olOolo?Oo1ogolmO6b/o<nLh?blk;alkC`ZP004Ra
dmOKcoWGnM;ie_[D4M3LdUl=1dkBl??gn__mno_jo_[mnOH?oooklVLV3ECCbL2o
a/S7`oW:j/h1cm;ce1OBd<_IeLWPgJ4:000R;A@64AXU7[oSk_;lo`Glmo?eo?kn
o`Od3@3olOolo?Oo1ogolmO6b/o<nLh?blk;alkC`ZP004RadmOKcoWGnM;ie_[D
3=K[i6`B14>ne=3?c/gnc27=emWHfMSIf=WAd]7BdM;AdN;^emE?5@=?dlg7alg@
cl_;n/[ZcP7=c??;7Lc@bmG>`=ODX0l98EA/HUiYHVEEk_oonoojnOSjoOgo0?kn
o`Od3@3olOolo?Oo1ogolmO6b/o<nLh?blk;alkC`ZP004RadmOKcoWGnM;ie_[D
<MK^i68000]gPGA_Jf]]L79`L6]]Jfe[KF]VI6ITIVAVIWN;Pi4Q001CgmWAb/K1
^;K5n/[IcQSBbm;8^Lk?W1DG?7VQX:Fa[:9lo_odj?7hoOl4oOCdnokno`7d3@6J
1@3olOolo?Oo1ogolmO6b/o<nLh?blk;alkC`ZPF3TfM]l;?aoW3lL;ja0c0]K]W
<2UQc=[UjNc]o^h1k>_jjO[U4>K^lmOKHbhDE=?9`;o6b<O3nL[ZcP7?d_?D5m;@
bmWEbN3MX@X0028]50HA6RDN_n?^l_co1OcgloGlo_ko1o@=0?oaooclmol7oOoc
elK:clcicPo;c/_7c]?2Z1H>CIfg`/o7nL?a`_[4<LK5cWDe9eJg_l?2`Knn_Kfo
al[9b/W:bL[5a/G6aLK5aLO=/[i;7@Y?dlg7alg@cl_;n/[ZcP7=c??;7Lc@bmG>
`=ODX0l98EA/HUiYHVEEk_oonoojnOSjoOgo0?kno`Od3@3olOolo?Oo1ogolmO6
b/o<nLh?blk;alkC`ZPF3TfM]l;?aoW3lL;ja376aLaX7P0PM71/IfEWJViaKVMP
HV1RH69PGUaNG5iLGUaPK65l7`<1DmoIdL[6`KRfaO[:fLhHd/_Bb;W>ci`E5cai
XJ2U/JbRO?kom>San?go1?gdm?_no_l1m0d1X@D0oo7oo?cgo`Omoo?Ga/[?c?W>
3l_=b/K;d;nU400>=BhY;27i:oT^nBWj;@/[7d@L1`dJG4mADeKmF05EBoY8nTlA
DEANEWd_7AQMelc3`LC5`l39n/[ZcP7?dO?B6=7Ac=[EbN3LX@P00BD_6P`G72LL
_^7/k_kmo`GlnOKfo_kno`Od3@3olOolo?Oo1ogolmO6b/o<nLh?blo<b<oD`jTB
00`a:20S5oTMnB0P7AhM7QdN7AhQ8R4R8B8Q8am66@001d4^:bXY:2LV9RPUnROj
;Q4];cTdGQ@71U;Ac<K7c];Ac<cjb^[>0Lg=l/`Lcl[Dc;oFe9l?221CJf1MIf=U
E^kooocoo?[jnogmo`3no_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?W>;L_>blO>dl:X
4@0=<RXS9QPM71dL7A`M720O81lP7b0O7A`M71dL7A`Q824P8B3n8@534?h001;U
00d`0006F]gHcLO5`;NfaO[:f/hJd=C?e/fme=:R5aPlMifKWZbUWWcooog_m_Wm
o_l4noKdoOkno`7d3@5Y1@3olOolo?Oo1ogolmO6b/o<nLX@bl_3^/37^:0@5aP@
3QDM823j8`4R8?dO0R0P6oXInQd;71/J6adQ9B`_:BXZoB/0:_8]4BXb71/Y8QY0
MMgGcLK0_;^na?[81]?Aclg=cm7hdoWFlLlH`mCB`/_NaYD300<Y>BLL9AHX7[GK
jO7ho?go1?kno?ono_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?W:3/g?bL?;d/>[5QTD
1P000]X00@84n@3b0A43400020<08Ug;c<_=cm?FeL_jb0KCdLo=cLoAn=?ie_7=
4kg<b;Joe;nC2@<LCfUQGFYIJ5SXm?l0o_ko1o@=0?oaooclmol7oOocelK:clci
bPo<c/O0aljoYa@H4`L110T6_@0<0@4^JmODc<Fl]kFi`o[81]?Aclg=cm7hdoWF
l/hCd/WKdl39gLNN6APjLiNCUJ>>UWkko`3mo_/4n_SjoOkno`7d3@5S1@3olOol
o?Oo1ogolmO6b/o<n/XAbLK6`K_1akNO0`/C5AdX<cTbnSD8>cTg=CDg>CT^nRgi
;PLb<Bl^;c4d=^Xa4Bh^82<[71TbJ=cDc<:m^;JjaO[91knm^kVi^kfonL7i`_W7
n/DJa/cMf/_Ci<fO0`02:cTW7RLG:QnefNO`mO_nn_l0o_ko1o@=0?oaooclmol7
oOocelK:clcjbP_;b/o<algC`ZP51P?n00410[h03@40011<a/O8b/c?e=?<n/T7
_kfk^KVk_Koi`OW2nLOjaAC4a=;>_lOIaih:11e?J5mLJEUYFNSdo`3no_l7m0d0
oo7oo?cgo`Omoo?Ga/[?c?W:3lW<b<?9ckbS0P<4000630Rn00d;00@QFm?>akni
/k:fa?[91knm^kVi^kfonL7i`_W7n/DCbM7Rg<gCim>/71/jLi:>Sif9U7kko`Sk
n?Khn?[koOkno`7d3@7G1@3olOolo?Oo1ogolmO6b/o<n/XAbKo2`Kk5bk^T4ald
Bf1^MWianW<8OgekNWYkOGe`nVoiK@MdLVm]K6e_L?U_lV/AJV1MHETe7CQZdLW2
^kJd]KO2n/D7e]CBd=3Be=Kif_7In]LJf<OEd/G;el>L0@009cDR5b8I;26ff>O_
mO_nn_l0o_ko1o@=0?oaooclmol7oOocelK:clcjbSS;b<k=b]7D`:<82Q8M9BPZ
;A/K6Q/J6aXK9RDR8R4S92LO81lP7b0O81dN7AhM7QdM924N71/L7Qoj7QTO6a`K
71/L6a`K71/L6a`K71DF81d101IB`Ok21<C5bLW7n/D7e]CBd=3Be=Kif_7In]LD
e[g9a[W1d<2P3@HODVYPGFULJUWWm?l0o_ko1o@=0?oaooclmol7oOocelK:clci
bSO7c<_6cLnjWPH94Al[<3@d7QXL6Q`J71XX92@Q8b8V9QhL7Q`N71hL71XL6Q`J
71`W9b@R8B8T9OXT8B8J61XH6QPJ61XH6QPJ61XL6A`X:@h29V3<bL:k]K:`/l3j
a@OFe=;@d=;De_WJlMWjea?Ia]G@`l[Hbj`M7SaeU8nAWHVCO?_o2?[hm_Shn__m
o_ko0O@=0O/50?oaooclmol7oOocelK:clcjbP77^Ojm2lS@`ZdQ<eR:[;Rk`OVi
B<G3`Kno`L?3]kJg][Nf]kJd/kBc];>d/kbi][:a[k6a];>d/kBc];>b/K:a/[6b
/K:a/[6b/K:bWjFWSE<Z>V;Ke<k9alS:cM?je0No_[bj^[bn_oW4nLOiaO[62<O>
fMO>dMO8ZOh03B8_6a0L6c0S^M[Yk_OlnOl0o_ko1o@=0?oaooclmol7oOocelK:
clcjbSC;aLg=c=?E_j052R12EEA@CdQ9B4U8BDQ9E5=@CdiADUE=CTe>CDi=CTY;
BT]:BdY;DU1;BOi69TQ9BTU:BDY9BTQ9B4U8BDQ9B4U8BDQ9B4Pd?d/m4@0HC]CE
dm;Be?kEn]@7_kjl^[Zl_[oia?W7nLGjaQC5aLk<`lSBak0@2R9DKF5MJUi/FNSd
o`3no_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?[:><c5c<c9clnjVP887dEKG5QGC4Q:
B4Y8BTQFDU9>D51DE4e;CD]=Bde;BTQ:B4Y8BTYFEE5>C4]<COY?8Di8ATQ6B4I8
ATQ6B4I8ATQ:?4YFBQl69U[Lf]K?b/S5b=3je0No_[bj^[bn_oW4nLOiaOW64/[D
d/W=f<fj7aloMiJBTI^;TG_lo`Wmn_Sfn?Sjnogno_l1m0d20PD0oo7oo?cgo`Om
oo?Ga/[?c?[:4LJf^KVkamC<^b0_H:?>e=3Bdo[BB=[He]CDe]SHdM3Ad=7@dM3=
c<g<cLc=c=CAc/[9alW9c<_<blc;c<_?c/o>clk?c/o>clk?c/oAaM3>XePV8SPf
;RTW9b/`<S3j;`M8AdE3@dE7B?U<nE7iFoYQ26AaMgMaLW9UD_h03A`Y4`PF73@X
^mc[kOKlnol2o_ono_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?[:=<c6cL_9d=>oW`00
33aECChl@TA3A4=4@dA;BTM6ADQ9C4U:BDY9BTU:ADI5ATE6ADI<BTE3oT0X@T=4
@dA3A4=4AdQ7B4M8AdQ7B4M8AdQ7ASE6DCX8004[=SLd<c0`;c7i;`M8AdE3@dE7
B?U<nE7iFoYQ5f1WJf]WJViYGA<=9UM^HemYGfaKioooo_Oo0?kno`Od3@3olOol
o?Oo1ogolmO6b/o<n/Xhc<K>blW=ckVK000<?eYDB4E5@dE3AD=5@de9BDE7Ad];
BDM9AdU7BDM5@dE3AD=5AE1@C4U7ATM8nTXQB4M5AdE7ADM5AdE7ADM5AdToEF59
5@0<=3hl=S<_;2/];OX_1dQ7AD=3ADM8nDciDOUKnV4CGfI[JfIXKFaS8B50NIRD
U9^:Sg[lo`Wmn_Sfn?Sjnogno_l1m0d1Q@D0oo7oo?cgo`Omoo?Ga/[?c?[:4LJg
]kFeaMSDbT=9L;?Lg=OKg?[I1mcKf=OGf=_LnMOiePKHemCAd=7Cn=Cbf0WKg^_T
/F8Z61d8oP040PP?40Wj1^T0n@7j1`H:1`X;1`H1o00=6RD>0A4P>2bng^g^m_kl
o`?no_ono_l7m0d0oo7oo?cgo`Omoo?Ga/[?c?[:4Lc;clW3bM2oX`P01S=7=bPZ
<oXe1cPg=3<c=3LhnCOi=PHg=S<`;c0bn3?b>14f;d9==0H001<A4Pl;1`H41@Gj
1^T0n@7j1`06n`0@0@@G42QIL6AOJF5]FnOmooggo`3no_l7m0d0oo7oo?cgo`Om
oo?Ga/[?c?[:4<c<dL[3b<fjWP@01SA;?Bl`nCH7>CPe=3@e>3Wi=oXf4CPm?3/f
=cHj>C/i>cTk>C/i>_<h43XnEEi44`016aHF4`h=2`X9n@KY0?T1nPL01OX030LQ
8T5lVYFCVhV=Mogno`[nnoSfm_Sjnogoo_ko0O@=0KL50?oaooclmol7oOocelK:
clcjbQ74^kNb/<7Hg]VUUJ3@knc_nnkjjPS^k>[Xj>[/k>KjiOWW1nGSh^7Ri>OY
nNCbi@WYk__`_7Dm8QD4oP040``D5Pcj20LG5Q@B4Q@F5oTDnA3b1`P:6adO7aX@
2`On00dH8P/03R<l;/;Ql>kfo_co0oknookno`Od3@3olOolo?Oo1ogolmO6b/o<
n/XAc=3@a[c3cL6XFc<T>dDb9S8anS<8=cDc<C4c=CPbnS?j=@8d<S3n;P/a<cH`
<C0a<34`<C;c<a4`:3Y5<Q401A<C50l;1@400PKj20LG5Q@B4Q@F5oTDnA3b1aP6
4A4C5A<@4ALI4RYJLFIPJ6=]F^Omoocln?l0o_ko1o@=0?oaooclmol7oOocelK:
clcjbQ3>dmC7_<;;_JAH<2@mB3L/>?Te1cTg=C<c=CLinC?j=A4g>3Hg=3Lg?3`i
=cTg>CLi=cGc<a4f>DmH@Qd72QPF61HB4@l>3P[j20LG5Q@B4Q@F5oTDnA3b1b83
20D72`T83ALP8D9jVYFDVXN;Lo[ooogjn_Sfm_Sjnogoo_ko0O@=0Ll50?oaoocl
mol7oOocelK:clcjbR34_[R`[KoJhn;_cL7NmO7koo?]kng_kNo]mO7akNo_lo?i
jOW]1nOViNKXjnoanNWbiQ7[i_;U]WE38Plm=C@h@DYCE4ojB@M4@d0o?d13A?Tn
lC?j;0P_:2T[;2HJ5aSn00`H8PX03bI0=<GTl_3go?l4o_clo_kno`Od3@3olOol
o?Oo1ogolmO6b/o<n/XPc=?A`kNmbl6[X6@m@T4]:3d`<c8c<S<b<cPg=3<b=CHi
nBoi<`L/:bX[;C0d=_T^lR`A:ADW=2D?10L?D55=AT0m>Sa6nTT7A4=0?cm0@dCi
?_4cnR`H:ahM7b8P6QhX6a@ZFg5UGfMRK5[Vo?ojo?So0?kno`Od3@3olOolo?Oo
1ogolmO6b/o<n/YHc]KEakRnb;nXW64k@d@a;T<d=3Hd=S@f=3`h>3@f=SXj<S0b
<38`<S0f=3Hd=S@f=S<b<c8f=cdm=cDg=CLe=cD_;Bl];bd_;Bl];bd_;Bla:3]8
=1`<317nE0E?CTi=C4_jB@M4@d0o?d13A?TnlC?j;28X50lA5Q@@5bLO841hV9:B
UHB5KoOooo_fn_Kfn?[koOgoo_ko0O@=0Kl50?oaooclmol7nO?Ve<Bn`l[jaR32
];>g_<G?fnWMZJoLi^[jlN_Ti^CVi>KTgmoShnGQhMoij@OOhN?UiN?Qgo7YnMhH
jNSWi^GThnKWn__9JBTaGl[4a/gGh>WWf^;DnLWjd@SDdloGd<_Qch;n01HK9P`0
4b0?@Kk`l>Gno_ooo_glnOWno_ko1o@=0?oaooclmol7nO?Ve<Bn`l[jaR37alS6
a<6m^;:>@Be2=RLY8bd`;c0_<2l`:2//;bh]:RSi<PLX:R`^;R`Z:?4anBLH<S4`
;bh];2TJ<dho200HHmgPgm_Fd/k?dN;DnLWjdA_@b/G=b<GQe94D2RAKLV5IIULe
I=[oo^koo_gmo_kno`3no_l7m0d0oo7oo?cgo`OilnKDa;k3b_[6HL[;cL_6`[^f
[hXn:d8h:bhW;c4c<C<a<c4/;30`<Rh^:SHd=S@f=3Hd;2``<38^;R`i>C/i>cTk
>C/i>cTk>C/i:bT[:B/Y:bTf<c@a<Rl`<2]6HD`C01aThN?Vi>CShMoFh]CibO[A
8/g1^L6k^MO=SQPE=gJDRXRBMTagj?oojo[fm?Cfn?WkoOono_l1m0d1YPD0oo7o
o?ceo`GjiM;:c=7jcA7:aL;7c=?LiO?`_L7Xko3ll^CjgPOLg^3Rh^3Ng?WT1nKX
j^c/j^SVjN@Hjn_ZjNOViN[Pg<fZJSHbA[fi^/3:d][Ic?;8lM;ibo[@5m7Len3K
eNcKTPX00bll9Q`a<bAFb?;hlOgo1_kmn_Wio_kno`Od3@3olOolo?Go1O[Ud/[<
dO[=4LkBdm;@cL[6`:INBea<?Che=oXj1cPj?3hn?3XhnCh7@494ATI4@T3a?OTn
64E5A4=1@3lm9bXb;Q<17T[Ad]7?b/K2`lKbb?7BnL_id1cEc]OBc^WNWQlG<FN1
M75lIDMch?oom_omo_gno_go0?kno`Od3@3olOolo?Go1O[Ud/[<dO[=4M7Hf]KC
cl[3_J=JBE]=@40i>OXk1cTk?Clo?C/inD0H@TA6B4Q6A4A5ADM5AdE7ADM5AdE7
ADM5@_Y064M7ATE3@T53=CY0>A/784gBe]OFe]CBd<[bb?7BnL_jd2;<cLG>bLCP
eiXR841nX9ZJXh1JPncooo;hm?;dm_SkoOgoo_ko0O@=0KH50?oaooclmOl5m=o:
_ko3n[hA_L2o`/K:dM[SdJ>VaLK8e<CLn]H8];Jh^[Zh][Fjn[/7`<;4a/K4`/3a
^oVo6<;2`L2n_Kbnf/Ng][BZXZ2f];Fi`<O>cLCb`O72nL[jb`S<clSBd<SLci7n
00/G:AXB938YE[[eknkmo`Kno?Wgmokno_l7m0d0oo7oo?ceo`GdglZo_l?i_Q37
b<O5a<6n^YIEA590=3@XCOY@1bh`<S@d<S0]nBlH=3Hh>SXh=S<^;Rd^;Bh];Rd^
;Bh];Rd^<_Xc63Hf=C@b<C0_A3LjDVf0TZC8bLS7`l2m_/3b`O72nL[ibaO:`<[9
`MO@U`D75DIQFe]UG4I]cOohlOono@7no_go0?kno`Od3@3olOolo?Go1OCOb[no
`oZn4L3=clg:a/6k]Y9A@Dlo=3H[CoYA1bla<cDe<c4_nC8H=cTk?Cdk>CTg=cTg
>CLi=cTg>CLi=cTg>?Xf5cTi>3Le=3<cCD52FW>4UJO:c<c:b/O5`o71lL;ib_[;
8/W7_LO3^m7;U@D<8EQlNgj5M5Ike?oej_Kbl_CfnO_mooono_l1m0d1V@D0oo7o
o?cgo`Ojm^cKbKno`oW0o/H=alc>e=_5WZ>n_<7=_:cjZ0Fh^Kbm_Kcn^OZk1kNi
^kfm^kVgj;/G^[Vh]kJe]L:_Y;GBi>7Ea/73a/_?e=C>l/gab?W@n/dGc/g2c=37
e]2K4@H?:cT_:SE:AFbhk_3boOl6o_cimoOno_ko1o@=0?oaooclmol7n_K/flVo
_l?i`?g53<?2`KjII5aVE4mBA43j@@QADUEFEUEBDDojCPM:C4i@D4i<B_5=n4hF
CDa;BTU8B5A6BFfPaMGIdM?Cd/o>c<cacO78nM3jcAS<b;c6akoAc9dI5BM<Hf9S
J6eOP<[hmO?oo_d1o_kmo`3no_l7m0d0oo7oo?cgo`Ojm^cKbKno`o[04L;;cL_:
a/:m^YIPF6ACCeA5@?Y21e9CEUMGEU=BnE48CDmADe=ACdmFleP1EU?iDAM@Cdi=
C4];EdY>LJ?:fMcEeM?Bd<c:b/_bcO78nM3icAg<`<S8_Lk9VQ/J<EeiOH63PFb9
c_WajoCalO;fnOgno`3no_l1m0d1U`D0oo7oo?ceo`Gml^KQi>Wjia3Xk>k^k>k^
l?Ggf^Chm?ooo?Wo2?WkoOoooO_jno[l1oCen?Win?GdlOcioA3lno[in?Ofm?S]
hN7/m_7RhokP0N?TknOakOWUnN4Ek=g[l^OcllZDRhbLXifFVZ6N/n7io_co1_kl
nOKgo_kno`Od3@3olOolo?Go1Ogbi^7TjO[W4NKUi>CViNKUhmni^L>c][j^bo[=
2;Vk_Kno_K^h]OZd1jb]/;6a/:f/lK?i]ARd/k:a/:n^[[Nb[[O>hnSSj>[Zjn[Z
jNWXl^OakOWUnN4CjM[UjmkZj/JDT9V_`<2n`;jda^omookm0OknoOl0o_ko1o@=
0?oaooclmOl5oO;VhNCYn^L0jOk/3N[Xi>?OfkBc_k6e_Jk;n/d7^K^m_knm^kWi
]`R_/;>d];>`/;cc_P6l^OZh6;Nf]KBc/[6^]Jj[^=3WkNS/k>_Whn3Lg^?bio7]
nNGjhAkSl^G_l^?]jlFDU:6md]KGeLjocO;on_KclO7bm_Wmo_l0o_ko0O@=0C85
0?oaoocllol2nOSmkol0o;?o0OWgo_H3m?Cfnn;lnOkinQCnkogooOookOWbko7a
kN[VjnW^mo_ko`Kno?Wfm_kno_l7m0d0oo7oo?cco`;in?gioa7nmoKgn?Wjno_m
k_Khko?aknCjiP3cnoD1l_7jl0O]k_7bl_7^kO7_lo8>lO;hn_[knocmoO[ko?gn
o_l0o^;lnOkjnPcioNcino?jnn?cl?;ko?l1oOgmo`Gjo?gmo_kmo`3no_l7m0d0
oo7oo?cco`;in?ghookn3?cln_Sgn^_`lngalNkii@3bnoChlPS_l??dm??`lOSc
n@7hm_Cd1_?aknocn?_mo`Onn_Kak^[/mn;lnOkjnP3noOl6o?ooi??cmoSo2Ogh
m>c_lO;fnOgno`3no_l1m0d1IPD0oo7oo?cgo`OioOonnOSmoo[nnol:n_Sfo>gk
ooKooogio`3mnol0o]7o1nO`m>W/o?oho_l5o?WhmOSll_oan?;o6?klk?_ooOoo
mooooOWhm?7^l?7elOGmoOKno`Knn_Ofm_kno_l7m0d0oo7oo?cgo`OioOonnOSm
oo[n4OcclO;dm_Sjnoobo?o^n?[]no[l2?Cfn?[jn?Kdlo[b1o?dmoShmoCclO7i
n17inOSgm_Cdm^[ko>k/n_gcoOk[oo7hlOl;oN[hno;en^Sko?_ln_l8no[mnO3l
oOgno?l0o_ko1o@=0?oaooclmol7nOgoo_WhoOoio__i2_OgoNcgn^_gn^gkn_d7
mOOino_imoGimPSgn?_lo?_hnO[co07jo_[l6?gmo?_jn?Sdgn_aj>cooo[ooogh
lngZkO[boo7hk?l5o_o[oOgnnOl:o?Kek^;_ko;fnOgno`3no_l1m0d1O0D0oo7o
o?cgo`3no_l1o_cboa[kn?OikoWkk?SojoSfn?Khm_Sfn_Wno?klno[io`3nnol0
o_7onOgnoaGno?_jm^obmO3fo_olo_kln_OdloCkl_kaooWjn_/2n_c]o?l=oOoo
n_CgnOS`jo;bk??ko`Kno?WgnOkno_l7m0d0oo7oo?cgo`3no_l1o_choa[mmOCe
moWko?gon?ook_SojO[jnO[in_Wjnogmo`;lnogjo07in_gm0O[ilOcin0Okno[i
moKen?ko2?_looggnOWkoOcol_kaooWjnO/Do^klo?Ohno7jnOKcn_oon_Soo?;e
o_omo@Gnooonookno`Od3@3olOolo?Oo0?kno`7no?OonO/8ooGmoN_foN[in_/1
oOkmo`7noOWo0OgnoOl1o_gaooWl6?ooo_gkn_Wgm?[kmOcoookooOWdl>gYkOWb
o_7onO[jnoWo1??kn_Ohnol;o_;bn_KdlO;fn?_mo_l0o_ko0O@=08h50?oaoocl
hOoko_co3?koo_onookoo_onook?o`Clnoclo_[o0?kno03nd_l1o_kgo`7no_cl
0?khookn0Oono_l7m0d0oo7oo?cXo`3no_d1o_kUom?nnOono/Won?k[o`3no_l7
m0d0oo7oo?bGookmnOl1oO_nnP3m_Ol0oOgk0Ogmo?l0o_ko0O@=03@50?oaoocl
POnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@5
0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko
0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o
]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3o
lOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kn
o`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1
okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0
oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3n
o_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaoocl
POnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@5
0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko
0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o
]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3o
lOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kn
o`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1
okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0
oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=0P/50?oaooclm_lCjooZ
o_o;oooSl_oUn?odoooimogno`kWoooelOWPoooZn?o_om?hobOalOoljOooinWo
onGhi_oEo_;/l__lmo?joooMonC[ooo^on;om?;gnOd>ooojooojm?kokOoDoo?g
mol0k?ko8M_oom[od^_omooYn?khnooomoo]ooGJoooKoO7ooo_molgno`CGonko
moOo0>Kmo`3[mol0o_ko1o@=0?oaooclm_lCjooZo_o;oooSl_oUn?odoooimogn
o`kWoooelOWPoooZn?o_om?hobOalOoljOooinWoonGhi_oEo_;/l__lmo?joooM
onC[ooo^on;om?;gnOd>ooojooojm?kokOoDoo?gmol0k?ko8M_oom[od^_omooY
n?khnooomoo]ooGJoooKoO7ooo_molgno`CGonkomoOo0>Kmo`3[mol0o_ko1o@=
0?oaooclm_lCjooZo_o;oooSl_oUn?odoooimogno`kWoooelOWPoooZn?o_om?h
obOalOoljOooinWoonGhi_oEo_;/l__lmo?joooMonC[ooo^on;om?;gnOd>oooj
ooojm?kokOoDoo?gmol0k?ko8M_oom[od^_omooYn?khnooomoo]ooGJoooKoO7o
oo_molgno`CGonkomoOo0>Kmo`3[mol0o_ko0O@=0R050?oaooclmolWinkoUE5G
H/_mkoool^Kfo?Ccm?Smooonooo_DEUT`oCol_kHZZ@]8?TL9a@^DfN;g_oomO;J
He=EdOojm_cooO3honkgon7oQUYfonCbLfMIEdoiF`m9H7^Tg_oonOoMdUQaG4iK
nF<JG3ecQn[oom?gogMognGon_ookOo`lOnTG5J:o_lAk_ohooWko?miS6>gookd
kOcenOl6mWJPm?ook?Oo0?kno`Od3@3olOolo?Oo9nO^oiEAEf;;oNoooo;Vm_cd
loChoOooo_ooke5II<?doo;nf:ZT;B3i72LD;U=WRmkoooGbfV=CEM7on_Kloog`
n?o^mooQohIJM_oTlW=WFEM?nE/?BF1kY=koooWogM9HLEa>FoUS6U`mLhOZoooC
momgOmoUoo[oongol?7oY5aFR_ko4Nkon?oinocoNHaS]oonm>glmOWo1_IfX?Co
oncgo`3no_l7m0d0oo7oo?cgobOWk_nEDEMRbog_ooobi_Klm??dn?goookoonmA
FFC3m?obo]RZY2dPnA`W52iCIh_Noooel]YSDeGAoo[fo?oml?Sok_OohOn6FWKo
i?9cIeUGCoUK3dUPNjCNoooiomgBF75LCU_iHaYL?G>7j_oodoOoMgoOiOojooo]
oo3aojALEX[noa7^ooSonO_logV<HkOoo_C]o?Gio`KfMZ3dooo/mol0o_ko0O@=
0P/50?oaooclmolAj_omG0007FGTo?kjo^gWoo;jn_l1l<gn00V/jN_oofTH000Q
nAT>61D3019eh?ool>@A001FoOl2oOOeo_l>n_ocoDL06_ogiR@04bXLn@L>52<?
45NZiOooj:H022LFn0/=8a0J0Uc?oncomAhO]nGmoag[onOTgS0Z02Son_ogoo[o
l?ook30N04CemOoFooOio`Kh1d7`oo[cmol0o_ko1o@=0?oaooclmolAj_omG000
7FGTo?kjo^gWoo;jn_l1l<gn00V/jN_oofTH000QnAT>61D3019eh?ool>@A001F
oOl2oOOeo_l>n_ocoDL06_ogiR@04bXLn@L>52<?45NZiOooj:H022LFn0/=8a0J
0Uc?oncomAhO]nGmoag[onOTgS0Z02Son_ogoo[ol?ook30N04CemOoFooOio`Kh
1d7`oo[cmol0o_ko1o@=0?oaooclmolAj_omG0007FGTo?kjo^gWoo;jn_l1l<gn
00V/jN_oofTH000QnAT>61D3019eh?ool>@A001FoOl2oOOeo_l>n_ocoDL06_og
iR@04bXLn@L>52<?45NZiOooj:H022LFn0/=8a0J0Uc?oncomAhO]nGmoag[onOT
gS0Z02Son_ogoo[ol?ook30N04CemOoFooOio`Kh1d7`oo[cmol0o_ko0O@=0QX5
0?oaooclmOl>jeH0:3H<X?OkgOkolokko_lCoOSioOn`TD=20:7nh_oI4ADZRLKi
cROA[7MB<REbj__eoa4L@`J0e__okNcooncon?khod00?Ooon1P1F:6KnIl?XiQE
8bLeQooonid04XbDP_VH;iVIR2X0@mGoonh53L[jooKom_ckonYT0Yh[5mORongo
mOo_ooo[:APB<I?4o]kdnOSo1P0ao_ojoo7ho`3no_l7m0d0oo7oo?ceo`k[EP0X
=PbPmo_Mo_oco__noa?mn?Wmok2A@d80XOkRomTA5BZ9a_W>9m6/Me8b9G;ZnoGo
4Aa31X3Fnoo]k?ook?oho_So@00moooh605HXI_iW`nSV5DS9cF7oookW@0BS9B2
nIP_VIV8:P13eOookPD=b_[om_ofo?_ojV@2WR/Gen;okOoeonooon/Y618aTlCn
g_Cin?l6037noo[olOSo0?kno`Od3@3olOolo?Go3^]F02Pf3:3gnmgnoo?nnoko
4oghnOgo/953@P2Qo^;ofA4E:XW6nLhWdJagDS8UL^[kmOlA74<6P=Kkong/ooo/
ooSnn?m003goooPH0ERQVoVO3j>HEB<W=HOooo^M01:<U8;iV2nIVHPZ04?Eooo^
1@g:n_ofooKlnooZI0:N:aOGh_o]ooGokooojbTH4S6Ca?kNm?Who`H0<Okon_oa
n?l0o_ko0O@=0QL50?oaooclmolWn?oCFAYRP1@OdOoan?olooOhmoC`koChb48a
aJ<ISOoce6D;^?7ojOSo9?GfolPS5:Sekol0ElPN2TG7ookWoooPonKalohn257Z
ooL=2i?go`omon_GT`LRkOkjT00Wj_ofnOl_koooc2<0KoWlnPhDg_oom_oTonoo
i@0^ol4jJLSojOoeoo;oonHoC=:H<Cmko?o[n?l604kol?ooj?So0?kno`Od3@3o
lOolo?Oo9oSodeTJHX0D7m7olOSoo?ogn?Odl>odn<Q2<LFS6HgolmAU2kSaonWh
obCem_o88aBXmNoo05O87PY5aoonioooh?oVlO?n?PQAj_og3@^Cmol?oOo[ei<7
8^gnnY009n[om_Wo;noool`S06oio?X>5=koooKoi?o_onD0;_o1>VW8onWomOob
oooV?dcBV34oNocojoSo1P1>oo3oonSho`3no_l7m0d0oo7oo?cgobOhom=I6V:0
51oAoo7hoocomoSgm?3_m?S8@S75XaV=oo?DI@^hlOoYn?lTmOKob2<DZ?G_o`1G
b1h:ALOoo^Ooon3oi_7coSh8DN[om`d;ToOo3ogojmNC1b;]o_Z@02OZooKiobo_
ooo<8`1_nOcj3QCNooofonCokooU02ko`CYYb?oYooGol_ooiSm<dYPa?g_lon_h
o`H0C_o`oooXn?l0o_ko0O@=0R<50?oaooclmolCiOoNHPAOeH@0T?oom>cfookj
mo_noa3kIP07m[8AQOoodBl`n?oolOWe6O[]noof7`2<oo?_063oV3H0M_[ojo7l
m?W/o_l:?@0ek_ob0P>CoooimP3ao_l;eP<0kOgoRP0Pn_oonOL_oogoodd0C_Sn
o`h6fOWhooWPonWo[@23o?if69Wgn?ojooCom]M4J_oX8`06oOognOl7n@1MonOo
oo3ho`3no_l7m0d0oo7oo?cgoa?UomiR15oEQ02@ooodk?Koo_[gnoko4?]V00Of
/Q65oooA;c3hoooanODIn^gkooHO08colnl0H?nH=P1fn_o[lOcdnNcno`Xm03G^
oo820i?oooWf0?7no`_F0`3]oOn:023joooimboooOooC@1>n?ko3PKInOSonN3o
jOn]08?loWHHVOOhoo[om?ofedAZonPS00KmooOio`Oi05goioool?So0?kno`Od
3@3olOolo?Oo4nGogV84GmF4093oooC/m_onn_Oko_l@nfH01oJb4HGoom4_<?So
oo7imAWjkO_omQl0S?ock`1PoiPf07Kjon_ao?Cik?ko2Sd0=NkolP83TooonOH0
lOko2mH30>gmohX08?[oooWg;oomoom=04kho_l>1]Win?oih?oYojd0PocnMQRI
moSon_odooKGA6[oj2<01_gomoWo1oT0GOoWooo`n?l0o_ko0O@=0QX50?oaoocl
mol>j?o[K@1:oma5CY[/mNWfo_l0oOko4>kC8a][m9/0/?Gnf1UKjNOKmolHn=ke
f2D0KOockP1>oon]=c]]`?3_l?ojoOko2T<0:ocol`T<ToWanOl?jOOQnM`Q2noo
ohl;7OChmoSo;^gWmcd0E?oko`D0fo_aooO_l>^IBGK7io_B4DF=oockoo3on]Ho
Ioo/T3X^T=G[nOl7mP1BoOGhoogho`3no_l7m0d0oo7oo?cgo`kXon]]04[og4E>
V^cejOKno`3mo_l@k]<S6f_dV`2`mOkH6E_Yim_goaShg_GH9@1]oo?^04koojdg
>fg0l>o`oo[mo_l:@`0[o?oc2@bCnO7io`oYmn7ig24;koooS`/Mm?Sgn?l^kNOg
?@1Doo_o1@3Kno7omno`jiU9M/OWnm8AAHgoo?_ol?ojeSmWonb@>Rj@eN_io`Of
05;mmOSooOSo0?kno`Od3@3olOolo?Oo3^Sojfd0B_oLADjJk?GYm_ko0?gnoa3^
db<KJoBK0;3eo]PIFnWWfoOo6?SNmMPU06golnh0C_oo[CLkKL3`ko3on_gno`Y3
02_loo<939?ilOWo3nWghOWL8@__oon?2agdn?Ohobk]ioLm05Conol50=_klOog
ko3[VDUfanOkdQ55SOolnoo`oo[F?fOok90j;Y3EjoWo1oH0D_gen?omn?l0o_ko
0O@=0QX50?oaooclmolVk_oMJP11on7/9@NOmooom_ohl_gokKR:3FSimYH0kNS[
]P1oooo<n?lWlooWkN]D03WXhOTV>n7oj^HV05g`on_lmOcoinQ02c[gondB7J7o
n_Wo3oSoiocoGQk9m_n;627el_[io2oZmOoo>`17nnoo0P3_onginOoBl3@0onOm
nOl^02ComOSlk?oohT1NoNGokYh0?:oho`D4A_ool?7go`3no_l7m0d0oo7oo?cg
obK^omeZ047ohN`U1iogooofooSboOo]^8X=J?WfUP3]j>^f07ooolchobOconO]
je@0>NSQnBHkhOoZiRH0GO3ojoceo?oWj40;>_OokA8MXOojnOl?n?oWo?mN7/Wf
oh/H8OGbn_Wl;n[eoolk04Okkol20>ookOWiom;`=03oiogiobh09?oen?c/oooR
@5kmiOo^WP0l[oSo1@A6ooo`lOOo0?kno`Od3@3olOolo?Oo9^kogFX0@OoQk2D7
WoOoooKon?;monfhRPeXnOJF0>gXjkH0Ooooc?So9o?oing[E00ij>7i9S_Qon[V
9P1Ml?o[o?GlonOX@0/jmoo]4QfQoo[io`ohonOloehNbOKoRaPQmO;jnO`_j_Go
oc/0Ao__o`80koo]nOWod_0d0?oWoOWo;P0TooGho>coon90G_gUonjN03b_n?l5
14Kooo3amol0o_ko0O@=0R`50?oaooclmolWo_ooD`=8n?kn?@00onoljnCooloo
l9T0X^;mnJ80V?giY@2Ln_gkm?Wo9^_ooOGn@aXSooGk04GooogocTd0EOooh_oc
oo;a<010ooWo4P2Oo_So3n[oonkoRA>Doon?00KbooWhoaGZool008Soo_l20=Kl
noooeomm01_mo_lUm>E40<7omNkoonSQ=UGkkogog6`;0?ohmOS`ooo[o`19oocg
ooWho`3no_l7m0d0oo7oo?cgobOnoomC0dSho_hm003okoc[i?oocoo`V@2Rh_gi
XP2HoOVU09cjoO_dnOlVjoommOi36R?omO/0AOoooOo>C@1EoooRoo?ol_4`043o
nOlB09onn?l?j_ook_n94iCoohl01_;onOSo5N[oo`00R?ono`80e_ckoooGogd0
6ognobGdiD@0`Ooek_ooj>4fEO__oOoLK0/0ooSen?3oon_o04Woo?OonOSo0?kn
o`Od3@3olOolo?Oo9okooe<3B?SnoSd00?o_o>_Tooo?oo2I0:;RoOVR09SmnJD0
W?[mnoCiobK[oogeoT<J8ooen`15ooomoli=05Goon;olooblC00@?oioa80Wokh
o`oZooo^ohTCU?ooS`06l_oin?lEj_oo0028ooko0P3Fo?_oomOoO@0KoOko9OCU
A031ooG^oooXhCIEnnomoma/2`3on?Ghl?oojol0BOolmooin?l0o_ko0O@=0Rl5
0?oaooclmolWo_ooD`=8n?koV4lJ`nSok_Oln=coSR`IaoSolYh0WOooUP2RloSo
noWo9_Goo_[o@aLQooGk04GooogZolm>87GGn>kWnoGoB`4XooWo4P2Oo_So3o7o
ooGoT1ZPjNn55BKWj_WioCoMd?_`BDF[kOgo0P3GoO_oiOo;6@^6oO3fkn?HM328
e?oio?oojS1]o^ohonfOGTVRc?ooi?3okOl0BOolmooin?l0o_ko1o@=0?oaoocl
molWo_ooD`=8n?koV4lJ`nSok_Oln=coSR`IaoSolYh0WOooUP2RloSonoWo9_Go
o_[o@aLQooGk04GooogZolm>87GGn>kWnoGoB`4XooWo4P2Oo_So3o7oooGoT1ZP
jNn55BKWj_WioCoMd?_`BDF[kOgo0P3GoO_oiOo;6@^6oO3fkn?HM328e?oio?oo
jS1]o^ohonfOGTVRc?ooi?3okOl0BOolmooin?l0o_ko1o@=0?oaooclmolWo_oo
D`=8n?koV4lJ`nSok_Oln=coSR`IaoSolYh0WOooUP2RloSonoWo9_Goo_[o@aLQ
ooGk04GooogZolm>87GGn>kWnoGoB`4XooWo4P2Oo_So3o7oooGoT1ZPjNn55BKW
j_WioCoMd?_`BDF[kOgo0P3GoO_oiOo;6@^6oO3fkn?HM328e?oio?oojS1]o^oh
onfOGTVRc?ooi?3okOl0BOolmooin?l0o_ko0O@=0R<50?oaooclmolUo_ooD`=8
n?kom;eJD:oon?[mo_ke7@2>lOoojY`2X_ooP@2^kO?eobCmoolm3aoomO/0AOoo
oOo/nNmU02k/n__ok?M>2BKonOlB09onn?l?m?onn?n=6jgoohL804DG9?T0?ah0
5Rakdoo`o?l30MSmn_gboh0IR?oaooomoooUVdYTnoo_l_oa8Wcol?;oomg5aA8_
V?Wonoolo`19oocgooWho`3no_l7m0d0oo7oo?cgobGnoomC0dSho_od_EY@[ooh
n_gno_DM08kaoooZW0:Roon10:k]loGo9?goocd?7ooen`15ooomoncikfD0;^cj
noo/mdh99_oioa80Wokho`odookhohdK[OooQ`P0AALTn@0o7P0F;7_Coo3lo`<1
f?gjoO;oP1V8oo7ooogoonFKBVCkonoboo4RO?o`l_oogLG54RnHnOokooco04Wo
o?OonOSo0?kno`Od3@3olOolo?Oo9Okooe<3B?SnooBmFU2_ooSjoOknmAd0S_7o
onZL0Z;ooh40[^gcmOlToOoo?@lOooGk04Gooogok?W_I@0^k?[koncgCPTVooWo
4P2Oo_So3oCoo_SoSA^]oon720155bCi03lN01H/Nm?ol?co0`7HoO[ml_n06HSo
lOoooOooiI]:I?_oko;olB9loo3boooMaLDB;iSioo_oo?l0BOolmooin?l0o_ko
0O@=0RT50?oaooclmolFo_ooD`=8n?kooo>]1DJkoo7loon?04Wno`glj:4:Y?_o
N@2gl?GooOOo9?Sooc059Ooen`15ooomol_TomDA06G^oooYgST<?Ooioa80Wokh
o`odoOKfogdF_OWoU180LUERnFhZM50k07oLongjoP@3f_kinnR`3eoYol?oo>go
o_o60`2aoo[MooHKL_odlOko4Ogo9@0CbOoooO[o04Woo?OonOSo0?kno`Od3@3o
lOolo?Oo5_kooe<3B?Snoooc[@E6^ooao?ooS`19o_l=o>RQ2ZCkogT0]o3eoogg
obChool`1BGomO/0AOoooOo;i?oE4@1Uk_oojMhi33gonOlB09onn?l?m?gfm_mm
5[gioi@B079EH_U^:WA@>`1og?o]n_h40m[nnO_X/0mOjOo3ooc]ookoaP<0/Ooj
gOof6g;om?7noa7mobD04lWooogjo`19oocgooWho`3no_l7m0d0oo7oo?cgoaKn
oomC0dSho_ooljd5A[_olOcoohl0BOko3OcXX@ZTnomi0;O`mOommolTn?oo<0DU
ooGk04GooogobnCoeA40INkoonWN>@`mooWo4P2Oo_So3oCmm_KoOAJmnOnD4P1b
EF;iKRYdD3/0OmcokO[n10?Jo_Wkj;0?GnWo`oolkOonolH30;7on]gomQ]booCa
o_lAoOlU01?9ooomn_l0BOolmooin?l0o_ko0O@=0R<50?oaooclmolWo_ooD`=8
n?komOGo601Oooo/l:hSD]com_ohjjXAXo?kRP2]m?comOOo9?Cooad0>_oen`15
ooomio[kkno@H`1_]ooomS/6?ooioa80Wokho`okoo[joFPCfM?nWQDJl?oonODZ
l?ooLT==e_ohoPD5g?oinOab6kglom_ok^;mhOoP=S5BmOoOn?hWHooimOco3ka<
;G_:nOo[o`19oocgooWho`3no_l7m0d0oo7oo?cgobOnoomC0dSho_oemOlH05oo
onc`[R=Bg?ofooS[ZQ6Slo^:0:gdo?oemolTm?oo7@0jooGk04GooogWn___km1S
06ngooof>`HoooWo4P2Oo_So3o_on_[mJ1?IdojN5A[`oooimB[`oomb@dgFooSn
1@GLooWio78K_Ocofoo^h_gQon0f<E;eomohoRMSooWeo?l?_4`]Nl[ion_o04Wo
o?OonOSo0?kno`Od3@3olOolo?Oo9okooe<3B?SnooGeoaP0Goook?2^8e;LooKo
n>^Z4J?cnhX0[OClooGgobCdoolM03[omO/0AOoooNOjnno_d6<0KkOoooHk1Soo
nOlB09onn?l?noojn_eX4mWCoYhE6_3oooWe:_3oog93CMKon?h51MconOWlLQ^m
o?oKonkRoN7oh3HaD_GogoSn9f?onOGlo`nlC2ekb_Wojol0BOolmooin?l0o_ko
0O@=0R<50?oaooclmolWo_ooD`=8n?koj>goMQ<`eOoJQ3<4bOoCjoojl:`@XO7e
]P:8l?oomOWo9_gjmOoh3@EOooGk04Gooogcoo[PoOo4A@10b?ooE00ZooWo4P2O
o_Co2ni=4?W_oih00>?gl_Wm?mGoojLI3ZSom_d61mkon?M;000Q1b@/3b0G5@0J
9`005/Som_Ko>V;ooOWloo_ck?cWWS0MWOojo`19oocgooWho`3no_l7m0d0oo7o
o?cgobOnoomC0dSho_oXkOmf4c3EomZ4<`C9om?[oo[`[12QlOFf0XS`oooenOlV
oO[eooP=1EoomO/0AOoooO?on^3molA50438oomD02[onOlB09onm?l;kTd@nNoo
WP00hoObnOdoeOooYaT>Z?ofo@H7g_ohmd/0024792`?81LE01XW000Fb?ofm_lj
H_omnOcono?/o>NN<1fMoo[o04Woo?OonOSo0?kno`Od3@3olOolo?Oo9okooe<3
B?SnonS]ogHC<=GofX@c1<Wodn_on_2/4:7amKH2R?3oooGiobKmn_Gon0d5Gooe
n`15ooomloojh?goa4D0@<Sooe@0:_oioa80Wokdo`_^CA3ikonN003Smo;ioCoE
oonW6@jXooKm1PONooSgB`008@LT;0lP5aD06RL001K8ooKfocYRoogio?oklncl
iih`7Igon_l0BOolmooin?l0o_ko0O@=0R<50?oaooclmolVo_ooD`=8n?knn^oo
fghfHNcR>`12oooJl?oolZL9X?Ojk@QDh?odn?lVno[loo@54h[omO/0AOoooOoc
jOoon^?M9aiV`OmH02SonOlB09onmOl<m]4V0?ohohX76>knooWh?oohon0T7I?T
m?`62=oomoH04e0l9ba74Ce2;C0[?F8g27kdoo[`>fWnoO_ko_ogkN_oiDT0>]Co
o`19oocgooWho`3no_l7m0d0oo7oo?cgobKnoomC0dSho_kjkooKOSIQk>8k04;o
om[`ooobY`VPmo[]25CPooChobKkn_com0DCR_oen`15ooomoo?YooojhmdW7VK1
oeP0:?oioa80Wokeo`cfdBH0ooSoRPLHk_konOPoooSoh2@MTnCdo0H8googmP0C
D3`W;4LA?D8]<2/mHSL8O_Con_0kJOkmno_nooO]jooUB@0je?oo04Woo?OonOSo
0?kno`Od3@3olOolo?Oo9_kooe<3B?Sno_[_om]n=V7/hS/0@_oof_3ooo:W2J3g
n^d8E>3om?So9__jo?od1A>:ooGk04GooogolnWooo[SgBLNI/7oF00XooWo4P2O
o_Go3?KA9P3on?n:1aS^o_oin3oon?oP91fCi?Cl1PSOooOf01=@?2L/Aa4m@Rd`
:ceR=`Qnm?ojl3]Yo_gknokomng[onE903[Dool0BOolmooin?l0o_ko0O@=0RH5
0?oaooclmolVo_ooD`=8n?kbooC]oma:0;;h<`2=om_onooolZ42X?koo`X]d_o]
n?lVnogooo@27ZSomO/0AOoooO;oonkaoooi`DPPHM=31CconOlB09onn?l>loSg
i[@40?okiW<G;n?WmolZi?oo20>=oo?l1PWPooOe06OYhOoYooKcoo7oj=ko^@e0
`OokfC5]o?gkn_ko4?cnoonZ6@:9ool0BOolmooin?l0o_ko1o@=0?oaooclmolV
o_ooD`=8n?kbooC]oma:0;;h<`2=om_onooolZ42X?koo`X]d_o]n?lVnogooo@2
7ZSomO/0AOoooO;oonkaoooi`DPPHM=31CconOlB09onn?l>loSgi[@40?okiW<G
;n?WmolZi?oo20>=oo?l1PWPooOe06OYhOoYooKcoo7oj=ko^@e0`OokfC5]o?gk
n_ko4?cnoonZ6@:9ool0BOolmooin?l0o_ko1o@=0?oaooclmolVo_ooD`=8n?kb
ooC]oma:0;;h<`2=om_onooolZ42X?koo`X]d_o]n?lVnogooo@27ZSomO/0AOoo
oO;oonkaoooi`DPPHM=31CconOlB09onn?l>loSgi[@40?okiW<G;n?WmolZi?oo
20>=oo?l1PWPooOe06OYhOoYooKcoo7oj=ko^@e0`OokfC5]o?gkn_ko4?cnoonZ
6@:9ool0BOolmooin?l0o_ko0O@=0OH50?oaooclm_lGn_V005Ojooo`oooTonDP
0a5ei_omoo[`o_l;S2JFooKoaS00:I75nLh?dl>9=@`mXNklooXQ;oooioSo3/EJ
3`lb=Akgoo0U43^/XOVT3jFMMRl0:Ikon_nE02CWom_hoaK[om`Y4Z?kom4M3MWo
L36Ed?oono_mnOWo1oL@58;oicIln?l=k>Soole;07@UEnKok>[go`3no_l7m0d0
oo7oo?cfoaOjnH00Eo[ooo3oonCoiB034GGVoogon_3no`^<9YKom_o6<00YTLGi
cPoC`hTe33fQk_conR4_oooWn?l>aEX?3c8e7_Ool2D@>jbQnJ@?YIef;`0YW_oj
oiD09>OofoSo5^_og2TBXo_odAd=fOm`<IG@oooknoginOl7ma0DP_oW=Wcho`g/
j?oocD/0M2EGi_o/j_Oo0?kno`Od3@3olOolo?Ko5o[iP01Gn_ool?ooi?oU80<A
MNKooOojl?ko2h`VU_ofolH`02VAaOW>3m?3RCD<?J7^o?oj8BooonOho`k5FPl?
<SDNmoo`9A0k[:7iY0nUWGH_02VNoo[oU@0TiooKn?lFjooL:A:SnooA7@gIog0a
UM3ooo_koOWio`Og41B2onLfO?So3NcXooo=B`1d9EOVoncZmol0o_ko0O@=0O<5
0?oaooclm_lAlmiU04[Tl_o^oooUooUR01R@oOl@nncnknZ58goYoooHH`h43POi
2od02aaee_oon>4K:?Olm?Wo0o_e_UKn00P9n_oI7000707i0`H4000@GK3/o_l5
S@0Pc?oZnOlGl>Ood0D0Q_gogB@BdNa?0<3Wooogn_oknOl7n@/0B>OX=4gho`gf
kooocF891@0id_oin?Oo0?kno`Od3@3olOolo?Ko4O?NI@1:i?;ok_ooiOoiHP0H
T?go4?_/o^oZQB=ojOoof6<>10h7n@_m00/LMMKoooSQ6bSgo?Cio`?kmKiFoP08
2O[ofA`001`1n@<6100045f`k?ko1Hd08<coj_Wo5o3Wom0508KmomdT4]7/C`30
iooomo[onoWo1oT;04SWj3A=n?l=m^oooleR2@D0>M;onOSgo`3no_l7m0d0oo7o
o?cfoa7cgVD0B^CbonkoonGonF80693moa3kk?k_jXDSOnWoomQS3P@>1oT;o@0;
77GFooohhA/XmocdnOl3noFnE_h020WjomTL000L0OT31P@0011M/>cno`F=023<
on[ioaO`ioo@1@26oOoM91;Ak4l0`>OoooOjoo_io`Oi2`18inPdCOSo3OK_ooo=
HPT503WBooWhmol0o_ko0O@=0O`50?oaooclm_lVo>bC>hKfm_o[o_o[oonj@f32
ooobn_gnonkf]6BUj?oom/RFJCdKnA<572TiEXoCo_l6lnAFH?KfoOWo3n?ookUE
:dA/nO[SLThbA2_i>0m8;Rm_coook_on[4]McOognOlGk>gojdXYYOoY`CPQYj`b
0o7ooo[enooln?l6GC=Vj?icOoSo3_ggoooQX6Xn=H?Yoo_jl_So0?kno`Od3@3o
lOolo?Ko9_c/Tc^6m_Kojokojooo^T=P`_ool_[mo_o^m[ATYNSoooK8UVTm6oTC
1A`Y>EJ?doko1_?TEV3fm_gio`oSooniEB]4K?Wjhg9><T@[nCP?B2h_Klooonko
oZa;GLgomoWo5nc]on]::JGojL4h8JN/<P?aooojmO_oo?So1UdcI^SnLgoho`km
mooohJ1Z?SF3jOokn_;ho`3no_l7m0d0oo7oo?cfobKlk9<kQ_Kfon_non_ookY3
H<;ooo;joOkok_JdI:GXooofb9IY?A_i4`DL:CUFSm?no`Kci5IPm_KmnOl?hooo
^ED[A6cin^=bCS94:oTh3dP^;fo?ooo^ooj/Beg=ooOioaO/kOo[BRVUonW1>26W
[383lOoon_Gkoocho`IM<fKXoW=on?l>oOOoon6PJShePnWono[bn?l0o_ko0O@=
0Ol50?oaooclmolFn?goj[gUoogojOSomOgom]W>l?o/h_Sno`gcooG1kooonOgo
oo7PfoWo3n[^kNglooobooOo`l[on__io`o^o?oehM[PioGgnnSXgnKQnNd?nO;^
lOWmnO?oon[8c?3on_Wo3o_WoooGb>[coooihooofoGno`Cin_kmmoSo1]SDc_oo
b_;ho`klnoooo^WFi=SdooGcoNgho`3no_l7m0d0oo7oo?cgoaKhoOoZ_NGooOoY
n?oeoOoffLk`oncRn?ko3O?omL7_oooioOoolN3KnOl?j^k]kOcooo;omoo3b_oj
noWo3nklooGQf^3WmOOkj>SOi^7ik@oil^kanOgiloooj/S<l?ojnOl?nnOoomO8
j_?oooWSoooKmOko1?Wjo_ggn?l6f=C>ooo:l_So3_ckooonjMKTf?ComO?mkOSo
0?kno`Od3@3olOolo?Oo5_SmonZmiOomonWhooGmooKIc_3ok>;ho_l=looe`Noo
ooWmoooah=_io`oZk^g]o?ool_ogol?:oo[knOl?k_comN7Jh>Oemo_Xj=oVhOW]
3oWbk_7ioOWcoooZb<c`oo[io`okioooelSZlooonN?oom_eo_l4nO[noOOho`KH
e<kool[bn?l>o?_oookYe^CHm?oelog]n?l0o_ko0O@=0Ll50?oaooclmol>i?Co
oocoonkok?Sooo7no_lEn?[Uk?olm_oVooo[ooofk?7ooo_oooWio_l6noWooo[n
nOgo0O_in?l2n^kko_l3n_WfloCo0?kno`C]iOWooOco0O_lnOl2n>3[oOl@k]Oo
oO?olNSooo[goOoon_Gio`Khooolooo[n?onnP3knOl3iO?on_So0?kno`Od3@3o
lOolo?Oo3^Cdooolooo^onchoooao_ko5OSjiNcoo?Koi_oojooom^caoookoooi
nOko1__iooojo_Wmo`7knOSo0_[^noko0o[im_?do`3no_l4kNGiooglo`7ko?Wo
0_SPjogo4>kGoogcoo7Xooojmogooo[enOl6n?ooo?oojoSoo_X0noWo0nGcoo[h
o`3no_l7m0d0oo7oo?cgo`kTm?ooo?ook_o/n?oolOknoaGhn^G/oocfonKoon_o
ooK/lOoonooonOWno`KknOoon_kioOl1noWho`;jk__no`?jnOKcm?l0o_ko1>gU
nOomo?l1nocio`;hh>_moa3^eoomlooaj?oon_OmooojmOWo1_Sooocoon_hookj
0?_io`?Uloojn?l0o_ko0O@=0OT50?oaooclmolVnOkmnooomo7hmO_oonk_oooZ
kO_gooogkooXooo`ooObm?_omNW_n?l?jOOhin7^o_oln?cno_chnoSo3_cfo?ce
m?[noNOoj_[TkoWd3^K]mO[inO_nooOkooobloSo1OKinOOhnOgo3O7gooo]n_Wa
m?ooo_SjnOl7jooljoook^gio`olo?[el_?jooG^ooo]nOofn?l0o_ko1o@=0?oa
ooclmolVnOkmnooomo7hmO_oonk_oooZkO_gooogkooXooo`ooObm?_omNW_n?l?
jOOhin7^o_oln?cno_chnoSo3_cfo?cem?[noNOoj_[TkoWd3^K]mO[inO_nooOk
ooobloSo1OKinOOhnOgo3O7gooo]n_Wam?ooo_SjnOl7jooljoook^gio`olo?[e
l_?jooG^ooo]nOofn?l0o_ko1o@=0?oaooclmolVnOkmnooomo7hmO_oonk_oooZ
kO_gooogkooXooo`ooObm?_omNW_n?l?jOOhin7^o_oln?cno_chnoSo3_cfo?ce
m?[noNOoj_[TkoWd3^K]mO[inO_nooOkooobloSo1OKinOOhnOgo3O7gooo]n_Wa
m?ooo_SjnOl7jooljoook^gio`olo?[el_?jooG^ooo]nOofn?l0o_ko0O@=0N45
0?oaooclmOlNm_CoooKom?olnoockooahoOoo?oomNoon?oolooem__o0?[ioOko
3?[amo_fnOkbmoG^o_cho`kgnOoml?Won?o[on;ol?cho`7no?ko2?GXooC_moS`
m_So5_Cooo?bkoKoooSYmOoeiNWmm?OoooOin?l7kooZi_oonN_go`gmnOGbloGo
k?gon__ol?So0?kno`Od3@3olOolo?Go7_KdooofooCoo?_olnoolN?goocoooG_
ooSooo?omOKko`3jnOgno`cjlOOkm_Wnl_Oek_kln?l>moWooO3iooSojooRoo3l
n?l1o_cno`Sej?odkoOhl?KhoaKdooocl^ofooohjOGomNGYoOCgooognOSo1noo
j^KoooW[mol=oOWel_?eoncmoo[koo3ho`3no_l7m0d0oo7oo?ceoakfm?oom_od
oockoo?_oo7SmooloooekoohooocooGfnol0n_Wmo_l<n_7gnoKio_;gmNkno?So
3_Oioog`nOohon_oh_o`o?So0Oklo_l8mNSom>ogn?3fn?lFm?oolo;_m_oon>We
ooGUjOgdmooomoWho`O_on[VoooijoOo3OgimO;cmOo/oOojnoo`n?l0o_ko0O@=
0M/50?oaooclmolWlOW/mOoom_odooc_o_[eooonooo_m_ofh_ojookaoo[koooc
o?oom?Wm3o7jo?Oloog/mOonooohoo[ho`7ckOko2Ogojoo_on3oo_oio0[dn?[g
l_?loooin?Co5^Onlngoongbl?;oooOSl_ooo?coo_3kn?l5jOojloocmol0oO_o
1_gok?3om_Wfo`3no_l7m0d0oo7oo?cgobOanNceooofooCoo>onn_Goookoonof
ooKRoo[oo_7on__ooo?looodnOd?lO[lmocooNceookoooSon_So0O?]o_l9oOo[
onooh?onooWl2_Chn_OblocoooWhm?lFiokckOookO;`l_oomn?booolo?onl?_h
o`GYoo[coo?go`3mnol6oOo/l?ofnOKo0?kno`Od3@3olOolo?Oo9o7ik?GoooKo
m?olkokjmOooo_ookoKom^;on_onlOojnooolocoooCio@oan_cgo?omk?Goo_oo
n?ojn?l1lngno`Wmon_okooPookonO`:m?Sjmo;co?oonOSdoaKWo_?]ooo]l_3b
ooogho;oooclook`noSo1NWon_?oloOo0?gko`Kmonc`ooKim_l0o_ko0O@=03@5
0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko
0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o
]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3o
lOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kn
o`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1
okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0
oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3n
o_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaoocl
POnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@5
0?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko
0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o
]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3o
lOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1okKo0?kn
o`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0oo7oo?b1
okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3no_l7m0d0
oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaooclPOnfo`3n
o_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=03@50?oaoocl
POnfo`3no_l7m0d0oo7oo?b1okKo0?kno`Od3@3olOolo87o]_l0o_ko0O@=0@<6
0?ooo^Wol?Ko1Oc`h]K<aoWD3mcKf]SFeM?Bb=;Ie<_?hoNOo`gknokon_CMfmSH
gNKamoWKnN8CgNSYh>7/kN?SiNW^loSkoNO/m?cdo`cbomgoo0H0ooonjOo`m_l5
o?3Re/c7nM@?g=_Jf=KEdm;8d]WDbloSmioo3O_ko_ojm=gKf=SMi_7gnM_ihQ?M
j>WPhNc]hn?UjNkcn?_mincdo?Co3?;ogOol1P3oookYoo3fo`Gll>;Fc<Oie0oL
fm[He]GCd/SBfMC;cn?gWol=no_noo[dgM_Hf=gVlOOifoWR4mgXjN3Qk>gShnGY
k_?hnogWk?Clm?l5l_oMoo`60B470NSioo_ojoSio0O^j^?JclJo^oW83l_:bLS6
a<?3^lC:a;^ncn6Qo0ooo?OhnocglLG3_kk2b];HnL[icQO9e=G<cMSId<W:cM3D
f=[Lj>ccnOcmo?_io0komooXonP00NSioo_ojoSio0O^j^?JclJo^oW83l_:bLS6
a<?3^lC:a;^ncn6Qo0ooo?OhnocglLG3_kk2b];HnL[icQO9e=G<cMSId<W:cM3D
f=[Lj>ccnOcmo?_io0komooXonP00NSioo_ojoSio0O^j^?JclJo^oW83l_:bLS6
a<?3^lC:a;^ncn6Qo0ooo?OhnocglLG3_kk2b];HnL[icQO9e=G<cMSId<W:cM3D
f=[Lj>ccnOcmo?_io0KomooXonP00@`2C?3Xo_l1j_oin_co0_chm_So3_knoO_j
n_WfoOokl_?ooj7j3okimOKjnoKanoSdl_Cho_oaoPCjoooloOko0o_ko?kmo`O^
l??fn?SfmOWj2NSSoM;deB]<l>Sno`7ZooWjo?l2o?Sfn?l>o_kmno[jnOKmoo_b
loooXOX?o_Wem_[km_7kn?Cbm?Snoo7n1?[ooocmo_l3no_lo_go1nk`loKhn?Ke
nOX9j>?md_CE:dc`j?ko0N[onO[lo`;ln?Kho`kno_gkn_[im_gono;coonQnPon
nOGfn__flO_hm?;dn?kolOh4n_ooo?gno`?knocnoOl7k_3cm_Shm_GinPKXhogB
m=D[09X702h070D60Aoi3>80006Q30L@2`L93Pl;1^@00@42n00120Sn2@881`Ki
30hG3QX05Qh002h070D60Aoi3>80006Q30L@2`L93Pl;1^@00@42n00120Sn2@88
1`Ki30hG3QX05Qh002h070D60Aoi3>80006Q30L@2`L93Pl;1^@00@42n00120Sn
2@881`Ki30HG3QX05Qh0003o\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{214.938, 299.938},
  ImageMargins->{{83.6875, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Principales fonctions", "Section",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "Nous d\[EAcute]crivons tout d'abord les fonctions servant au \
d\[EAcute]coupage par une ligne horizontale ou verticale d'un rectangle d\
\[EAcute]crit par les coordonn\[EAcute]es de ces sommets dans l'ordre horaire \
\[AGrave] partir du sommet inf\[EAcute]rieur gauche. Pour des raisons de \
constructions graphiques qui n\[EAcute]cessiteront l'usage des polygones, \
nous convenons d'adopter une description compatible avec celle de la fonction \
",
  StyleBox["Polygon",
    FontFamily->"Courier"],
  " (polygone ferm\[EAcute] dont le dernier sommet est identique au \
premier)."
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["2.1. D\[EAcute]coupage vertical", "Subsection",
  PageBreakAbove->Automatic],

Cell["\<\
Le principe consiste ici \[AGrave] choisir une position \
al\[EAcute]atoire (une valeur de x) entre les bords verticaux du rectangle \
consid\[EAcute]r\[EAcute]. La premi\[EGrave]re d\[EAcute]finition sert \
\[AGrave] d\[EAcute]couper un rectangle en deux. La deuxi\[EGrave]me d\
\[EAcute]finition sert \[AGrave] d\[EAcute]couper en deux des rectangles en \
nombre ind\[EAcute]termin\[EAcute] plac\[EAcute]s dans une liste. On notera \
l'abondance des symboles utilis\[EAcute]s pour d\[EAcute]crire la forme de \
l'argument qui permet d'une part de r\[EAcute]aliser des tests implicites \
(p5_:p1 signifie que l'argument not\[EAcute] p5 doit \[EHat]tre identique \
\[AGrave] p1), et d'autre part d'exprimer le r\[EAcute]sultat de \
fa\[CCedilla]on simple. On notera \[EAcute]galement la possibilit\[EAcute] de \
r\[EAcute]aliser des affectations multiples: pa={r=Random[...],...,y2} et \
l'utilisation faite de l'ordre d'\[EAcute]valuation des expressions qui \
permet l'\[EAcute]valuation des instructions les plus profondes \
pr\[EAcute]alablement \[AGrave] celle des instructions les plus \[EAcute]lev\
\[EAcute]es.\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\(Clear[VCut];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(VCut[{p1 : {x1_, y1_}, p2 : {x1_, y2_}, p3 : {x2_, y2_}, 
            p4 : {x2_, y1_}, p5_:  p1}] := {{p1, p2, 
            pa = {r = Random[Real, {x1, x2}], y2}, pb = {r, y1}, p1}, {pb, 
            pa, p3, p4, pb}};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(VCut[rect : {___List}] := Flatten[Map[VCut, rect], 1]\)}], "Input",
  PageBreakAbove->Automatic],

Cell["Exemple : ", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(r1 = {{0, 0}, {0, 1}, {1.6, 1}, {1.6, 0}, {0, 0}};\)\)], "Input",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(r2 = VCut[rect]\)], "Input",
  PageBreakAbove->Automatic],

Cell[BoxData[
    \({{{0, 0}, {0, 1}, {0.33346168820647426`, 1}, {0.33346168820647426`, 
          0}, {0, 0}}, {{0.33346168820647426`, 0}, {0.33346168820647426`, 
          1}, {1.6`, 1}, {1.6`, 0}, {0.33346168820647426`, 0}}}\)], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, r2]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.2223 .60332 L
.2223 .01472 L
.02381 .01472 L
s
.2223 .01472 m
.2223 .60332 L
.97619 .60332 L
.97619 .01472 L
.2223 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oooo000B0008Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eo
o`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool0
0`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo
0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001o
ogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo
0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03
001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol0
1Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eo
o`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007oo
Ool01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo
03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<0
07ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001o
ogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03
001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0
eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Mo
o`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007oo
Ool0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool0
00Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<0
07ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06
Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo
00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomo
o`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0
=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00
Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007oo
Ool0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol0
0`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<0
07ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3E
Ool00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo
00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomo
o`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`00
1goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00
Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Io
o`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol0
0`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo
00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0e
Ool00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001o
ogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomo
o`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03
001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00
Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eo
o`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool0
0`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo
0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001o
ogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo
0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03
001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol0
1Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eo
o`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007oo
Ool01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo
03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<0
07ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001o
ogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03
001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0
eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Mo
o`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007oo
Ool0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool0
00Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<0
07ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06
Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo
00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomo
o`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0
=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00
Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007oo
Ool0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol0
0`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<0
07ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3E
Ool00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo
00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomo
o`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`00
1goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00
Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Io
o`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol0
0`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo
00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0e
Ool00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001o
ogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomo
o`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03
001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00
Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eo
o`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool0
0`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo
0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001o
ogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo
0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03
001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol0
1Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eo
o`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<007oo
Ool01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001oogoo
03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo00<0
07ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03001o
ogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0eGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Moo`03
001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007ooOol0
eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool000Mo
o`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<007oo
Ool0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06Ool0
00Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo00<0
07ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomoo`06
Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0=Goo
00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00Oomo
o`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007ooOol0
=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol00`00
Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<007oo
Ool0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3EOol0
0`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo00<0
07ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomoo`3E
Ool00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`001goo
00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Ool00`00Oomoo`0eOol00`00Oomo
o`3EOol00`00Oomoo`06Ool000Moo`03001oogoo03Eoo`03001oogoo0=Eoo`03001oogoo00Ioo`00
1goo00<007ooOol0=Goo00<007ooOol0eGoo00<007ooOol01Woo0007Oooo000B0008Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{153.312, 382.688}, {184.375, 43.0625}} -> {-1.16914, \
0.294965, 0.00587804, 0.00594429}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell["\<\
Sur chaque rectangle ainsi constitu\[EAcute], on peut appliquer de \
nouveau la fonction :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(r3 = VCut[r2]\)], "Input",
  PageBreakAbove->Automatic],

Cell[BoxData[
    \({{{0, 0}, {0, 1}, {0.09998291149734419`, 1}, {0.09998291149734419`, 
          0}, {0, 0}}, {{0.09998291149734419`, 0}, {0.09998291149734419`, 
          1}, {0.33346168820647426`, 1}, {0.33346168820647426`, 
          0}, {0.09998291149734419`, 0}}, {{0.33346168820647426`, 
          0}, {0.33346168820647426`, 1}, {0.3749358276785454`, 
          1}, {0.3749358276785454`, 0}, {0.33346168820647426`, 
          0}}, {{0.3749358276785454`, 0}, {0.3749358276785454`, 1}, {1.6`, 
          1}, {1.6`, 0}, {0.3749358276785454`, 0}}}\)], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, r3], PlotRange \[Rule] All]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.08332 .60332 L
.08332 .01472 L
.02381 .01472 L
s
.08332 .01472 m
.08332 .60332 L
.2223 .60332 L
.2223 .01472 L
.08332 .01472 L
s
.2223 .01472 m
.2223 .60332 L
.24699 .60332 L
.24699 .01472 L
.2223 .01472 L
s
.24699 .01472 m
.24699 .60332 L
.97619 .60332 L
.97619 .01472 L
.24699 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oooo000B0008Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Ao
o`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007oo
Ool097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo
00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001oogoo00Ioo`001goo00<0
07ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol01Woo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`06
Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo0<eoo`03001o
ogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol0cGoo
00<007ooOol01Woo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`3=Ool00`00Oomoo`06Ool000Moo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo0<eoo`03001oogoo00Ioo`001goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol0cGoo00<007ooOol01Woo0007Oooo000B0008Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{153.312, 382.688}, {501.312, 360}} -> {-1.16914, \
2.64993, 0.00587804, 0.00594429}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2. D\[EAcute]coupage horizontal", "Subsection",
  PageBreakAbove->Automatic],

Cell["\<\
Sur le m\[EHat]me principe, on \[EAcute]crira facilement la \
fonction de d\[EAcute]coupage horizontal :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\(Clear[HCut];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(HCut[{p1 : {x1_, y1_}, p2 : {x1_, y2_}, p3 : {x2_, y2_}, 
            p4 : {x2_, y1_}, p5_:  p1}] := {{p1, 
            pa = {x1, r = Random[Real, {y1, y2}]}, pb = {x2, r}, p4, 
            p1}, {pa, p2, p3, pb, pa}};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(HCut[rect : {___List}] := Flatten[Map[HCut, rect], 1]\)}], "Input",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(r4 = HCut[r1]\)], "Input",
  PageBreakAbove->Automatic],

Cell[BoxData[
    \({{{0, 0}, {0, 0.2615656733345574`}, {1.6`, 0.2615656733345574`}, {1.6`, 
          0}, {0, 0}}, {{0, 0.2615656733345574`}, {0, 1}, {1.6`, 1}, {1.6`, 
          0.2615656733345574`}, {0, 0.2615656733345574`}}}\)], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, r4]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .16867 L
.97619 .16867 L
.97619 .01472 L
.02381 .01472 L
s
.02381 .16867 m
.02381 .60332 L
.97619 .60332 L
.97619 .16867 L
.02381 .16867 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oooo000B0008Ool000Moo`03001oogoo0?moo`ioo`03001oogoo
00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00
Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo
00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?mo
o`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomo
o`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<0
07ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Mo
o`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo
0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo
00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00
Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo
00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?mo
o`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomo
o`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<0
07ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Mo
o`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo
0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo
00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00
Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo
00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?mo
o`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomo
o`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<0
07ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Mo
o`03001oogoo0?moo`ioo`03001oogoo00Ioo`001gooo`004P0027oo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`00
1goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06
Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007oo
Ool01Woo0007Ool00`00Oomoo`3oOol>Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03
001oogoo00Ioo`001goo00<007ooOol0ogoo3Woo00<007ooOol01Woo0007Ool00`00Oomoo`3oOol>
Ool00`00Oomoo`06Ool000Moo`03001oogoo0?moo`ioo`03001oogoo00Ioo`001goo00<007ooOol0
ogoo3Woo00<007ooOol01Woo0007Oooo000B0008Ool00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{153.312, 382.688}, {417, 275.688}} -> {-1.16914, \
2.02345, 0.00587804, 0.00594429}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. R\[EAcute]cursivit\[EAcute]", "Section",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "Pour permettre la r\[EAcute]cursivit\[EAcute] \[AGrave] un niveau d\
\[EAcute]termin\[EAcute] par l'utilisateur, nous allons employer la fonction \
",
  StyleBox["Nest",
    FontFamily->"Courier"],
  " dont le premier argument est la fonction qu'on cherche \[AGrave] appeler \
r\[EAcute]cursivement. Mais pour produire une repr\[EAcute]sentation \
graphique convenable, il faut alterner d\[EAcute]coupage vertical et d\
\[EAcute]coupage horizontal, c'est-\[AGrave]-dire appeler successivement, \
\[EAcute]ventuellement de fa\[CCedilla]on al\[EAcute]atoire l'une ou l'autre \
des deux fonctions de d\[EAcute]coupage. Aussi nous \[EAcute]crivons une \
fonction unique de d\[EAcute]coupage qui appelle de fa\[CCedilla]on al\
\[EAcute]atoire (avec une chance sur deux) l'une ou l'autre des fonctions \
principales de d\[EAcute]coupage. "
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\(Clear[Cut];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Cut[
        rect : {p1 : {x1_, y1_}, {x1_, y2_}, p3 : {x2_, y2_}, 
            p4 : {x2_, y1_}, p5_:  p1}] := 
      If[Random[Integer] == 0, VCut[rect], HCut[rect]]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Cut[rect : {___List}] := Flatten[Map[Cut, rect], 1]\)}], "Input",
  PageBreakAbove->Automatic],

Cell["Exemples :", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, Cut[r1]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.28928 .60332 L
.28928 .01472 L
.02381 .01472 L
s
.28928 .01472 m
.28928 .60332 L
.97619 .60332 L
.97619 .01472 L
.28928 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oooo000B0008Ool000Moo`03001oogoo04Uoo`03001oogoo0<5o
o`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool0
0`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo
0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007
Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001o
ogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo
0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03
001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol0
1Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uo
o`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007oo
Ool01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo
04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<0
07ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001o
ogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo
00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03
001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0
`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Mo
o`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007oo
Ool0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool0
00Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<0
07ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06
Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo
00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomo
o`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0
BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00
Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007oo
Ool0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool0
0`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<0
07ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31
Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo
00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomo
o`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`00
1goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00
Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Io
o`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool0
0`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo
00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19
Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001o
ogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomo
o`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03
001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00
Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5o
o`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool0
0`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo
0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007
Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001o
ogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo
0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03
001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol0
1Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uo
o`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007oo
Ool01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo
04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<0
07ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001o
ogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo
00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03
001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0
`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Mo
o`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007oo
Ool0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool0
00Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<0
07ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06
Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo
00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomo
o`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0
BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00
Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007oo
Ool0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool0
0`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<0
07ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31
Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo
00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomo
o`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`00
1goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00
Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Io
o`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool0
0`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo
00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19
Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001o
ogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomo
o`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03
001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00
Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5o
o`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool0
0`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo
0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007
Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001o
ogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo
0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03
001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol0
1Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uo
o`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<007oo
Ool01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001oogoo
04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo00<0
07ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03001o
ogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0`Goo
00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Moo`03
001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007ooOol0
`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool000Mo
o`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<007oo
Ool0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06Ool0
00Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo00<0
07ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomoo`06
Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0BGoo
00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00Oomo
o`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007ooOol0
BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool00`00
Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<007oo
Ool0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31Ool0
0`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo00<0
07ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomoo`31
Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`001goo
00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Ool00`00Oomoo`19Ool00`00Oomo
o`31Ool00`00Oomoo`06Ool000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo00Ioo`00
1goo00<007ooOol0BGoo00<007ooOol0`Goo00<007ooOol01Woo0007Oooo000B0008Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{153.312, 382.688}, {464.25, 322.938}} -> {-1.16914, \
2.37454, 0.00587804, 0.00594429}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, Cut[r1]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .22658 L
.97619 .22658 L
.97619 .01472 L
.02381 .01472 L
s
.02381 .22658 m
.02381 .60332 L
.97619 .60332 L
.97619 .22658 L
.02381 .22658 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{287.938, 177.875},
  ImageMargins->{{42.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000SR000`400?l00000o`00003oiP3oool0
0>H0oooo003V0?ooo`00iP3oool000D0oooof`0000060?ooo`001@3oool00`000000oooo0?ooo`3G
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?oo
o`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?oo
o`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool0
0`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
0=L0oooo00<000000?ooo`3oool0103oool000D0oooof`0000060?ooo`001@3oool00`000000oooo
0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool0
0`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000
oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo
00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3o
ool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?oo
o`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?oo
o`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0=L0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0e`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`3G0?ooo`03
0000003oool0oooo00@0oooo00050?ooom/000001P3oool00>H0oooo003V0?ooo`00iP3oool00001
\
\>"],
  ImageRangeCache->{{{153.25, 382.562}, {184.312, 43.0625}} -> {-1.16933, \
0.295106, 0.00588064, 0.00594692}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[TextData[{
  "Passons maintenant \[AGrave] la r\[EAcute]cursivit\[EAcute] proprement \
dite. Le principe est donc d'appeler de fa\[CCedilla]on r\[EAcute]cursive, la \
fonction ",
  StyleBox["Cut",
    FontFamily->"Courier"],
  " sur les rectangles produits \[AGrave] une \[EAcute]tape pr\[EAcute]c\
\[EAcute]dente par la m\[EHat]me fonction. Voici un exemple de \
r\[EAcute]sultat possible :"
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(r5 = Nest[Cut, r1, 3]\)], "Input",
  PageBreakAbove->Automatic],

Cell[BoxData[
    \({{{0, 0}, {0, 0.044946612696929254`}, {0.752513047731862`, 
          0.044946612696929254`}, {0.752513047731862`, 0}, {0, 0}}, {{0, 
          0.044946612696929254`}, {0, 
          0.24318077851032918`}, {0.752513047731862`, 
          0.24318077851032918`}, {0.752513047731862`, 
          0.044946612696929254`}, {0, 0.044946612696929254`}}, {{0, 
          0.24318077851032918`}, {0, 1}, {0.3716785207921694`, 
          1}, {0.3716785207921694`, 0.24318077851032918`}, {0, 
          0.24318077851032918`}}, {{0.3716785207921694`, 
          0.24318077851032918`}, {0.3716785207921694`, 
          1}, {0.752513047731862`, 1}, {0.752513047731862`, 
          0.24318077851032918`}, {0.3716785207921694`, 
          0.24318077851032918`}}, {{0.752513047731862`, 
          0}, {0.752513047731862`, 0.21597735290989692`}, {1.6`, 
          0.21597735290989692`}, {1.6`, 0}, {0.752513047731862`, 
          0}}, {{0.752513047731862`, 
          0.21597735290989692`}, {0.752513047731862`, 
          0.3116274797777809`}, {1.6`, 0.3116274797777809`}, {1.6`, 
          0.21597735290989692`}, {0.752513047731862`, 
          0.21597735290989692`}}, {{0.752513047731862`, 
          0.3116274797777809`}, {0.752513047731862`, 
          0.8199542996740468`}, {1.6`, 0.8199542996740468`}, {1.6`, 
          0.3116274797777809`}, {0.752513047731862`, 
          0.3116274797777809`}}, {{0.752513047731862`, 
          0.8199542996740468`}, {0.752513047731862`, 1}, {1.6`, 1}, {1.6`, 
          0.8199542996740468`}, {0.752513047731862`, 
          0.8199542996740468`}}}\)], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, r5]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .04117 L
.47173 .04117 L
.47173 .01472 L
.02381 .01472 L
s
.02381 .04117 m
.02381 .15785 L
.47173 .15785 L
.47173 .04117 L
.02381 .04117 L
s
.02381 .15785 m
.02381 .60332 L
.24505 .60332 L
.24505 .15785 L
.02381 .15785 L
s
.24505 .15785 m
.24505 .60332 L
.47173 .60332 L
.47173 .15785 L
.24505 .15785 L
s
.47173 .01472 m
.47173 .14184 L
.97619 .14184 L
.97619 .01472 L
.47173 .01472 L
s
.47173 .14184 m
.47173 .19814 L
.97619 .19814 L
.97619 .14184 L
.47173 .14184 L
s
.47173 .19814 m
.47173 .49734 L
.97619 .49734 L
.97619 .19814 L
.47173 .19814 L
s
.47173 .49734 m
.47173 .60332 L
.97619 .60332 L
.97619 .49734 L
.47173 .49734 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{253.938, 156.688},
  ImageMargins->{{47.6875, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0000OB000`400?l00000o`00003ob`3oool0
0</0oooo003;0?ooo`001@3oooo0000000H0oooo00050?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`00
1@3ooomK000006@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3o
ool00`000000oooo0?ooo`1G0?ooofH000001P3oool000D0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`001@3ooomK000006@0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0[0?ooofH000001P3oool000D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooofH000001P3oool0
00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0103oool000D0oooo`00000060?ooo`00b`3oool00</0oooo0000
\
\>"],
  ImageRangeCache->{{{157.062, 359.188}, {167.375, 43.0625}} -> {-1.35595, \
0.338721, 0.00668188, 0.00675719}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell["Ou \[AGrave] un niveau plus important : ", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, Nest[Cut, r1, 5]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .01654 L
.12033 .01654 L
.12033 .01472 L
.02381 .01472 L
s
.02381 .01654 m
.02381 .03396 L
.12033 .03396 L
.12033 .01654 L
.02381 .01654 L
s
.12033 .01472 m
.12033 .03396 L
.12322 .03396 L
.12322 .01472 L
.12033 .01472 L
s
.12322 .01472 m
.12322 .03396 L
.12443 .03396 L
.12443 .01472 L
.12322 .01472 L
s
.02381 .03396 m
.02381 .20877 L
.0295 .20877 L
.0295 .03396 L
.02381 .03396 L
s
.0295 .03396 m
.0295 .20877 L
.12443 .20877 L
.12443 .03396 L
.0295 .03396 L
s
.02381 .20877 m
.02381 .25123 L
.11962 .25123 L
.11962 .20877 L
.02381 .20877 L
s
.11962 .20877 m
.11962 .25123 L
.12443 .25123 L
.12443 .20877 L
.11962 .20877 L
s
.12443 .01472 m
.12443 .04353 L
.97619 .04353 L
.97619 .01472 L
.12443 .01472 L
s
.12443 .04353 m
.12443 .09087 L
.97619 .09087 L
.97619 .04353 L
.12443 .04353 L
s
.12443 .09087 m
.12443 .22675 L
.97619 .22675 L
.97619 .09087 L
.12443 .09087 L
s
.12443 .22675 m
.12443 .23991 L
.97619 .23991 L
.97619 .22675 L
.12443 .22675 L
s
.12443 .23991 m
.12443 .24932 L
.97619 .24932 L
.97619 .23991 L
.12443 .23991 L
s
.12443 .24932 m
.12443 .25002 L
.97619 .25002 L
.97619 .24932 L
.12443 .24932 L
s
.12443 .25002 m
.12443 .25016 L
.97619 .25016 L
.97619 .25002 L
.12443 .25002 L
s
.12443 .25016 m
.12443 .25123 L
.97619 .25123 L
.97619 .25016 L
.12443 .25016 L
s
.02381 .25123 m
.02381 .44177 L
.29954 .44177 L
.29954 .25123 L
.02381 .25123 L
s
.29954 .25123 m
.29954 .44177 L
.42298 .44177 L
.42298 .25123 L
.29954 .25123 L
s
.42298 .25123 m
.42298 .34838 L
.63677 .34838 L
.63677 .25123 L
.42298 .25123 L
s
.42298 .34838 m
.42298 .44177 L
.63677 .44177 L
.63677 .34838 L
.42298 .34838 L
s
.63677 .25123 m
.63677 .4084 L
.92059 .4084 L
.92059 .25123 L
.63677 .25123 L
s
.63677 .4084 m
.63677 .44177 L
.92059 .44177 L
.92059 .4084 L
.63677 .4084 L
s
.92059 .25123 m
.92059 .36094 L
.97619 .36094 L
.97619 .25123 L
.92059 .25123 L
s
.92059 .36094 m
.92059 .44177 L
.97619 .44177 L
.97619 .36094 L
.92059 .36094 L
s
.02381 .44177 m
.02381 .60332 L
.15238 .60332 L
.15238 .44177 L
.02381 .44177 L
s
.15238 .44177 m
.15238 .60332 L
.23479 .60332 L
.23479 .44177 L
.15238 .44177 L
s
.23479 .44177 m
.23479 .60332 L
.3928 .60332 L
.3928 .44177 L
.23479 .44177 L
s
.3928 .44177 m
.3928 .60332 L
.51809 .60332 L
.51809 .44177 L
.3928 .44177 L
s
.51809 .44177 m
.51809 .47105 L
.76085 .47105 L
.76085 .44177 L
.51809 .44177 L
s
.51809 .47105 m
.51809 .60332 L
.76085 .60332 L
.76085 .47105 L
.51809 .47105 L
s
.76085 .44177 m
.76085 .60332 L
.77308 .60332 L
.77308 .44177 L
.76085 .44177 L
s
.77308 .44177 m
.77308 .60332 L
.97619 .60332 L
.97619 .44177 L
.77308 .44177 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{287.938, 177.875},
  ImageMargins->{{42.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000SR000`400?l00000o`00003oiP3oool0
0>H0oooo003V0?ooo`00iP3oool000D0oooof`0000060?ooo`001@3oool00`000000oooo0?ooo`0C
0?ooo`800000`P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0C0?oo
o`800000`P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0C0?ooo`80
0000`P3oool00`000000oooo0?ooo`040?ooo`001@3ooolH00000<80oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0000001@0ooooa00000060?ooo`001@3oool00`00
0000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`30
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0000001@0oooo00<000000?oo
o`3oool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0000000D0?ooo`03
0000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`000000
503oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0000001@0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool0
0`000000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`000000503oooo4000000H0oooo00050?ooo`030000003oool0000001@0
oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0000000D0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`000000503oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`300?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0000000D0?ooo`030000003o
ool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`000000503oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool00000
01@0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`000000503oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0oooo
00050?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0000001@0oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0000000D0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`000000503o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
000001@0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0000000D0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`30
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0000001@0oooo00<000000?oo
o`3oool0`03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0000000D0?ooo`03
0000003oool0oooo0<00oooo00<000000?ooo`3oool0103oool000D0oooo600000320?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01<0oooo0P0000320?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo01<0oooo0P0000320?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo01<0oooo0P0000320?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo01<0ooooa@0000060?ooo`001@3oool00`000000oooo
0?ooo`0C0?ooo`800000`P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?oo
o`0C0?ooo`800000`P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0C
0?ooolD000001P3oool000D0oooo00<000000?ooo`3oool04`3oool200000<80oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool04`3oooo5000000H0oooo00050?ooom/00000
1P3oool000D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?oo
o`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0J0?oooc400000@03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool>000000H0oooo
00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0;@3ooom2000000`0oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?oo
o`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0103oool000D0oooof`0000060?ooo`001@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000;@3oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03D0
oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000;@3oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03D0
oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000;@3oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03D0
oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0I0?ooocT000000P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00@0oooo00050?ooom/000001P3oool00>H0oooo003V
0?ooo`00iP3oool00001\
\>"],
  ImageRangeCache->{{{153.25, 382.562}, {385, 243.75}} -> {-1.16933, 1.78695, \
0.00588064, 0.00594692}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Optimisation", "Subsection",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell["4.1. R\[EAcute]\[EAcute]criture des arguments", "Subsubsection",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "Sur le plan de la programmation, on peut d\[EAcute]j\[AGrave] optimiser l'\
\[EAcute]criture des fonctions. En effet, puisque la fonction ",
  StyleBox["Cut",
    FontFamily->"Courier"],
  " appelle les fonctions ",
  StyleBox["HCut",
    FontFamily->"Courier"],
  " ou ",
  StyleBox["VCut",
    FontFamily->"Courier"],
  " et que ces deux derni\[EGrave]res fonctions ne seront pas \
utilis\[EAcute]es directement, il est inutile, pour ces deux fonctions, \
d'expliciter avec autant de d\[EAcute]tail la forme de leurs arguments. La \
fonction ",
  StyleBox["Cut",
    FontFamily->"Courier"],
  " se chargera de faire les tests n\[EAcute]cessaires pr\[EAcute]alables \
\[AGrave] l'ex\[EAcute]cution. On peut donc r\[EAcute]\[EAcute]crire plus \
simplement l'ensemble des fonctions de la fa\[CCedilla]on suivante :"
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\(Clear[VCut, HCut, Cut];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(VCut[{p1 : {x1_, y1_}, p2_, p3 : {x2_, y2_}, p4_, _}] := {{p1, p2, 
            pa = {r = Random[Real, {x1, x2}], y2}, pb = {r, y1}, p1}, {pb, 
            pa, p3, p4, pb}};\)\), "\n", 
    \(\(\(VCut[rect : {___List}] := Flatten[Map[VCut, rect], 1];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(HCut[{p1 : {x1_, y1_}, p2_, p3 : {x2_, y2_}, p4_, _}] := {{p1, 
            pa = {x1, r = Random[Real, {y1, y2}]}, pb = {x2, r}, p4, 
            p1}, {pa, p2, p3, pb, pa}};\)\), "\n", 
    \(\(\(HCut[rect : {___List}] := Flatten[Map[HCut, rect], 1]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Cut[
          rect : {p1 : {x1_, y1_}, {x1_, y2_}, p3 : {x2_, y2_}, 
              p4 : {x2_, y1_}, p5_:  p1}] := 
        If[Random[Integer] \[Equal] 0, VCut[rect], HCut[rect]];\)\), "\n", 
    \(\(Cut[rect : {___List}] := Flatten[Map[Cut, rect], 1];\)\)}], "Input",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2. Am\[EAcute]lioration des positions des d\[EAcute]coupages", \
"Subsubsection",
  PageBreakAbove->Automatic],

Cell["\<\
Par ailleurs, la d\[EAcute]marche pr\[EAcute]c\[EAcute]dente \
produit un r\[EAcute]sultat graphique assez \[EAcute]loign\[EAcute] des \
figures recherch\[EAcute]es dont l'une des raisons provient du choix de la \
position du d\[EAcute]coupage al\[EAcute]atoire. En r\[EAcute]alit\[EAcute], \
pour obtenir une figure plus \[EAcute]quilibr\[EAcute]e, il est important de \
ne pas d\[EAcute]couper trop pr\[EGrave]s des bords d'un rectangle. Il faut \
donc restreindre le choix de la position de d\[EAcute]coupage \[AGrave] une \
valeur, certes al\[EAcute]atoire, mais \[EAcute]loign\[EAcute]e des bords. \
Nous r\[EAcute]\[EAcute]crivons donc les fonctions de la fa\[CCedilla]on \
suivante :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\(Clear[VCut, HCut, Cut];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(VCut[{p1 : {x1_, y1_}, p2_, p3 : {x2_, y2_}, p4_, _}] := {{p1, p2, 
            pa = {r = Random[Real, {x1 + \((d = \((x2 - x1)\)/5)\), x2 - d}], 
                y2}, pb = {r, y1}, p1}, {pb, pa, p3, p4, pb}};\)\), "\n", 
    \(\(\(VCut[rect : {___List}] := Flatten[Map[VCut, rect], 1];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(HCut[{p1 : {x1_, y1_}, p2_, p3 : {x2_, y2_}, p4_, _}] := {{p1, 
            pa = {x1, 
                r = Random[Real, {y1 + \((d = \((y2 - y1)\)/5)\), y2 - d}]}, 
            pb = {x2, r}, p4, p1}, {pa, p2, p3, pb, pa}};\)\), "\n", 
    \(\(\(HCut[rect : {___List}] := Flatten[Map[HCut, rect], 1];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Cut[
          rect : {{x1_, y1_}, {x1_, y2_}, {x2_, y2_}, {x2_, y1_}, {x1_, 
                y1_}}] := 
        If[Random[Integer] \[Equal] 0, VCut[rect], HCut[rect]];\)\), "\n", 
    \(\(Cut[rect : {___List}] := Flatten[Map[Cut, rect], 1];\)\)}], "Input",
  PageBreakAbove->Automatic],

Cell["On obtient alors, par exemple :", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, Nest[Cut, r1, 5]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .39166 L
.07308 .39166 L
.07308 .01472 L
.02381 .01472 L
s
.07308 .01472 m
.07308 .39166 L
.12756 .39166 L
.12756 .01472 L
.07308 .01472 L
s
.12756 .01472 m
.12756 .10706 L
.21785 .10706 L
.21785 .01472 L
.12756 .01472 L
s
.12756 .10706 m
.12756 .39166 L
.21785 .39166 L
.21785 .10706 L
.12756 .10706 L
s
.02381 .39166 m
.02381 .51028 L
.10192 .51028 L
.10192 .39166 L
.02381 .39166 L
s
.10192 .39166 m
.10192 .51028 L
.21785 .51028 L
.21785 .39166 L
.10192 .39166 L
s
.02381 .51028 m
.02381 .60332 L
.06743 .60332 L
.06743 .51028 L
.02381 .51028 L
s
.06743 .51028 m
.06743 .60332 L
.21785 .60332 L
.21785 .51028 L
.06743 .51028 L
s
.21785 .01472 m
.21785 .22152 L
.25547 .22152 L
.25547 .01472 L
.21785 .01472 L
s
.25547 .01472 m
.25547 .22152 L
.27879 .22152 L
.27879 .01472 L
.25547 .01472 L
s
.21785 .22152 m
.21785 .51985 L
.27879 .51985 L
.27879 .22152 L
.21785 .22152 L
s
.21785 .51985 m
.21785 .60332 L
.27879 .60332 L
.27879 .51985 L
.21785 .51985 L
s
.27879 .01472 m
.27879 .60332 L
.30281 .60332 L
.30281 .01472 L
.27879 .01472 L
s
.30281 .01472 m
.30281 .60332 L
.32532 .60332 L
.32532 .01472 L
.30281 .01472 L
s
.32532 .01472 m
.32532 .40674 L
.34565 .40674 L
.34565 .01472 L
.32532 .01472 L
s
.32532 .40674 m
.32532 .60332 L
.34565 .60332 L
.34565 .40674 L
.32532 .40674 L
s
.34565 .01472 m
.34565 .04979 L
.55204 .04979 L
.55204 .01472 L
.34565 .01472 L
s
.55204 .01472 m
.55204 .04979 L
.97619 .04979 L
.97619 .01472 L
.55204 .01472 L
s
.34565 .04979 m
.34565 .0838 L
.75138 .0838 L
.75138 .04979 L
.34565 .04979 L
s
.75138 .04979 m
.75138 .0838 L
.97619 .0838 L
.97619 .04979 L
.75138 .04979 L
s
.34565 .0838 m
.34565 .14652 L
.64579 .14652 L
.64579 .0838 L
.34565 .0838 L
s
.64579 .0838 m
.64579 .14652 L
.76637 .14652 L
.76637 .0838 L
.64579 .0838 L
s
.76637 .0838 m
.76637 .14652 L
.90109 .14652 L
.90109 .0838 L
.76637 .0838 L
s
.90109 .0838 m
.90109 .14652 L
.97619 .14652 L
.97619 .0838 L
.90109 .0838 L
s
.34565 .14652 m
.34565 .36895 L
.40016 .36895 L
.40016 .14652 L
.34565 .14652 L
s
.34565 .36895 m
.34565 .60332 L
.40016 .60332 L
.40016 .36895 L
.34565 .36895 L
s
.40016 .14652 m
.40016 .60332 L
.4317 .60332 L
.4317 .14652 L
.40016 .14652 L
s
.4317 .14652 m
.4317 .60332 L
.48619 .60332 L
.48619 .14652 L
.4317 .14652 L
s
.48619 .14652 m
.48619 .28914 L
.67693 .28914 L
.67693 .14652 L
.48619 .14652 L
s
.67693 .14652 m
.67693 .28914 L
.97619 .28914 L
.97619 .14652 L
.67693 .14652 L
s
.48619 .28914 m
.48619 .60332 L
.7896 .60332 L
.7896 .28914 L
.48619 .28914 L
s
.7896 .28914 m
.7896 .60332 L
.97619 .60332 L
.97619 .28914 L
.7896 .28914 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{287.938, 177.875},
  ImageMargins->{{42.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000SR000`400?l00000o`00003oiP3oool0
0>H0oooo003V0?ooo`00iP3oool000D0oooof`0000060?ooo`001@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3ooonA000000H0
oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3ooonA000000H0oooo00050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3ooolF000000L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3ooonA000000H0oooo00050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?oo
o`001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0180oooo3`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oooma000000H0oooo00050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo
00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo3@0000070?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooobh000003@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
1P00000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo
00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool^000000d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo3`0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo
00050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`040?ooo`001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool000D0oooof`0000060?ooo`00iP3o
ool00>H0oooo003V0?ooo`00\
\>"],
  ImageRangeCache->{{{153.25, 382.562}, {422.438, 281.188}} -> {-1.16933, \
2.06524, 0.00588064, 0.00594692}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[TextData[{
  "Il peut arriver \[EAcute]galement que plusieurs d\[EAcute]coupes dans une \
m\[EHat]me direction se produisent successivement. Cela produira un effet \
assez \[EAcute]loign\[EAcute] des figures de Mondrian. On utilisera alors une \
autre technique qui consistera \[AGrave] faire suivre \
syst\[EAcute]matiquement un d\[EAcute]coupage vertical d'un d\[EAcute]coupage \
horizontal ou r\[EAcute]ciproquement. La fonction ",
  StyleBox["Cut",
    FontFamily->"Courier"],
  " devient ainsi :"
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\(Clear[Cut];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Cut[
          rect : {p1 : {x1_, y1_}, {x1_, y2_}, p3 : {x2_, y2_}, 
              p4 : {x2_, y1_}, p5_:  p1}] := 
        If[Random[Integer] \[Equal] 0, VCut[HCut[rect]], 
          HCut[VCut[rect]]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Cut[rect : {___List}] := Flatten[Map[Cut, rect], 1];\)\)}], "Input",
  PageBreakAbove->Automatic],

Cell["\<\
Cette modification entra\[IHat]ne le doublement \
syst\[EAcute]matique du niveau de r\[EAcute]cursi-vit\[EAcute]. Ainsi, \
\[AGrave] partir d'un rectangle, on fabrique 4 rectangles :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, r6 = Cut[r1]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .4575 L
.60117 .4575 L
.60117 .01472 L
.02381 .01472 L
s
.60117 .01472 m
.60117 .4575 L
.97619 .4575 L
.97619 .01472 L
.60117 .01472 L
s
.02381 .4575 m
.02381 .60332 L
.25041 .60332 L
.25041 .4575 L
.02381 .4575 L
s
.25041 .4575 m
.25041 .60332 L
.97619 .60332 L
.97619 .4575 L
.25041 .4575 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{217.625, 134.25},
  ImageMargins->{{46.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^0000Jb000`400?l00000o`00003o[_ooool0
0:kooooo002^ooooo`001?oooonUo`0000Gooooo0004ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`00
1?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
0oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03oooo
o`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03
ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo
0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Co
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?o
oooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool0
00Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00ooo
ool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`00
1?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
0oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Cooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo0004oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03oooo
o`001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool00oooool000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00?ooooo0004ooooojGo00001Oooool000Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00oooool000Cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00?ooooo
0004ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`03ooooo`001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool00oooool000Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00oooool000Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00?o
oooo0004ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`03ooooo`001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool00oooool000Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`03ooooo`001?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00?ooooo0004ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`03ooooo`001?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00oooool0
00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
00?ooooo0004ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`03ooooo`001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool00oooool000CoooooYOl00005ooooo`00[_ooool00:kooooo0000\
\>"],
  ImageRangeCache->{{{156, 329.062}, {287.562, 181.188}} -> {-1.56729, \
1.76346, 0.00780861, 0.00789662}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[TextData[{
  "Un double appel \[AGrave] la fonction Cut produit ",
  Cell[BoxData[
      \(TraditionalForm\`4\^2 = 16\)]],
  " rectangles"
}], "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, Cut[r6]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .21154 L
.44137 .21154 L
.44137 .01472 L
.02381 .01472 L
s
.02381 .21154 m
.02381 .4575 L
.44137 .4575 L
.44137 .21154 L
.02381 .21154 L
s
.44137 .01472 m
.44137 .34193 L
.60117 .34193 L
.60117 .01472 L
.44137 .01472 L
s
.44137 .34193 m
.44137 .4575 L
.60117 .4575 L
.60117 .34193 L
.44137 .34193 L
s
.60117 .01472 m
.60117 .28526 L
.84496 .28526 L
.84496 .01472 L
.60117 .01472 L
s
.60117 .28526 m
.60117 .4575 L
.84496 .4575 L
.84496 .28526 L
.60117 .28526 L
s
.84496 .01472 m
.84496 .35547 L
.97619 .35547 L
.97619 .01472 L
.84496 .01472 L
s
.84496 .35547 m
.84496 .4575 L
.97619 .4575 L
.97619 .35547 L
.84496 .35547 L
s
.02381 .4575 m
.02381 .52276 L
.18107 .52276 L
.18107 .4575 L
.02381 .4575 L
s
.02381 .52276 m
.02381 .60332 L
.18107 .60332 L
.18107 .52276 L
.02381 .52276 L
s
.18107 .4575 m
.18107 .54298 L
.25041 .54298 L
.25041 .4575 L
.18107 .4575 L
s
.18107 .54298 m
.18107 .60332 L
.25041 .60332 L
.25041 .54298 L
.18107 .54298 L
s
.25041 .4575 m
.25041 .56141 L
.506 .56141 L
.506 .4575 L
.25041 .4575 L
s
.25041 .56141 m
.25041 .60332 L
.506 .60332 L
.506 .56141 L
.25041 .56141 L
s
.506 .4575 m
.506 .56412 L
.97619 .56412 L
.97619 .4575 L
.506 .4575 L
s
.506 .56412 m
.506 .60332 L
.97619 .60332 L
.97619 .56412 L
.506 .56412 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{251.5, 155.25},
  ImageMargins->{{41.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000390000O2000`400?l00000o`00003obOooool0
0<Wooooo0039ooooo`001Ooooonoo`0000Gooooo0005ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool0
00Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
0oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo
0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`03ooooo`001OoooomDo`0001oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo01gooooo<Ol0000Jooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Go
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0
D?oooolQo`0002oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo7?l00005ooooo`001Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
0oooool000Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`001Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00oooool000Gooooo_ol00005ooooo`001Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool00oooool000Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03
ooooo`001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo00?ooooo0005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool0
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`03ooooo`001OoooolPo`0000gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool00oooool000Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`00
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oo
oooooooo01cooooo3ol0000booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00ooo
ool000Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`001Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool02oooooldo`0005gooooo00?o0000ooooooooool00oooool000Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo033ooooo
Gol00005ooooo`001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
0oooool000Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`001Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo0005oooookoo00001Oooool00<Wo
oooo0039ooooo`00\
\>"],
  ImageRangeCache->{{{152.125, 352.312}, {487.125, 363.938}} -> {-1.32586, \
3.07706, 0.0067429, 0.0068189}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell["Plus g\[EAcute]n\[EAcute]ralement : ", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Line, Nest[Cut, r1, 3]]]]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .13233 L
.06966 .13233 L
.06966 .01472 L
.02381 .01472 L
s
.02381 .13233 m
.02381 .17835 L
.06966 .17835 L
.06966 .13233 L
.02381 .13233 L
s
.06966 .01472 m
.06966 .13746 L
.21937 .13746 L
.21937 .01472 L
.06966 .01472 L
s
.06966 .13746 m
.06966 .17835 L
.21937 .17835 L
.21937 .13746 L
.06966 .13746 L
s
.02381 .17835 m
.02381 .2264 L
.15078 .2264 L
.15078 .17835 L
.02381 .17835 L
s
.15078 .17835 m
.15078 .2264 L
.21937 .2264 L
.21937 .17835 L
.15078 .17835 L
s
.02381 .2264 m
.02381 .24566 L
.14671 .24566 L
.14671 .2264 L
.02381 .2264 L
s
.14671 .2264 m
.14671 .24566 L
.21937 .24566 L
.21937 .2264 L
.14671 .2264 L
s
.21937 .01472 m
.21937 .10206 L
.6602 .10206 L
.6602 .01472 L
.21937 .01472 L
s
.6602 .01472 m
.6602 .10206 L
.77568 .10206 L
.77568 .01472 L
.6602 .01472 L
s
.21937 .10206 m
.21937 .15374 L
.66286 .15374 L
.66286 .10206 L
.21937 .10206 L
s
.66286 .10206 m
.66286 .15374 L
.77568 .15374 L
.77568 .10206 L
.66286 .10206 L
s
.21937 .15374 m
.21937 .21248 L
.46187 .21248 L
.46187 .15374 L
.21937 .15374 L
s
.46187 .15374 m
.46187 .21248 L
.77568 .21248 L
.77568 .15374 L
.46187 .15374 L
s
.21937 .21248 m
.21937 .24566 L
.53626 .24566 L
.53626 .21248 L
.21937 .21248 L
s
.53626 .21248 m
.53626 .24566 L
.77568 .24566 L
.77568 .21248 L
.53626 .21248 L
s
.02381 .24566 m
.02381 .4361 L
.23766 .4361 L
.23766 .24566 L
.02381 .24566 L
s
.23766 .24566 m
.23766 .4361 L
.31657 .4361 L
.31657 .24566 L
.23766 .24566 L
s
.02381 .4361 m
.02381 .50401 L
.20941 .50401 L
.20941 .4361 L
.02381 .4361 L
s
.20941 .4361 m
.20941 .50401 L
.31657 .50401 L
.31657 .4361 L
.20941 .4361 L
s
.02381 .50401 m
.02381 .54178 L
.08668 .54178 L
.08668 .50401 L
.02381 .50401 L
s
.08668 .50401 m
.08668 .54178 L
.31657 .54178 L
.31657 .50401 L
.08668 .50401 L
s
.02381 .54178 m
.02381 .60332 L
.1777 .60332 L
.1777 .54178 L
.02381 .54178 L
s
.1777 .54178 m
.1777 .60332 L
.31657 .60332 L
.31657 .54178 L
.1777 .54178 L
s
.31657 .24566 m
.31657 .33763 L
.61238 .33763 L
.61238 .24566 L
.31657 .24566 L
s
.31657 .33763 m
.31657 .39045 L
.61238 .39045 L
.61238 .33763 L
.31657 .33763 L
s
.61238 .24566 m
.61238 .28974 L
.77568 .28974 L
.77568 .24566 L
.61238 .24566 L
s
.61238 .28974 m
.61238 .39045 L
.77568 .39045 L
.77568 .28974 L
.61238 .28974 L
s
.31657 .39045 m
.31657 .52408 L
.66485 .52408 L
.66485 .39045 L
.31657 .39045 L
s
.66485 .39045 m
.66485 .52408 L
.77568 .52408 L
.77568 .39045 L
.66485 .39045 L
s
.31657 .52408 m
.31657 .60332 L
.56395 .60332 L
.56395 .52408 L
.31657 .52408 L
s
.56395 .52408 m
.56395 .60332 L
.77568 .60332 L
.77568 .52408 L
.56395 .52408 L
s
.77568 .01472 m
.77568 .15404 L
.80519 .15404 L
.80519 .01472 L
.77568 .01472 L
s
.77568 .15404 m
.77568 .21122 L
.80519 .21122 L
.80519 .15404 L
.77568 .15404 L
s
.80519 .01472 m
.80519 .05568 L
.88498 .05568 L
.88498 .01472 L
.80519 .01472 L
s
.80519 .05568 m
.80519 .21122 L
.88498 .21122 L
.88498 .05568 L
.80519 .05568 L
s
.88498 .01472 m
.88498 .09738 L
.94198 .09738 L
.94198 .01472 L
.88498 .01472 L
s
.88498 .09738 m
.88498 .21122 L
.94198 .21122 L
.94198 .09738 L
.88498 .09738 L
s
.94198 .01472 m
.94198 .06984 L
.97619 .06984 L
.97619 .01472 L
.94198 .01472 L
s
.94198 .06984 m
.94198 .21122 L
.97619 .21122 L
.97619 .06984 L
.94198 .06984 L
s
.77568 .21122 m
.77568 .23112 L
.86577 .23112 L
.86577 .21122 L
.77568 .21122 L
s
.86577 .21122 m
.86577 .23112 L
.91811 .23112 L
.91811 .21122 L
.86577 .21122 L
s
.77568 .23112 m
.77568 .26357 L
.836 .26357 L
.836 .23112 L
.77568 .23112 L
s
.836 .23112 m
.836 .26357 L
.91811 .26357 L
.91811 .23112 L
.836 .23112 L
s
.91811 .21122 m
.91811 .23433 L
.96134 .23433 L
.96134 .21122 L
.91811 .21122 L
s
.96134 .21122 m
.96134 .23433 L
.97619 .23433 L
.97619 .21122 L
.96134 .21122 L
s
.91811 .23433 m
.91811 .26357 L
.93338 .26357 L
.93338 .23433 L
.91811 .23433 L
s
.93338 .23433 m
.93338 .26357 L
.97619 .26357 L
.97619 .23433 L
.93338 .23433 L
s
.77568 .26357 m
.77568 .37688 L
.8472 .37688 L
.8472 .26357 L
.77568 .26357 L
s
.8472 .26357 m
.8472 .37688 L
.91561 .37688 L
.91561 .26357 L
.8472 .26357 L
s
.77568 .37688 m
.77568 .49654 L
.81911 .49654 L
.81911 .37688 L
.77568 .37688 L
s
.81911 .37688 m
.81911 .49654 L
.91561 .49654 L
.91561 .37688 L
.81911 .37688 L
s
.77568 .49654 m
.77568 .5469 L
.8712 .5469 L
.8712 .49654 L
.77568 .49654 L
s
.77568 .5469 m
.77568 .60332 L
.8712 .60332 L
.8712 .5469 L
.77568 .5469 L
s
.8712 .49654 m
.8712 .58041 L
.91561 .58041 L
.91561 .49654 L
.8712 .49654 L
s
.8712 .58041 m
.8712 .60332 L
.91561 .60332 L
.91561 .58041 L
.8712 .58041 L
s
.91561 .26357 m
.91561 .28848 L
.94384 .28848 L
.94384 .26357 L
.91561 .26357 L
s
.91561 .28848 m
.91561 .36425 L
.94384 .36425 L
.94384 .28848 L
.91561 .28848 L
s
.94384 .26357 m
.94384 .30054 L
.97619 .30054 L
.97619 .26357 L
.94384 .26357 L
s
.94384 .30054 m
.94384 .36425 L
.97619 .36425 L
.97619 .30054 L
.94384 .30054 L
s
.91561 .36425 m
.91561 .44976 L
.94635 .44976 L
.94635 .36425 L
.91561 .36425 L
s
.94635 .36425 m
.94635 .44976 L
.97619 .44976 L
.97619 .36425 L
.94635 .36425 L
s
.91561 .44976 m
.91561 .60332 L
.94643 .60332 L
.94643 .44976 L
.91561 .44976 L
s
.94643 .44976 m
.94643 .60332 L
.97619 .60332 L
.97619 .44976 L
.94643 .44976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{287.938, 177.875},
  ImageMargins->{{42.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000SR000`400?l00000o`00003oiP3oool0
0>H0oooo003V0?ooo`00iP3oool000D0oooof`0000060?ooo`001@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0103ooolC000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo2@0000060?oo
o`001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool>000000L0oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0O0?oooh0000001P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00050?ooo``000008@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0203ooolS000006@0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooohL000004@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`001@3oool^000003H0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00d0oooo[P0000060?ooo`001@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000H0oooo00050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3o
ool000D0oooo;P0000170?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3o
ool000D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0=03ooolR000000T0oooo00@000000?ooo`3oool000001P3o
ool000D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0100oooo3P0000060?ooo`001@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo00050?ooojd000003@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool08P3oool_000000H0oooo00050?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0440oooo9P00000@0?ooo`030000003oool0oooo00`0oooo200000060?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool8
000000H0oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0ooooA@00000T0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool?000000H0oooo00050?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool08P3ooolQ000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool000D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3ooomZ
000000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?oood@00000C`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04`3oool?000000H0oooo00050?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0F
0?ooob4000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?oo
od@00000C`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0<@3ooomZ000001D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool000D0ooooA000000h0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0]0?oo
oaL000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04`3oool;000000H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00050?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool000D0oooof`0000060?ooo`00iP3oool00>H0oooo003V0?ooo`00\
\>"],
  ImageRangeCache->{{{153.25, 382.562}, {209.312, 68.0625}} -> {-1.16933, \
0.480948, 0.00588064, 0.00594692}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Introduction des couleurs", "Subsection",
  PageBreakAbove->Automatic],

Cell["\<\
Il nous faut maintenant introduire de la couleur dans la figure. \
Nous retiendrons les cinq couleurs suivantes pour le remplissage des \
rectangles :  le rouge, le bleu, le jaune, le noir et le blanc et nous \
choissirons de dessiner des contours \[EAcute]pais en couleur grise.\
\>", \
"Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Le choix des couleurs de remplissage se faisant de fa\[CCedilla]on \
pseudo-al\[EAcute]atoire, on d\[EAcute]finit une fonction dont les arguments \
entiers, allant de 1 \[AGrave] 5 sont mis en correspondance avec chacune des \
5 couleurs choisies :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Clear[Col];
Col[1]=RGBColor[1,1,1]; (* blanc *)
Col[2]=RGBColor[1,0,0]; (* rouge *)
Col[3]=RGBColor[0,0,0.8]; (* bleu *)
Col[4]=RGBColor[1,1,0]; (* jaune *)
Col[5]=RGBColor[0,0,0]; (* noir *)\
\>", "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell["\<\
Puis on construit une fonction plus g\[EAcute]n\[EAcute]rale dans \
laquelle on int\[EGrave]gre le niveau de r\[EAcute]cursivit\[EAcute] souhait\
\[EAcute], le choix des couleurs, l'affectation des couleurs aux \
diff\[EAcute]rents rectangles, et l'affichage graphique. On pourra par \
exemple l'\[EAcute]crire de la fa\[CCedilla]on suivante :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(Clear[Mondrian];\)\), "\n", 
    \(Mondrian[rect : {{x1_, y1_}, {x1_, y2_}, {x2_, y2_}, {x2_, y1_}}, 
        n_Integer:  1] := 
      Module[{nr, lines, polys}, \[IndentingNewLine]nr = 
          Flatten[{rect, {{x1, y1}}}, 1]; \[IndentingNewLine]nr = 
          Nest[Cut, nr, n]; \[IndentingNewLine]lines = 
          Map[Line, nr]; \[IndentingNewLine]polys = 
          Map[Polygon, nr]; \[IndentingNewLine]polys = 
          polys /. p_Polygon \[RuleDelayed] {Col[Random[Integer, {1, 5}]], 
                p}; \[IndentingNewLine]Show[
          Graphics[{polys, Thickness[0.01], GrayLevel[0.5], 
              lines}]]]\)}], "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell["Dont voici quelques exemples d'utilisation :", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mondrian[{{0, 0}, {0, 1}, {1.6, 1}, {1.6, 0}}, 2]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 .8 r
.02381 .01472 m
.02381 .06115 L
.3058 .06115 L
.3058 .01472 L
.02381 .01472 L
F
.02381 .06115 m
.02381 .19461 L
.3058 .19461 L
.3058 .06115 L
.02381 .06115 L
F
0 0 0 r
.3058 .01472 m
.3058 .07369 L
.4953 .07369 L
.4953 .01472 L
.3058 .01472 L
F
.3058 .07369 m
.3058 .19461 L
.4953 .19461 L
.4953 .07369 L
.3058 .07369 L
F
0 0 .8 r
.4953 .01472 m
.4953 .067 L
.62628 .067 L
.62628 .01472 L
.4953 .01472 L
F
1 1 0 r
.4953 .067 m
.4953 .19461 L
.62628 .19461 L
.62628 .067 L
.4953 .067 L
F
1 1 1 r
.62628 .01472 m
.62628 .11356 L
.97619 .11356 L
.97619 .01472 L
.62628 .01472 L
F
0 0 0 r
.62628 .11356 m
.62628 .19461 L
.97619 .19461 L
.97619 .11356 L
.62628 .11356 L
F
1 1 0 r
.02381 .19461 m
.02381 .28887 L
.27926 .28887 L
.27926 .19461 L
.02381 .19461 L
F
1 0 0 r
.27926 .19461 m
.27926 .28887 L
.43337 .28887 L
.43337 .19461 L
.27926 .19461 L
F
0 0 0 r
.02381 .28887 m
.02381 .60332 L
.26615 .60332 L
.26615 .28887 L
.02381 .28887 L
F
1 1 0 r
.26615 .28887 m
.26615 .60332 L
.43337 .60332 L
.43337 .28887 L
.26615 .28887 L
F
0 0 .8 r
.43337 .19461 m
.43337 .46671 L
.62557 .46671 L
.62557 .19461 L
.43337 .19461 L
F
1 1 1 r
.62557 .19461 m
.62557 .46671 L
.97619 .46671 L
.97619 .19461 L
.62557 .19461 L
F
1 1 0 r
.43337 .46671 m
.43337 .60332 L
.6807 .60332 L
.6807 .46671 L
.43337 .46671 L
F
1 1 1 r
.6807 .46671 m
.6807 .60332 L
.97619 .60332 L
.97619 .46671 L
.6807 .46671 L
F
.5 g
.01 w
[ ] 0 setdash
.02381 .01472 m
.02381 .06115 L
.3058 .06115 L
.3058 .01472 L
.02381 .01472 L
s
.02381 .06115 m
.02381 .19461 L
.3058 .19461 L
.3058 .06115 L
.02381 .06115 L
s
.3058 .01472 m
.3058 .07369 L
.4953 .07369 L
.4953 .01472 L
.3058 .01472 L
s
.3058 .07369 m
.3058 .19461 L
.4953 .19461 L
.4953 .07369 L
.3058 .07369 L
s
.4953 .01472 m
.4953 .067 L
.62628 .067 L
.62628 .01472 L
.4953 .01472 L
s
.4953 .067 m
.4953 .19461 L
.62628 .19461 L
.62628 .067 L
.4953 .067 L
s
.62628 .01472 m
.62628 .11356 L
.97619 .11356 L
.97619 .01472 L
.62628 .01472 L
s
.62628 .11356 m
.62628 .19461 L
.97619 .19461 L
.97619 .11356 L
.62628 .11356 L
s
.02381 .19461 m
.02381 .28887 L
.27926 .28887 L
.27926 .19461 L
.02381 .19461 L
s
.27926 .19461 m
.27926 .28887 L
.43337 .28887 L
.43337 .19461 L
.27926 .19461 L
s
.02381 .28887 m
.02381 .60332 L
.26615 .60332 L
.26615 .28887 L
.02381 .28887 L
s
.26615 .28887 m
.26615 .60332 L
.43337 .60332 L
.43337 .28887 L
.26615 .28887 L
s
.43337 .19461 m
.43337 .46671 L
.62557 .46671 L
.62557 .19461 L
.43337 .19461 L
s
.62557 .19461 m
.62557 .46671 L
.97619 .46671 L
.97619 .19461 L
.62557 .19461 L
s
.43337 .46671 m
.43337 .60332 L
.6807 .60332 L
.6807 .46671 L
.43337 .46671 L
s
.6807 .46671 m
.6807 .60332 L
.97619 .60332 L
.97619 .46671 L
.6807 .46671 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{287.938, 177.875},
  ImageMargins->{{42.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000SR000`400?l00000o`00003oiP3oool0
0>H0oooo003V0?ooo`00iP3oool000@0oooog01oOgl60?ooo`00103ooooL07moO`H0oooo00040?oo
o`80Ogmo?`000<`207moObT000000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80
Ogmo?`000<`207moObT000000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80Ogmo
?`000<`207moObT000000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80Ogmo?`00
0<`207moObT000000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80Ogmo?`000<`2
07moObT000000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80Ogmo?`000<`207mo
ObT000000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80Ogmo?`000<`207moObT0
00000P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?ooo`80Ogmo?`000<`207moObT00000
0P1oOglL0000c080OgmoCP3oool207moO`H0oooo00040?oood<0Ogmo:@00000207moOa`0003<0P1o
Ogm>0?ooo`80Ogmo1P3oool000@0oooo@`1oOglY00000080Ogmo70000<`207moOdh0oooo0P1oOgl6
0?ooo`00103oool207moOcl0003<0P1oOglY00000200OgmoCP3oool207moO`H0oooo00040?ooo`80
Ogmo?`000<a;07moOdh0oooo0P1oOgl60?ooo`00103oool207moOcl0003<;@1oOglL0?oo0080Ogmo
CP3oool207moO`H0oooo00040?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3o
ool207moO`H0oooo00040?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3oool2
07moO`H0oooo00040?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3oool207mo
O`H0oooo00040?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3oool207moO`H0
oooo00040?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3oool207moO`H0oooo
00040?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3oool207moO`H0oooo0004
0?ooo`80Ogmo?`000<`207moObT000000P1oOglL0?oo0080OgmoCP3oool207moO`H0oooo00040?oo
o`80Ogmo?`000<`207moObT000000P1oOglL0?oo0580Ogmo1P3oool000@0oooo0P1oOglo0000c080
Ogmo:@00000207moOa`0ool0DP1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo
703oo`0207moOdh000000P1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703o
o`0207moOdh000000P1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`02
07moOdh000000P1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207mo
Odh000000P1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh0
00000P1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh00000
0P1oOgl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1o
Ogl60?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl6
0?ooo`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?oo
o`00103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00
103oool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103o
ool207moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103oool2
07moOcl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103oool207mo
Ocl0003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103oool207moOcl0
003<0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103oool207moOcl0003<
0P1oOglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103oool207moOcl0003<0P1o
OglY00000080Ogmo703oo`0207moOdh000000P1oOgl60?ooo`00103ooooL07moO`H0oooo00040?oo
om`0Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80
Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo
1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3o
ool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool0
00@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0
oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo
0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1o
Ogli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli
0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo
0080Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080
Ogmo8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo
8@3o000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o
000207moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o0002
07moObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207mo
ObX0003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0
003<0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<
0P1oOgm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1o
Ogm>0?ooo`80Ogmo1P3oool000@0oooo0P1oOgli0?oo0080Ogmo8@3o000207moObX0003<0P1oOgm>
0?ooo`80Ogmo1P3oool000@0ooooH01oOglZ0000c080OgmoCP3oool207moO`H0oooo00040?ooof00
Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo
:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P00
0<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`2
07moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207mo
Odh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0
oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo
0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1o
Ogl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl6
0?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?oo
o`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00
103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103o
ool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool2
07moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207mo
OcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH0
00000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH00000
0P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1o
OglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT
0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo
0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080
Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo
:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P00
0<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`2
07moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207mo
Odh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0
oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo
0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1o
Ogl60?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl6
0?ooo`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?oo
o`00103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00
103oool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103o
ool207moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool2
07moOcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207mo
OcH000000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH0
00000P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH00000
0P1oOglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1o
OglT0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT
0?oo0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo
0080Ogmo:P000<`207moOdh0oooo0P1oOgl60?ooo`00103oool207moOcH000000P1oOglT0?oo07h0
Ogmo1P3oool000@0oooo0P1oOglf00000080Ogmo903oo`1n07moO`H0oooo00040?ooo`80Ogmo=P00
000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P000002
07moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207mo
Ob@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0
ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool0
0P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1o
Oglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf
0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo
0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080
Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo
@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3o
ool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool2
07moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207mo
O`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0
oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo
00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo0004
0?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?oo
o`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80
Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo
=P00000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00
000207moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P000002
07moOb@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207mo
Ob@0ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0
ool00P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool0
0P1oOglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1o
Oglf0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf
0?oo0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo
0080Ogmo@P3oool207moO`H0oooo00040?ooo`80Ogmo=P00000207moOb@0ool00P1oOglf0?oo0080
Ogmo@P3oool207moO`H0oooo00040?ooom`0Ogmo1P3oool000@0oooog01oOgl60?ooo`00iP3oool0
0>H0oooo0000\
\>"],
  ImageRangeCache->{{{153.25, 382.562}, {354.438, 213.188}} -> {-1.16933, \
1.55976, 0.00588064, 0.00594692}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mondrian[{{0, 0}, {0, 1}, {1.6, 1}, {1.6, 0}}, 3]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .01472 m
.02381 .08072 L
.1062 .08072 L
.1062 .01472 L
.02381 .01472 L
F
.1062 .01472 m
.1062 .08072 L
.26214 .08072 L
.26214 .01472 L
.1062 .01472 L
F
1 1 1 r
.02381 .08072 m
.02381 .12271 L
.19375 .12271 L
.19375 .08072 L
.02381 .08072 L
F
.19375 .08072 m
.19375 .12271 L
.26214 .12271 L
.26214 .08072 L
.19375 .08072 L
F
.02381 .12271 m
.02381 .19395 L
.21149 .19395 L
.21149 .12271 L
.02381 .12271 L
F
0 0 .8 r
.21149 .12271 m
.21149 .19395 L
.26214 .19395 L
.26214 .12271 L
.21149 .12271 L
F
1 1 0 r
.02381 .19395 m
.02381 .37646 L
.15584 .37646 L
.15584 .19395 L
.02381 .19395 L
F
1 0 0 r
.15584 .19395 m
.15584 .37646 L
.26214 .37646 L
.26214 .19395 L
.15584 .19395 L
F
0 0 .8 r
.26214 .01472 m
.26214 .17936 L
.3146 .17936 L
.3146 .01472 L
.26214 .01472 L
F
.26214 .17936 m
.26214 .24128 L
.3146 .24128 L
.3146 .17936 L
.26214 .17936 L
F
0 0 0 r
.3146 .01472 m
.3146 .13521 L
.47426 .13521 L
.47426 .01472 L
.3146 .01472 L
F
1 0 0 r
.3146 .13521 m
.3146 .24128 L
.47426 .24128 L
.47426 .13521 L
.3146 .13521 L
F
.26214 .24128 m
.26214 .29977 L
.32175 .29977 L
.32175 .24128 L
.26214 .24128 L
F
.26214 .29977 m
.26214 .37646 L
.32175 .37646 L
.32175 .29977 L
.26214 .29977 L
F
.32175 .24128 m
.32175 .27179 L
.47426 .27179 L
.47426 .24128 L
.32175 .24128 L
F
0 0 0 r
.32175 .27179 m
.32175 .37646 L
.47426 .37646 L
.47426 .27179 L
.32175 .27179 L
F
0 0 .8 r
.02381 .37646 m
.02381 .41023 L
.13435 .41023 L
.13435 .37646 L
.02381 .37646 L
F
.13435 .37646 m
.13435 .41023 L
.16508 .41023 L
.16508 .37646 L
.13435 .37646 L
F
0 0 0 r
.02381 .41023 m
.02381 .54305 L
.10948 .54305 L
.10948 .41023 L
.02381 .41023 L
F
1 0 0 r
.10948 .41023 m
.10948 .54305 L
.16508 .54305 L
.16508 .41023 L
.10948 .41023 L
F
1 1 0 r
.16508 .37646 m
.16508 .49126 L
.25516 .49126 L
.25516 .37646 L
.16508 .37646 L
F
1 0 0 r
.16508 .49126 m
.16508 .54305 L
.25516 .54305 L
.25516 .49126 L
.16508 .49126 L
F
1 1 1 r
.25516 .37646 m
.25516 .50108 L
.47426 .50108 L
.47426 .37646 L
.25516 .37646 L
F
.25516 .50108 m
.25516 .54305 L
.47426 .54305 L
.47426 .50108 L
.25516 .50108 L
F
1 1 0 r
.02381 .54305 m
.02381 .56027 L
.09267 .56027 L
.09267 .54305 L
.02381 .54305 L
F
1 1 1 r
.09267 .54305 m
.09267 .56027 L
.1294 .56027 L
.1294 .54305 L
.09267 .54305 L
F
0 0 0 r
.02381 .56027 m
.02381 .60332 L
.04551 .60332 L
.04551 .56027 L
.02381 .56027 L
F
1 1 1 r
.04551 .56027 m
.04551 .60332 L
.1294 .60332 L
.1294 .56027 L
.04551 .56027 L
F
1 0 0 r
.1294 .54305 m
.1294 .58061 L
.30588 .58061 L
.30588 .54305 L
.1294 .54305 L
F
.1294 .58061 m
.1294 .60332 L
.30588 .60332 L
.30588 .58061 L
.1294 .58061 L
F
0 0 0 r
.30588 .54305 m
.30588 .57564 L
.47426 .57564 L
.47426 .54305 L
.30588 .54305 L
F
1 1 0 r
.30588 .57564 m
.30588 .60332 L
.47426 .60332 L
.47426 .57564 L
.30588 .57564 L
F
0 0 0 r
.47426 .01472 m
.47426 .09944 L
.55496 .09944 L
.55496 .01472 L
.47426 .01472 L
F
1 0 0 r
.55496 .01472 m
.55496 .09944 L
.69474 .09944 L
.69474 .01472 L
.55496 .01472 L
F
0 0 .8 r
.47426 .09944 m
.47426 .22956 L
.63083 .22956 L
.63083 .09944 L
.47426 .09944 L
F
0 0 0 r
.63083 .09944 m
.63083 .22956 L
.69474 .22956 L
.69474 .09944 L
.63083 .09944 L
F
1 1 1 r
.69474 .01472 m
.69474 .11353 L
.80925 .11353 L
.80925 .01472 L
.69474 .01472 L
F
.80925 .01472 m
.80925 .11353 L
.97619 .11353 L
.97619 .01472 L
.80925 .01472 L
F
0 0 .8 r
.69474 .11353 m
.69474 .22956 L
.867 .22956 L
.867 .11353 L
.69474 .11353 L
F
1 1 1 r
.867 .11353 m
.867 .22956 L
.97619 .22956 L
.97619 .11353 L
.867 .11353 L
F
0 0 0 r
.47426 .22956 m
.47426 .33502 L
.70168 .33502 L
.70168 .22956 L
.47426 .22956 L
F
1 0 0 r
.47426 .33502 m
.47426 .42733 L
.70168 .42733 L
.70168 .33502 L
.47426 .33502 L
F
.70168 .22956 m
.70168 .36306 L
.81737 .36306 L
.81737 .22956 L
.70168 .22956 L
F
1 1 1 r
.70168 .36306 m
.70168 .42733 L
.81737 .42733 L
.81737 .36306 L
.70168 .36306 L
F
0 0 .8 r
.81737 .22956 m
.81737 .33458 L
.88568 .33458 L
.88568 .22956 L
.81737 .22956 L
F
1 1 0 r
.88568 .22956 m
.88568 .33458 L
.97619 .33458 L
.97619 .22956 L
.88568 .22956 L
F
1 1 1 r
.81737 .33458 m
.81737 .42733 L
.89798 .42733 L
.89798 .33458 L
.81737 .33458 L
F
0 0 .8 r
.89798 .33458 m
.89798 .42733 L
.97619 .42733 L
.97619 .33458 L
.89798 .33458 L
F
1 1 0 r
.47426 .42733 m
.47426 .48206 L
.5944 .48206 L
.5944 .42733 L
.47426 .42733 L
F
0 0 .8 r
.5944 .42733 m
.5944 .48206 L
.69327 .48206 L
.69327 .42733 L
.5944 .42733 L
F
1 1 0 r
.47426 .48206 m
.47426 .50873 L
.61085 .50873 L
.61085 .48206 L
.47426 .48206 L
F
1 0 0 r
.61085 .48206 m
.61085 .50873 L
.69327 .50873 L
.69327 .48206 L
.61085 .48206 L
F
0 0 0 r
.47426 .50873 m
.47426 .58281 L
.56541 .58281 L
.56541 .50873 L
.47426 .50873 L
F
1 1 0 r
.47426 .58281 m
.47426 .60332 L
.56541 .60332 L
.56541 .58281 L
.47426 .58281 L
F
0 0 .8 r
.56541 .50873 m
.56541 .56553 L
.69327 .56553 L
.69327 .50873 L
.56541 .50873 L
F
1 1 0 r
.56541 .56553 m
.56541 .60332 L
.69327 .60332 L
.69327 .56553 L
.56541 .56553 L
F
0 0 .8 r
.69327 .42733 m
.69327 .45681 L
.85287 .45681 L
.85287 .42733 L
.69327 .42733 L
F
1 1 0 r
.85287 .42733 m
.85287 .45681 L
.97619 .45681 L
.97619 .42733 L
.85287 .42733 L
F
1 0 0 r
.69327 .45681 m
.69327 .48213 L
.91327 .48213 L
.91327 .45681 L
.69327 .45681 L
F
.91327 .45681 m
.91327 .48213 L
.97619 .48213 L
.97619 .45681 L
.91327 .45681 L
F
.69327 .48213 m
.69327 .51713 L
.89548 .51713 L
.89548 .48213 L
.69327 .48213 L
F
0 0 .8 r
.89548 .48213 m
.89548 .51713 L
.97619 .51713 L
.97619 .48213 L
.89548 .48213 L
F
1 1 1 r
.69327 .51713 m
.69327 .60332 L
.75647 .60332 L
.75647 .51713 L
.69327 .51713 L
F
0 0 .8 r
.75647 .51713 m
.75647 .60332 L
.97619 .60332 L
.97619 .51713 L
.75647 .51713 L
F
.5 g
.01 w
[ ] 0 setdash
.02381 .01472 m
.02381 .08072 L
.1062 .08072 L
.1062 .01472 L
.02381 .01472 L
s
.1062 .01472 m
.1062 .08072 L
.26214 .08072 L
.26214 .01472 L
.1062 .01472 L
s
.02381 .08072 m
.02381 .12271 L
.19375 .12271 L
.19375 .08072 L
.02381 .08072 L
s
.19375 .08072 m
.19375 .12271 L
.26214 .12271 L
.26214 .08072 L
.19375 .08072 L
s
.02381 .12271 m
.02381 .19395 L
.21149 .19395 L
.21149 .12271 L
.02381 .12271 L
s
.21149 .12271 m
.21149 .19395 L
.26214 .19395 L
.26214 .12271 L
.21149 .12271 L
s
.02381 .19395 m
.02381 .37646 L
.15584 .37646 L
.15584 .19395 L
.02381 .19395 L
s
.15584 .19395 m
.15584 .37646 L
.26214 .37646 L
.26214 .19395 L
.15584 .19395 L
s
.26214 .01472 m
.26214 .17936 L
.3146 .17936 L
.3146 .01472 L
.26214 .01472 L
s
.26214 .17936 m
.26214 .24128 L
.3146 .24128 L
.3146 .17936 L
.26214 .17936 L
s
.3146 .01472 m
.3146 .13521 L
.47426 .13521 L
.47426 .01472 L
.3146 .01472 L
s
.3146 .13521 m
.3146 .24128 L
.47426 .24128 L
.47426 .13521 L
.3146 .13521 L
s
.26214 .24128 m
.26214 .29977 L
.32175 .29977 L
.32175 .24128 L
.26214 .24128 L
s
.26214 .29977 m
.26214 .37646 L
.32175 .37646 L
.32175 .29977 L
.26214 .29977 L
s
.32175 .24128 m
.32175 .27179 L
.47426 .27179 L
.47426 .24128 L
.32175 .24128 L
s
.32175 .27179 m
.32175 .37646 L
.47426 .37646 L
.47426 .27179 L
.32175 .27179 L
s
.02381 .37646 m
.02381 .41023 L
.13435 .41023 L
.13435 .37646 L
.02381 .37646 L
s
.13435 .37646 m
.13435 .41023 L
.16508 .41023 L
.16508 .37646 L
.13435 .37646 L
s
.02381 .41023 m
.02381 .54305 L
.10948 .54305 L
.10948 .41023 L
.02381 .41023 L
s
.10948 .41023 m
.10948 .54305 L
.16508 .54305 L
.16508 .41023 L
.10948 .41023 L
s
.16508 .37646 m
.16508 .49126 L
.25516 .49126 L
.25516 .37646 L
.16508 .37646 L
s
.16508 .49126 m
.16508 .54305 L
.25516 .54305 L
.25516 .49126 L
.16508 .49126 L
s
.25516 .37646 m
.25516 .50108 L
.47426 .50108 L
.47426 .37646 L
.25516 .37646 L
s
.25516 .50108 m
.25516 .54305 L
.47426 .54305 L
.47426 .50108 L
.25516 .50108 L
s
.02381 .54305 m
.02381 .56027 L
.09267 .56027 L
.09267 .54305 L
.02381 .54305 L
s
.09267 .54305 m
.09267 .56027 L
.1294 .56027 L
.1294 .54305 L
.09267 .54305 L
s
.02381 .56027 m
.02381 .60332 L
.04551 .60332 L
.04551 .56027 L
.02381 .56027 L
s
.04551 .56027 m
.04551 .60332 L
.1294 .60332 L
.1294 .56027 L
.04551 .56027 L
s
.1294 .54305 m
.1294 .58061 L
.30588 .58061 L
.30588 .54305 L
.1294 .54305 L
s
.1294 .58061 m
.1294 .60332 L
.30588 .60332 L
.30588 .58061 L
.1294 .58061 L
s
.30588 .54305 m
.30588 .57564 L
.47426 .57564 L
.47426 .54305 L
.30588 .54305 L
s
.30588 .57564 m
.30588 .60332 L
.47426 .60332 L
.47426 .57564 L
.30588 .57564 L
s
.47426 .01472 m
.47426 .09944 L
.55496 .09944 L
.55496 .01472 L
.47426 .01472 L
s
.55496 .01472 m
.55496 .09944 L
.69474 .09944 L
.69474 .01472 L
.55496 .01472 L
s
.47426 .09944 m
.47426 .22956 L
.63083 .22956 L
.63083 .09944 L
.47426 .09944 L
s
.63083 .09944 m
.63083 .22956 L
.69474 .22956 L
.69474 .09944 L
.63083 .09944 L
s
.69474 .01472 m
.69474 .11353 L
.80925 .11353 L
.80925 .01472 L
.69474 .01472 L
s
.80925 .01472 m
.80925 .11353 L
.97619 .11353 L
.97619 .01472 L
.80925 .01472 L
s
.69474 .11353 m
.69474 .22956 L
.867 .22956 L
.867 .11353 L
.69474 .11353 L
s
.867 .11353 m
.867 .22956 L
.97619 .22956 L
.97619 .11353 L
.867 .11353 L
s
.47426 .22956 m
.47426 .33502 L
.70168 .33502 L
.70168 .22956 L
.47426 .22956 L
s
.47426 .33502 m
.47426 .42733 L
.70168 .42733 L
.70168 .33502 L
.47426 .33502 L
s
.70168 .22956 m
.70168 .36306 L
.81737 .36306 L
.81737 .22956 L
.70168 .22956 L
s
.70168 .36306 m
.70168 .42733 L
.81737 .42733 L
.81737 .36306 L
.70168 .36306 L
s
.81737 .22956 m
.81737 .33458 L
.88568 .33458 L
.88568 .22956 L
.81737 .22956 L
s
.88568 .22956 m
.88568 .33458 L
.97619 .33458 L
.97619 .22956 L
.88568 .22956 L
s
.81737 .33458 m
.81737 .42733 L
.89798 .42733 L
.89798 .33458 L
.81737 .33458 L
s
.89798 .33458 m
.89798 .42733 L
.97619 .42733 L
.97619 .33458 L
.89798 .33458 L
s
.47426 .42733 m
.47426 .48206 L
.5944 .48206 L
.5944 .42733 L
.47426 .42733 L
s
.5944 .42733 m
.5944 .48206 L
.69327 .48206 L
.69327 .42733 L
.5944 .42733 L
s
.47426 .48206 m
.47426 .50873 L
.61085 .50873 L
.61085 .48206 L
.47426 .48206 L
s
.61085 .48206 m
.61085 .50873 L
.69327 .50873 L
.69327 .48206 L
.61085 .48206 L
s
.47426 .50873 m
.47426 .58281 L
.56541 .58281 L
.56541 .50873 L
.47426 .50873 L
s
.47426 .58281 m
.47426 .60332 L
.56541 .60332 L
.56541 .58281 L
.47426 .58281 L
s
.56541 .50873 m
.56541 .56553 L
.69327 .56553 L
.69327 .50873 L
.56541 .50873 L
s
.56541 .56553 m
.56541 .60332 L
.69327 .60332 L
.69327 .56553 L
.56541 .56553 L
s
.69327 .42733 m
.69327 .45681 L
.85287 .45681 L
.85287 .42733 L
.69327 .42733 L
s
.85287 .42733 m
.85287 .45681 L
.97619 .45681 L
.97619 .42733 L
.85287 .42733 L
s
.69327 .45681 m
.69327 .48213 L
.91327 .48213 L
.91327 .45681 L
.69327 .45681 L
s
.91327 .45681 m
.91327 .48213 L
.97619 .48213 L
.97619 .45681 L
.91327 .45681 L
s
.69327 .48213 m
.69327 .51713 L
.89548 .51713 L
.89548 .48213 L
.69327 .48213 L
s
.89548 .48213 m
.89548 .51713 L
.97619 .51713 L
.97619 .48213 L
.89548 .48213 L
s
.69327 .51713 m
.69327 .60332 L
.75647 .60332 L
.75647 .51713 L
.69327 .51713 L
s
.75647 .51713 m
.75647 .60332 L
.97619 .60332 L
.97619 .51713 L
.75647 .51713 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakAbove->Automatic,
  ImageSize->{336.438, 207.625},
  ImageMargins->{{30.1875, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004=0000YR000`400?l00000o`00003oo`3oool>
0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`001@3ooooo07moO`80Ogmo1`3o
ool000D0ooooo`1oOgl207moO`L0oooo00050?ooo`80Ogmo503o000207moObP0o`000P1oOgl<0000
c080Ogmo:@00000207moOa<000000P1oOglT0?l00080Ogmo703oool207moOb/0oooo0P1oOgl70?oo
o`001@3oool207moOa@0o`000P1oOglX0?l00080Ogmo30000<`207moObT000000P1oOglC00000080
Ogmo903o000207moOa`0oooo0P1oOgl[0?ooo`80Ogmo1`3oool000D0oooo0P1oOglD0?l00080Ogmo
:03o000207moO``0003<0P1oOglY00000080Ogmo4`00000207moOb@0o`000P1oOglL0?ooo`80Ogmo
:`3oool207moO`L0oooo00050?ooo`80Ogmo503o000207moObP0o`000P1oOgl<0000c080Ogmo:@00
000207moOa<000000P1oOglT0?l00080Ogmo703oool207moOb/0oooo0P1oOgl70?ooo`001@3oool2
07moOa@0o`000P1oOglX0?l00080Ogmo30000<`207moObT000000P1oOglC00000080Ogmo903o0002
07moOa`0oooo0P1oOgl[0?ooo`80Ogmo1`3oool000D0oooo0P1oOglD0?l00080Ogmo:03o000207mo
O``0003<0P1oOglY00000080Ogmo4`00000207moOb@0o`000P1oOglL0?ooo`80Ogmo:`3oool207mo
O`L0oooo00050?ooo`80Ogmo503o000207moObP0o`000P1oOgl<0000c080Ogmo:@00000207moOa<0
00000P1oOglT0?l00080Ogmo703oool207moOb/0oooo0P1oOgl70?ooo`001@3oool207moOa@0o`00
0P1oOglX0?l00080Ogmo30000<`207moObT000000P1oOglC00000080Ogmo903o000207moOa`0oooo
0P1oOgl[0?ooo`80Ogmo1`3oool000D0oooo0P1oOglD0?l00080Ogmo:03o000207moO``0003<0P1o
OglY00000080Ogmo4`00000207moOb@0o`000P1oOglL0?ooo`80Ogmo:`3oool207moO`L0oooo0005
0?ooo`80Ogmo503o000207moObP0o`000P1oOgl<0000c080Ogmo:@00000207moOa<000000P1oOglT
0?l00080Ogmo703oool207moOb/0oooo0P1oOgl70?ooo`001@3oool207moOa@0o`000P1oOglX0?l0
0080Ogmo30000<`207moObT000000P1oOglC00000080Ogmo903o000207moOa`0oooo0P1oOgl[0?oo
o`80Ogmo1`3oool000D0oooo0P1oOglD0?l00080Ogmo:03o000207moO``0003<0P1oOglY00000080
Ogmo4`00000207moOb@0o`000P1oOglL0?ooo`80Ogmo:`3oool207moO`L0oooo00050?ooo`80Ogmo
503o000207moObP0o`000P1oOgl<0000c080Ogmo:@00000207moOa<000000P1oOglT0?l00080Ogmo
703oool207moOb/0oooo0P1oOgl70?ooo`001@3oool207moOa@0o`000P1oOglX0?l00080Ogmo3000
0<`207moObT000000P1oOglC00000080Ogmo903o000207moOa`0oooo0P1oOgl[0?ooo`80Ogmo1`3o
ool000D0oooo0P1oOglD0?l00080Ogmo:03o000207moO``0003<0P1oOglY00000080Ogmo4`000002
07moOb@0o`000P1oOglL0?ooo`80Ogmo:`3oool207moO`L0oooo00050?ooo`80Ogmo503o000207mo
ObP0o`000P1oOgl<0000c080Ogmo:@00000207moOa<000000P1oOglT0?l00080Ogmo703oool207mo
Ob/0oooo0P1oOgl70?ooo`001@3ooom207moO``0003<0P1oOglY00000080Ogmo4`00000207moOb@0
o`000P1oOglL0?ooo`80Ogmo:`3oool207moO`L0oooo00050?oood80Ogmo30000<`207moObT00000
0P1oOglC00000080Ogmo903o000207moOa`0oooo0P1oOgl[0?ooo`80Ogmo1`3oool000D0oooo0P1o
Ogl/0?ooo`80Ogmo403oool207moO``0003<0P1oOglY00000080Ogmo4`00000207moOb@0o`000P1o
OglL0?ooo`80Ogmo:`3oool207moO`L0oooo00050?ooo`80Ogmo;03oool207moOa00oooo0P1oOgl<
0000c080Ogmo:@00000207moOa<000000P1oOglT0?l00080Ogmo703oool207moOb/0oooo0P1oOgl7
0?ooo`001@3oool207moOb`0oooo0P1oOgl@0?ooo`80Ogmo30000<`207moObT000000P1oOglC0000
0080Ogmo903o000207moOa`0oooo0P1oOgl[0?ooo`80Ogmo1`3oool000D0oooo0P1oOgl/0?ooo`80
Ogmo403oool207moO``0003<0P1oOglY000003d0Ogmo703oool207moOb/0oooo0P1oOgl70?ooo`00
1@3oool207moOb`0oooo0P1oOgl@0?ooo`80Ogmo30000<`207moObT00000?@1oOglL0?ooo`80Ogmo
:`3oool207moO`L0oooo00050?ooo`80Ogmo;03oool207moOa00oooo0P1oOgl<0000c080Ogmo:@00
000207moObP0003<0P1oOgl?00000080Ogmo703oool207moOb/0oooo0P1oOgl70?ooo`001@3oool2
07moOb`0oooo0P1oOgl@0?ooo`80Ogmo30000<`207moObT000000P1oOglX0000c080Ogmo3`000002
07moOa`0oooo0P1oOgl[0?ooo`80Ogmo1`3oool000D0oooo0P1oOgl/0?ooo`80Ogmo403oool207mo
O``0003<0P1oOglY00000080Ogmo:0000<`207moO`l00000C@1oOgl70?ooo`001@3oool207moOb`0
oooo0P1oOgl@0?ooo`80Ogmo30000<`207moObT000000P1oOglX0000c080Ogmo3`00001=07moO`L0
oooo00050?oood80Ogmo30000<`207moObT000000P1oOglX0000c080Ogmo3`00000207moOb`0003<
0P1oOglK0?ooo`80Ogmo1`3oool000D0oooo@P1oOgl<0000c080Ogmo:@00000207moObP0003<0P1o
Ogl?00000080Ogmo;0000<`207moOa/0oooo0P1oOgl70?ooo`001@3oool207moOc40oooo0P1oOgl;
0000c080Ogmo30000<`207moObT000000P1oOglX0000c080Ogmo3`00000207moOb`0003<0P1oOglK
0?ooo`80Ogmo1`3oool000D0oooo0P1oOgla0?ooo`80Ogmo2`000<`207moO``0003<0P1oOglY0000
0080Ogmo:0000<`207moO`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80
Ogmo<@3oool207moO`/0003<0P1oOgl<0000c2d0Ogmo:0000<`207moO`l000000P1oOgl/0000c080
Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo<@3oool207moO`/0003<0P1oOgl<0000c2d0Ogmo
:0000<`207moO`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo<@3o
ool207moO`/0003<0P1oOgl<0000c080Ogmo:@3o000207moObP0003<0P1oOgl?00000080Ogmo;000
0<`207moOa/0oooo0P1oOgl70?ooo`001@3oool207moOc40oooo0P1oOgl;0000c080Ogmo30000<`2
07moObT0o`000P1oOglX0000c080Ogmo3`00000207moOb`0003<0P1oOglK0?ooo`80Ogmo1`3oool0
00D0oooo0P1oOgla0?ooo`80Ogmo2`000<`207moO``0003<0P1oOglY0?l00080Ogmo:0000<`207mo
O`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo<@3oool207moO`/0
003<0P1oOgl<0000c080Ogmo:@3o000207moObP0003<0P1oOgl?00000080Ogmo;0000<`207moOa/0
oooo0P1oOgl70?ooo`001@3oool207moOc40oooo0P1oOgl;0000c080Ogmo30000<`207moObT0o`00
0P1oOglX0000c080Ogmo3`00000207moOb`0003<0P1oOglK0?ooo`80Ogmo1`3oool000D0oooo0P1o
Ogla0?ooo`80Ogmo2`000<`207moO``0003<0P1oOglY0?l00080Ogmo:0000<`207moO`l000000P1o
Ogl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo<@3oool207moO`/0003<0P1oOgl<
0000c080Ogmo:@3o000207moObP0003<0P1oOgl?00000080Ogmo;0000<`207moOa/0oooo0P1oOgl7
0?ooo`001@3oool207moOc40oooo0P1oOgl;0000c080Ogmo30000<`207moObT0o`000P1oOglX0000
c080Ogmo3`00000207moOb`0003<0P1oOglK0?ooo`80Ogmo1`3oool000D0oooo0P1oOgla0?ooo`80
Ogmo2`000<`207moO``0003<0P1oOglY0?l00080Ogmo:0000<`207moO`l000000P1oOgl/0000c080
Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo<@3oool207moO`/0003<401oOglY0?l00080Ogmo
:0000<`207moO`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo<@3o
ool207moO`/0003<401oOglY0?l00080Ogmo:0000<`207moO`l000000P1oOgl/0000c080Ogmo6`3o
ool207moO`L0oooo00050?ooo`80Ogmo<@3oool207moO`/0003<0P1oOgl<0000c080Ogmo:@3o0002
07moObP0003<0P1oOgl?00000080Ogmo;0000<`207moOa/0oooo0P1oOgl70?ooo`001@3oool207mo
Oc40oooo0P1oOgl;0000c080Ogmo30000<`207moObT0o`000P1oOglX0000c080Ogmo3`00000207mo
Ob`0003<0P1oOglK0?ooo`80Ogmo1`3oool000D0oooo@P1oOgl<0000c080Ogmo:@3o000207moObP0
003<0P1oOgl?00000080Ogmo;0000<`207moOa/0oooo0P1oOgl70?ooo`001@3ooom207moO``0003<
0P1oOglY0?l00080Ogmo:0000<`207moO`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo
00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl<0000c080Ogmo:@3o000207moObP0003<0P1o
Ogl?00000080Ogmo;0000<`207moOa/0oooo0P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ
0?l00080Ogmo30000<`207moObT0o`000P1oOglX0000c080Ogmo3`00000207moOb`0003<0P1oOglK
0?ooo`80Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207moO``0003<0P1oOglY0?l0
0080Ogmo:0000<`207moO`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80
Ogmo8P3oo`0207moOaX0o`000P1oOgl<0000c080Ogmo:@3o000207moObP0003<0P1oOgl?00000080
Ogmo;0000<`207moOa/0oooo0P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo
30000<`207moObT0o`000P1oOglX0000c080Ogmo3`00000207moOb`0003<0P1oOglK0?ooo`80Ogmo
1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207moO``0003<0P1oOglY0?l00080Ogmo:000
0<`207moO`l000000P1oOgl/0000c080Ogmo6`3oool207moO`L0oooo00050?ooo`80Ogmo8P3oo`02
07moOaX0o`000P1oOgl<0000c080Ogmo:@3o000207moObP0003<0P1oOgl?00000080Ogmo;0000<`2
07moOa/0oooo0P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo30000<`207mo
ObT0o`000P1oOglX0000c080Ogmo3`00000207moOb`0003<0P1oOglK0?ooo`80Ogmo1`3oool000D0
oooo0P1oOglR0?oo0080Ogmo6P3o000207moO``0003<0P1oOglY0?l008P0Ogmo1`3oool000D0oooo
0P1oOglR0?oo0080Ogmo6P3o000207moO``0003<0P1oOglY0?l008P0Ogmo1`3oool000D0oooo0P1o
OglR0?oo0080Ogmo6P3o000207moO``0003<0P1oOglY0?l00080Ogmo>P00000207moOad0o`000P1o
OglA0000c080Ogmo5P3oo`0207moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`00>`1oOglj
00000080Ogmo7@3o000207moOa40003<0P1oOglF0?oo0080Ogmo1`3oool000D0oooo0P1oOglR0?oo
0080Ogmo6P3o000k07moOcX000000P1oOglM0?l00080Ogmo4@000<`207moOaH0ool00P1oOgl70?oo
o`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo3P3o000207moObL0o`000P1oOglj00000080
Ogmo7@3o000207moOa40003<0P1oOglF0?oo0080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo
6P3o000207moO`h0o`000P1oOglW0?l00080Ogmo>P00000207moOad0o`000P1oOglA0000c080Ogmo
5P3oo`0207moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo9`3o
000207moOcX000000P1oOglM0?l00080Ogmo4@000<`207moOaH0ool00P1oOgl70?ooo`001@3oool2
07moOb80ool00P1oOglJ0?l00080Ogmo3P3o000207moObL0o`000P1oOglj00000080Ogmo7@3o0002
07moOa40003<0P1oOglF0?oo0080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207mo
O`h0o`000P1oOglW0?l00080Ogmo>P00000207moOad0o`000P1oOglA0000c080Ogmo5P3oo`0207mo
O`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo9`3o000207moOcX0
00000P1oOglM0?l00080Ogmo4@000<`207moOaH0ool00P1oOgl70?ooo`001@3oool207moOb80ool0
0P1oOglJ0?l00080Ogmo3P3o000[07moOcX000000P1oOglM0?l00080Ogmo4@000<`207moOaH0ool0
0P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo3P3o000[07moOcX000000P1o
OglM0?l00080Ogmo4@000<`207moOaH0ool00P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ
0?l00080Ogmo3P3o000207moObL000000P1oOglj00000080Ogmo7@3o000207moOa40003<0P1oOglF
0?oo0080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207moO`h0o`000P1oOglW0000
0080Ogmo>P00000207moOad0o`000P1oOglA0000c080Ogmo5P3oo`0207moO`L0oooo00050?ooo`80
Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo9`00000207moOcX000000P1oOglM0?l00080
Ogmo4@000<`207moOaH0ool00P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo
3P3o000207moObL000000P1oOglj00000080Ogmo7@3o000207moOa40003<0P1oOglF0?oo0080Ogmo
1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207moO`h0o`000P1oOglW00000080Ogmo>P00
000207moOad0o`000P1oOglA0000c080Ogmo5P3oo`0207moO`L0oooo00050?ooo`80Ogmo8P3oo`02
07moOaX0o`004P1oOglW00000080Ogmo>P00000207moOad0o`000P1oOglA0000c080Ogmo5P3oo`02
07moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`004P1oOglW00000080Ogmo>P00000207mo
Oad0o`000P1oOglA0000c080Ogmo5P3oo`0207moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0
o`000P1oOgl>0?l00080Ogmo9`00000207moOcX000000P1oOglM0?l00080Ogmo4@000<`207moOaH0
ool00P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo3P3o000207moObL00000
0P1oOglj00000080Ogmo7@3o000207moOa40003<0P1oOglF0?oo0080Ogmo1`3oool000D0oooo0P1o
OglR0?oo0080Ogmo6P3o000207moO`h0o`000P1oOglW00000080Ogmo>P00000207moOad0o`000P1o
OglA0000c080Ogmo5P3oo`0207moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl>
0?l00080Ogmo9`00000207moOcX000000P1oOglM0?l00080Ogmo4@000<`207moOaH0ool00P1oOgl7
0?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo3P3o000207moObL000000P1oOglj0000
0080Ogmo7@3o000207moOa40003<0P1oOglF0?oo0080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080
Ogmo6P3o000207moO`h0o`000P1oOglW00000080Ogmo>P00000207moOad0o`000P1oOglA0000c080
Ogmo5P3oo`0207moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo
9`00000207moOcX000000P1oOglM0?l00080Ogmo4@000<`207moOaH0ool00P1oOgl70?ooo`001@3o
ool207moOb80ool00P1oOglJ0?l00080Ogmo3P3o000207moObL000000P1oOglj00000080Ogmo7@3o
000207moOa40003<0P1oOglF0?oo0080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o0002
07moO`h0o`000P1oOglW000003h0Ogmo7@3o000]07moO`L0oooo00050?ooo`80Ogmo8P3oo`0207mo
OaX0o`000P1oOgl>0?l00080Ogmo9`00000n07moOad0o`00;@1oOgl70?ooo`001@3oool207moOb80
ool00P1oOglJ0?l00080Ogmo3P3o000207moObL000000P1oOglj0?l00080Ogmo7@3o000207moOa@0
oooo0P1oOglC0000c080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207moO`h0o`00
0P1oOglW00000080Ogmo>P3o000207moOad0o`000P1oOglD0?ooo`80Ogmo4`000<`207moO`L0oooo
00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo9`00000207moOcX0o`000P1o
OglM0?l00080Ogmo503oool207moOa<0003<0P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ
0?l00080Ogmo3P3o000207moObL000000P1oOglj0?l00080Ogmo7@3o000207moOa@0oooo0P1oOglC
0000c080Ogmo1`3oool000D0oooo0P1oOglR0?oo0080Ogmo6P3o000207moO`h0o`000P1oOglW0000
0080Ogmo>P3o000207moOad0o`000P1oOglD0?ooo`80Ogmo4`000<`207moO`L0oooo00050?ooo`80
Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo9`00000207moOcX0o`008@1oOglD0?ooo`80
Ogmo4`000<`207moO`L0oooo00050?ooo`80Ogmo8P3oo`0207moOaX0o`000P1oOgl>0?l00080Ogmo
9`00000207moOcX0o`008@1oOglD0?ooo`80Ogmo4`000<`207moO`L0oooo00050?ooo`80Ogmo8P3o
o`0207moOaX0o`000P1oOgl>0?l00080Ogmo9`00000207moOcX0o`000P1oOglM0?ooo`80Ogmo503o
ool207moOa<0003<0P1oOgl70?ooo`001@3oool207moOb80ool00P1oOglJ0?l00080Ogmo3P3o0002
07moObL000000P1oOglj0?l00080Ogmo7@3oool207moOa@0oooo0P1oOglC0000c080Ogmo1`3oool0
00D0ooooN`1oOglj0?l00080Ogmo7@3oool207moOa@0oooo0P1oOglC0000c080Ogmo1`3oool000D0
ooooN`1oOglj0?l00080Ogmo7@3oool207moOa@0oooo0P1oOglC0000c080Ogmo1`3oool000D0oooo
0P1oOglL0000c080Ogmo1P000<`207moOaH0ool00P1oOgli0?ooo`80Ogmo>P3o000207moOad0oooo
0P1oOglD0?ooo`80Ogmo4`000<`207moO`L0oooo00050?ooo`80Ogmo70000<`207moO`H0003<0P1o
OglF0?oo0080Ogmo>@3oool207moOcX0o`000P1oOglM0?ooo`80Ogmo503oool207moOa<0003<0P1o
Ogl70?ooo`001@3oool207moOa`0003<0P1oOgl60000c080Ogmo5P3oo`0207moOcT0oooo0P1oOglj
0?l00080Ogmo7@3oool207moOa@0oooo0P1oOglC0000c080Ogmo1`3oool000D0oooo0P1oOglL0000
c080Ogmo1P000<`207moOaH0ool00P1oOgli0?ooo`80Ogmo>P3o000207moOad0oooo0P1oOglD0?oo
o`80Ogmo4`000<`207moO`L0oooo00050?ooo`80Ogmo70000<`207moO`H0003<0P1oOglF0?oo0080
Ogmo>@3oool207moOcX0o`000P1oOglM0?ooo`80Ogmo503oool207moOa<0003<0P1oOgl70?ooo`00
1@3oool207moOa`0003<0P1oOgl60000c080Ogmo5P3oo`0207moOcT0oooo0P1oOglj0?l00080Ogmo
7@3oool207moOa@0oooo0P1oOglC0000c080Ogmo1`3oool000D0oooo0P1oOglL0000c080Ogmo1P00
0<`207moOaH0ool00P1oOgli0?ooo`80Ogmo>P3o000207moOad0oooo0P1oOglD0?ooo`80Ogmo4`00
0<`207moO`L0oooo00050?ooobP0Ogmo5P3oo`0207moOcT0oooo0P1oOglj0?l00080Ogmo7@3oool2
07moOa@0oooo0P1oOglC0000c080Ogmo1`3oool000D0oooo:01oOglF0?oo0080Ogmo>@3oool207mo
OcX0o`000P1oOglM0?ooo`80Ogmo503oool207moOa<0003<0P1oOgl70?ooo`001@3oool207moOaD0
00000P1oOgl=0?l00080Ogmo5P3oo`0207moOcT0oooo0P1oOglj0?l00080Ogmo7@3oool207moOa@0
oooo0P1oOglC0000c080Ogmo1`3oool000D0oooo0P1oOglE00000080Ogmo3@3o000207moOaH0ool0
0P1oOgli0?ooo`80Ogmo>P3o000207moOad0oooo0P1oOglD0?ooo`80Ogmo4`000<`207moO`L0oooo
00050?ooo`80Ogmo5@00000207moO`d0o`000P1oOglF0?oo0080Ogmo>@3oool207moOcX0o`000P1o
OglM0?ooo`80Ogmo503oool207moOa<0003<0P1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=
0?l00080Ogmo5P3oo`0207moOcT0ooooR01oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l0
0080Ogmo5P3oo`0207moOcT0ooooR01oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l00080
Ogmo5P3oo`0207moOcT0oooo0P1oOglN0?oo0080Ogmo60000<`207moObT0003<0P1oOglO0?oo0080
Ogmo1`3oool000D0oooo0P1oOglE00000080Ogmo3@3o000207moOaH0ool00P1oOgli0?ooo`80Ogmo
7P3oo`0207moOaP0003<0P1oOglY0000c080Ogmo7`3oo`0207moO`L0oooo00050?ooo`80Ogmo5@00
000207moO`d0o`000P1oOglF0?oo0080Ogmo>@3oool207moOah0ool00P1oOglH0000c080Ogmo:@00
0<`207moOal0ool00P1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l00080Ogmo5P3oo`02
07moOcT0oooo0P1oOglN0?oo0080Ogmo60000<`207moObT0003<0P1oOglO0?oo0080Ogmo1`3oool0
00D0oooo0P1oOglE00000080Ogmo3@3o000207moOaH0ool00P1oOgli0?ooo`80Ogmo7P3oo`0207mo
OaP0003<0P1oOglY0000c080Ogmo7`3oo`0207moO`L0oooo00050?ooo`80Ogmo5@00000207moO`d0
o`000P1oOglF0?oo0080Ogmo>@3oool207moOah0ool00P1oOglH0000c4h0Ogmo1`3oool000D0oooo
0P1oOglE00000080Ogmo3@3o000207moOaH0ool00P1oOgli0?ooo`80Ogmo7P3oo`0207moOaP0003<
CP1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l00080Ogmo5P3oo`0207moOcT0oooo0P1o
OglN0?oo0080Ogmo60000<`207moOcT0o`000P1oOgl?0?l00080Ogmo1`3oool000D0oooo0P1oOglE
00000080Ogmo3@3o000207moOaH0ool00P1oOgli0?ooo`80Ogmo7P3oo`0207moOaP0003<0P1oOgli
0?l00080Ogmo3`3o000207moO`L0oooo00050?ooo`80Ogmo5@00000207moO`d0o`000P1oOglF0?oo
0080Ogmo>@3oool207moOah0ool00P1oOglH0000c080Ogmo>@3o000207moO`l0o`000P1oOgl70?oo
o`001@3oool207moOaD000000P1oOgl=0?l00080Ogmo5P3oo`0207moOcT0oooo0P1oOglN0?oo0080
Ogmo60000<`207moOcT0o`000P1oOgl?0?l00080Ogmo1`3oool000D0oooo0P1oOglE00000080Ogmo
3@3o000207moOaH0ool00P1oOgli0?ooo`80Ogmo7P3oo`0207moOaP0003<0P1oOgli0?l00080Ogmo
3`3o000207moO`L0oooo00050?ooo`80Ogmo5@00000207moO`d0o`000P1oOglF0?oo0080Ogmo>@3o
oon807moO`L0oooo00050?ooo`80Ogmo5@00000207moO`d0o`000P1oOglF0?oo0080Ogmo>@3ooon8
07moO`L0oooo00050?ooo`80Ogmo5@00000207moO`d0o`000P1oOglF0?oo0080Ogmo>@3oool207mo
Ob80ool00P1oOglD0?l00080Ogmo=03o000207moOa@0003<0P1oOgl70?ooo`001@3oool207moOaD0
00000P1oOgl=0?l001X0Ogmo>@3oool207moOb80ool00P1oOglD0?l00080Ogmo=03o000207moOa@0
003<0P1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l001X0Ogmo>@3oool207moOb80ool0
0P1oOglD0?l00080Ogmo=03o000207moOa@0003<0P1oOgl70?ooo`001@3oool207moOaD000000P1o
Ogl=0?l00080Ogmo5P3o000m07moOb80ool00P1oOglD0?l00080Ogmo=03o000207moOa@0003<0P1o
Ogl70?ooo`001@3oool207moOaD000000P1oOgl=0?l00080Ogmo5P3o000m07moOb80ool00P1oOglD
0?l00080Ogmo=03o000207moOa@0003<0P1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l0
0080Ogmo5P3o000207moOcT0oooo?01oOgld0?l00080Ogmo50000<`207moO`L0oooo00050?ooo`80
Ogmo5@00000207moO`d0o`000P1oOglF0?l00080Ogmo>@3oooll07moOc@0o`000P1oOglD0000c080
Ogmo1`3oool000D0oooo0P1oOglE00000080Ogmo3@3o000207moOaH0o`000P1oOgli0?ooo`80Ogmo
5P00000207moOb00003<0P1oOgld0?l00080Ogmo50000<`207moO`L0oooo00050?ooo`80Ogmo5@00
000207moO`d0o`000P1oOglF0?l00080Ogmo>@3oool207moOaH000000P1oOglP0000c4h0Ogmo1`3o
ool000D0oooo0P1oOglE00000080Ogmo3@3o000207moOaH0o`000P1oOgli0?ooo`80Ogmo5P000002
07moOb00003<CP1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l00080Ogmo5P3o000207mo
OcT0oooo0P1oOglF00000080Ogmo80000<`207moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0
oooo0P1oOglE00000080Ogmo3@3o000207moOaH0o`000P1oOgli0?ooo`80Ogmo5P00000207moOb00
003<0P1oOgl?0?ooo`80Ogmo>@000<`207moO`L0oooo00050?ooo`80Ogmo5@00000207moO`d0o`00
0P1oOglF0?l00080Ogmo>@3oool207moOaH000000P1oOglP0000c080Ogmo3`3oool207moOcT0003<
0P1oOgl70?ooo`001@3oool207moOaD000000P1oOgl=0?l00080Ogmo5P3o000207moOcT0oooo0P1o
OglF00000080Ogmo80000<`207moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0ooooN`1oOglF
00000080Ogmo80000<`207moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0ooooN`1oOglF0000
0080Ogmo80000<`207moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0oooo0P1oOglA0?oo0080
Ogmo203oool207moObd0o`000P1oOgl[00000080Ogmo5P00000207moOb00003<0P1oOgl?0?ooo`80
Ogmo>@000<`207moO`L0oooo00050?ooo`80Ogmo4@3oo`0207moO`P0oooo0P1oOgl]0?l00080Ogmo
:`00000207moOaH000000P1oOglP0000c080Ogmo3`3oool207moOcT0003<0P1oOgl70?ooo`001@3o
ool207moOa40ool00P1oOgl80?ooo`80Ogmo;@3o000207moOb/000000P1oOglF00000080Ogmo8000
0<`207moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0oooo7`1oOgl]0?l00080Ogmo:`000002
07moOaH000000P1oOglP0000c080Ogmo3`3oool207moOcT0003<0P1oOgl70?ooo`001@3ooolO07mo
Obd0o`000P1oOgl[00000080Ogmo5P00000T07moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0
oooo0P1oOgl400000080Ogmo5@3oool207moObd0o`000P1oOgl[00000080Ogmo5P00000T07moO`l0
oooo0P1oOgli0000c080Ogmo1`3oool000D0oooo0P1oOgl400000080Ogmo5@3oool207moObd0o`00
0P1oOgl[00000080Ogmo5P00000207moOb00ool00P1oOgl?0?ooo`80Ogmo>@000<`207moO`L0oooo
00050?ooo`80Ogmo1000000207moOaD0oooo0P1oOgl]0?l002l0Ogmo5P00000207moOb00ool00P1o
Ogl?0?ooo`80Ogmo>@000<`207moO`L0oooo00050?ooo`80Ogmo1000000207moOaD0oooo0P1oOgl]
0?l002l0Ogmo5P00000207moOb00ool00P1oOgl?0?ooo`80Ogmo>@000<`207moO`L0oooo00050?oo
o`80Ogmo1000000207moOaD0oooo<@1oOgl[0?oo01X0Ogmo803oo`0207moO`l0oooo0P1oOgli0000
c080Ogmo1`3oool000D0oooo0P1oOgl400000080Ogmo5@3ooola07moOb/0ool06P1oOglP0?oo0080
Ogmo3`3oool207moOcT0003<0P1oOgl70?ooo`001@3oool207moO`@000000P1oOglE0?ooo`80Ogmo
;@3o000207moOb/0ool00P1oOglF0?oo0080Ogmo803oo`0207moO`l0oooo0P1oOgli0000c080Ogmo
1`3oool000D0oooo0P1oOgl400000080Ogmo5@3oool207moObd0o`000P1oOgl[0?oo0080Ogmo5P3o
o`0207moOb00ool00P1oOgl?0?ooo`80Ogmo>@000<`207moO`L0oooo00050?ooo`80Ogmo10000002
07moOaD0oooo0P1oOgl]0?l00080Ogmo:`3oo`0207moOaH0ool00P1oOglP0?oo0080Ogmo3`3oool2
07moOcT0003<0P1oOgl70?ooo`001@3oool207moO`@000000P1oOglE0?ooo`80Ogmo;@3o000207mo
Ob/0ool00P1oOglF0?oo0080Ogmo803oo`0207moO`l0oooo0P1oOgli0000c080Ogmo1`3oool000D0
ooooo`1oOgl207moO`L0oooo00050?ooool0Ogmo0P1oOgl70?ooo`00o`3oool>0?ooo`00o`3oool>
0?ooo`00\
\>"],
  ImageRangeCache->{{{143.062, 411.188}, {208.125, 43.0625}} -> {-0.943213, \
0.248926, 0.00503228, 0.005089}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Optimisation de la r\[EAcute]partition des couleurs", "Subsection",
  PageBreakAbove->Automatic],

Cell["\<\
On pourra constater que le choix de couleurs al\[EAcute]atoires \
(dans un \[EAcute]chantillon limit\[EAcute] \[AGrave] 5 couleurs) implique \
une probabilit\[EAcute] de juxtaposition de rectangles de m\[EHat]me couleur \
assez \[EAcute]lev\[EAcute]. Cela induit un r\[EAcute]sultat visuel qui n'est \
pas du meilleur effet. On pourra am\[EAcute]liorer la repr\[EAcute]sentation \
en optant pour une permutation circulaire des couleurs de la fa\[CCedilla]on \
suivante :\
\>", "Text",
  PageBreakAbove->Automatic,
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(Clear[Mondrian];\)\), "\n", 
    \(Mondrian[rect : {{x1_, y1_}, {x1_, y2_}, {x2_, y2_}, {x2_, y1_}}, 
        n_Integer:  1] := 
      Module[{nr, lines, polys}, \[IndentingNewLine]nr = 
          Flatten[{rect, {{x1, y1}}}, 1]; \[IndentingNewLine]nr = 
          Nest[Cut, nr, n]; \[IndentingNewLine]lines = 
          Map[Line, nr]; \[IndentingNewLine]polys = 
          Map[Polygon, nr]; \[IndentingNewLine]polys = 
          Table[{Col[Mod[i, 5] + 1], polys[\([i]\)]}, {i, 1, 
              Length[polys]}]; \[IndentingNewLine]Show[
          Graphics[{polys, Thickness[0.01], GrayLevel[0.5], 
              lines}]]]\)}], "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mondrian[{{0, 0}, {0, 1}, {1.6, 1}, {1.6, 0}}, 3]\)], "Input",
  PageBreakAbove->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.595238 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .01472 m
.02381 .04074 L
.20251 .04074 L
.20251 .01472 L
.02381 .01472 L
F
0 0 .8 r
.02381 .04074 m
.02381 .06779 L
.20251 .06779 L
.20251 .04074 L
.02381 .04074 L
F
1 1 0 r
.20251 .01472 m
.20251 .02718 L
.48343 .02718 L
.48343 .01472 L
.20251 .01472 L
F
0 0 0 r
.20251 .02718 m
.20251 .06779 L
.48343 .06779 L
.48343 .02718 L
.20251 .02718 L
F
1 1 1 r
.02381 .06779 m
.02381 .15682 L
.20274 .15682 L
.20274 .06779 L
.02381 .06779 L
F
1 0 0 r
.02381 .15682 m
.02381 .2018 L
.20274 .2018 L
.20274 .15682 L
.02381 .15682 L
F
0 0 .8 r
.20274 .06779 m
.20274 .13483 L
.48343 .13483 L
.48343 .06779 L
.20274 .06779 L
F
1 1 0 r
.20274 .13483 m
.20274 .2018 L
.48343 .2018 L
.48343 .13483 L
.20274 .13483 L
F
0 0 0 r
.48343 .01472 m
.48343 .04004 L
.54559 .04004 L
.54559 .01472 L
.48343 .01472 L
F
1 1 1 r
.48343 .04004 m
.48343 .07938 L
.54559 .07938 L
.54559 .04004 L
.48343 .04004 L
F
1 0 0 r
.54559 .01472 m
.54559 .03671 L
.6002 .03671 L
.6002 .01472 L
.54559 .01472 L
F
0 0 .8 r
.54559 .03671 m
.54559 .07938 L
.6002 .07938 L
.6002 .03671 L
.54559 .03671 L
F
1 1 0 r
.48343 .07938 m
.48343 .13012 L
.56459 .13012 L
.56459 .07938 L
.48343 .07938 L
F
0 0 0 r
.48343 .13012 m
.48343 .2018 L
.56459 .2018 L
.56459 .13012 L
.48343 .13012 L
F
1 1 1 r
.56459 .07938 m
.56459 .15311 L
.6002 .15311 L
.6002 .07938 L
.56459 .07938 L
F
1 0 0 r
.56459 .15311 m
.56459 .2018 L
.6002 .2018 L
.6002 .15311 L
.56459 .15311 L
F
0 0 .8 r
.02381 .2018 m
.02381 .3024 L
.16627 .3024 L
.16627 .2018 L
.02381 .2018 L
F
1 1 0 r
.02381 .3024 m
.02381 .36634 L
.16627 .36634 L
.16627 .3024 L
.02381 .3024 L
F
0 0 0 r
.16627 .2018 m
.16627 .24604 L
.43955 .24604 L
.43955 .2018 L
.16627 .2018 L
F
1 1 1 r
.16627 .24604 m
.16627 .36634 L
.43955 .36634 L
.43955 .24604 L
.16627 .24604 L
F
1 0 0 r
.43955 .2018 m
.43955 .27113 L
.50261 .27113 L
.50261 .2018 L
.43955 .2018 L
F
0 0 .8 r
.43955 .27113 m
.43955 .36634 L
.50261 .36634 L
.50261 .27113 L
.43955 .27113 L
F
1 1 0 r
.50261 .2018 m
.50261 .33192 L
.6002 .33192 L
.6002 .2018 L
.50261 .2018 L
F
0 0 0 r
.50261 .33192 m
.50261 .36634 L
.6002 .36634 L
.6002 .33192 L
.50261 .33192 L
F
1 1 1 r
.02381 .36634 m
.02381 .51605 L
.24766 .51605 L
.24766 .36634 L
.02381 .36634 L
F
1 0 0 r
.02381 .51605 m
.02381 .60332 L
.24766 .60332 L
.24766 .51605 L
.02381 .51605 L
F
0 0 .8 r
.24766 .36634 m
.24766 .43302 L
.38152 .43302 L
.38152 .36634 L
.24766 .36634 L
F
1 1 0 r
.24766 .43302 m
.24766 .60332 L
.38152 .60332 L
.38152 .43302 L
.24766 .43302 L
F
0 0 0 r
.38152 .36634 m
.38152 .47395 L
.46335 .47395 L
.46335 .36634 L
.38152 .36634 L
F
1 1 1 r
.46335 .36634 m
.46335 .47395 L
.6002 .47395 L
.6002 .36634 L
.46335 .36634 L
F
1 0 0 r
.38152 .47395 m
.38152 .60332 L
.54689 .60332 L
.54689 .47395 L
.38152 .47395 L
F
0 0 .8 r
.54689 .47395 m
.54689 .60332 L
.6002 .60332 L
.6002 .47395 L
.54689 .47395 L
F
1 1 0 r
.6002 .01472 m
.6002 .16328 L
.71558 .16328 L
.71558 .01472 L
.6002 .01472 L
F
0 0 0 r
.6002 .16328 m
.6002 .20925 L
.71558 .20925 L
.71558 .16328 L
.6002 .16328 L
F
1 1 1 r
.71558 .01472 m
.71558 .08074 L
.7668 .08074 L
.7668 .01472 L
.71558 .01472 L
F
1 0 0 r
.71558 .08074 m
.71558 .20925 L
.7668 .20925 L
.7668 .08074 L
.71558 .08074 L
F
0 0 .8 r
.6002 .20925 m
.6002 .29564 L
.63822 .29564 L
.63822 .20925 L
.6002 .20925 L
F
1 1 0 r
.63822 .20925 m
.63822 .29564 L
.7668 .29564 L
.7668 .20925 L
.63822 .20925 L
F
0 0 0 r
.6002 .29564 m
.6002 .36164 L
.6774 .36164 L
.6774 .29564 L
.6002 .29564 L
F
1 1 1 r
.6774 .29564 m
.6774 .36164 L
.7668 .36164 L
.7668 .29564 L
.6774 .29564 L
F
1 0 0 r
.7668 .01472 m
.7668 .08632 L
.84537 .08632 L
.84537 .01472 L
.7668 .01472 L
F
0 0 .8 r
.84537 .01472 m
.84537 .08632 L
.97619 .08632 L
.97619 .01472 L
.84537 .01472 L
F
1 1 0 r
.7668 .08632 m
.7668 .13267 L
.91089 .13267 L
.91089 .08632 L
.7668 .08632 L
F
0 0 0 r
.91089 .08632 m
.91089 .13267 L
.97619 .13267 L
.97619 .08632 L
.91089 .08632 L
F
1 1 1 r
.7668 .13267 m
.7668 .26279 L
.84899 .26279 L
.84899 .13267 L
.7668 .13267 L
F
1 0 0 r
.84899 .13267 m
.84899 .26279 L
.97619 .26279 L
.97619 .13267 L
.84899 .13267 L
F
0 0 .8 r
.7668 .26279 m
.7668 .36164 L
.88677 .36164 L
.88677 .26279 L
.7668 .26279 L
F
1 1 0 r
.88677 .26279 m
.88677 .36164 L
.97619 .36164 L
.97619 .26279 L
.88677 .26279 L
F
0 0 0 r
.6002 .36164 m
.6002 .44424 L
.71028 .44424 L
.71028 .36164 L
.6002 .36164 L
F
1 1 1 r
.6002 .44424 m
.6002 .47077 L
.71028 .47077 L
.71028 .44424 L
.6002 .44424 L
F
1 0 0 r
.71028 .36164 m
.71028 .39696 L
.802 .39696 L
.802 .36164 L
.71028 .36164 L
F
0 0 .8 r
.71028 .39696 m
.71028 .47077 L
.802 .47077 L
.802 .39696 L
.71028 .39696 L
F
1 1 0 r
.6002 .47077 m
.6002 .51373 L
.67697 .51373 L
.67697 .47077 L
.6002 .47077 L
F
0 0 0 r
.6002 .51373 m
.6002 .60332 L
.67697 .60332 L
.67697 .51373 L
.6002 .51373 L
F
1 1 1 r
.67697 .47077 m
.67697 .57232 L
.802 .57232 L
.802 .47077 L
.67697 .47077 L
F
1 0 0 r
.67697 .57232 m
.67697 .60332 L
.802 .60332 L
.802 .57232 L
.67697 .57232 L
F
0 0 .8 r
.802 .36164 m
.802 .45121 L
.88873 .45121 L
.88873 .36164 L
.802 .36164 L
F
1 1 0 r
.802 .45121 m
.802 .5249 L
.88873 .5249 L
.88873 .45121 L
.802 .45121 L
F
0 0 0 r
.88873 .36164 m
.88873 .40126 L
.97619 .40126 L
.97619 .36164 L
.88873 .36164 L
F
1 1 1 r
.88873 .40126 m
.88873 .5249 L
.97619 .5249 L
.97619 .40126 L
.88873 .40126 L
F
1 0 0 r
.802 .5249 m
.802 .55028 L
.89119 .55028 L
.89119 .5249 L
.802 .5249 L
F
0 0 .8 r
.802 .55028 m
.802 .60332 L
.89119 .60332 L
.89119 .55028 L
.802 .55028 L
F
1 1 0 r
.89119 .5249 m
.89119 .57136 L
.97619 .57136 L
.97619 .5249 L
.89119 .5249 L
F
0 0 0 r
.89119 .57136 m
.89119 .60332 L
.97619 .60332 L
.97619 .57136 L
.89119 .57136 L
F
.5 g
.01 w
[ ] 0 setdash
.02381 .01472 m
.02381 .04074 L
.20251 .04074 L
.20251 .01472 L
.02381 .01472 L
s
.02381 .04074 m
.02381 .06779 L
.20251 .06779 L
.20251 .04074 L
.02381 .04074 L
s
.20251 .01472 m
.20251 .02718 L
.48343 .02718 L
.48343 .01472 L
.20251 .01472 L
s
.20251 .02718 m
.20251 .06779 L
.48343 .06779 L
.48343 .02718 L
.20251 .02718 L
s
.02381 .06779 m
.02381 .15682 L
.20274 .15682 L
.20274 .06779 L
.02381 .06779 L
s
.02381 .15682 m
.02381 .2018 L
.20274 .2018 L
.20274 .15682 L
.02381 .15682 L
s
.20274 .06779 m
.20274 .13483 L
.48343 .13483 L
.48343 .06779 L
.20274 .06779 L
s
.20274 .13483 m
.20274 .2018 L
.48343 .2018 L
.48343 .13483 L
.20274 .13483 L
s
.48343 .01472 m
.48343 .04004 L
.54559 .04004 L
.54559 .01472 L
.48343 .01472 L
s
.48343 .04004 m
.48343 .07938 L
.54559 .07938 L
.54559 .04004 L
.48343 .04004 L
s
.54559 .01472 m
.54559 .03671 L
.6002 .03671 L
.6002 .01472 L
.54559 .01472 L
s
.54559 .03671 m
.54559 .07938 L
.6002 .07938 L
.6002 .03671 L
.54559 .03671 L
s
.48343 .07938 m
.48343 .13012 L
.56459 .13012 L
.56459 .07938 L
.48343 .07938 L
s
.48343 .13012 m
.48343 .2018 L
.56459 .2018 L
.56459 .13012 L
.48343 .13012 L
s
.56459 .07938 m
.56459 .15311 L
.6002 .15311 L
.6002 .07938 L
.56459 .07938 L
s
.56459 .15311 m
.56459 .2018 L
.6002 .2018 L
.6002 .15311 L
.56459 .15311 L
s
.02381 .2018 m
.02381 .3024 L
.16627 .3024 L
.16627 .2018 L
.02381 .2018 L
s
.02381 .3024 m
.02381 .36634 L
.16627 .36634 L
.16627 .3024 L
.02381 .3024 L
s
.16627 .2018 m
.16627 .24604 L
.43955 .24604 L
.43955 .2018 L
.16627 .2018 L
s
.16627 .24604 m
.16627 .36634 L
.43955 .36634 L
.43955 .24604 L
.16627 .24604 L
s
.43955 .2018 m
.43955 .27113 L
.50261 .27113 L
.50261 .2018 L
.43955 .2018 L
s
.43955 .27113 m
.43955 .36634 L
.50261 .36634 L
.50261 .27113 L
.43955 .27113 L
s
.50261 .2018 m
.50261 .33192 L
.6002 .33192 L
.6002 .2018 L
.50261 .2018 L
s
.50261 .33192 m
.50261 .36634 L
.6002 .36634 L
.6002 .33192 L
.50261 .33192 L
s
.02381 .36634 m
.02381 .51605 L
.24766 .51605 L
.24766 .36634 L
.02381 .36634 L
s
.02381 .51605 m
.02381 .60332 L
.24766 .60332 L
.24766 .51605 L
.02381 .51605 L
s
.24766 .36634 m
.24766 .43302 L
.38152 .43302 L
.38152 .36634 L
.24766 .36634 L
s
.24766 .43302 m
.24766 .60332 L
.38152 .60332 L
.38152 .43302 L
.24766 .43302 L
s
.38152 .36634 m
.38152 .47395 L
.46335 .47395 L
.46335 .36634 L
.38152 .36634 L
s
.46335 .36634 m
.46335 .47395 L
.6002 .47395 L
.6002 .36634 L
.46335 .36634 L
s
.38152 .47395 m
.38152 .60332 L
.54689 .60332 L
.54689 .47395 L
.38152 .47395 L
s
.54689 .47395 m
.54689 .60332 L
.6002 .60332 L
.6002 .47395 L
.54689 .47395 L
s
.6002 .01472 m
.6002 .16328 L
.71558 .16328 L
.71558 .01472 L
.6002 .01472 L
s
.6002 .16328 m
.6002 .20925 L
.71558 .20925 L
.71558 .16328 L
.6002 .16328 L
s
.71558 .01472 m
.71558 .08074 L
.7668 .08074 L
.7668 .01472 L
.71558 .01472 L
s
.71558 .08074 m
.71558 .20925 L
.7668 .20925 L
.7668 .08074 L
.71558 .08074 L
s
.6002 .20925 m
.6002 .29564 L
.63822 .29564 L
.63822 .20925 L
.6002 .20925 L
s
.63822 .20925 m
.63822 .29564 L
.7668 .29564 L
.7668 .20925 L
.63822 .20925 L
s
.6002 .29564 m
.6002 .36164 L
.6774 .36164 L
.6774 .29564 L
.6002 .29564 L
s
.6774 .29564 m
.6774 .36164 L
.7668 .36164 L
.7668 .29564 L
.6774 .29564 L
s
.7668 .01472 m
.7668 .08632 L
.84537 .08632 L
.84537 .01472 L
.7668 .01472 L
s
.84537 .01472 m
.84537 .08632 L
.97619 .08632 L
.97619 .01472 L
.84537 .01472 L
s
.7668 .08632 m
.7668 .13267 L
.91089 .13267 L
.91089 .08632 L
.7668 .08632 L
s
.91089 .08632 m
.91089 .13267 L
.97619 .13267 L
.97619 .08632 L
.91089 .08632 L
s
.7668 .13267 m
.7668 .26279 L
.84899 .26279 L
.84899 .13267 L
.7668 .13267 L
s
.84899 .13267 m
.84899 .26279 L
.97619 .26279 L
.97619 .13267 L
.84899 .13267 L
s
.7668 .26279 m
.7668 .36164 L
.88677 .36164 L
.88677 .26279 L
.7668 .26279 L
s
.88677 .26279 m
.88677 .36164 L
.97619 .36164 L
.97619 .26279 L
.88677 .26279 L
s
.6002 .36164 m
.6002 .44424 L
.71028 .44424 L
.71028 .36164 L
.6002 .36164 L
s
.6002 .44424 m
.6002 .47077 L
.71028 .47077 L
.71028 .44424 L
.6002 .44424 L
s
.71028 .36164 m
.71028 .39696 L
.802 .39696 L
.802 .36164 L
.71028 .36164 L
s
.71028 .39696 m
.71028 .47077 L
.802 .47077 L
.802 .39696 L
.71028 .39696 L
s
.6002 .47077 m
.6002 .51373 L
.67697 .51373 L
.67697 .47077 L
.6002 .47077 L
s
.6002 .51373 m
.6002 .60332 L
.67697 .60332 L
.67697 .51373 L
.6002 .51373 L
s
.67697 .47077 m
.67697 .57232 L
.802 .57232 L
.802 .47077 L
.67697 .47077 L
s
.67697 .57232 m
.67697 .60332 L
.802 .60332 L
.802 .57232 L
.67697 .57232 L
s
.802 .36164 m
.802 .45121 L
.88873 .45121 L
.88873 .36164 L
.802 .36164 L
s
.802 .45121 m
.802 .5249 L
.88873 .5249 L
.88873 .45121 L
.802 .45121 L
s
.88873 .36164 m
.88873 .40126 L
.97619 .40126 L
.97619 .36164 L
.88873 .36164 L
s
.88873 .40126 m
.88873 .5249 L
.97619 .5249 L
.97619 .40126 L
.88873 .40126 L
s
.802 .5249 m
.802 .55028 L
.89119 .55028 L
.89119 .5249 L
.802 .5249 L
s
.802 .55028 m
.802 .60332 L
.89119 .60332 L
.89119 .55028 L
.802 .55028 L
s
.89119 .5249 m
.89119 .57136 L
.97619 .57136 L
.97619 .5249 L
.89119 .5249 L
s
.89119 .57136 m
.89119 .60332 L
.97619 .60332 L
.97619 .57136 L
.89119 .57136 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{2, Inherited}, {Inherited, Inherited}},
  PageBreakAbove->Automatic,
  ImageSize->{338.625, 208.875},
  ImageMargins->{{43.6875, 0}, {0, 4.9375}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000Yb000`400?l00000o`00003oooooool?
ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`001OooooooogmoO`?oOgmo1ooo
ool000GooooooomoOgl3ogmoO`Oooooo0005ooooo`;oOgmo;ooo0002ogmoOdWoool00_moOgl?o`00
00;oOgmo3?oo0002ogmoOagoool00_moOgl<ooooo`;oOgmo4ooo0002ogmoOb7o003<0_moOgl7oooo
o`001Oooool2ogmoObooo`000_moOgm9oooo00;oOgmo3ol00002ogmoO`coo`000_moOglMoooo00;o
Ogmo3?ooool2ogmoOa?oo`000_moOglQo`00c0;oOgmo1oooool000Gooooo0_moOgl_ool004goOgmo
3ol00002ogmoO`coo`000_moOglMoooo00;oOgmo3?ooool2ogmoOa?oo`000_moOglQo`00c0;oOgmo
1oooool000Gooooo0_moOgl_ool004goOgmo3ol00002ogmoO`coo`000_moOglMoooo00;oOgmo3?oo
ool2ogmoOa?oo`000_moOglQo`00c0;oOgmo1oooool000Gooooo0_moOgl_ool000;oOgmoBOl00002
ogmoO`oo00004?moOglMoooo00;oOgmo3?ooool2ogmoOa?oo`000_moOglQo`00c0;oOgmo1oooool0
00Gooooo<omoOgm9o`00027oOgmo7Oooo`02ogmoO`cooooo0_moOglCool000;oOgmo8Ol00<`2ogmo
O`Oooooo0005oooooc?oOgmoBOl0000CogmoO`co003<0_moOglMoooo00;oOgmo3?ooool2ogmoOa?o
o`000_moOglQo`00c0;oOgmo1oooool000Gooooo0_moOgl_o`00c0;oOgmoBOl00002ogmoO`oooooo
0_moOgl<o`00c0;oOgmo7Oooo`02ogmoO`cooooo0_moOglCool000;oOgmo8Ol00<`2ogmoO`Oooooo
0005ooooo`;oOgmo;ol00<`2ogmoOdWo00000_moOgl?ooooo`;oOgmo3?l00<`2ogmoOagoool00_mo
Ogl<ooooo`;oOgmo4ooo0002ogmoOb7o003<0_moOgl7ooooo`001Oooool2ogmoOboo003<0_moOgm9
o`0000;oOgmo3oooool2ogmoO`co003<0_moOglMoooo00;oOgmo3?ooool2ogmoOa?oo`000_moOglQ
o`00c0;oOgmo1oooool000Gooooo0_moOgl_o`00c0;oOgmoBOl00002ogmoO`oooooo0_moOgl<o`00
c0;oOgmo7Oooo`02ogmoO`cooooo0_moOglCool000;oOgmo8Ol00<`2ogmoO`Oooooo0005ooooo`;o
Ogmo;ol00<`2ogmoOdWo00000_moOgl?ooooo`;oOgmo3?l00<`2ogmoOagoool00_moOgl<ooooo`;o
Ogmo4ooo0002ogmoOb7o003<0_moOgl7ooooo`001Oooool2ogmoOboo003<0_moOgm9o`0000;oOgmo
3oooool2ogmoO`co003<0_moOglMoooo00;oOgmo3?ooool2ogmoOa?oo`000_moOglQo`00c0;oOgmo
1oooool000GoooooO_moOgl?ooooo`;oOgmo3?l00<`2ogmoOagoool00_moOgl<ooooo`;oOgmo4ooo
0002ogmoOb7o003<0_moOgl7ooooo`001OoooomnogmoO`oooooo0_moOgl<o`00c0;oOgmo7Oooo`02
ogmoO`cooooo0_moOglCool000;oOgmo8Ol00<`2ogmoO`Oooooo0005ooooo`;oOgmo;oooool2ogmo
OdWo003<0_moOgl?ooooo`;oOgmo3?l00<`2ogmoOagoool00_moOgl<ooooo`;oOgmo4ooo0002ogmo
Ob7o003<0_moOgl7ooooo`001Oooool2ogmoOboooooo0_moOgm9o`00c27oOgmo7Oooo`0@ogmoOa?o
o`000_moOglQo`00c0;oOgmo1oooool000Gooooo0_moOgl_ooooo`;oOgmoBOl00<`QogmoOagoool0
4?moOglCool000;oOgmo8Ol00<`2ogmoO`Oooooo0005ooooo`;oOgmo;oooool2ogmoOdWo003<0_mo
OglDoooo00;oOgmo1oooool2ogmoOagoool00_moOgl<ool003[oOgmo1oooool000Gooooo0_moOgl_
ooooo`;oOgmoBOl00<`2ogmoOaCoool00_moOgl7ooooo`;oOgmo7Oooo`02ogmoO`coo`00>_moOgl7
ooooo`001Oooool2ogmoOboooooo0_moOgm9o`00c0;oOgmo5?ooo`02ogmoO`Oooooo0_moOglMoooo
00;oOgmo3?oo0002ogmoObGoool00_moOgl?o`0000;oOgmo1oooool000Gooooo0_moOgl_ooooo`;o
OgmoBOl00<`2ogmoOaCoool00_moOgl7ooooo`;oOgmo7Oooo`02ogmoO`coo`000_moOglUoooo00;o
Ogmo3ol00002ogmoO`Oooooo0005ooooo`;oOgmo;oooool2ogmoOdWo003<0_moOglDoooo00;oOgmo
1oooool2ogmoOagoool00_moOgl<ool000;oOgmo9Oooo`02ogmoO`oo00000_moOgl7ooooo`001Ooo
ool2ogmoOboooooo0_moOgm9o`00c0;oOgmo5?ooo`02ogmoO`Oooooo0_moOglMoooo00;oOgmo3?oo
0002ogmoObGoool00_moOgl?o`0000;oOgmo1oooool000Gooooo0_moOgl_ooooo`;oOgmoBOl00<`2
ogmoOaCoool00_moOgl7ooooo`;oOgmo7Oooo`02ogmoO`coo`000_moOglUoooo00;oOgmo3ol00002
ogmoO`Oooooo0005ooooo`;oOgmo;oooool2ogmoOdWo003<0_moOglDoooo00;oOgmo1oooool2ogmo
Oagoool00_moOgl<ool000;oOgmo9Oooo`02ogmoO`oo00000_moOgl7ooooo`001Oooool2ogmoOboo
oooo0_moOgm9o`00c0;oOgmo5?ooo`02ogmoO`Oooooo0_moOglMoooo00;oOgmo3?oo0002ogmoObGo
ool00_moOgl?o`0000;oOgmo1oooool000Gooooo0_moOgl_ooooo`;oOgmoBOl00<`2ogmoOaCoool0
0_moOgl7ooooo`;oOgmo7Oooo`02ogmoO`coo`000_moOglUoooo00;oOgmo3ol00002ogmoO`Oooooo
0005ooooo`;oOgmo;oooool2ogmoOdWo003<0_moOglDoooo00;oOgmo1oooool2ogmoOagoool00_mo
Ogl<ool000;oOgmo9Oooo`02ogmoO`oo00000_moOgl7ooooo`001Oooool2ogmoOboooooo0_moOgm9
o`00c1SoOgmo1oooool2ogmoOagoool00_moOgl<ool000;oOgmo9Oooo`02ogmoO`oo00000_moOgl7
ooooo`001Oooool2ogmoOboooooo0_moOgm9o`00c1SoOgmo1oooool2ogmoOagoool00_moOgl<ool0
03[oOgmo1oooool000Gooooo0_moOgl_ooooodgoOgmo5?l00002ogmoO`Oooooo0_moOglMoooo00;o
Ogmo3?oo000jogmoO`Oooooo0005ooooo`;oOgmo;ooooom=ogmoOaCo00000_moOgl7ooooo`;oOgmo
7Oooo`02ogmoO`coo`000_moOglDooooo`;oOgmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo;ooo
ool2ogmoOdWoool00_moOglDo`0000;oOgmo1oooool2ogmoOagoool00_moOgl<ool000;oOgmo5?oo
ool2ogmoOb3oo`000_moOgl7ooooo`001Oooool2ogmoOboooooo0_moOgm9oooo00;oOgmo5?l00002
ogmoO`Oooooo0_moOglMoooo00;oOgmo3?oo0002ogmoOaCooooo0_moOglPool000;oOgmo1oooool0
00Gooooo0_moOgl_ooooo`;oOgmoBOooo`02ogmoOaCo00000_moOgl7ooooo`;oOgmo7Oooo`02ogmo
O`coo`000_moOglDooooo`;oOgmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo;oooool2ogmoOdWo
ool00_moOglDo`0000_oOgmo7Oooo`02ogmoO`coo`000_moOglDooooo`;oOgmo8?oo0002ogmoO`Oo
oooo0005oooooc?oOgmoBOooo`02ogmoOaCo00002omoOglMoooo00;oOgmo3?oo0002ogmoOaCooooo
0_moOglPool000;oOgmo1oooool000Gooooo<omoOgm9oooo00;oOgmo5?l00002ogmoO`Ooo`008Omo
Ogl<ool000;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001Oooool2ogmoObooo`000_moOgm9
oooo00;oOgmo5?l00002ogmoO`Ooo`008OmoOgl<ool000;oOgmo5?ooool2ogmoOb3oo`000_moOgl7
ooooo`001Oooool2ogmoObooo`000_moOgm9oooo00;oOgmo5?l00002ogmoO`Ooo`000_moOglMo`00
00;oOgmo3?oo0002ogmoOaCooooo0_moOglPool000;oOgmo1oooool000Gooooo0_moOgl_ool000;o
OgmoBOooo`02ogmoOaCo00000_moOgl7ool000;oOgmo7Ol00002ogmoO`coo`000_moOglDooooo`;o
Ogmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo;ooo0002ogmoOdWoool00_moOglDo`0000;oOgmo
1ooo0002ogmoOago00000_moOgl<ool000;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001Ooo
ool2ogmoObooo`000_moOgm9oooo00;oOgmo5?l00002ogmoO`Ooo`000_moOglMo`0000;oOgmo3?oo
0002ogmoOaCooooo0_moOglPool000;oOgmo1oooool000Gooooo0_moOgl_ool000;oOgmoBOooo`02
ogmoOaCo00000_moOgl7ool000;oOgmo7Ol00002ogmoO`coo`000_moOglDooooo`;oOgmo8?oo0002
ogmoO`Oooooo0005ooooo`;oOgmo;ooo0002ogmoOdWoool00_moOglDo`0000;oOgmo1ooo0002ogmo
Oago00000_moOgl<ool000;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001Oooool2ogmoOboo
o`000_moOgm9oooo00;oOgmo5?l00002ogmoO`Ooo`000_moOglMo`0000;oOgmo3?oo0002ogmoOaCo
oooo0_moOglPool000;oOgmo1oooool000Gooooo0_moOgl_ool000;oOgmoBOooo`02ogmoOaCo0000
0_moOgl7ool000;oOgmo7Ol00002ogmoO`coo`000_moOglDooooo`;oOgmo8?oo0002ogmoO`Oooooo
0005ooooo`;oOgmo;ooo0002ogmoOdWoool00_moOglDo`0000;oOgmo1ooo0002ogmoOago00000_mo
Ogl<ool000;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001OoooonMogmoOago00000_moOgl<
ool000;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001OoooonMogmoOago00000_moOgl<ool0
00;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001Oooool2ogmoObGo003<0_moOgm7o`0000;o
Ogmo3ooo0002ogmoOaSoool0;omoOglDooooo`;oOgmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo
9Ol00<`2ogmoOdOo00000_moOgl?ool000;oOgmo6?ooo`0_ogmoOaCooooo0_moOglPool000;oOgmo
1oooool000Gooooo0_moOglUo`00c0;oOgmoAol00002ogmoO`ooo`000_moOglHoooo00;oOgmo2Ol0
0<`2ogmoOb3oool00_moOglDooooo`;oOgmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo9Ol00<`2
ogmoOdOo00000_moOgl?ool000;oOgmo6?ooo`02ogmoO`Wo003<0_moOglPoooo00;oOgmo5?ooool2
ogmoOb3oo`000_moOgl7ooooo`001Oooool2ogmoObGo003<0_moOgm7o`0000;oOgmo3ooo0002ogmo
OaSoool00_moOgl9o`00c0;oOgmo8?ooo`02ogmoOaCooooo0_moOglPool000;oOgmo1oooool000Go
oooo0_moOglUo`00c0;oOgmoAol00002ogmoO`ooo`000_moOglHoooo00;oOgmo2Ol00<`2ogmoOb3o
ool00_moOglDooooo`;oOgmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo9Ol00<`2ogmoOdOo0000
0_moOgl?ool000;oOgmo6?ooo`02ogmoO`Wo003<0_moOglPoooo00;oOgmo5?ooool2ogmoOb3oo`00
0_moOgl7ooooo`001Oooool2ogmoObGo003<0_moOgm7o`0000;oOgmo3ooo0002ogmoOaSoool00_mo
Ogl9o`00c0;oOgmo8?ooo`02ogmoOaCooooo0_moOglPool000;oOgmo1oooool000Gooooo0_moOglU
o`00c0;oOgmoAol00002ogmoO`ooo`000_moOglHoooo00;oOgmo2Ol00<`2ogmoOb3oool00_moOglD
ooooo`;oOgmo8?oo0002ogmoO`Oooooo0005ooooo`;oOgmo9Ol00<`2ogmoOdOo00000_moOgl?ool0
00;oOgmo6?ooo`02ogmoO`Wo003<0_moOglPoooo00;oOgmo5?ooool2ogmoOb3oo`000_moOgl7oooo
o`001Oooool2ogmoObGo003<BomoOgl?ool000;oOgmo6?ooo`02ogmoO`Wo003<0_moOglPoooo00;o
Ogmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001Oooool2ogmoObGo003<BomoOgl?ool000;oOgmo
6?ooo`02ogmoO`Wo003<0_moOglPoooo00;oOgmo5?ooool2ogmoOb3oo`000_moOgl7ooooo`001Ooo
ool2ogmoObGo003<0_moOgm7ooooo`;oOgmo3ooo0002ogmoOaSoool00_moOgl9o`00c0;oOgmo8?oo
o`02ogmoOaCooooo0_moOglPool000;oOgmo1oooool000Gooooo0_moOglUo`00c0;oOgmoAoooool2
ogmoO`ooo`000_moOglHoooo00;oOgmo2Ol00<`2ogmoOb3oool00_moOglDooooo`;oOgmo8?oo0002
ogmoO`Oooooo0005ooooo`;oOgmo9Ol00<`2ogmoOdOooooo0_moOgl?ool000;oOgmo6?ooo`02ogmo
O`Wo003<0_moOglPoooo03[oOgmo1oooool000Gooooo0_moOglUo`00c0;oOgmoAoooool2ogmoO`oo
o`000_moOglHoooo00;oOgmo2Ol00<`2ogmoOb3oool0>_moOgl7ooooo`001Oooool2ogmoObGo003<
0_moOgm7oooooa?oOgmo6?ooo`02ogmoO`Wo003<0_moOglPoooo00;oOgmo7_l00<`2ogmoOaKoool0
0_moOgl7ooooo`001Oooool2ogmoObGo003<0_moOgm7oooooa?oOgmo6?ooo`02ogmoO`Wo003<0_mo
OglPoooo00;oOgmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001Oooool2ogmoObGo003<0_moOgm7
ooooo`;oOgmo3ol00<`2ogmoOaSoool00_moOgl9o`00c0;oOgmo8?ooo`02ogmoOako003<0_moOglF
oooo00;oOgmo1oooool000Gooooo0_moOglUo`00c0;oOgmoAoooool2ogmoO`oo003<0_moOglHoooo
00;oOgmo2Ol00<`2ogmoOb3oool00_moOglNo`00c0;oOgmo5_ooo`02ogmoO`Oooooo0005ooooo`;o
Ogmo9Ol00<`2ogmoOdOooooo0_moOgl?o`00c0;oOgmo6?ooo`02ogmoO`Wo003<0_moOglPoooo00;o
Ogmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001Oooool2ogmoObGo003<0_moOgm7ooooo`;oOgmo
3ol00<`2ogmoOaSoool00_moOgl9o`00c0;oOgmo8?ooo`02ogmoOako003<0_moOglFoooo00;oOgmo
1oooool000Gooooo0_moOglUo`00c0;oOgmoAoooool2ogmoO`oo003<0_moOglHoooo00;oOgmo2Ol0
0<`2ogmoOb3oool00_moOglNo`00c0;oOgmo5_ooo`02ogmoO`Oooooo0005ooooo`;oOgmo9Ol00<`2
ogmoOdOooooo0_moOgl?o`00c0;oOgmo6?ooo`0_ogmoOako003<0_moOglFoooo00;oOgmo1oooool0
00Gooooo0_moOglUo`00c0;oOgmoAoooool2ogmoO`oo003<0_moOglHoooo02ooOgmo7_l00<`2ogmo
OaKoool00_moOgl7ooooo`001OoooolYogmoOdOooooo0_moOgl?o`00c0;oOgmo6?ooo`02ogmoOa?o
00000_moOglFooooo`;oOgmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001OoooolYogmoOdOooooo
0_moOgl?o`00c0;oOgmo6?ooo`02ogmoOa?o00000_moOglFooooo`;oOgmo7_l00<`2ogmoOaKoool0
0_moOgl7ooooo`001Oooool2ogmoObGoool00_moOgm7ooooo`;oOgmo3ol00<`2ogmoOaSoool00_mo
OglCo`0000;oOgmo5_ooool2ogmoOako003<0_moOglFoooo00;oOgmo1oooool000Gooooo0_moOglU
oooo00;oOgmoAoooool2ogmoO`oo003<0_moOglHoooo00;oOgmo4ol00002ogmoOaKooooo0_moOglN
o`00c0;oOgmo5_ooo`02ogmoO`Oooooo0005ooooo`;oOgmo9Oooo`02ogmoOdOooooo0_moOgl?o`00
c0;oOgmo6?ooo`02ogmoOa?o00000_moOglFooooo`;oOgmo7_l00<`2ogmoOaKoool00_moOgl7oooo
o`001Oooool2ogmoObGoool00_moOgm7ooooo`;oOgmo3ol00<`2ogmoOaSoool00_moOglCo`0000;o
Ogmo5_ooool2ogmoOako003<0_moOglFoooo00;oOgmo1oooool000Gooooo0_moOglUoooo00;oOgmo
Aoooool2ogmoO`oo003<0_moOglHoooo00;oOgmo4ol00002ogmoOaKooooo0_moOglNo`00c0;oOgmo
5_ooo`02ogmoO`Oooooo0005ooooo`;oOgmo9Oooo`02ogmoOdOooooo0_moOgl?o`00c0;oOgmo6?oo
o`02ogmoOa?o00000_moOglFooooo`;oOgmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001Oooool2
ogmoObGoool00_moOgm7ooooo`;oOgmo3ol00<`LogmoOa?o00000_moOglFooooo`;oOgmo7_l00<`2
ogmoOaKoool00_moOgl7ooooo`001Oooool2ogmoObGoool00_moOgm7ooooo`;oOgmo3ol00<`Logmo
Oa?o00000_moOglFooooo`;oOgmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001Oooool2ogmoObGo
ool00_moOgm7ooooo`;oOgmo3ol00<`2ogmoOaSo00000_moOglCo`0000;oOgmo5_ooool2ogmoOako
003<0_moOglFoooo00;oOgmo1oooool000Gooooo0_moOglUoooo00;oOgmoAoooool2ogmoO`oo003<
0_moOglHo`0000;oOgmo4ol00002ogmoOaKooooo0_moOglNo`00c0;oOgmo5_ooo`02ogmoO`Oooooo
0005ooooo`;oOgmo9Oooo`02ogmoOdOooooo0_moOgl?o`00c0;oOgmo6?l00002ogmoOa?o00000_mo
OglFooooo`;oOgmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001Oooool2ogmoObGoool00_moOgm7
ooooo`;oOgmo3ol00<`2ogmoOaSo00000_moOglCo`0000;oOgmo5_ooool2ogmoOako003<0_moOglF
oooo00;oOgmo1oooool000Gooooo0_moOglUoooo00;oOgmoAoooool2ogmoO`oo003<0_moOglHo`00
00;oOgmo4ol00002ogmoOaKooooo0_moOglNo`00c0;oOgmo5_ooo`02ogmoO`Oooooo0005ooooo`;o
Ogmo9Oooo`02ogmoOdOooooo0_moOgl?o`00c0;oOgmo6?l00002ogmoOa?o00000_moOglFooooo`;o
Ogmo7_l00<`2ogmoOaKoool00_moOgl7ooooo`001Oooool2ogmoObGoool00_moOgm7ooooo`;oOgmo
3ol00<`2ogmoOaSo0000IomoOgl7ooooo`001OooooooogmoO`?oOgmo1oooool000GoooooWOmoOglL
o`0000;oOgmo5ooo0002ogmoOaGo003<0_moOglEo`0000;oOgmo1oooool000Gooooo0_moOglkoooo
o`;oOgmo8_l00<`2ogmoOaCo00000_moOglRooooo`;oOgmo7?l00002ogmoOaOoo`000_moOglEo`00
c0;oOgmo5Ol00002ogmoO`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;o003<0_moOglDo`0000;o
Ogmo8_ooool2ogmoOaco00000_moOglGool000;oOgmo5Ol00<`2ogmoOaGo00000_moOgl7ooooo`00
1Oooool2ogmoOc_ooooo0_moOglRo`00c0;oOgmo5?l00002ogmoOb;ooooo0_moOglLo`0000;oOgmo
5ooo0002ogmoOaGo003<0_moOglEo`0000;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_l0
0<`2ogmoOaCo00000_moOglRooooo`;oOgmo7?l00002ogmoOaOoo`000_moOglEo`00c0;oOgmo5Ol0
0002ogmoO`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;o003<0_moOglDo`0000;oOgmo8_ooool2
ogmoOaco00000_moOglGool000;oOgmo5Ol00<`2ogmoOaGo00000_moOgl7ooooo`001Oooool2ogmo
Oc_ooooo0_moOglRo`00c0;oOgmo5?l00002ogmoOb;ooooo0_moOglLo`0000;oOgmo5ooo0002ogmo
OaGo003<0_moOglEo`0000;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_l00<`2ogmoOaCo
00000_moOglRooooo`;oOgmo7?l0000KogmoOaGo003<0_moOglEo`0000;oOgmo1oooool000Gooooo
0_moOglkooooo`;oOgmo8_l00<`2ogmoOaCo00000_moOglRooooo`;oOgmo7?l0000KogmoOaGo003<
6OmoOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglRo`00c0;oOgmo5?l00002ogmoOb;ooooo0_mo
OglLo`0000;oOgmo5ol00<`2ogmoOaGo003<6OmoOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglR
o`00c0;oOgmo5?l00002ogmoOb;ooooo0_moOglLo`0000;oOgmo5ol00<`2ogmoOaGo003<0_moOglE
ooooo`;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_l00<`2ogmoOaCo00000_moOglRoooo
o`;oOgmo7?l00002ogmoOaOo003<0_moOglEo`00c0;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;o
Ogmo>oooool2ogmoOb;o003<0_moOglDo`0000;oOgmo8_ooool2ogmoOaco00000_moOglGo`00c0;o
Ogmo5Ol00<`2ogmoOaGooooo0_moOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglRo`00c0;oOgmo
5?l00002ogmoOb;ooooo0_moOglLo`0000;oOgmo5ol00<`2ogmoOaGo003<0_moOglEooooo`;oOgmo
1oooool000Gooooo0_moOglkooooo`;oOgmo8_l00<`2ogmoOaCo00000_moOglRooooo`;oOgmo7?l0
0002ogmoOaOo003<0_moOglEo`00c0;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo>oooool2
ogmoOb;o003<0_moOglDo`0000;oOgmo8_ooool2ogmoOaco00000_moOglGo`00c0;oOgmo5Ol00<`2
ogmoOaGooooo0_moOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglRo`00c0;oOgmo5?l00002ogmo
Ob;ooooo0_moOglLo`0000;oOgmo5ol00<`2ogmoOaGo003<0_moOglEooooo`;oOgmo1oooool000Go
oooo0_moOglkooooobKoOgmo5?l00002ogmoOb;ooooo0_moOglLo`0000;oOgmo5ol00<`2ogmoOaGo
003<0_moOglEooooo`;oOgmo1oooool000Gooooo0_moOglkooooobKoOgmo5?l00002ogmoOb;ooooo
0_moOglLo`0000;oOgmo5ol00<`2ogmoOaGo003<0_moOglEooooo`;oOgmo1oooool000Gooooo0_mo
Oglkooooo`;oOgmo8_ooo`02ogmoOaCo00000_moOglRooooo`;oOgmo7?l00002ogmoOaOo003<0_mo
OglEo`00c0;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;oool00_moOglD
o`0000;oOgmo8_oooolPogmoOaOo003<0_moOglEo`00c0;oOgmo5Oooool2ogmoO`Oooooo0005oooo
o`;oOgmo>oooool2ogmoOb;oool00_moOglDo`0000;oOgmo8_oooolPogmoOaOo003<0_moOglEo`00
c0;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;oool00_moOglDo`0000;o
Ogmo8_ooool2ogmoOacooooo0_moOglGo`00c1WoOgmo5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo
>oooool2ogmoOb;oool00_moOglDo`0000;oOgmo8_ooool2ogmoOacooooo0_moOglGo`00c1WoOgmo
5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;oool00_moOglDo`0000;oOgmo8_oo
ool2ogmoOacooooo0_moOglGo`00c0;oOgmo5Oooo`02ogmoOaGooooo0_moOgl7ooooo`001Oooool2
ogmoOc_ooooo0_moOglRoooo00;oOgmo5?l00002ogmoOb;ooooo0_moOglLooooo`;oOgmo5ol00<`2
ogmoOaGoool00_moOglEooooo`;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_ooo`02ogmo
OaCo00000_moOglRooooo`;oOgmo7?ooool2ogmoOaOo003<0_moOglEoooo00;oOgmo5Oooool2ogmo
O`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;oool00_moOglDo`0000;oOgmo8_ooooliogmoOaGo
ool00_moOglEooooo`;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_ooo`1cogmoOaGoool0
0_moOglEooooo`;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_ooo`0logmoOa?oool00_mo
OglPooooo`;oOgmo5Oooo`02ogmoOaGooooo0_moOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglR
oooo00;oOgmo:_oo0002ogmoO`co003<0_moOglCoooo00;oOgmo8?ooool2ogmoOaGoool00_moOglE
ooooo`;oOgmo1oooool000Gooooo0_moOglkooooo`;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00
c0;oOgmo4oooo`02ogmoOb3ooooo0_moOglEoooo00;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;o
Ogmo>oooool2ogmoOb;oool00_moOglZool000;oOgmo3?l00<`2ogmoOa?oool00_moOglPooooo`;o
Ogmo5Oooo`02ogmoOaGooooo0_moOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglRoooo00;oOgmo
:_oo0002ogmoO`co003<0_moOglCoooo00;oOgmo8?ooool2ogmoOaGoool00_moOglEooooo`;oOgmo
1oooool000Gooooo0_moOglkooooo`;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ooo
o`02ogmoOb3ooooo0_moOglEoooo00;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo>oooool2
ogmoOb;oool00_moOglZool000;oOgmo3?l00<`2ogmoOa?oool00_moOglPooooo`;oOgmo5Oooo`02
ogmoOaGooooo0_moOgl7ooooo`001Oooool2ogmoOc_ooooo0_moOglRoooo00;oOgmo:_oo0002ogmo
O`co003<0_moOglCoooo00;oOgmo8?ooool2ogmoOaGoool00_moOglEooooo`;oOgmo1oooool000Go
oooo0_moOglkooooo`;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4oooo`02ogmoOb3o
oooo0_moOglEoooo00;oOgmo5Oooool2ogmoO`Oooooo0005ooooo`;oOgmo>oooool2ogmoOb;oool0
0_moOglZool000;oOgmo3?l00<`GogmoOb3ooooo0_moOglEoooo00;oOgmo5Oooool2ogmoO`Oooooo
0005ooooocooOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c1OoOgmo8?ooool2ogmoOaGoool00_mo
OglEooooo`;oOgmo1oooool000Gooooo?omoOglRoooo00;oOgmo:_oo0002ogmoO`co003<0_moOglC
o`0000;oOgmo8?ooool2ogmoOaGoool00_moOglEooooo`;oOgmo1oooool000Gooooo0_moOglkool0
00;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ol00002ogmoOb3ooooo<?moOgl7oooo
o`001Oooool2ogmoOc_oo`000_moOglRoooo00;oOgmo:_oo0002ogmoO`co003<0_moOglCo`0000;o
Ogmo8?ooool`ogmoO`Oooooo0005ooooo`;oOgmo>ooo0002ogmoOb;oool00_moOglZool000;oOgmo
3?l00<`2ogmoOa?o00000_moOglPooooo`;oOgmo5_oo0002ogmoOaCoool00_moOgl7ooooo`001Ooo
ool2ogmoOc_oo`000_moOglRoooo00;oOgmo:_oo0002ogmoO`co003<0_moOglCo`0000;oOgmo8?oo
ool2ogmoOaKoo`000_moOglDoooo00;oOgmo1oooool000Gooooo0_moOglkool000;oOgmo8_ooo`02
ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ol00002ogmoOb3ooooo0_moOglFool000;oOgmo5?ooo`02
ogmoO`Oooooo0005ooooo`;oOgmo>ooo0002ogmoOb;oool00_moOglZool000;oOgmo3?l00<`2ogmo
Oa?o00000_moOglPooooo`;oOgmo5_oo0002ogmoOaCoool00_moOgl7ooooo`001Oooool2ogmoOc_o
o`000_moOglRoooo00;oOgmo:_oo0002ogmoO`co003<0_moOglCo`0000;oOgmo8?ooool2ogmoOaKo
o`000_moOglDoooo00;oOgmo1oooool000Gooooo0_moOglkool000;oOgmo8_ooo`02ogmoOb[oo`00
0_moOgl<o`00c0;oOgmo4ol00002ogmoOb3ooooo6_moOglDoooo00;oOgmo1oooool000Gooooo0_mo
Oglkool000;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ol00002ogmoOb3ooooo6_mo
OglDoooo00;oOgmo1oooool000Gooooo0_moOglkool000;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<
o`00c0;oOgmo4ol00002ogmoOb3ooooo0_moOglFo`00c0;oOgmo5?ooo`02ogmoO`Oooooo0005oooo
o`;oOgmo>ooo0002ogmoOb;oool00_moOglZool000;oOgmo3?l00<`2ogmoOa?o00000_moOglPoooo
o`;oOgmo5_l00<`2ogmoOaCoool00_moOgl7ooooo`001Oooool2ogmoOc_oo`000_moOglRoooo00;o
Ogmo:_oo0002ogmoO`co003<0_moOglCo`0000;oOgmo8?ooool2ogmoOaKo003<0_moOglDoooo00;o
Ogmo1oooool000Gooooo0_moOglkool000;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo
4ol00002ogmoOb3ooooo0_moOglFo`00c0;oOgmo5?ooo`02ogmoO`Oooooo0005ooooo`;oOgmo>ooo
0002ogmoOb;oool00_moOglZool000;oOgmo3?l00<`2ogmoOa?o00009?moOglFo`00c1SoOgmo1ooo
ool000Gooooo0_moOglkool000;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ol0000T
ogmoOaKo003<6?moOgl7ooooo`001Oooool2ogmoOc_oo`000_moOglRoooo00;oOgmo:_oo0002ogmo
O`co003<0_moOglCo`0000;oOgmo8?oo0002ogmoOaKo003<0_moOglDo`0000;oOgmo1oooool000Go
oooo0_moOglkool000;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ol00002ogmoOb3o
o`000_moOglFo`00c0;oOgmo5?l00002ogmoO`Oooooo0005ooooo`;oOgmo>ooo0002ogmoOb;oool0
0_moOglZool000;oOgmo3?l00<`2ogmoOa?o00000_moOglPool000;oOgmo5_l00<`2ogmoOaCo0000
0_moOgl7ooooo`001Oooool2ogmoOc_oo`000_moOglRoooo00;oOgmo:_oo0002ogmoO`co003<0_mo
OglCo`0000;oOgmo8?oo0002ogmoOaKo003<0_moOglDo`0000;oOgmo1oooool000Gooooo0_moOglk
ool000;oOgmo8_ooo`02ogmoOb[oo`000_moOgl<o`00c0;oOgmo4ol00002ogmoOb3oo`000_moOglF
o`00c0;oOgmo5?l00002ogmoO`Oooooo0005ooooo`;oOgmo>ooo0002ogmoOb;oool00_moOglZool0
00;oOgmo3?l00<`2ogmoOa?o00000_moOglPool000;oOgmo5_l00<`2ogmoOaCo00000_moOgl7oooo
o`001Oooool2ogmoOc_oo`000_moOglRoooo00;oOgmo:_oo0002ogmoO`co003<0_moOglCo`0000;o
Ogmo8?oo0002ogmoOaKo003<0_moOglDo`0000;oOgmo1oooool000GooooooomoOgl3ogmoO`Oooooo
0005ooooooooOgmo0omoOgl7ooooo`00ooooool?ooooo`00ooooool?ooooo`00\
\>"],
  ImageRangeCache->{{{152.25, 422.125}, {213.062, 47}} -> {-0.995631, \
0.272173, 0.00500198, 0.00505835}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Int\[EAcute]gralit\[EAcute] du code : 24 (petites) lignes", \
"Subsection",
  PageBreakAbove->Automatic],

Cell[BoxData[
    \(\(Clear[VCut, HCut, Cut, Col, Mondrian];\)\)], "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(VCut[{p1 : {x1_, y1_}, p2_, p3 : {x2_, y2_}, p4_, _}] := {{p1, p2, 
            pa = {r = Random[Real, {x1 + \((d = \((x2 - x1)\)/5)\), x2 - d}], 
                y2}, pb = {r, y1}, p1}, {pb, pa, p3, p4, pb}};\)\), "\n", 
    \(\(VCut[rect : {___List}] := Flatten[Map[VCut, rect], 1];\)\)}], "Input",\

  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(HCut[{p1 : {x1_, y1_}, p2_, p3 : {x2_, y2_}, p4_, _}] := {{p1, 
            pa = {x1, 
                r = Random[Real, {y1 + \((d = \((y2 - y1)\)/5)\), y2 - d}]}, 
            pb = {x2, r}, p4, p1}, {pa, p2, p3, pb, pa}};\)\), "\n", 
    \(\(HCut[rect : {___List}] := Flatten[Map[HCut, rect], 1];\)\)}], "Input",\

  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Cut[
          rect : {p1 : {x1_, y1_}, {x1_, y2_}, p3 : {x2_, y2_}, 
              p4 : {x2_, y1_}, p5_:  p1}] := 
        If[Random[Integer] \[Equal] 0, VCut[HCut[rect]], 
          HCut[VCut[rect]]];\)\), "\n", 
    \(\(Cut[rect : {___List}] := Flatten[Map[Cut, rect], 1];\)\)}], "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\(Col[1] = RGBColor[1, 1, 1];\)\  (*blanc*) \[IndentingNewLine]
    \(Col[2] = RGBColor[1, 0, 0];\)\  (*rouge*) \[IndentingNewLine]
    \(Col[3] = RGBColor[0, 0, 0.8];\)\  (*bleu*) \[IndentingNewLine]
    \(Col[4] = RGBColor[1, 1, 0];\)\  (*jaune*) \[IndentingNewLine]
    \(Col[5] = RGBColor[0, 0, 0];\)\)\(\ \)\( (*noir*) \)\)\)], "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mondrian[rect : {{x1_, y1_}, {x1_, y2_}, {x2_, y2_}, {x2_, y1_}}, 
        n_Integer:  1] := 
      Module[{nr, lines, polys}, \[IndentingNewLine]nr = 
          Flatten[{rect, {{x1, y1}}}, 1]; \[IndentingNewLine]nr = 
          Nest[Cut, nr, n]; \[IndentingNewLine]lines = 
          Map[Line, nr]; \[IndentingNewLine]polys = 
          Map[Polygon, nr]; \[IndentingNewLine]polys = 
          Table[{Col[Mod[i, 5] + 1], polys[\([i]\)]}, {i, 1, 
              Length[polys]}]; \[IndentingNewLine]Show[
          Graphics[{polys, Thickness[0.01], GrayLevel[0.5], 
              lines}]]]\)], "Input",
  PageBreakAbove->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\ \)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Automatic,
WindowSize->{688, 651},
WindowMargins->{{Automatic, 147}, {Automatic, 0}},
PrintingCopies->30,
PrintingStartingPageNumber->39,
PrintingPageRange->{54, 54},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{133.875, 133.875}, {252, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->Automatic,
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 10}, {10, 30}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 10}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{60, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 187, 4, 51, "Subtitle",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic],
Cell[1966, 59, 314, 10, 45, "SmallText",
  PageBreakAbove->Automatic],
Cell[2283, 71, 390, 11, 52, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[2698, 86, 63, 1, 73, "Section",
  PageBreakAbove->Automatic],
Cell[2764, 89, 679, 12, 90, "Text",
  PageBreakAbove->Automatic],
Cell[3446, 103, 578, 11, 90, "Text",
  PageBreakAbove->Automatic],
Cell[4027, 116, 611, 12, 71, "Text",
  PageBreakAbove->Automatic],
Cell[4641, 130, 132612, 2042, 308, 132477, 2038, "GraphicsData", "PICT", \
"Graphics",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[137290, 2177, 72, 1, 50, "Section",
  PageBreakAbove->Automatic],
Cell[137365, 2180, 689, 15, 90, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[138079, 2199, 82, 1, 42, "Subsection",
  PageBreakAbove->Automatic],
Cell[138164, 2202, 1218, 20, 142, "Text",
  PageBreakAbove->Automatic],
Cell[139385, 2224, 452, 9, 100, "Input",
  PageBreakAbove->Automatic],
Cell[139840, 2235, 102, 3, 25, "Text",
  PageBreakAbove->Automatic],
Cell[139945, 2240, 116, 2, 22, "Input",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[140086, 2246, 77, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[140166, 2250, 270, 4, 43, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[140473, 2259, 91, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[140567, 2263, 10507, 176, 148, 786, 51, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[151077, 2441, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],
Cell[151251, 2448, 190, 6, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[151466, 2458, 75, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[151544, 2462, 594, 9, 77, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[152175, 2476, 114, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[152292, 2480, 16077, 255, 148, 950, 63, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[168372, 2737, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[168580, 2747, 84, 1, 42, "Subsection",
  PageBreakAbove->Automatic],
Cell[168667, 2750, 204, 6, 25, "Text",
  PageBreakAbove->Automatic],
Cell[168874, 2758, 452, 9, 100, "Input",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[169351, 2771, 75, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[169429, 2775, 271, 4, 43, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[169737, 2784, 91, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[169831, 2788, 8454, 151, 148, 791, 51, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[178288, 2941, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[178508, 2952, 78, 1, 50, "Section",
  PageBreakAbove->Automatic],
Cell[178589, 2955, 940, 18, 116, "Text",
  PageBreakAbove->Automatic],
Cell[179532, 2975, 398, 9, 88, "Input",
  PageBreakAbove->Automatic],
Cell[179933, 2986, 102, 3, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[180060, 2993, 96, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[180159, 2997, 10510, 176, 148, 791, 51, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[190672, 3175, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[190868, 3184, 96, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[190967, 3188, 9674, 166, 148, 791, 51, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[200644, 3356, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],
Cell[200818, 3363, 485, 12, 51, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[201328, 3379, 83, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[201414, 3383, 1632, 28, 189, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[203083, 3416, 91, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[203177, 3420, 14622, 257, 131, 1283, 87, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[217802, 3679, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],
Cell[217976, 3686, 132, 3, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[218133, 3693, 105, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[218241, 3697, 22501, 474, 148, 3236, 231, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[240745, 4173, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[240941, 4182, 66, 1, 42, "Subsection",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[241032, 4187, 99, 1, 33, "Subsubsection",
  PageBreakAbove->Automatic],
Cell[241134, 4190, 921, 23, 90, "Text",
  PageBreakAbove->Automatic],
Cell[242058, 4215, 997, 18, 190, "Input",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[243092, 4238, 118, 2, 33, "Subsubsection",
  PageBreakAbove->Automatic],
Cell[243213, 4242, 790, 14, 90, "Text",
  PageBreakAbove->Automatic],
Cell[244006, 4258, 1072, 19, 213, "Input",
  PageBreakAbove->Automatic],
Cell[245081, 4279, 123, 3, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[245229, 4286, 105, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[245337, 4290, 49310, 805, 148, 3225, 231, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[294650, 5097, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],
Cell[294824, 5104, 594, 13, 77, "Text",
  PageBreakAbove->Automatic],
Cell[295421, 5119, 456, 10, 100, "Input",
  PageBreakAbove->Automatic],
Cell[295880, 5131, 282, 7, 38, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[296187, 5142, 101, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[296291, 5146, 10380, 184, 113, 945, 63, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[306674, 5332, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],
Cell[306848, 5339, 231, 8, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[307104, 5351, 96, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[307203, 5355, 18809, 349, 130, 1899, 135, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[326015, 5706, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],
Cell[326189, 5713, 128, 3, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[326342, 5720, 105, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[326450, 5724, 37762, 822, 148, 5815, 423, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[364215, 6548, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[364435, 6559, 79, 1, 42, "Subsection",
  PageBreakAbove->Automatic],
Cell[364517, 6562, 381, 9, 64, "Text",
  PageBreakAbove->Automatic],
Cell[364901, 6573, 348, 8, 51, "Text",
  PageBreakAbove->Automatic],
Cell[365252, 6583, 271, 9, 70, "Input",
  PageBreakAbove->Automatic],
Cell[365526, 6594, 443, 9, 64, "Text",
  PageBreakAbove->Automatic],
Cell[365972, 6605, 716, 14, 145, "Input",
  PageBreakAbove->Automatic],
Cell[366691, 6621, 136, 3, 25, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[366852, 6628, 111, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[366966, 6632, 13644, 378, 148, 3292, 245, "GraphicsData", "PostScript", \
"Graphics",
  PageBreakAbove->Automatic],
Cell[380613, 7012, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[380809, 7021, 111, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[380923, 7025, 30953, 1103, 172, 11451, 857, "GraphicsData", \
"PostScript", "Graphics",
  PageBreakAbove->Automatic],
Cell[411879, 8130, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[412087, 8140, 105, 1, 42, "Subsection",
  PageBreakAbove->Automatic],
Cell[412195, 8143, 570, 11, 77, "Text",
  PageBreakAbove->Automatic],
Cell[412768, 8156, 713, 14, 145, "Input",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[413506, 8174, 111, 2, 22, "Input",
  PageBreakAbove->Automatic],
Cell[413620, 8178, 31061, 1119, 177, 11364, 871, "GraphicsData", \
"PostScript", "Graphics",
  PageBreakAbove->Automatic],
Cell[444684, 9299, 159, 4, 22, "Output",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[444892, 9309, 113, 2, 42, "Subsection",
  PageBreakAbove->Automatic],
Cell[445008, 9313, 130, 3, 22, "Input",
  PageBreakAbove->Automatic],
Cell[445141, 9318, 380, 7, 66, "Input",
  PageBreakAbove->Automatic],
Cell[445524, 9327, 393, 8, 66, "Input",
  PageBreakAbove->Automatic],
Cell[445920, 9337, 369, 8, 66, "Input",
  PageBreakAbove->Automatic],
Cell[446292, 9347, 420, 7, 66, "Input",
  PageBreakAbove->Automatic],
Cell[446715, 9356, 674, 13, 133, "Input",
  PageBreakAbove->Automatic],
Cell[447392, 9371, 35, 1, 22, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

